/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_f0hf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (f0|hf) integrals */

void d12hrr_order_f0hf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][8][11] = int_stack + 0;
 Libderiv->deriv_classes[3][8][10] = int_stack + 450;
 Libderiv->deriv_classes[3][8][9] = int_stack + 900;
 Libderiv->deriv_classes[3][8][8] = int_stack + 1350;
 Libderiv->deriv_classes[3][8][7] = int_stack + 1800;
 Libderiv->dvrr_classes[3][7] = int_stack + 2250;
 Libderiv->deriv_classes[3][8][6] = int_stack + 2610;
 Libderiv->deriv_classes[3][8][2] = int_stack + 3060;
 Libderiv->deriv_classes[3][8][1] = int_stack + 3510;
 Libderiv->deriv_classes[3][8][0] = int_stack + 3960;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 4410;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 4620;
 Libderiv->deriv2_classes[3][7][143] = int_stack + 4900;
 Libderiv->deriv2_classes[3][8][143] = int_stack + 5260;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 5710;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 5920;
 Libderiv->deriv2_classes[3][7][131] = int_stack + 6200;
 Libderiv->deriv2_classes[3][8][131] = int_stack + 6560;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 7010;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 7220;
 Libderiv->deriv2_classes[3][7][130] = int_stack + 7500;
 Libderiv->deriv2_classes[3][8][130] = int_stack + 7860;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 8310;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 8520;
 Libderiv->deriv2_classes[3][7][119] = int_stack + 8800;
 Libderiv->deriv2_classes[3][8][119] = int_stack + 9160;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 9610;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 9820;
 Libderiv->deriv2_classes[3][7][118] = int_stack + 10100;
 Libderiv->deriv2_classes[3][8][118] = int_stack + 10460;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 10910;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 11120;
 Libderiv->deriv2_classes[3][7][117] = int_stack + 11400;
 Libderiv->deriv2_classes[3][8][117] = int_stack + 11760;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 12210;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 12420;
 Libderiv->deriv2_classes[3][7][107] = int_stack + 12700;
 Libderiv->deriv2_classes[3][8][107] = int_stack + 13060;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 13510;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 13720;
 Libderiv->deriv2_classes[3][7][106] = int_stack + 14000;
 Libderiv->deriv2_classes[3][8][106] = int_stack + 14360;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 14810;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 15020;
 Libderiv->deriv2_classes[3][7][105] = int_stack + 15300;
 Libderiv->deriv2_classes[3][8][105] = int_stack + 15660;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 16110;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 16320;
 Libderiv->deriv2_classes[3][7][104] = int_stack + 16600;
 Libderiv->deriv2_classes[3][8][104] = int_stack + 16960;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 17410;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 17620;
 Libderiv->deriv2_classes[3][7][95] = int_stack + 17900;
 Libderiv->deriv2_classes[3][8][95] = int_stack + 18260;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 18710;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 18920;
 Libderiv->deriv2_classes[3][7][94] = int_stack + 19200;
 Libderiv->deriv2_classes[3][8][94] = int_stack + 19560;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 20010;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 20220;
 Libderiv->deriv2_classes[3][7][93] = int_stack + 20500;
 Libderiv->deriv2_classes[3][8][93] = int_stack + 20860;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 21310;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 21520;
 Libderiv->deriv2_classes[3][7][92] = int_stack + 21800;
 Libderiv->deriv2_classes[3][8][92] = int_stack + 22160;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 22610;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 22820;
 Libderiv->deriv2_classes[3][7][91] = int_stack + 23100;
 Libderiv->deriv2_classes[3][8][91] = int_stack + 23460;
 Libderiv->deriv_classes[3][5][11] = int_stack + 23910;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 24120;
 Libderiv->deriv_classes[3][6][11] = int_stack + 24330;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 24610;
 Libderiv->deriv_classes[3][7][11] = int_stack + 24890;
 Libderiv->deriv2_classes[3][7][83] = int_stack + 25250;
 Libderiv->deriv2_classes[3][8][83] = int_stack + 25610;
 Libderiv->deriv_classes[3][5][10] = int_stack + 26060;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 26270;
 Libderiv->deriv_classes[3][6][10] = int_stack + 26480;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 26760;
 Libderiv->deriv_classes[3][7][10] = int_stack + 27040;
 Libderiv->deriv2_classes[3][7][82] = int_stack + 27400;
 Libderiv->deriv2_classes[3][8][82] = int_stack + 27760;
 Libderiv->deriv_classes[3][5][9] = int_stack + 28210;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 28420;
 Libderiv->deriv_classes[3][6][9] = int_stack + 28630;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 28910;
 Libderiv->deriv_classes[3][7][9] = int_stack + 29190;
 Libderiv->deriv2_classes[3][7][81] = int_stack + 29550;
 Libderiv->deriv2_classes[3][8][81] = int_stack + 29910;
 Libderiv->deriv_classes[3][5][8] = int_stack + 30360;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 30570;
 Libderiv->deriv_classes[3][6][8] = int_stack + 30780;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 31060;
 Libderiv->deriv_classes[3][7][8] = int_stack + 31340;
 Libderiv->deriv2_classes[3][7][80] = int_stack + 31700;
 Libderiv->deriv2_classes[3][8][80] = int_stack + 32060;
 Libderiv->deriv_classes[3][5][7] = int_stack + 32510;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 32720;
 Libderiv->deriv_classes[3][6][7] = int_stack + 32930;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 33210;
 Libderiv->deriv_classes[3][7][7] = int_stack + 33490;
 Libderiv->deriv2_classes[3][7][79] = int_stack + 33850;
 Libderiv->deriv2_classes[3][8][79] = int_stack + 34210;
 Libderiv->dvrr_classes[3][5] = int_stack + 34660;
 Libderiv->deriv_classes[3][5][6] = int_stack + 34870;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 35080;
 Libderiv->dvrr_classes[3][6] = int_stack + 35290;
 Libderiv->deriv_classes[3][6][6] = int_stack + 35570;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 35850;
 Libderiv->deriv_classes[3][7][6] = int_stack + 36130;
 Libderiv->deriv2_classes[3][7][78] = int_stack + 36490;
 Libderiv->deriv2_classes[3][8][78] = int_stack + 36850;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 37300;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 37510;
 Libderiv->deriv2_classes[3][7][35] = int_stack + 37790;
 Libderiv->deriv2_classes[3][8][35] = int_stack + 38150;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 38600;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 38810;
 Libderiv->deriv2_classes[3][7][34] = int_stack + 39090;
 Libderiv->deriv2_classes[3][8][34] = int_stack + 39450;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 39900;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 40110;
 Libderiv->deriv2_classes[3][7][33] = int_stack + 40390;
 Libderiv->deriv2_classes[3][8][33] = int_stack + 40750;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 41200;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 41410;
 Libderiv->deriv2_classes[3][7][32] = int_stack + 41690;
 Libderiv->deriv2_classes[3][8][32] = int_stack + 42050;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 42500;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 42710;
 Libderiv->deriv2_classes[3][7][31] = int_stack + 42990;
 Libderiv->deriv2_classes[3][8][31] = int_stack + 43350;
 Libderiv->deriv_classes[3][5][2] = int_stack + 43800;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 44010;
 Libderiv->deriv_classes[3][6][2] = int_stack + 44220;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 44500;
 Libderiv->deriv_classes[3][7][2] = int_stack + 44780;
 Libderiv->deriv2_classes[3][7][30] = int_stack + 45140;
 Libderiv->deriv2_classes[3][8][30] = int_stack + 45500;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 45950;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 46160;
 Libderiv->deriv2_classes[3][7][26] = int_stack + 46440;
 Libderiv->deriv2_classes[3][8][26] = int_stack + 46800;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 47250;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 47460;
 Libderiv->deriv2_classes[3][7][23] = int_stack + 47740;
 Libderiv->deriv2_classes[3][8][23] = int_stack + 48100;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 48550;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 48760;
 Libderiv->deriv2_classes[3][7][22] = int_stack + 49040;
 Libderiv->deriv2_classes[3][8][22] = int_stack + 49400;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 49850;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 50060;
 Libderiv->deriv2_classes[3][7][21] = int_stack + 50340;
 Libderiv->deriv2_classes[3][8][21] = int_stack + 50700;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 51150;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 51360;
 Libderiv->deriv2_classes[3][7][20] = int_stack + 51640;
 Libderiv->deriv2_classes[3][8][20] = int_stack + 52000;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 52450;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 52660;
 Libderiv->deriv2_classes[3][7][19] = int_stack + 52940;
 Libderiv->deriv2_classes[3][8][19] = int_stack + 53300;
 Libderiv->deriv_classes[3][5][1] = int_stack + 53750;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 53960;
 Libderiv->deriv_classes[3][6][1] = int_stack + 54170;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 54450;
 Libderiv->deriv_classes[3][7][1] = int_stack + 54730;
 Libderiv->deriv2_classes[3][7][18] = int_stack + 55090;
 Libderiv->deriv2_classes[3][8][18] = int_stack + 55450;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 55900;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 56110;
 Libderiv->deriv2_classes[3][7][14] = int_stack + 56390;
 Libderiv->deriv2_classes[3][8][14] = int_stack + 56750;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 57200;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 57410;
 Libderiv->deriv2_classes[3][7][13] = int_stack + 57690;
 Libderiv->deriv2_classes[3][8][13] = int_stack + 58050;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 58500;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 58710;
 Libderiv->deriv2_classes[3][7][11] = int_stack + 58990;
 Libderiv->deriv2_classes[3][8][11] = int_stack + 59350;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 59800;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 60010;
 Libderiv->deriv2_classes[3][7][10] = int_stack + 60290;
 Libderiv->deriv2_classes[3][8][10] = int_stack + 60650;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 61100;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 61310;
 Libderiv->deriv2_classes[3][7][9] = int_stack + 61590;
 Libderiv->deriv2_classes[3][8][9] = int_stack + 61950;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 62400;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 62610;
 Libderiv->deriv2_classes[3][7][8] = int_stack + 62890;
 Libderiv->deriv2_classes[3][8][8] = int_stack + 63250;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 63700;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 63910;
 Libderiv->deriv2_classes[3][7][7] = int_stack + 64190;
 Libderiv->deriv2_classes[3][8][7] = int_stack + 64550;
 Libderiv->deriv_classes[3][5][0] = int_stack + 65000;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 65210;
 Libderiv->deriv_classes[3][6][0] = int_stack + 65420;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 65700;
 Libderiv->deriv_classes[3][7][0] = int_stack + 65980;
 Libderiv->deriv2_classes[3][7][6] = int_stack + 66340;
 Libderiv->deriv2_classes[3][8][6] = int_stack + 66700;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 67150;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 67360;
 Libderiv->deriv2_classes[3][7][2] = int_stack + 67640;
 Libderiv->deriv2_classes[3][8][2] = int_stack + 68000;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 68450;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 68660;
 Libderiv->deriv2_classes[3][7][1] = int_stack + 68940;
 Libderiv->deriv2_classes[3][8][1] = int_stack + 69300;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 69750;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 69960;
 Libderiv->deriv2_classes[3][7][0] = int_stack + 70240;
 Libderiv->deriv2_classes[3][8][0] = int_stack + 70600;
 memset(int_stack,0,568400);

 Libderiv->dvrr_stack = int_stack + 177190;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_f0hf(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+71050,int_stack+35290,int_stack+34660,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+71680,int_stack+2250,int_stack+35290,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+72520,int_stack+71680,int_stack+71050,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+73780,int_stack+24330,int_stack+23910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34660,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+74410,int_stack+24890,int_stack+24330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35290,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+75250,int_stack+74410,int_stack+73780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+76510,int_stack+0,int_stack+24890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2250,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+77590,int_stack+76510,int_stack+74410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71680,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+76510,int_stack+26480,int_stack+26060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34660, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+79270,int_stack+27040,int_stack+26480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35290, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+80110,int_stack+79270,int_stack+76510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+81370,int_stack+450,int_stack+27040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2250, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+82450,int_stack+81370,int_stack+79270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71680, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+81370,int_stack+28630,int_stack+28210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34660, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+29190,int_stack+28630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35290, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+84130,int_stack+0,int_stack+81370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+85390,int_stack+900,int_stack+29190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2250, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+86470,int_stack+85390,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71680, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+85390,int_stack+30780,int_stack+30360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+31340,int_stack+30780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+88990,int_stack+88150,int_stack+85390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+90250,int_stack+1350,int_stack+31340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+91330,int_stack+90250,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90250,int_stack+32930,int_stack+32510, 0.0, zero_stack, 1.0, int_stack+34660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840,int_stack+33490,int_stack+32930, 0.0, zero_stack, 1.0, int_stack+35290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+93010,int_stack+840,int_stack+90250, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94270,int_stack+1800,int_stack+33490, 0.0, zero_stack, 1.0, int_stack+2250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+95350,int_stack+94270,int_stack+840, 0.0, zero_stack, 1.0, int_stack+71680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+94270,int_stack+35570,int_stack+34870, 1.0, int_stack+34660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+36130,int_stack+35570, 1.0, int_stack+35290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+97870,int_stack+97030,int_stack+94270, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+2610,int_stack+36130, 1.0, int_stack+2250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+100210,int_stack+99130,int_stack+97030, 1.0, int_stack+71680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+99130,int_stack+44220,int_stack+43800,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+71050,int_stack+44780,int_stack+44220,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1680,int_stack+71050,int_stack+99130,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+3060,int_stack+44780,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+102970,int_stack+101890,int_stack+71050,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+71890,int_stack+54170,int_stack+53750,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+101890,int_stack+54730,int_stack+54170,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+104650,int_stack+101890,int_stack+71890,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+105910,int_stack+3510,int_stack+54730,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+106990,int_stack+105910,int_stack+101890,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+105910,int_stack+65420,int_stack+65000,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2940,int_stack+65980,int_stack+65420,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+108670,int_stack+2940,int_stack+105910,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+3960,int_stack+65980,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+111010,int_stack+109930,int_stack+2940,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+4620,int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+23910,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+4900,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24330,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+112690,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+73780,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3780,int_stack+5260,int_stack+4900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24890,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+113950,int_stack+3780,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74410,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+5920,int_stack+5710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23910, 1.0, int_stack+26060,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+6200,int_stack+5920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24330, 1.0, int_stack+26480,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4620,int_stack+3780,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73780, 1.0, int_stack+76510,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+6560,int_stack+6200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24890, 1.0, int_stack+27040,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+115630,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74410, 1.0, int_stack+79270,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+7220,int_stack+7010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26060, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+7500,int_stack+7220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26480, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5880,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+76510, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+117310,int_stack+7860,int_stack+7500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+27040, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+118390,int_stack+117310,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+79270, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+8520,int_stack+8310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23910, 0.0, zero_stack, 1.0, int_stack+28210,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+8800,int_stack+8520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24330, 0.0, zero_stack, 1.0, int_stack+28630,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7140,int_stack+3780,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73780, 0.0, zero_stack, 1.0, int_stack+81370,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+9160,int_stack+8800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24890, 0.0, zero_stack, 1.0, int_stack+29190,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+120070,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74410, 0.0, zero_stack, 1.0, int_stack+0,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+9820,int_stack+9610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26060, 1.0, int_stack+28210, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+10100,int_stack+9820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26480, 1.0, int_stack+28630, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8400,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76510, 1.0, int_stack+81370, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+117310,int_stack+10460,int_stack+10100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27040, 1.0, int_stack+29190, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+121750,int_stack+117310,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79270, 1.0, int_stack+0, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+11120,int_stack+10910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+28210, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+11400,int_stack+11120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+28630, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9660,int_stack+3780,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+81370, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+11760,int_stack+11400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+29190, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+123430,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+12420,int_stack+12210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30360,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+12700,int_stack+12420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30780,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10920,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85390,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+117310,int_stack+13060,int_stack+12700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31340,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+125110,int_stack+117310,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88150,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+13720,int_stack+13510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26060, 0.0, zero_stack, 1.0, int_stack+30360, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+14000,int_stack+13720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26480, 0.0, zero_stack, 1.0, int_stack+30780, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12180,int_stack+3780,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76510, 0.0, zero_stack, 1.0, int_stack+85390, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+14360,int_stack+14000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27040, 0.0, zero_stack, 1.0, int_stack+31340, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+126790,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79270, 0.0, zero_stack, 1.0, int_stack+88150, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+15020,int_stack+14810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28210, 1.0, int_stack+30360, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+15300,int_stack+15020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28630, 1.0, int_stack+30780, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13440,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81370, 1.0, int_stack+85390, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+117310,int_stack+15660,int_stack+15300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29190, 1.0, int_stack+31340, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+128470,int_stack+117310,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+88150, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+16320,int_stack+16110, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+30360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+16600,int_stack+16320, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+30780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14700,int_stack+3780,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+85390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+16960,int_stack+16600, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+31340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+130150,int_stack+109930,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+17620,int_stack+17410, 0.0, zero_stack, 1.0, int_stack+23910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32510,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+17900,int_stack+17620, 0.0, zero_stack, 1.0, int_stack+24330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32930,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15960,int_stack+109930,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+73780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90250,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+117310,int_stack+18260,int_stack+17900, 0.0, zero_stack, 1.0, int_stack+24890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33490,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+131830,int_stack+117310,int_stack+109930, 0.0, zero_stack, 1.0, int_stack+74410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+18920,int_stack+18710, 0.0, zero_stack, 1.0, int_stack+26060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32510, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+19200,int_stack+18920, 0.0, zero_stack, 1.0, int_stack+26480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32930, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17220,int_stack+3780,int_stack+109930, 0.0, zero_stack, 1.0, int_stack+76510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90250, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+19560,int_stack+19200, 0.0, zero_stack, 1.0, int_stack+27040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33490, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+133510,int_stack+109930,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+79270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+20220,int_stack+20010, 0.0, zero_stack, 1.0, int_stack+28210, 0.0, zero_stack, 1.0, int_stack+32510, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+20500,int_stack+20220, 0.0, zero_stack, 1.0, int_stack+28630, 0.0, zero_stack, 1.0, int_stack+32930, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18480,int_stack+109930,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+81370, 0.0, zero_stack, 1.0, int_stack+90250, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+117310,int_stack+20860,int_stack+20500, 0.0, zero_stack, 1.0, int_stack+29190, 0.0, zero_stack, 1.0, int_stack+33490, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+135190,int_stack+117310,int_stack+109930, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+840, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+21520,int_stack+21310, 0.0, zero_stack, 1.0, int_stack+30360, 1.0, int_stack+32510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+21800,int_stack+21520, 0.0, zero_stack, 1.0, int_stack+30780, 1.0, int_stack+32930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19740,int_stack+3780,int_stack+109930, 0.0, zero_stack, 1.0, int_stack+85390, 1.0, int_stack+90250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+22160,int_stack+21800, 0.0, zero_stack, 1.0, int_stack+31340, 1.0, int_stack+33490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+136870,int_stack+109930,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+88150, 1.0, int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+22820,int_stack+22610, 0.0, zero_stack, 2.0, int_stack+32510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+23100,int_stack+22820, 0.0, zero_stack, 2.0, int_stack+32930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21000,int_stack+109930,int_stack+3780, 0.0, zero_stack, 2.0, int_stack+90250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+117310,int_stack+23460,int_stack+23100, 0.0, zero_stack, 2.0, int_stack+33490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+138550,int_stack+117310,int_stack+109930, 0.0, zero_stack, 2.0, int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109930,int_stack+24610,int_stack+24120, 1.0, int_stack+23910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34870,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+25250,int_stack+24610, 1.0, int_stack+24330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35570,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22260,int_stack+3780,int_stack+109930, 1.0, int_stack+73780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94270,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109930,int_stack+25610,int_stack+25250, 1.0, int_stack+24890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36130,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+23520,int_stack+109930,int_stack+3780, 1.0, int_stack+74410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97030,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+26760,int_stack+26270, 1.0, int_stack+26060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34870, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109930,int_stack+27400,int_stack+26760, 1.0, int_stack+26480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35570, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+73780,int_stack+109930,int_stack+3780, 1.0, int_stack+76510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94270, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+76510,int_stack+27760,int_stack+27400, 1.0, int_stack+27040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36130, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+25200,int_stack+76510,int_stack+109930, 1.0, int_stack+79270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97030, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+79270,int_stack+28910,int_stack+28420, 1.0, int_stack+28210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34870, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+29550,int_stack+28910, 1.0, int_stack+28630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35570, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+26880,int_stack+3780,int_stack+79270, 1.0, int_stack+81370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94270, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+81370,int_stack+29910,int_stack+29550, 1.0, int_stack+29190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36130, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28140,int_stack+81370,int_stack+3780, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97030, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+31060,int_stack+30570, 1.0, int_stack+30360, 0.0, zero_stack, 1.0, int_stack+34870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+31700,int_stack+31060, 1.0, int_stack+30780, 0.0, zero_stack, 1.0, int_stack+35570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29820,int_stack+3780,int_stack+0, 1.0, int_stack+85390, 0.0, zero_stack, 1.0, int_stack+94270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+85390,int_stack+32060,int_stack+31700, 1.0, int_stack+31340, 0.0, zero_stack, 1.0, int_stack+36130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+140230,int_stack+85390,int_stack+3780, 1.0, int_stack+88150, 0.0, zero_stack, 1.0, int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+33210,int_stack+32720, 1.0, int_stack+32510, 1.0, int_stack+34870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3780,int_stack+33850,int_stack+33210, 1.0, int_stack+32930, 1.0, int_stack+35570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+31080,int_stack+3780,int_stack+88150, 1.0, int_stack+90250, 1.0, int_stack+94270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+90250,int_stack+34210,int_stack+33850, 1.0, int_stack+33490, 1.0, int_stack+36130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32340,int_stack+90250,int_stack+3780, 1.0, int_stack+840, 1.0, int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+35850,int_stack+35080, 2.0, int_stack+34870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+36490,int_stack+35850, 2.0, int_stack+35570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+88150,int_stack+3780, 2.0, int_stack+94270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94270,int_stack+36850,int_stack+36490, 2.0, int_stack+36130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34020,int_stack+94270,int_stack+88150, 2.0, int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+37510,int_stack+37300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43800,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+37790,int_stack+37510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44220,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35700,int_stack+88150,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99130,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94270,int_stack+38150,int_stack+37790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44780,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+141910,int_stack+94270,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+38810,int_stack+38600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43800, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+39090,int_stack+38810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44220, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36960,int_stack+97030,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99130, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94270,int_stack+39450,int_stack+39090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44780, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38220,int_stack+94270,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+40110,int_stack+39900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43800, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+40390,int_stack+40110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44220, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+143590,int_stack+88150,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99130, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94270,int_stack+40750,int_stack+40390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44780, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+144850,int_stack+94270,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+41410,int_stack+41200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+41690,int_stack+41410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39900,int_stack+97030,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94270,int_stack+42050,int_stack+41690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+146530,int_stack+94270,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+42710,int_stack+42500, 0.0, zero_stack, 1.0, int_stack+43800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+42990,int_stack+42710, 0.0, zero_stack, 1.0, int_stack+44220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+41160,int_stack+88150,int_stack+97030, 0.0, zero_stack, 1.0, int_stack+99130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94270,int_stack+43350,int_stack+42990, 0.0, zero_stack, 1.0, int_stack+44780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+148210,int_stack+94270,int_stack+88150, 0.0, zero_stack, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+44500,int_stack+44010, 1.0, int_stack+43800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+45140,int_stack+44500, 1.0, int_stack+44220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+42420,int_stack+97030,int_stack+88150, 1.0, int_stack+99130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+45500,int_stack+45140, 1.0, int_stack+44780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43680,int_stack+99130,int_stack+97030, 1.0, int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+71050,int_stack+46160,int_stack+45950,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+46440,int_stack+46160,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+149890,int_stack+97030,int_stack+71050,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+46800,int_stack+46440,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+45360,int_stack+99130,int_stack+97030,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+47460,int_stack+47250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53750,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71050,int_stack+47740,int_stack+47460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54170,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+151150,int_stack+71050,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71890,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+48100,int_stack+47740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54730,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+152410,int_stack+99130,int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101890,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71050,int_stack+48760,int_stack+48550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53750, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+49040,int_stack+48760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54170, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+47040,int_stack+97030,int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71890, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+49400,int_stack+49040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54730, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+154090,int_stack+99130,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101890, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+50060,int_stack+49850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53750, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71050,int_stack+50340,int_stack+50060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54170, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48300,int_stack+71050,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71890, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+50700,int_stack+50340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54730, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+155770,int_stack+99130,int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101890, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71050,int_stack+51360,int_stack+51150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+51640,int_stack+51360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49560,int_stack+97030,int_stack+71050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+52000,int_stack+51640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+157450,int_stack+99130,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+52660,int_stack+52450, 0.0, zero_stack, 1.0, int_stack+53750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71050,int_stack+52940,int_stack+52660, 0.0, zero_stack, 1.0, int_stack+54170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50820,int_stack+71050,int_stack+97030, 0.0, zero_stack, 1.0, int_stack+71890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+53300,int_stack+52940, 0.0, zero_stack, 1.0, int_stack+54730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+159130,int_stack+99130,int_stack+71050, 0.0, zero_stack, 1.0, int_stack+101890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71050,int_stack+54450,int_stack+53960, 1.0, int_stack+53750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+55090,int_stack+54450, 1.0, int_stack+54170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+52080,int_stack+97030,int_stack+71050, 1.0, int_stack+71890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99130,int_stack+55450,int_stack+55090, 1.0, int_stack+54730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+53340,int_stack+99130,int_stack+97030, 1.0, int_stack+101890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+101890,int_stack+56110,int_stack+55900,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+56390,int_stack+56110,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+71050,int_stack+97030,int_stack+101890,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+56750,int_stack+56390,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+55020,int_stack+101890,int_stack+97030,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+57410,int_stack+57200,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+57690,int_stack+57410,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+160810,int_stack+88150,int_stack+97030,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+58050,int_stack+57690,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+56700,int_stack+101890,int_stack+88150,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+58710,int_stack+58500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65000,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+58990,int_stack+58710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65420,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+162070,int_stack+97030,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105910,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+59350,int_stack+58990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65980,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+163330,int_stack+101890,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+60010,int_stack+59800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65000, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+60290,int_stack+60010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65420, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+58380,int_stack+88150,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105910, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+60650,int_stack+60290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65980, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+165010,int_stack+101890,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+61310,int_stack+61100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65000, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+61590,int_stack+61310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65420, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+59640,int_stack+97030,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+61950,int_stack+61590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65980, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+166690,int_stack+101890,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+62610,int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+62890,int_stack+62610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+60900,int_stack+88150,int_stack+97030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+63250,int_stack+62890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+168370,int_stack+101890,int_stack+88150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+63910,int_stack+63700, 0.0, zero_stack, 1.0, int_stack+65000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+64190,int_stack+63910, 0.0, zero_stack, 1.0, int_stack+65420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+62160,int_stack+97030,int_stack+88150, 0.0, zero_stack, 1.0, int_stack+105910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+101890,int_stack+64550,int_stack+64190, 0.0, zero_stack, 1.0, int_stack+65980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+170050,int_stack+101890,int_stack+97030, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+65700,int_stack+65210, 1.0, int_stack+65000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+66340,int_stack+65700, 1.0, int_stack+65420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+63420,int_stack+88150,int_stack+97030, 1.0, int_stack+105910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+105910,int_stack+66700,int_stack+66340, 1.0, int_stack+65980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+64680,int_stack+105910,int_stack+88150, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2940,int_stack+67360,int_stack+67150,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+67640,int_stack+67360,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+66360,int_stack+88150,int_stack+2940,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+105910,int_stack+68000,int_stack+67640,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2940,int_stack+105910,int_stack+88150,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+88150,int_stack+68660,int_stack+68450,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+97030,int_stack+68940,int_stack+68660,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+67620,int_stack+97030,int_stack+88150,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+105910,int_stack+69300,int_stack+68940,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+171730,int_stack+105910,int_stack+97030,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+97030,int_stack+69960,int_stack+69750,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+88150,int_stack+70240,int_stack+69960,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+68880,int_stack+88150,int_stack+97030,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+105910,int_stack+70600,int_stack+70240,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+173410,int_stack+105910,int_stack+88150,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+175090,int_stack+77590,int_stack+75250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72520,10);
     Libderiv->ABCD[11] = int_stack + 175090;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+76510,int_stack+82450,int_stack+80110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72520, 0.0, zero_stack,10);
     Libderiv->ABCD[10] = int_stack + 76510;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+81370,int_stack+86470,int_stack+84130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72520, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[9] = int_stack + 81370;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+85390,int_stack+91330,int_stack+88990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[8] = int_stack + 85390;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+90250,int_stack+95350,int_stack+93010, 0.0, zero_stack, 1.0, int_stack+72520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[7] = int_stack + 90250;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+94270,int_stack+100210,int_stack+97870, 1.0, int_stack+72520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[6] = int_stack + 94270;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+99130,int_stack+102970,int_stack+1680,10);
     Libderiv->ABCD[2] = int_stack + 99130;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+101230,int_stack+106990,int_stack+104650,10);
     Libderiv->ABCD[1] = int_stack + 101230;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+105910,int_stack+111010,int_stack+108670,10);
     Libderiv->ABCD[0] = int_stack + 105910;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+109930,int_stack+113950,int_stack+112690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+75250,10);
     Libderiv->ABCD[155] = int_stack + 109930;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+112030,int_stack+115630,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75250, 1.0, int_stack+80110,10);
     Libderiv->ABCD[143] = int_stack + 112030;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+114130,int_stack+118390,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+80110, 0.0, zero_stack,10);
     Libderiv->ABCD[142] = int_stack + 114130;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4620,int_stack+120070,int_stack+7140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75250, 0.0, zero_stack, 1.0, int_stack+84130,10);
     Libderiv->ABCD[131] = int_stack + 4620;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+116230,int_stack+121750,int_stack+8400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80110, 1.0, int_stack+84130, 0.0, zero_stack,10);
     Libderiv->ABCD[130] = int_stack + 116230;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6720,int_stack+123430,int_stack+9660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+84130, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[129] = int_stack + 6720;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8820,int_stack+125110,int_stack+10920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88990,10);
     Libderiv->ABCD[119] = int_stack + 8820;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+118330,int_stack+126790,int_stack+12180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80110, 0.0, zero_stack, 1.0, int_stack+88990, 0.0, zero_stack,10);
     Libderiv->ABCD[118] = int_stack + 118330;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10920,int_stack+128470,int_stack+13440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84130, 1.0, int_stack+88990, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[117] = int_stack + 10920;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+120430,int_stack+130150,int_stack+14700, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+88990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[116] = int_stack + 120430;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13020,int_stack+131830,int_stack+15960, 0.0, zero_stack, 1.0, int_stack+75250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93010,10);
     Libderiv->ABCD[107] = int_stack + 13020;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15120,int_stack+133510,int_stack+17220, 0.0, zero_stack, 1.0, int_stack+80110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93010, 0.0, zero_stack,10);
     Libderiv->ABCD[106] = int_stack + 15120;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+122530,int_stack+135190,int_stack+18480, 0.0, zero_stack, 1.0, int_stack+84130, 0.0, zero_stack, 1.0, int_stack+93010, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[105] = int_stack + 122530;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+17220,int_stack+136870,int_stack+19740, 0.0, zero_stack, 1.0, int_stack+88990, 1.0, int_stack+93010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[104] = int_stack + 17220;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+124630,int_stack+138550,int_stack+21000, 0.0, zero_stack, 2.0, int_stack+93010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[103] = int_stack + 124630;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+19320,int_stack+23520,int_stack+22260, 1.0, int_stack+75250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97870,10);
     Libderiv->ABCD[95] = int_stack + 19320;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+21420,int_stack+25200,int_stack+73780, 1.0, int_stack+80110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97870, 0.0, zero_stack,10);
     Libderiv->ABCD[94] = int_stack + 21420;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+23520,int_stack+28140,int_stack+26880, 1.0, int_stack+84130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97870, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[93] = int_stack + 23520;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+25620,int_stack+140230,int_stack+29820, 1.0, int_stack+88990, 0.0, zero_stack, 1.0, int_stack+97870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[92] = int_stack + 25620;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+27720,int_stack+32340,int_stack+31080, 1.0, int_stack+93010, 1.0, int_stack+97870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[91] = int_stack + 27720;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+29820,int_stack+34020,int_stack+0, 2.0, int_stack+97870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[90] = int_stack + 29820;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+31920,int_stack+141910,int_stack+35700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680,10);
     Libderiv->ABCD[47] = int_stack + 31920;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+34020,int_stack+38220,int_stack+36960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680, 0.0, zero_stack,10);
     Libderiv->ABCD[46] = int_stack + 34020;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+36120,int_stack+144850,int_stack+143590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[45] = int_stack + 36120;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+72310,int_stack+146530,int_stack+39900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[44] = int_stack + 72310;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+74410,int_stack+148210,int_stack+41160, 0.0, zero_stack, 1.0, int_stack+1680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[43] = int_stack + 74410;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+38220,int_stack+43680,int_stack+42420, 1.0, int_stack+1680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[42] = int_stack + 38220;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+45360,int_stack+149890,10);
     Libderiv->ABCD[38] = int_stack + 0;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+40320,int_stack+152410,int_stack+151150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104650,10);
     Libderiv->ABCD[35] = int_stack + 40320;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+42420,int_stack+154090,int_stack+47040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104650, 0.0, zero_stack,10);
     Libderiv->ABCD[34] = int_stack + 42420;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+44520,int_stack+155770,int_stack+48300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104650, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[33] = int_stack + 44520;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46620,int_stack+157450,int_stack+49560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[32] = int_stack + 46620;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48720,int_stack+159130,int_stack+50820, 0.0, zero_stack, 1.0, int_stack+104650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[31] = int_stack + 48720;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+96370,int_stack+53340,int_stack+52080, 1.0, int_stack+104650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[30] = int_stack + 96370;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+50820,int_stack+55020,int_stack+71050,10);
     Libderiv->ABCD[26] = int_stack + 50820;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+52920,int_stack+56700,int_stack+160810,10);
     Libderiv->ABCD[25] = int_stack + 52920;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+55020,int_stack+163330,int_stack+162070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108670,10);
     Libderiv->ABCD[23] = int_stack + 55020;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+103330,int_stack+165010,int_stack+58380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108670, 0.0, zero_stack,10);
     Libderiv->ABCD[22] = int_stack + 103330;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+57120,int_stack+166690,int_stack+59640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108670, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[21] = int_stack + 57120;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+70140,int_stack+168370,int_stack+60900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[20] = int_stack + 70140;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+59220,int_stack+170050,int_stack+62160, 0.0, zero_stack, 1.0, int_stack+108670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[19] = int_stack + 59220;
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+61320,int_stack+64680,int_stack+63420, 1.0, int_stack+108670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[18] = int_stack + 61320;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+63420,int_stack+2940,int_stack+66360,10);
     Libderiv->ABCD[14] = int_stack + 63420;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+65520,int_stack+171730,int_stack+67620,10);
     Libderiv->ABCD[13] = int_stack + 65520;
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2100,int_stack+173410,int_stack+68880,10);
     Libderiv->ABCD[12] = int_stack + 2100;

}
