/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_f0hp(Libderiv_t *, prim_data *);

  /* Computes derivatives of (f0|hp) integrals */

void d12hrr_order_f0hp(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][6][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][10] = int_stack + 280;
 Libderiv->deriv_classes[3][6][9] = int_stack + 560;
 Libderiv->deriv_classes[3][6][8] = int_stack + 840;
 Libderiv->deriv_classes[3][6][7] = int_stack + 1120;
 Libderiv->dvrr_classes[3][5] = int_stack + 1400;
 Libderiv->deriv_classes[3][6][6] = int_stack + 1610;
 Libderiv->deriv_classes[3][6][2] = int_stack + 1890;
 Libderiv->deriv_classes[3][6][1] = int_stack + 2170;
 Libderiv->deriv_classes[3][6][0] = int_stack + 2450;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 2730;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 2940;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 3220;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 3430;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 3710;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 3920;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 4200;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 4410;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 4690;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 4900;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 5180;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 5390;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 5670;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 5880;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 6160;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 6370;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 6650;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 6860;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 7140;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 7350;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 7630;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 7840;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 8120;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 8330;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 8610;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 8820;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 9100;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 9310;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 9590;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 9800;
 Libderiv->deriv_classes[3][5][11] = int_stack + 10080;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 10290;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 10500;
 Libderiv->deriv_classes[3][5][10] = int_stack + 10780;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 10990;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 11200;
 Libderiv->deriv_classes[3][5][9] = int_stack + 11480;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 11690;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 11900;
 Libderiv->deriv_classes[3][5][8] = int_stack + 12180;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 12390;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 12600;
 Libderiv->deriv_classes[3][5][7] = int_stack + 12880;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 13090;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 13300;
 Libderiv->deriv_classes[3][5][6] = int_stack + 13580;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 13790;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 14000;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 14280;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 14490;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 14770;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 14980;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 15260;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 15470;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 15750;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 15960;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 16240;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 16450;
 Libderiv->deriv_classes[3][5][2] = int_stack + 16730;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 16940;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 17150;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 17430;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 17640;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 17920;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 18130;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 18410;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 18620;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 18900;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 19110;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 19390;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 19600;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 19880;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 20090;
 Libderiv->deriv_classes[3][5][1] = int_stack + 20370;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 20580;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 20790;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 21070;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 21280;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 21560;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 21770;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 22050;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 22260;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 22540;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 22750;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 23030;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 23240;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 23520;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 23730;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 24010;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 24220;
 Libderiv->deriv_classes[3][5][0] = int_stack + 24500;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 24710;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 24920;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 25200;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 25410;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 25690;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 25900;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 26180;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 26390;
 memset(int_stack,0,213360);

 Libderiv->dvrr_stack = int_stack + 34860;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_f0hp(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26670,int_stack+0,int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400,10);
     Libderiv->ABCD[11] = int_stack + 26670;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27300,int_stack+280,int_stack+10780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack,10);
     Libderiv->ABCD[10] = int_stack + 27300;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27930,int_stack+560,int_stack+11480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[9] = int_stack + 27930;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+840,int_stack+12180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28560,int_stack+1120,int_stack+12880, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[7] = int_stack + 28560;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+630,int_stack+1610,int_stack+13580, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[6] = int_stack + 630;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1260,int_stack+1890,int_stack+16730,10);
     Libderiv->ABCD[2] = int_stack + 1260;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29190,int_stack+2170,int_stack+20370,10);
     Libderiv->ABCD[1] = int_stack + 29190;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29820,int_stack+2450,int_stack+24500,10);
     Libderiv->ABCD[0] = int_stack + 29820;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1890,int_stack+2940,int_stack+2730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+10080,10);
     Libderiv->ABCD[155] = int_stack + 1890;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2520,int_stack+3430,int_stack+3220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10080, 1.0, int_stack+10780,10);
     Libderiv->ABCD[143] = int_stack + 2520;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30450,int_stack+3920,int_stack+3710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+10780, 0.0, zero_stack,10);
     Libderiv->ABCD[142] = int_stack + 30450;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+4410,int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10080, 0.0, zero_stack, 1.0, int_stack+11480,10);
     Libderiv->ABCD[131] = int_stack + 3150;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+4900,int_stack+4690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10780, 1.0, int_stack+11480, 0.0, zero_stack,10);
     Libderiv->ABCD[130] = int_stack + 3780;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4410,int_stack+5390,int_stack+5180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+11480, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[129] = int_stack + 4410;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5040,int_stack+5880,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12180,10);
     Libderiv->ABCD[119] = int_stack + 5040;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+31080,int_stack+6370,int_stack+6160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10780, 0.0, zero_stack, 1.0, int_stack+12180, 0.0, zero_stack,10);
     Libderiv->ABCD[118] = int_stack + 31080;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+6860,int_stack+6650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11480, 1.0, int_stack+12180, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[117] = int_stack + 5670;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+7350,int_stack+7140, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+12180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[116] = int_stack + 6300;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6930,int_stack+7840,int_stack+7630, 0.0, zero_stack, 1.0, int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12880,10);
     Libderiv->ABCD[107] = int_stack + 6930;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+31710,int_stack+8330,int_stack+8120, 0.0, zero_stack, 1.0, int_stack+10780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12880, 0.0, zero_stack,10);
     Libderiv->ABCD[106] = int_stack + 31710;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7560,int_stack+8820,int_stack+8610, 0.0, zero_stack, 1.0, int_stack+11480, 0.0, zero_stack, 1.0, int_stack+12880, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[105] = int_stack + 7560;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8190,int_stack+9310,int_stack+9100, 0.0, zero_stack, 1.0, int_stack+12180, 1.0, int_stack+12880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[104] = int_stack + 8190;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8820,int_stack+9800,int_stack+9590, 0.0, zero_stack, 2.0, int_stack+12880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[103] = int_stack + 8820;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+10500,int_stack+10290, 1.0, int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13580,10);
     Libderiv->ABCD[95] = int_stack + 9450;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10080,int_stack+11200,int_stack+10990, 1.0, int_stack+10780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13580, 0.0, zero_stack,10);
     Libderiv->ABCD[94] = int_stack + 10080;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10710,int_stack+11900,int_stack+11690, 1.0, int_stack+11480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13580, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[93] = int_stack + 10710;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11340,int_stack+12600,int_stack+12390, 1.0, int_stack+12180, 0.0, zero_stack, 1.0, int_stack+13580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[92] = int_stack + 11340;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11970,int_stack+13300,int_stack+13090, 1.0, int_stack+12880, 1.0, int_stack+13580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[91] = int_stack + 11970;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+14000,int_stack+13790, 2.0, int_stack+13580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[90] = int_stack + 12600;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13230,int_stack+14490,int_stack+14280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16730,10);
     Libderiv->ABCD[47] = int_stack + 13230;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13860,int_stack+14980,int_stack+14770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16730, 0.0, zero_stack,10);
     Libderiv->ABCD[46] = int_stack + 13860;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14490,int_stack+15470,int_stack+15260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16730, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[45] = int_stack + 14490;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15120,int_stack+15960,int_stack+15750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[44] = int_stack + 15120;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32340,int_stack+16450,int_stack+16240, 0.0, zero_stack, 1.0, int_stack+16730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[43] = int_stack + 32340;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15750,int_stack+17150,int_stack+16940, 1.0, int_stack+16730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[42] = int_stack + 15750;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+16380,int_stack+17640,int_stack+17430,10);
     Libderiv->ABCD[38] = int_stack + 16380;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17010,int_stack+18130,int_stack+17920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20370,10);
     Libderiv->ABCD[35] = int_stack + 17010;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17640,int_stack+18620,int_stack+18410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20370, 0.0, zero_stack,10);
     Libderiv->ABCD[34] = int_stack + 17640;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18270,int_stack+19110,int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[33] = int_stack + 18270;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32970,int_stack+19600,int_stack+19390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[32] = int_stack + 32970;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+20090,int_stack+19880, 0.0, zero_stack, 1.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[31] = int_stack + 18900;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19530,int_stack+20790,int_stack+20580, 1.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[30] = int_stack + 19530;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+20160,int_stack+21280,int_stack+21070,10);
     Libderiv->ABCD[26] = int_stack + 20160;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+20790,int_stack+21770,int_stack+21560,10);
     Libderiv->ABCD[25] = int_stack + 20790;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21420,int_stack+22260,int_stack+22050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24500,10);
     Libderiv->ABCD[23] = int_stack + 21420;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+33600,int_stack+22750,int_stack+22540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24500, 0.0, zero_stack,10);
     Libderiv->ABCD[22] = int_stack + 33600;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+22050,int_stack+23240,int_stack+23030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24500, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[21] = int_stack + 22050;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+22680,int_stack+23730,int_stack+23520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[20] = int_stack + 22680;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23310,int_stack+24220,int_stack+24010, 0.0, zero_stack, 1.0, int_stack+24500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[19] = int_stack + 23310;
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34230,int_stack+24920,int_stack+24710, 1.0, int_stack+24500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[18] = int_stack + 34230;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+23940,int_stack+25410,int_stack+25200,10);
     Libderiv->ABCD[14] = int_stack + 23940;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+24570,int_stack+25900,int_stack+25690,10);
     Libderiv->ABCD[13] = int_stack + 24570;
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+25200,int_stack+26390,int_stack+26180,10);
     Libderiv->ABCD[12] = int_stack + 25200;

}
