/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_gpgp(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gp|gp) integrals */

void d12hrr_order_gpgp(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][5][11] = int_stack + 0;
 Libderiv->deriv_classes[5][5][10] = int_stack + 441;
 Libderiv->deriv_classes[5][5][9] = int_stack + 882;
 Libderiv->deriv_classes[5][5][8] = int_stack + 1323;
 Libderiv->deriv_classes[5][5][7] = int_stack + 1764;
 Libderiv->dvrr_classes[5][4] = int_stack + 2205;
 Libderiv->deriv_classes[5][5][6] = int_stack + 2520;
 Libderiv->deriv_classes[5][5][2] = int_stack + 2961;
 Libderiv->deriv_classes[5][5][1] = int_stack + 3402;
 Libderiv->dvrr_classes[4][5] = int_stack + 3843;
 Libderiv->deriv_classes[5][5][0] = int_stack + 4158;
 Libderiv->deriv2_classes[4][4][143] = int_stack + 4599;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 4824;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 5139;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 5454;
 Libderiv->deriv2_classes[4][4][131] = int_stack + 5895;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 6120;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 6435;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 6750;
 Libderiv->deriv2_classes[4][4][130] = int_stack + 7191;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 7416;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 7731;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 8046;
 Libderiv->deriv2_classes[4][4][119] = int_stack + 8487;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 8712;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 9027;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 9342;
 Libderiv->deriv2_classes[4][4][118] = int_stack + 9783;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 10008;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 10323;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 10638;
 Libderiv->deriv2_classes[4][4][117] = int_stack + 11079;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 11304;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 11619;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 11934;
 Libderiv->deriv2_classes[4][4][107] = int_stack + 12375;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 12600;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 12915;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 13230;
 Libderiv->deriv2_classes[4][4][106] = int_stack + 13671;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 13896;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 14211;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 14526;
 Libderiv->deriv2_classes[4][4][105] = int_stack + 14967;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 15192;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 15507;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 15822;
 Libderiv->deriv2_classes[4][4][104] = int_stack + 16263;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 16488;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 16803;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 17118;
 Libderiv->deriv2_classes[4][4][95] = int_stack + 17559;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 17784;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 18099;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 18414;
 Libderiv->deriv2_classes[4][4][94] = int_stack + 18855;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 19080;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 19395;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 19710;
 Libderiv->deriv2_classes[4][4][93] = int_stack + 20151;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 20376;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 20691;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 21006;
 Libderiv->deriv2_classes[4][4][92] = int_stack + 21447;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 21672;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 21987;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 22302;
 Libderiv->deriv2_classes[4][4][91] = int_stack + 22743;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 22968;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 23283;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 23598;
 Libderiv->deriv2_classes[4][4][83] = int_stack + 24039;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 24264;
 Libderiv->deriv_classes[5][4][11] = int_stack + 24579;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 24894;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 25209;
 Libderiv->deriv2_classes[4][4][82] = int_stack + 25650;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 25875;
 Libderiv->deriv_classes[5][4][10] = int_stack + 26190;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 26505;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 26820;
 Libderiv->deriv2_classes[4][4][81] = int_stack + 27261;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 27486;
 Libderiv->deriv_classes[5][4][9] = int_stack + 27801;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 28116;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 28431;
 Libderiv->deriv2_classes[4][4][80] = int_stack + 28872;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 29097;
 Libderiv->deriv_classes[5][4][8] = int_stack + 29412;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 29727;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 30042;
 Libderiv->deriv2_classes[4][4][79] = int_stack + 30483;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 30708;
 Libderiv->deriv_classes[5][4][7] = int_stack + 31023;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 31338;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 31653;
 Libderiv->deriv2_classes[4][4][78] = int_stack + 32094;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 32319;
 Libderiv->deriv_classes[5][4][6] = int_stack + 32634;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 32949;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 33264;
 Libderiv->deriv2_classes[4][4][35] = int_stack + 33705;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 33930;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 34245;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 34560;
 Libderiv->deriv2_classes[4][4][34] = int_stack + 35001;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 35226;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 35541;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 35856;
 Libderiv->deriv2_classes[4][4][33] = int_stack + 36297;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 36522;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 36837;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 37152;
 Libderiv->deriv2_classes[4][4][32] = int_stack + 37593;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 37818;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 38133;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 38448;
 Libderiv->deriv2_classes[4][4][31] = int_stack + 38889;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 39114;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 39429;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 39744;
 Libderiv->deriv2_classes[4][4][30] = int_stack + 40185;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 40410;
 Libderiv->deriv_classes[5][4][2] = int_stack + 40725;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 41040;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 41355;
 Libderiv->deriv2_classes[4][4][26] = int_stack + 41796;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 42021;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 42336;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 42651;
 Libderiv->deriv2_classes[4][4][23] = int_stack + 43092;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 43317;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 43632;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 43947;
 Libderiv->deriv2_classes[4][4][22] = int_stack + 44388;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 44613;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 44928;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 45243;
 Libderiv->deriv2_classes[4][4][21] = int_stack + 45684;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 45909;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 46224;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 46539;
 Libderiv->deriv2_classes[4][4][20] = int_stack + 46980;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 47205;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 47520;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 47835;
 Libderiv->deriv2_classes[4][4][19] = int_stack + 48276;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 48501;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 48816;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 49131;
 Libderiv->deriv2_classes[4][4][18] = int_stack + 49572;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 49797;
 Libderiv->deriv_classes[5][4][1] = int_stack + 50112;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 50427;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 50742;
 Libderiv->deriv2_classes[4][4][14] = int_stack + 51183;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 51408;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 51723;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 52038;
 Libderiv->deriv2_classes[4][4][13] = int_stack + 52479;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 52704;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 53019;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 53334;
 Libderiv->deriv_classes[4][4][11] = int_stack + 53775;
 Libderiv->deriv_classes[4][5][11] = int_stack + 54000;
 Libderiv->deriv2_classes[4][4][11] = int_stack + 54315;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 54540;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 54855;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 55170;
 Libderiv->deriv_classes[4][4][10] = int_stack + 55611;
 Libderiv->deriv_classes[4][5][10] = int_stack + 55836;
 Libderiv->deriv2_classes[4][4][10] = int_stack + 56151;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 56376;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 56691;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 57006;
 Libderiv->deriv_classes[4][4][9] = int_stack + 57447;
 Libderiv->deriv_classes[4][5][9] = int_stack + 57672;
 Libderiv->deriv2_classes[4][4][9] = int_stack + 57987;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 58212;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 58527;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 58842;
 Libderiv->deriv_classes[4][4][8] = int_stack + 59283;
 Libderiv->deriv_classes[4][5][8] = int_stack + 59508;
 Libderiv->deriv2_classes[4][4][8] = int_stack + 59823;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 60048;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 60363;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 60678;
 Libderiv->deriv_classes[4][4][7] = int_stack + 61119;
 Libderiv->deriv_classes[4][5][7] = int_stack + 61344;
 Libderiv->deriv2_classes[4][4][7] = int_stack + 61659;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 61884;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 62199;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 62514;
 Libderiv->dvrr_classes[4][4] = int_stack + 62955;
 Libderiv->deriv_classes[4][4][6] = int_stack + 63180;
 Libderiv->deriv_classes[4][5][6] = int_stack + 63405;
 Libderiv->deriv2_classes[4][4][6] = int_stack + 63720;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 63945;
 Libderiv->deriv_classes[5][4][0] = int_stack + 64260;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 64575;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 64890;
 Libderiv->deriv_classes[4][4][2] = int_stack + 65331;
 Libderiv->deriv_classes[4][5][2] = int_stack + 65556;
 Libderiv->deriv2_classes[4][4][2] = int_stack + 65871;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 66096;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 66411;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 66726;
 Libderiv->deriv_classes[4][4][1] = int_stack + 67167;
 Libderiv->deriv_classes[4][5][1] = int_stack + 67392;
 Libderiv->deriv2_classes[4][4][1] = int_stack + 67707;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 67932;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 68247;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 68562;
 Libderiv->deriv_classes[4][4][0] = int_stack + 69003;
 Libderiv->deriv_classes[4][5][0] = int_stack + 69228;
 Libderiv->deriv2_classes[4][4][0] = int_stack + 69543;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 69768;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 70083;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 70398;
 memset(int_stack,0,566712);

 Libderiv->dvrr_stack = int_stack + 122544;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_gpgp(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+70839,int_stack+54000,int_stack+53775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62955,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+71514,int_stack+0,int_stack+24579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+72459,int_stack+55836,int_stack+55611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62955, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+73134,int_stack+441,int_stack+26190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+57672,int_stack+57447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62955, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74079,int_stack+882,int_stack+27801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+75024,int_stack+59508,int_stack+59283, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+75699,int_stack+1323,int_stack+29412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+675,int_stack+61344,int_stack+61119, 0.0, zero_stack, 1.0, int_stack+62955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+76644,int_stack+1764,int_stack+31023, 0.0, zero_stack, 1.0, int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+63405,int_stack+63180, 1.0, int_stack+62955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+77589,int_stack+2520,int_stack+32634, 1.0, int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2025,int_stack+3843,int_stack+62955,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+78534,int_stack+65556,int_stack+65331,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+79209,int_stack+2961,int_stack+40725,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+67392,int_stack+67167,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+80154,int_stack+3402,int_stack+50112,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+3375,int_stack+69228,int_stack+69003,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+81099,int_stack+4158,int_stack+64260,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+82044,int_stack+4824,int_stack+4599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+53775,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+4050,int_stack+5454,int_stack+5139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24579,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+4995,int_stack+6120,int_stack+5895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53775, 1.0, int_stack+55611,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+82719,int_stack+6750,int_stack+6435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24579, 1.0, int_stack+26190,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+5670,int_stack+7416,int_stack+7191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+55611, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+6345,int_stack+8046,int_stack+7731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26190, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+7290,int_stack+8712,int_stack+8487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53775, 0.0, zero_stack, 1.0, int_stack+57447,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+7965,int_stack+9342,int_stack+9027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24579, 0.0, zero_stack, 1.0, int_stack+27801,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+8910,int_stack+10008,int_stack+9783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55611, 1.0, int_stack+57447, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+83664,int_stack+10638,int_stack+10323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26190, 1.0, int_stack+27801, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9585,int_stack+11304,int_stack+11079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+57447, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+10260,int_stack+11934,int_stack+11619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+27801, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11205,int_stack+12600,int_stack+12375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59283,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11880,int_stack+13230,int_stack+12915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24579, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29412,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12825,int_stack+13896,int_stack+13671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55611, 0.0, zero_stack, 1.0, int_stack+59283, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+84609,int_stack+14526,int_stack+14211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26190, 0.0, zero_stack, 1.0, int_stack+29412, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+13500,int_stack+15192,int_stack+14967, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57447, 1.0, int_stack+59283, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14175,int_stack+15822,int_stack+15507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27801, 1.0, int_stack+29412, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+15120,int_stack+16488,int_stack+16263, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+59283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+15795,int_stack+17118,int_stack+16803, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+29412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+16740,int_stack+17784,int_stack+17559, 0.0, zero_stack, 1.0, int_stack+53775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61119,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+85554,int_stack+18414,int_stack+18099, 0.0, zero_stack, 1.0, int_stack+24579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31023,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+17415,int_stack+19080,int_stack+18855, 0.0, zero_stack, 1.0, int_stack+55611, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61119, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+18090,int_stack+19710,int_stack+19395, 0.0, zero_stack, 1.0, int_stack+26190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31023, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+19035,int_stack+20376,int_stack+20151, 0.0, zero_stack, 1.0, int_stack+57447, 0.0, zero_stack, 1.0, int_stack+61119, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+19710,int_stack+21006,int_stack+20691, 0.0, zero_stack, 1.0, int_stack+27801, 0.0, zero_stack, 1.0, int_stack+31023, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+20655,int_stack+21672,int_stack+21447, 0.0, zero_stack, 1.0, int_stack+59283, 1.0, int_stack+61119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+86499,int_stack+22302,int_stack+21987, 0.0, zero_stack, 1.0, int_stack+29412, 1.0, int_stack+31023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+21330,int_stack+22968,int_stack+22743, 0.0, zero_stack, 2.0, int_stack+61119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+22005,int_stack+23598,int_stack+23283, 0.0, zero_stack, 2.0, int_stack+31023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+22950,int_stack+24264,int_stack+24039, 1.0, int_stack+53775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63180,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+23625,int_stack+25209,int_stack+24894, 1.0, int_stack+24579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32634,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+24570,int_stack+25875,int_stack+25650, 1.0, int_stack+55611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63180, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+25245,int_stack+26820,int_stack+26505, 1.0, int_stack+26190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32634, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+26190,int_stack+27486,int_stack+27261, 1.0, int_stack+57447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63180, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87444,int_stack+28431,int_stack+28116, 1.0, int_stack+27801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32634, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+26865,int_stack+29097,int_stack+28872, 1.0, int_stack+59283, 0.0, zero_stack, 1.0, int_stack+63180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+27540,int_stack+30042,int_stack+29727, 1.0, int_stack+29412, 0.0, zero_stack, 1.0, int_stack+32634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+28485,int_stack+30708,int_stack+30483, 1.0, int_stack+61119, 1.0, int_stack+63180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+29160,int_stack+31653,int_stack+31338, 1.0, int_stack+31023, 1.0, int_stack+32634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+30105,int_stack+32319,int_stack+32094, 2.0, int_stack+63180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+30780,int_stack+33264,int_stack+32949, 2.0, int_stack+32634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+31725,int_stack+33930,int_stack+33705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65331,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+32400,int_stack+34560,int_stack+34245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40725,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+33345,int_stack+35226,int_stack+35001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65331, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34020,int_stack+35856,int_stack+35541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40725, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34965,int_stack+36522,int_stack+36297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65331, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+35640,int_stack+37152,int_stack+36837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40725, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+36585,int_stack+37818,int_stack+37593, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+88389,int_stack+38448,int_stack+38133, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+37260,int_stack+39114,int_stack+38889, 0.0, zero_stack, 1.0, int_stack+65331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+37935,int_stack+39744,int_stack+39429, 0.0, zero_stack, 1.0, int_stack+40725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38880,int_stack+40410,int_stack+40185, 1.0, int_stack+65331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+39555,int_stack+41355,int_stack+41040, 1.0, int_stack+40725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+40500,int_stack+42021,int_stack+41796,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+41175,int_stack+42651,int_stack+42336,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+42120,int_stack+43317,int_stack+43092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67167,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+89334,int_stack+43947,int_stack+43632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50112,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+42795,int_stack+44613,int_stack+44388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67167, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+43470,int_stack+45243,int_stack+44928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50112, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+44415,int_stack+45909,int_stack+45684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67167, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+45090,int_stack+46539,int_stack+46224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50112, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+46035,int_stack+47205,int_stack+46980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90279,int_stack+47835,int_stack+47520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+46710,int_stack+48501,int_stack+48276, 0.0, zero_stack, 1.0, int_stack+67167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+47385,int_stack+49131,int_stack+48816, 0.0, zero_stack, 1.0, int_stack+50112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+48330,int_stack+49797,int_stack+49572, 1.0, int_stack+67167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+49005,int_stack+50742,int_stack+50427, 1.0, int_stack+50112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+49950,int_stack+51408,int_stack+51183,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+50625,int_stack+52038,int_stack+51723,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+51570,int_stack+52704,int_stack+52479,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+91224,int_stack+53334,int_stack+53019,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+52245,int_stack+54540,int_stack+54315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69003,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+52920,int_stack+55170,int_stack+54855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64260,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+53865,int_stack+56376,int_stack+56151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69003, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54540,int_stack+57006,int_stack+56691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64260, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+55485,int_stack+58212,int_stack+57987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69003, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+56160,int_stack+58842,int_stack+58527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64260, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+57105,int_stack+60048,int_stack+59823, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+57780,int_stack+60678,int_stack+60363, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+58725,int_stack+61884,int_stack+61659, 0.0, zero_stack, 1.0, int_stack+69003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+59400,int_stack+62514,int_stack+62199, 0.0, zero_stack, 1.0, int_stack+64260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+60345,int_stack+63945,int_stack+63720, 1.0, int_stack+69003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+61020,int_stack+64890,int_stack+64575, 1.0, int_stack+64260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+61965,int_stack+66096,int_stack+65871,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+62640,int_stack+66726,int_stack+66411,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+63585,int_stack+67932,int_stack+67707,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+64260,int_stack+68562,int_stack+68247,21);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+65205,int_stack+69768,int_stack+69543,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+65880,int_stack+70398,int_stack+70083,21);
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+66825,int_stack+71514,int_stack+70839,45);
     Libderiv->ABCD[11] = int_stack + 66825;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+92169,int_stack+73134,int_stack+72459,45);
     Libderiv->ABCD[10] = int_stack + 92169;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+94194,int_stack+74079,int_stack+0,45);
     Libderiv->ABCD[9] = int_stack + 94194;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+96219,int_stack+75699,int_stack+75024,45);
     Libderiv->ABCD[8] = int_stack + 96219;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+98244,int_stack+76644,int_stack+675,45);
     Libderiv->ABCD[7] = int_stack + 98244;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+100269,int_stack+77589,int_stack+1350,45);
     Libderiv->ABCD[6] = int_stack + 100269;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+75699,int_stack+79209,int_stack+78534, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[2] = int_stack + 75699;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+102294,int_stack+80154,int_stack+2700, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[1] = int_stack + 102294;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+104319,int_stack+81099,int_stack+3375, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[0] = int_stack + 104319;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+79209,int_stack+4050,int_stack+82044,45);
     Libderiv->ABCD[155] = int_stack + 79209;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+106344,int_stack+82719,int_stack+4995,45);
     Libderiv->ABCD[143] = int_stack + 106344;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+81234,int_stack+6345,int_stack+5670,45);
     Libderiv->ABCD[142] = int_stack + 81234;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+4050,int_stack+7965,int_stack+7290,45);
     Libderiv->ABCD[131] = int_stack + 4050;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+6075,int_stack+83664,int_stack+8910,45);
     Libderiv->ABCD[130] = int_stack + 6075;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+108369,int_stack+10260,int_stack+9585,45);
     Libderiv->ABCD[129] = int_stack + 108369;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8100,int_stack+11880,int_stack+11205,45);
     Libderiv->ABCD[119] = int_stack + 8100;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+10125,int_stack+84609,int_stack+12825,45);
     Libderiv->ABCD[118] = int_stack + 10125;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+83259,int_stack+14175,int_stack+13500,45);
     Libderiv->ABCD[117] = int_stack + 83259;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+12150,int_stack+15795,int_stack+15120,45);
     Libderiv->ABCD[116] = int_stack + 12150;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+14175,int_stack+85554,int_stack+16740,45);
     Libderiv->ABCD[107] = int_stack + 14175;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+110394,int_stack+18090,int_stack+17415,45);
     Libderiv->ABCD[106] = int_stack + 110394;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+16200,int_stack+19710,int_stack+19035,45);
     Libderiv->ABCD[105] = int_stack + 16200;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+18225,int_stack+86499,int_stack+20655,45);
     Libderiv->ABCD[104] = int_stack + 18225;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+85284,int_stack+22005,int_stack+21330,45);
     Libderiv->ABCD[103] = int_stack + 85284;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+20250,int_stack+23625,int_stack+22950,45);
     Libderiv->ABCD[95] = int_stack + 20250;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+22275,int_stack+25245,int_stack+24570,45);
     Libderiv->ABCD[94] = int_stack + 22275;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+112419,int_stack+87444,int_stack+26190,45);
     Libderiv->ABCD[93] = int_stack + 112419;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+24300,int_stack+27540,int_stack+26865,45);
     Libderiv->ABCD[92] = int_stack + 24300;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+26325,int_stack+29160,int_stack+28485,45);
     Libderiv->ABCD[91] = int_stack + 26325;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+114444,int_stack+30780,int_stack+30105,45);
     Libderiv->ABCD[90] = int_stack + 114444;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+28350,int_stack+32400,int_stack+31725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[47] = int_stack + 28350;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+30375,int_stack+34020,int_stack+33345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[46] = int_stack + 30375;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+32400,int_stack+35640,int_stack+34965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[45] = int_stack + 32400;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+34425,int_stack+88389,int_stack+36585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[44] = int_stack + 34425;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+87309,int_stack+37935,int_stack+37260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[43] = int_stack + 87309;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+36450,int_stack+39555,int_stack+38880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[42] = int_stack + 36450;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+38475,int_stack+41175,int_stack+40500, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+78534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[38] = int_stack + 38475;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+116469,int_stack+89334,int_stack+42120, 0.0, zero_stack, 1.0, int_stack+70839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[35] = int_stack + 116469;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+40500,int_stack+43470,int_stack+42795, 0.0, zero_stack, 1.0, int_stack+72459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[34] = int_stack + 40500;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+118494,int_stack+45090,int_stack+44415, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[33] = int_stack + 118494;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+42525,int_stack+90279,int_stack+46035, 0.0, zero_stack, 1.0, int_stack+75024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[32] = int_stack + 42525;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+44550,int_stack+47385,int_stack+46710, 0.0, zero_stack, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[31] = int_stack + 44550;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+120519,int_stack+49005,int_stack+48330, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[30] = int_stack + 120519;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+46575,int_stack+50625,int_stack+49950, 0.0, zero_stack, 1.0, int_stack+78534, 1.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[26] = int_stack + 46575;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+48600,int_stack+91224,int_stack+51570, 0.0, zero_stack, 2.0, int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[25] = int_stack + 48600;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+89334,int_stack+52920,int_stack+52245, 1.0, int_stack+70839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[23] = int_stack + 89334;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+50625,int_stack+54540,int_stack+53865, 1.0, int_stack+72459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[22] = int_stack + 50625;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+52650,int_stack+56160,int_stack+55485, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[21] = int_stack + 52650;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+54675,int_stack+57780,int_stack+57105, 1.0, int_stack+75024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[20] = int_stack + 54675;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+56700,int_stack+59400,int_stack+58725, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[19] = int_stack + 56700;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+68850,int_stack+61020,int_stack+60345, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[18] = int_stack + 68850;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+58725,int_stack+62640,int_stack+61965, 1.0, int_stack+78534, 0.0, zero_stack, 1.0, int_stack+3375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[14] = int_stack + 58725;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+60750,int_stack+64260,int_stack+63585, 1.0, int_stack+2700, 1.0, int_stack+3375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[13] = int_stack + 60750;
 /*--- compute (gp|gp) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+62775,int_stack+65880,int_stack+65205, 2.0, int_stack+3375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
     Libderiv->ABCD[12] = int_stack + 62775;

}
