/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hpgd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hp|gd) integrals */

void d12hrr_order_hpgd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][6][10] = int_stack + 784;
 Libderiv->deriv_classes[6][6][9] = int_stack + 1568;
 Libderiv->deriv_classes[6][6][8] = int_stack + 2352;
 Libderiv->deriv_classes[6][6][7] = int_stack + 3136;
 Libderiv->dvrr_classes[6][5] = int_stack + 3920;
 Libderiv->deriv_classes[6][6][6] = int_stack + 4508;
 Libderiv->deriv_classes[6][6][2] = int_stack + 5292;
 Libderiv->deriv_classes[6][6][1] = int_stack + 6076;
 Libderiv->dvrr_classes[5][6] = int_stack + 6860;
 Libderiv->deriv_classes[6][6][0] = int_stack + 7448;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 8232;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 8547;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 8988;
 Libderiv->deriv2_classes[6][4][143] = int_stack + 9576;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 9996;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 10584;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 11368;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 11683;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 12124;
 Libderiv->deriv2_classes[6][4][131] = int_stack + 12712;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 13132;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 13720;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 14504;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 14819;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 15260;
 Libderiv->deriv2_classes[6][4][130] = int_stack + 15848;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 16268;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 16856;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 17640;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 17955;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 18396;
 Libderiv->deriv2_classes[6][4][119] = int_stack + 18984;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 19404;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 19992;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 20776;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 21091;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 21532;
 Libderiv->deriv2_classes[6][4][118] = int_stack + 22120;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 22540;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 23128;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 23912;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 24227;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 24668;
 Libderiv->deriv2_classes[6][4][117] = int_stack + 25256;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 25676;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 26264;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 27048;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 27363;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 27804;
 Libderiv->deriv2_classes[6][4][107] = int_stack + 28392;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 28812;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 29400;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 30184;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 30499;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 30940;
 Libderiv->deriv2_classes[6][4][106] = int_stack + 31528;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 31948;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 32536;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 33320;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 33635;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 34076;
 Libderiv->deriv2_classes[6][4][105] = int_stack + 34664;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 35084;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 35672;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 36456;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 36771;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 37212;
 Libderiv->deriv2_classes[6][4][104] = int_stack + 37800;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 38220;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 38808;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 39592;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 39907;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 40348;
 Libderiv->deriv2_classes[6][4][95] = int_stack + 40936;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 41356;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 41944;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 42728;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 43043;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 43484;
 Libderiv->deriv2_classes[6][4][94] = int_stack + 44072;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 44492;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 45080;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 45864;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 46179;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 46620;
 Libderiv->deriv2_classes[6][4][93] = int_stack + 47208;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 47628;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 48216;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 49000;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 49315;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 49756;
 Libderiv->deriv2_classes[6][4][92] = int_stack + 50344;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 50764;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 51352;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 52136;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 52451;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 52892;
 Libderiv->deriv2_classes[6][4][91] = int_stack + 53480;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 53900;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 54488;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 55272;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 55587;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 56028;
 Libderiv->deriv_classes[6][4][11] = int_stack + 56616;
 Libderiv->deriv2_classes[6][4][83] = int_stack + 57036;
 Libderiv->deriv_classes[6][5][11] = int_stack + 57456;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 58044;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 58632;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 59416;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 59731;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 60172;
 Libderiv->deriv_classes[6][4][10] = int_stack + 60760;
 Libderiv->deriv2_classes[6][4][82] = int_stack + 61180;
 Libderiv->deriv_classes[6][5][10] = int_stack + 61600;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 62188;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 62776;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 63560;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 63875;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 64316;
 Libderiv->deriv_classes[6][4][9] = int_stack + 64904;
 Libderiv->deriv2_classes[6][4][81] = int_stack + 65324;
 Libderiv->deriv_classes[6][5][9] = int_stack + 65744;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 66332;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 66920;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 67704;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 68019;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 68460;
 Libderiv->deriv_classes[6][4][8] = int_stack + 69048;
 Libderiv->deriv2_classes[6][4][80] = int_stack + 69468;
 Libderiv->deriv_classes[6][5][8] = int_stack + 69888;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 70476;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 71064;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 71848;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 72163;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 72604;
 Libderiv->deriv_classes[6][4][7] = int_stack + 73192;
 Libderiv->deriv2_classes[6][4][79] = int_stack + 73612;
 Libderiv->deriv_classes[6][5][7] = int_stack + 74032;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 74620;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 75208;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 75992;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 76307;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 76748;
 Libderiv->dvrr_classes[6][4] = int_stack + 77336;
 Libderiv->deriv_classes[6][4][6] = int_stack + 77756;
 Libderiv->deriv2_classes[6][4][78] = int_stack + 78176;
 Libderiv->deriv_classes[6][5][6] = int_stack + 78596;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 79184;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 79772;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 80556;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 80871;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 81312;
 Libderiv->deriv2_classes[6][4][35] = int_stack + 81900;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 82320;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 82908;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 83692;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 84007;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 84448;
 Libderiv->deriv2_classes[6][4][34] = int_stack + 85036;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 85456;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 86044;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 86828;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 87143;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 87584;
 Libderiv->deriv2_classes[6][4][33] = int_stack + 88172;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 88592;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 89180;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 89964;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 90279;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 90720;
 Libderiv->deriv2_classes[6][4][32] = int_stack + 91308;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 91728;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 92316;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 93100;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 93415;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 93856;
 Libderiv->deriv2_classes[6][4][31] = int_stack + 94444;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 94864;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 95452;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 96236;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 96551;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 96992;
 Libderiv->deriv_classes[6][4][2] = int_stack + 97580;
 Libderiv->deriv2_classes[6][4][30] = int_stack + 98000;
 Libderiv->deriv_classes[6][5][2] = int_stack + 98420;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 99008;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 99596;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 100380;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 100695;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 101136;
 Libderiv->deriv2_classes[6][4][26] = int_stack + 101724;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 102144;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 102732;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 103516;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 103831;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 104272;
 Libderiv->deriv2_classes[6][4][23] = int_stack + 104860;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 105280;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 105868;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 106652;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 106967;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 107408;
 Libderiv->deriv2_classes[6][4][22] = int_stack + 107996;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 108416;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 109004;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 109788;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 110103;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 110544;
 Libderiv->deriv2_classes[6][4][21] = int_stack + 111132;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 111552;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 112140;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 112924;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 113239;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 113680;
 Libderiv->deriv2_classes[6][4][20] = int_stack + 114268;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 114688;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 115276;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 116060;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 116375;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 116816;
 Libderiv->deriv2_classes[6][4][19] = int_stack + 117404;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 117824;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 118412;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 119196;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 119511;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 119952;
 Libderiv->deriv_classes[6][4][1] = int_stack + 120540;
 Libderiv->deriv2_classes[6][4][18] = int_stack + 120960;
 Libderiv->deriv_classes[6][5][1] = int_stack + 121380;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 121968;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 122556;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 123340;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 123655;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 124096;
 Libderiv->deriv2_classes[6][4][14] = int_stack + 124684;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 125104;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 125692;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 126476;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 126791;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 127232;
 Libderiv->deriv2_classes[6][4][13] = int_stack + 127820;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 128240;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 128828;
 Libderiv->deriv_classes[5][4][11] = int_stack + 129612;
 Libderiv->deriv_classes[5][5][11] = int_stack + 129927;
 Libderiv->deriv_classes[5][6][11] = int_stack + 130368;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 130956;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 131271;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 131712;
 Libderiv->deriv2_classes[6][4][11] = int_stack + 132300;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 132720;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 133308;
 Libderiv->deriv_classes[5][4][10] = int_stack + 134092;
 Libderiv->deriv_classes[5][5][10] = int_stack + 134407;
 Libderiv->deriv_classes[5][6][10] = int_stack + 134848;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 135436;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 135751;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 136192;
 Libderiv->deriv2_classes[6][4][10] = int_stack + 136780;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 137200;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 137788;
 Libderiv->deriv_classes[5][4][9] = int_stack + 138572;
 Libderiv->deriv_classes[5][5][9] = int_stack + 138887;
 Libderiv->deriv_classes[5][6][9] = int_stack + 139328;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 139916;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 140231;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 140672;
 Libderiv->deriv2_classes[6][4][9] = int_stack + 141260;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 141680;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 142268;
 Libderiv->deriv_classes[5][4][8] = int_stack + 143052;
 Libderiv->deriv_classes[5][5][8] = int_stack + 143367;
 Libderiv->deriv_classes[5][6][8] = int_stack + 143808;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 144396;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 144711;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 145152;
 Libderiv->deriv2_classes[6][4][8] = int_stack + 145740;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 146160;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 146748;
 Libderiv->deriv_classes[5][4][7] = int_stack + 147532;
 Libderiv->deriv_classes[5][5][7] = int_stack + 147847;
 Libderiv->deriv_classes[5][6][7] = int_stack + 148288;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 148876;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 149191;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 149632;
 Libderiv->deriv2_classes[6][4][7] = int_stack + 150220;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 150640;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 151228;
 Libderiv->dvrr_classes[5][4] = int_stack + 152012;
 Libderiv->deriv_classes[5][4][6] = int_stack + 152327;
 Libderiv->dvrr_classes[5][5] = int_stack + 152642;
 Libderiv->deriv_classes[5][5][6] = int_stack + 153083;
 Libderiv->deriv_classes[5][6][6] = int_stack + 153524;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 154112;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 154427;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 154868;
 Libderiv->deriv_classes[6][4][0] = int_stack + 155456;
 Libderiv->deriv2_classes[6][4][6] = int_stack + 155876;
 Libderiv->deriv_classes[6][5][0] = int_stack + 156296;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 156884;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 157472;
 Libderiv->deriv_classes[5][4][2] = int_stack + 158256;
 Libderiv->deriv_classes[5][5][2] = int_stack + 158571;
 Libderiv->deriv_classes[5][6][2] = int_stack + 159012;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 159600;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 159915;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 160356;
 Libderiv->deriv2_classes[6][4][2] = int_stack + 160944;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 161364;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 161952;
 Libderiv->deriv_classes[5][4][1] = int_stack + 162736;
 Libderiv->deriv_classes[5][5][1] = int_stack + 163051;
 Libderiv->deriv_classes[5][6][1] = int_stack + 163492;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 164080;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 164395;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 164836;
 Libderiv->deriv2_classes[6][4][1] = int_stack + 165424;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 165844;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 166432;
 Libderiv->deriv_classes[5][4][0] = int_stack + 167216;
 Libderiv->deriv_classes[5][5][0] = int_stack + 167531;
 Libderiv->deriv_classes[5][6][0] = int_stack + 167972;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 168560;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 168875;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 169316;
 Libderiv->deriv2_classes[6][4][0] = int_stack + 169904;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 170324;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 170912;
 memset(int_stack,0,1373568);

 Libderiv->dvrr_stack = int_stack + 361011;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hpgd(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+152642,int_stack+152012,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+129927,int_stack+129612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152012,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+173586,int_stack+130368,int_stack+129927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152642,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+174909,int_stack+173586,int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+173586,int_stack+3920,int_stack+77336,28);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+176799,int_stack+57456,int_stack+56616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77336,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+178059,int_stack+0,int_stack+57456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+179823,int_stack+178059,int_stack+176799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+178059,int_stack+134407,int_stack+134092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152012, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+182343,int_stack+134848,int_stack+134407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152642, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+183666,int_stack+182343,int_stack+178059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+182343,int_stack+61600,int_stack+60760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77336, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+185556,int_stack+784,int_stack+61600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+187320,int_stack+185556,int_stack+182343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+185556,int_stack+138887,int_stack+138572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152012, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+139328,int_stack+138887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152642, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+189840,int_stack+0,int_stack+185556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+65744,int_stack+64904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77336, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+191730,int_stack+1568,int_stack+65744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+193494,int_stack+191730,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+191730,int_stack+143367,int_stack+143052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+143808,int_stack+143367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+197337,int_stack+196014,int_stack+191730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+69888,int_stack+69048, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+199227,int_stack+2352,int_stack+69888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+200991,int_stack+199227,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+199227,int_stack+147847,int_stack+147532, 0.0, zero_stack, 1.0, int_stack+152012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1260,int_stack+148288,int_stack+147847, 0.0, zero_stack, 1.0, int_stack+152642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+203511,int_stack+1260,int_stack+199227, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1260,int_stack+74032,int_stack+73192, 0.0, zero_stack, 1.0, int_stack+77336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+3136,int_stack+74032, 0.0, zero_stack, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+207165,int_stack+205401,int_stack+1260, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+205401,int_stack+153083,int_stack+152327, 1.0, int_stack+152012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2520,int_stack+153524,int_stack+153083, 1.0, int_stack+152642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+209685,int_stack+2520,int_stack+205401, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2520,int_stack+78596,int_stack+77756, 1.0, int_stack+77336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+4508,int_stack+78596, 1.0, int_stack+3920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+213339,int_stack+211575,int_stack+2520, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+173586,int_stack+6860,int_stack+152642,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+215859,int_stack+173586,int_stack+171696,21);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+158571,int_stack+158256,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+173586,int_stack+159012,int_stack+158571,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+217749,int_stack+173586,int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+173586,int_stack+98420,int_stack+97580,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+5292,int_stack+98420,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+219639,int_stack+211575,int_stack+173586,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+211575,int_stack+163051,int_stack+162736,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+163492,int_stack+163051,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+222159,int_stack+3780,int_stack+211575,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+121380,int_stack+120540,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+224049,int_stack+6076,int_stack+121380,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+225813,int_stack+224049,int_stack+3780,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+224049,int_stack+167531,int_stack+167216,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5040,int_stack+167972,int_stack+167531,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+228333,int_stack+5040,int_stack+224049,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+5040,int_stack+156296,int_stack+155456,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+230223,int_stack+7448,int_stack+156296,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+231987,int_stack+230223,int_stack+5040,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+8547,int_stack+8232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+129612,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+8988,int_stack+8547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+129927,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+7623,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+172641,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+9996,int_stack+9576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+56616,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+10584,int_stack+9996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+57456,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+236271,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+176799,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+11683,int_stack+11368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129612, 1.0, int_stack+134092,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+12124,int_stack+11683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129927, 1.0, int_stack+134407,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+9513,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172641, 1.0, int_stack+178059,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+13132,int_stack+12712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56616, 1.0, int_stack+60760,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+13720,int_stack+13132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57456, 1.0, int_stack+61600,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+11403,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176799, 1.0, int_stack+182343,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+14819,int_stack+14504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+134092, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+15260,int_stack+14819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+134407, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13923,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+178059, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+16268,int_stack+15848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+60760, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+16856,int_stack+16268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+61600, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+238791,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+182343, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+17955,int_stack+17640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129612, 0.0, zero_stack, 1.0, int_stack+138572,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+18396,int_stack+17955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129927, 0.0, zero_stack, 1.0, int_stack+138887,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+15813,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172641, 0.0, zero_stack, 1.0, int_stack+185556,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+19404,int_stack+18984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56616, 0.0, zero_stack, 1.0, int_stack+64904,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+19992,int_stack+19404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57456, 0.0, zero_stack, 1.0, int_stack+65744,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17703,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176799, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+21091,int_stack+20776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134092, 1.0, int_stack+138572, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+21532,int_stack+21091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134407, 1.0, int_stack+138887, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+20223,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178059, 1.0, int_stack+185556, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+22540,int_stack+22120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60760, 1.0, int_stack+64904, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+23128,int_stack+22540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61600, 1.0, int_stack+65744, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+241311,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182343, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+24227,int_stack+23912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+138572, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+24668,int_stack+24227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+138887, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22113,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+185556, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+25676,int_stack+25256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+64904, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+26264,int_stack+25676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+65744, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+24003,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+27363,int_stack+27048, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143052,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+27804,int_stack+27363, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143367,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+243831,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191730,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+28812,int_stack+28392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69048,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+29400,int_stack+28812, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69888,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26523,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+176799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196014,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+30499,int_stack+30184, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134092, 0.0, zero_stack, 1.0, int_stack+143052, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+30940,int_stack+30499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134407, 0.0, zero_stack, 1.0, int_stack+143367, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29043,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178059, 0.0, zero_stack, 1.0, int_stack+191730, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+31948,int_stack+31528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60760, 0.0, zero_stack, 1.0, int_stack+69048, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+32536,int_stack+31948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61600, 0.0, zero_stack, 1.0, int_stack+69888, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+245721,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182343, 0.0, zero_stack, 1.0, int_stack+196014, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+33635,int_stack+33320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138572, 1.0, int_stack+143052, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+34076,int_stack+33635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138887, 1.0, int_stack+143367, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30933,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185556, 1.0, int_stack+191730, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+35084,int_stack+34664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64904, 1.0, int_stack+69048, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+35672,int_stack+35084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65744, 1.0, int_stack+69888, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+32823,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+196014, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+36771,int_stack+36456, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+143052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+37212,int_stack+36771, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+143367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+35343,int_stack+6300,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+191730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+38220,int_stack+37800, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+69048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+38808,int_stack+38220, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+69888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+248241,int_stack+234507,int_stack+230223, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+39907,int_stack+39592, 0.0, zero_stack, 1.0, int_stack+129612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147532,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+40348,int_stack+39907, 0.0, zero_stack, 1.0, int_stack+129927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147847,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37233,int_stack+6300,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199227,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+41356,int_stack+40936, 0.0, zero_stack, 1.0, int_stack+56616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73192,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+41944,int_stack+41356, 0.0, zero_stack, 1.0, int_stack+57456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74032,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39123,int_stack+234507,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+176799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+43043,int_stack+42728, 0.0, zero_stack, 1.0, int_stack+134092, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147532, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+43484,int_stack+43043, 0.0, zero_stack, 1.0, int_stack+134407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147847, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+41643,int_stack+6300,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+178059, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199227, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+44492,int_stack+44072, 0.0, zero_stack, 1.0, int_stack+60760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73192, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+45080,int_stack+44492, 0.0, zero_stack, 1.0, int_stack+61600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74032, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+250761,int_stack+234507,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+182343, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+46179,int_stack+45864, 0.0, zero_stack, 1.0, int_stack+138572, 0.0, zero_stack, 1.0, int_stack+147532, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+46620,int_stack+46179, 0.0, zero_stack, 1.0, int_stack+138887, 0.0, zero_stack, 1.0, int_stack+147847, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+43533,int_stack+6300,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+185556, 0.0, zero_stack, 1.0, int_stack+199227, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+47628,int_stack+47208, 0.0, zero_stack, 1.0, int_stack+64904, 0.0, zero_stack, 1.0, int_stack+73192, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+48216,int_stack+47628, 0.0, zero_stack, 1.0, int_stack+65744, 0.0, zero_stack, 1.0, int_stack+74032, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+45423,int_stack+234507,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+49315,int_stack+49000, 0.0, zero_stack, 1.0, int_stack+143052, 1.0, int_stack+147532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+49756,int_stack+49315, 0.0, zero_stack, 1.0, int_stack+143367, 1.0, int_stack+147847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+47943,int_stack+6300,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+191730, 1.0, int_stack+199227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+50764,int_stack+50344, 0.0, zero_stack, 1.0, int_stack+69048, 1.0, int_stack+73192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+51352,int_stack+50764, 0.0, zero_stack, 1.0, int_stack+69888, 1.0, int_stack+74032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+253281,int_stack+234507,int_stack+230223, 0.0, zero_stack, 1.0, int_stack+196014, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+52451,int_stack+52136, 0.0, zero_stack, 2.0, int_stack+147532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+52892,int_stack+52451, 0.0, zero_stack, 2.0, int_stack+147847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49833,int_stack+6300,int_stack+230223, 0.0, zero_stack, 2.0, int_stack+199227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+53900,int_stack+53480, 0.0, zero_stack, 2.0, int_stack+73192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+54488,int_stack+53900, 0.0, zero_stack, 2.0, int_stack+74032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+51723,int_stack+234507,int_stack+230223, 0.0, zero_stack, 2.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+55587,int_stack+55272, 1.0, int_stack+129612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152327,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+56028,int_stack+55587, 1.0, int_stack+129927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153083,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54243,int_stack+6300,int_stack+230223, 1.0, int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205401,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+230223,int_stack+58044,int_stack+57036, 1.0, int_stack+56616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77756,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234507,int_stack+58632,int_stack+58044, 1.0, int_stack+57456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78596,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56133,int_stack+234507,int_stack+230223, 1.0, int_stack+176799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+59731,int_stack+59416, 1.0, int_stack+134092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152327, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6300,int_stack+60172,int_stack+59731, 1.0, int_stack+134407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153083, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+58653,int_stack+6300,int_stack+172641, 1.0, int_stack+178059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205401, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+6300,int_stack+62188,int_stack+61180, 1.0, int_stack+60760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77756, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+230223,int_stack+62776,int_stack+62188, 1.0, int_stack+61600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78596, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+176799,int_stack+230223,int_stack+6300, 1.0, int_stack+182343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+63875,int_stack+63560, 1.0, int_stack+138572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152327, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+182343,int_stack+64316,int_stack+63875, 1.0, int_stack+138887, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153083, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+60543,int_stack+182343,int_stack+172641, 1.0, int_stack+185556, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205401, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+185556,int_stack+66332,int_stack+65324, 1.0, int_stack+64904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77756, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+230223,int_stack+66920,int_stack+66332, 1.0, int_stack+65744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78596, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+62433,int_stack+230223,int_stack+185556, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+68019,int_stack+67704, 1.0, int_stack+143052, 0.0, zero_stack, 1.0, int_stack+152327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+182343,int_stack+68460,int_stack+68019, 1.0, int_stack+143367, 0.0, zero_stack, 1.0, int_stack+153083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+64953,int_stack+182343,int_stack+172641, 1.0, int_stack+191730, 0.0, zero_stack, 1.0, int_stack+205401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+70476,int_stack+69468, 1.0, int_stack+69048, 0.0, zero_stack, 1.0, int_stack+77756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+191730,int_stack+71064,int_stack+70476, 1.0, int_stack+69888, 0.0, zero_stack, 1.0, int_stack+78596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+66843,int_stack+191730,int_stack+0, 1.0, int_stack+196014, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+72163,int_stack+71848, 1.0, int_stack+147532, 1.0, int_stack+152327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+72604,int_stack+72163, 1.0, int_stack+147847, 1.0, int_stack+153083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+69363,int_stack+196014,int_stack+172641, 1.0, int_stack+199227, 1.0, int_stack+205401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+74620,int_stack+73612, 1.0, int_stack+73192, 1.0, int_stack+77756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+199227,int_stack+75208,int_stack+74620, 1.0, int_stack+74032, 1.0, int_stack+78596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+71253,int_stack+199227,int_stack+0, 1.0, int_stack+1260, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+76307,int_stack+75992, 2.0, int_stack+152327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+76748,int_stack+76307, 2.0, int_stack+153083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+196014,int_stack+172641, 2.0, int_stack+205401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+205401,int_stack+79184,int_stack+78176, 2.0, int_stack+77756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+199227,int_stack+79772,int_stack+79184, 2.0, int_stack+78596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+73773,int_stack+199227,int_stack+205401, 2.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+80871,int_stack+80556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158256,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+81312,int_stack+80871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158571,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1890,int_stack+196014,int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+82320,int_stack+81900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97580,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+82908,int_stack+82320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98420,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+76293,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+84007,int_stack+83692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158256, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+84448,int_stack+84007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158571, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+78813,int_stack+196014,int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+85456,int_stack+85036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97580, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+86044,int_stack+85456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98420, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+80703,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+87143,int_stack+86828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158256, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+87584,int_stack+87143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158571, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+83223,int_stack+196014,int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+88592,int_stack+88172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97580, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+89180,int_stack+88592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98420, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+85113,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+90279,int_stack+89964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+90720,int_stack+90279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+87633,int_stack+196014,int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+91728,int_stack+91308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+92316,int_stack+91728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+89523,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+93415,int_stack+93100, 0.0, zero_stack, 1.0, int_stack+158256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+93856,int_stack+93415, 0.0, zero_stack, 1.0, int_stack+158571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+92043,int_stack+196014,int_stack+172641, 0.0, zero_stack, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+94864,int_stack+94444, 0.0, zero_stack, 1.0, int_stack+97580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+95452,int_stack+94864, 0.0, zero_stack, 1.0, int_stack+98420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+255801,int_stack+205401,int_stack+196014, 0.0, zero_stack, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+172641,int_stack+96551,int_stack+96236, 1.0, int_stack+158256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+96992,int_stack+96551, 1.0, int_stack+158571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+93933,int_stack+196014,int_stack+172641, 1.0, int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+99008,int_stack+98000, 1.0, int_stack+97580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+99596,int_stack+99008, 1.0, int_stack+98420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+95823,int_stack+205401,int_stack+171696, 1.0, int_stack+173586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+100695,int_stack+100380,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+101136,int_stack+100695,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+172641,int_stack+196014,int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+102144,int_stack+101724,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+102732,int_stack+102144,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+98343,int_stack+205401,int_stack+196014,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+103831,int_stack+103516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162736,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+104272,int_stack+103831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163051,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+100863,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211575,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+105280,int_stack+104860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120540,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+105868,int_stack+105280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+102753,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+106967,int_stack+106652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162736, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+107408,int_stack+106967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163051, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+105273,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211575, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+108416,int_stack+107996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120540, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+109004,int_stack+108416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+107163,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+110103,int_stack+109788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162736, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+110544,int_stack+110103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163051, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+152012,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211575, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+111552,int_stack+111132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120540, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+112140,int_stack+111552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+109683,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+113239,int_stack+112924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+113680,int_stack+113239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+112203,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+114688,int_stack+114268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+115276,int_stack+114688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+258321,int_stack+205401,int_stack+196014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+116375,int_stack+116060, 0.0, zero_stack, 1.0, int_stack+162736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+116816,int_stack+116375, 0.0, zero_stack, 1.0, int_stack+163051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+114093,int_stack+196014,int_stack+171696, 0.0, zero_stack, 1.0, int_stack+211575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+117824,int_stack+117404, 0.0, zero_stack, 1.0, int_stack+120540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+118412,int_stack+117824, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+115983,int_stack+205401,int_stack+196014, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+119511,int_stack+119196, 1.0, int_stack+162736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+119952,int_stack+119511, 1.0, int_stack+163051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+118503,int_stack+196014,int_stack+171696, 1.0, int_stack+211575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+211575,int_stack+121968,int_stack+120960, 1.0, int_stack+120540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+205401,int_stack+122556,int_stack+121968, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+120393,int_stack+205401,int_stack+211575, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+123655,int_stack+123340,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+124096,int_stack+123655,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+260841,int_stack+196014,int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+125104,int_stack+124684,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+125692,int_stack+125104,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+122913,int_stack+211575,int_stack+3780,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+126791,int_stack+126476,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+127232,int_stack+126791,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+125433,int_stack+196014,int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+128240,int_stack+127820,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+128828,int_stack+128240,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+127323,int_stack+211575,int_stack+3780,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+131271,int_stack+130956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167216,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+131712,int_stack+131271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167531,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+129843,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224049,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+132720,int_stack+132300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155456,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+133308,int_stack+132720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+131733,int_stack+211575,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+135751,int_stack+135436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167216, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+136192,int_stack+135751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167531, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+134253,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224049, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+137200,int_stack+136780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155456, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+137788,int_stack+137200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+136143,int_stack+211575,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+140231,int_stack+139916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167216, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+140672,int_stack+140231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167531, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+138663,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224049, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+141680,int_stack+141260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155456, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+142268,int_stack+141680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+140553,int_stack+211575,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+144711,int_stack+144396, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+145152,int_stack+144711, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+143073,int_stack+196014,int_stack+171696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+146160,int_stack+145740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+146748,int_stack+146160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+144963,int_stack+211575,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+149191,int_stack+148876, 0.0, zero_stack, 1.0, int_stack+167216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+149632,int_stack+149191, 0.0, zero_stack, 1.0, int_stack+167531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+147483,int_stack+196014,int_stack+171696, 0.0, zero_stack, 1.0, int_stack+224049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+150640,int_stack+150220, 0.0, zero_stack, 1.0, int_stack+155456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+211575,int_stack+151228,int_stack+150640, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+149373,int_stack+211575,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+154427,int_stack+154112, 1.0, int_stack+167216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+154868,int_stack+154427, 1.0, int_stack+167531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+262731,int_stack+196014,int_stack+171696, 1.0, int_stack+224049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3780,int_stack+156884,int_stack+155876, 1.0, int_stack+155456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+224049,int_stack+157472,int_stack+156884, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+153902,int_stack+224049,int_stack+3780, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+159915,int_stack+159600,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+160356,int_stack+159915,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+3780,int_stack+196014,int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+161364,int_stack+160944,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+224049,int_stack+161952,int_stack+161364,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+156422,int_stack+224049,int_stack+196014,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+164395,int_stack+164080,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+164836,int_stack+164395,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+5670,int_stack+196014,int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+165844,int_stack+165424,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+224049,int_stack+166432,int_stack+165844,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+158942,int_stack+224049,int_stack+196014,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171696,int_stack+168875,int_stack+168560,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196014,int_stack+169316,int_stack+168875,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+161462,int_stack+196014,int_stack+171696,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+196014,int_stack+170324,int_stack+169904,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+224049,int_stack+170912,int_stack+170324,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+163352,int_stack+224049,int_stack+196014,28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+165872,int_stack+179823,int_stack+174909,90);
     Libderiv->ABCD[11] = int_stack + 165872;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+264621,int_stack+187320,int_stack+183666,90);
     Libderiv->ABCD[10] = int_stack + 264621;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+270291,int_stack+193494,int_stack+189840,90);
     Libderiv->ABCD[9] = int_stack + 270291;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+275961,int_stack+200991,int_stack+197337,90);
     Libderiv->ABCD[8] = int_stack + 275961;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+281631,int_stack+207165,int_stack+203511,90);
     Libderiv->ABCD[7] = int_stack + 281631;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+287301,int_stack+213339,int_stack+209685,90);
     Libderiv->ABCD[6] = int_stack + 287301;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+292971,int_stack+219639,int_stack+217749, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[2] = int_stack + 292971;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+298641,int_stack+225813,int_stack+222159, 0.0, zero_stack, 1.0, int_stack+215859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[1] = int_stack + 298641;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+304311,int_stack+231987,int_stack+228333, 1.0, int_stack+215859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[0] = int_stack + 304311;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+211575,int_stack+236271,int_stack+7623,90);
     Libderiv->ABCD[155] = int_stack + 211575;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+230223,int_stack+11403,int_stack+9513,90);
     Libderiv->ABCD[143] = int_stack + 230223;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7560,int_stack+238791,int_stack+13923,90);
     Libderiv->ABCD[142] = int_stack + 7560;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+309981,int_stack+17703,int_stack+15813,90);
     Libderiv->ABCD[131] = int_stack + 309981;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+13230,int_stack+241311,int_stack+20223,90);
     Libderiv->ABCD[130] = int_stack + 13230;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+235893,int_stack+24003,int_stack+22113,90);
     Libderiv->ABCD[129] = int_stack + 235893;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+18900,int_stack+26523,int_stack+243831,90);
     Libderiv->ABCD[119] = int_stack + 18900;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+315651,int_stack+245721,int_stack+29043,90);
     Libderiv->ABCD[118] = int_stack + 315651;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+24570,int_stack+32823,int_stack+30933,90);
     Libderiv->ABCD[117] = int_stack + 24570;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+241563,int_stack+248241,int_stack+35343,90);
     Libderiv->ABCD[116] = int_stack + 241563;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+30240,int_stack+39123,int_stack+37233,90);
     Libderiv->ABCD[107] = int_stack + 30240;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+35910,int_stack+250761,int_stack+41643,90);
     Libderiv->ABCD[106] = int_stack + 35910;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+247233,int_stack+45423,int_stack+43533,90);
     Libderiv->ABCD[105] = int_stack + 247233;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+41580,int_stack+253281,int_stack+47943,90);
     Libderiv->ABCD[104] = int_stack + 41580;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+321321,int_stack+51723,int_stack+49833,90);
     Libderiv->ABCD[103] = int_stack + 321321;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+47250,int_stack+56133,int_stack+54243,90);
     Libderiv->ABCD[95] = int_stack + 47250;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+52920,int_stack+176799,int_stack+58653,90);
     Libderiv->ABCD[94] = int_stack + 52920;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+176799,int_stack+62433,int_stack+60543,90);
     Libderiv->ABCD[93] = int_stack + 176799;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+58590,int_stack+66843,int_stack+64953,90);
     Libderiv->ABCD[92] = int_stack + 58590;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+326991,int_stack+71253,int_stack+69363,90);
     Libderiv->ABCD[91] = int_stack + 326991;
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+64260,int_stack+73773,int_stack+0,90);
     Libderiv->ABCD[90] = int_stack + 64260;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+69930,int_stack+76293,int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[47] = int_stack + 69930;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+332661,int_stack+80703,int_stack+78813, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[46] = int_stack + 332661;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+75600,int_stack+85113,int_stack+83223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[45] = int_stack + 75600;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+81270,int_stack+89523,int_stack+87633, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[44] = int_stack + 81270;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+338331,int_stack+255801,int_stack+92043, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[43] = int_stack + 338331;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+86940,int_stack+95823,int_stack+93933, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[42] = int_stack + 86940;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+92610,int_stack+98343,int_stack+172641, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+217749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[38] = int_stack + 92610;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+344001,int_stack+102753,int_stack+100863, 0.0, zero_stack, 1.0, int_stack+174909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[35] = int_stack + 344001;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+98280,int_stack+107163,int_stack+105273, 0.0, zero_stack, 1.0, int_stack+183666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[34] = int_stack + 98280;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+103950,int_stack+109683,int_stack+152012, 0.0, zero_stack, 1.0, int_stack+189840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[33] = int_stack + 103950;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+349671,int_stack+258321,int_stack+112203, 0.0, zero_stack, 1.0, int_stack+197337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[32] = int_stack + 349671;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+252903,int_stack+115983,int_stack+114093, 0.0, zero_stack, 1.0, int_stack+203511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[31] = int_stack + 252903;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+109620,int_stack+120393,int_stack+118503, 0.0, zero_stack, 1.0, int_stack+209685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[30] = int_stack + 109620;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+115290,int_stack+122913,int_stack+260841, 0.0, zero_stack, 1.0, int_stack+217749, 1.0, int_stack+222159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[26] = int_stack + 115290;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+355341,int_stack+127323,int_stack+125433, 0.0, zero_stack, 2.0, int_stack+222159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[25] = int_stack + 355341;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+120960,int_stack+131733,int_stack+129843, 1.0, int_stack+174909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[23] = int_stack + 120960;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+126630,int_stack+136143,int_stack+134253, 1.0, int_stack+183666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[22] = int_stack + 126630;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+182469,int_stack+140553,int_stack+138663, 1.0, int_stack+189840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[21] = int_stack + 182469;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+188139,int_stack+144963,int_stack+143073, 1.0, int_stack+197337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[20] = int_stack + 188139;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+193809,int_stack+149373,int_stack+147483, 1.0, int_stack+203511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[19] = int_stack + 193809;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+199479,int_stack+153902,int_stack+262731, 1.0, int_stack+209685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[18] = int_stack + 199479;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+205149,int_stack+156422,int_stack+3780, 1.0, int_stack+217749, 0.0, zero_stack, 1.0, int_stack+228333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[14] = int_stack + 205149;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+158942,int_stack+5670, 1.0, int_stack+222159, 1.0, int_stack+228333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[13] = int_stack + 0;
 /*--- compute (hp|gd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+132300,int_stack+163352,int_stack+161462, 2.0, int_stack+228333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[12] = int_stack + 132300;

}
