/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ddhf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dd|hf) integrals */

void d1hrr_order_ddhf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][5][11] = int_stack + 0;
 Libderiv->deriv_classes[2][6][11] = int_stack + 126;
 Libderiv->deriv_classes[2][7][11] = int_stack + 294;
 Libderiv->deriv_classes[2][8][11] = int_stack + 510;
 Libderiv->deriv_classes[3][5][11] = int_stack + 780;
 Libderiv->deriv_classes[3][6][11] = int_stack + 990;
 Libderiv->deriv_classes[3][7][11] = int_stack + 1270;
 Libderiv->deriv_classes[3][8][11] = int_stack + 1630;
 Libderiv->deriv_classes[4][5][11] = int_stack + 2080;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2395;
 Libderiv->deriv_classes[4][7][11] = int_stack + 2815;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3355;
 Libderiv->deriv_classes[2][5][10] = int_stack + 4030;
 Libderiv->deriv_classes[2][6][10] = int_stack + 4156;
 Libderiv->deriv_classes[2][7][10] = int_stack + 4324;
 Libderiv->deriv_classes[2][8][10] = int_stack + 4540;
 Libderiv->deriv_classes[3][5][10] = int_stack + 4810;
 Libderiv->deriv_classes[3][6][10] = int_stack + 5020;
 Libderiv->deriv_classes[3][7][10] = int_stack + 5300;
 Libderiv->deriv_classes[3][8][10] = int_stack + 5660;
 Libderiv->deriv_classes[4][5][10] = int_stack + 6110;
 Libderiv->deriv_classes[4][6][10] = int_stack + 6425;
 Libderiv->deriv_classes[4][7][10] = int_stack + 6845;
 Libderiv->deriv_classes[4][8][10] = int_stack + 7385;
 Libderiv->deriv_classes[2][5][9] = int_stack + 8060;
 Libderiv->deriv_classes[2][6][9] = int_stack + 8186;
 Libderiv->deriv_classes[2][7][9] = int_stack + 8354;
 Libderiv->deriv_classes[2][8][9] = int_stack + 8570;
 Libderiv->deriv_classes[3][5][9] = int_stack + 8840;
 Libderiv->deriv_classes[3][6][9] = int_stack + 9050;
 Libderiv->deriv_classes[3][7][9] = int_stack + 9330;
 Libderiv->deriv_classes[3][8][9] = int_stack + 9690;
 Libderiv->deriv_classes[4][5][9] = int_stack + 10140;
 Libderiv->deriv_classes[4][6][9] = int_stack + 10455;
 Libderiv->deriv_classes[4][7][9] = int_stack + 10875;
 Libderiv->deriv_classes[4][8][9] = int_stack + 11415;
 Libderiv->deriv_classes[2][5][8] = int_stack + 12090;
 Libderiv->deriv_classes[2][6][8] = int_stack + 12216;
 Libderiv->deriv_classes[2][7][8] = int_stack + 12384;
 Libderiv->deriv_classes[2][8][8] = int_stack + 12600;
 Libderiv->deriv_classes[3][5][8] = int_stack + 12870;
 Libderiv->deriv_classes[3][6][8] = int_stack + 13080;
 Libderiv->deriv_classes[3][7][8] = int_stack + 13360;
 Libderiv->deriv_classes[3][8][8] = int_stack + 13720;
 Libderiv->deriv_classes[4][5][8] = int_stack + 14170;
 Libderiv->deriv_classes[4][6][8] = int_stack + 14485;
 Libderiv->deriv_classes[4][7][8] = int_stack + 14905;
 Libderiv->deriv_classes[4][8][8] = int_stack + 15445;
 Libderiv->deriv_classes[2][5][7] = int_stack + 16120;
 Libderiv->deriv_classes[2][6][7] = int_stack + 16246;
 Libderiv->deriv_classes[2][7][7] = int_stack + 16414;
 Libderiv->deriv_classes[2][8][7] = int_stack + 16630;
 Libderiv->deriv_classes[3][5][7] = int_stack + 16900;
 Libderiv->deriv_classes[3][6][7] = int_stack + 17110;
 Libderiv->deriv_classes[3][7][7] = int_stack + 17390;
 Libderiv->deriv_classes[3][8][7] = int_stack + 17750;
 Libderiv->deriv_classes[4][5][7] = int_stack + 18200;
 Libderiv->deriv_classes[4][6][7] = int_stack + 18515;
 Libderiv->deriv_classes[4][7][7] = int_stack + 18935;
 Libderiv->deriv_classes[4][8][7] = int_stack + 19475;
 Libderiv->deriv_classes[2][5][6] = int_stack + 20150;
 Libderiv->deriv_classes[2][6][6] = int_stack + 20276;
 Libderiv->deriv_classes[2][7][6] = int_stack + 20444;
 Libderiv->deriv_classes[2][8][6] = int_stack + 20660;
 Libderiv->deriv_classes[3][5][6] = int_stack + 20930;
 Libderiv->deriv_classes[3][6][6] = int_stack + 21140;
 Libderiv->deriv_classes[3][7][6] = int_stack + 21420;
 Libderiv->deriv_classes[3][8][6] = int_stack + 21780;
 Libderiv->dvrr_classes[4][5] = int_stack + 22230;
 Libderiv->deriv_classes[4][5][6] = int_stack + 22545;
 Libderiv->dvrr_classes[4][6] = int_stack + 22860;
 Libderiv->deriv_classes[4][6][6] = int_stack + 23280;
 Libderiv->dvrr_classes[4][7] = int_stack + 23700;
 Libderiv->deriv_classes[4][7][6] = int_stack + 24240;
 Libderiv->deriv_classes[4][8][6] = int_stack + 24780;
 Libderiv->deriv_classes[2][5][2] = int_stack + 25455;
 Libderiv->deriv_classes[2][6][2] = int_stack + 25581;
 Libderiv->deriv_classes[2][7][2] = int_stack + 25749;
 Libderiv->deriv_classes[2][8][2] = int_stack + 25965;
 Libderiv->deriv_classes[3][5][2] = int_stack + 26235;
 Libderiv->deriv_classes[3][6][2] = int_stack + 26445;
 Libderiv->deriv_classes[3][7][2] = int_stack + 26725;
 Libderiv->deriv_classes[3][8][2] = int_stack + 27085;
 Libderiv->deriv_classes[4][5][2] = int_stack + 27535;
 Libderiv->deriv_classes[4][6][2] = int_stack + 27850;
 Libderiv->deriv_classes[4][7][2] = int_stack + 28270;
 Libderiv->deriv_classes[4][8][2] = int_stack + 28810;
 Libderiv->deriv_classes[2][5][1] = int_stack + 29485;
 Libderiv->deriv_classes[2][6][1] = int_stack + 29611;
 Libderiv->deriv_classes[2][7][1] = int_stack + 29779;
 Libderiv->deriv_classes[2][8][1] = int_stack + 29995;
 Libderiv->deriv_classes[3][5][1] = int_stack + 30265;
 Libderiv->deriv_classes[3][6][1] = int_stack + 30475;
 Libderiv->deriv_classes[3][7][1] = int_stack + 30755;
 Libderiv->deriv_classes[3][8][1] = int_stack + 31115;
 Libderiv->deriv_classes[4][5][1] = int_stack + 31565;
 Libderiv->deriv_classes[4][6][1] = int_stack + 31880;
 Libderiv->deriv_classes[4][7][1] = int_stack + 32300;
 Libderiv->deriv_classes[4][8][1] = int_stack + 32840;
 Libderiv->dvrr_classes[2][5] = int_stack + 33515;
 Libderiv->dvrr_classes[2][6] = int_stack + 33641;
 Libderiv->dvrr_classes[2][7] = int_stack + 33809;
 Libderiv->dvrr_classes[2][8] = int_stack + 34025;
 Libderiv->deriv_classes[2][5][0] = int_stack + 34295;
 Libderiv->deriv_classes[2][6][0] = int_stack + 34421;
 Libderiv->deriv_classes[2][7][0] = int_stack + 34589;
 Libderiv->deriv_classes[2][8][0] = int_stack + 34805;
 Libderiv->dvrr_classes[3][5] = int_stack + 35075;
 Libderiv->dvrr_classes[3][6] = int_stack + 35285;
 Libderiv->dvrr_classes[3][7] = int_stack + 35565;
 Libderiv->dvrr_classes[3][8] = int_stack + 35925;
 Libderiv->deriv_classes[3][5][0] = int_stack + 36375;
 Libderiv->deriv_classes[3][6][0] = int_stack + 36585;
 Libderiv->deriv_classes[3][7][0] = int_stack + 36865;
 Libderiv->deriv_classes[3][8][0] = int_stack + 37225;
 Libderiv->deriv_classes[4][5][0] = int_stack + 37675;
 Libderiv->deriv_classes[4][6][0] = int_stack + 37990;
 Libderiv->deriv_classes[4][7][0] = int_stack + 38410;
 Libderiv->deriv_classes[4][8][0] = int_stack + 38950;
 memset(int_stack,0,317000);

 Libderiv->dvrr_stack = int_stack + 123877;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ddhf(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+39625,int_stack+33641,int_stack+33515,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+40003,int_stack+33809,int_stack+33641,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+40507,int_stack+40003,int_stack+39625,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41263,int_stack+126,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33515,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+41641,int_stack+294,int_stack+126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33641,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+42145,int_stack+41641,int_stack+41263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39625,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+42901,int_stack+510,int_stack+294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33809,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43549,int_stack+42901,int_stack+41641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40003,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+44557,int_stack+43549,int_stack+42145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40507,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+41263,int_stack+35285,int_stack+35075,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+41893,int_stack+35565,int_stack+35285,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+42733,int_stack+41893,int_stack+41263,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+990,int_stack+780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35075,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+45817,int_stack+1270,int_stack+990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35285,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+46657,int_stack+45817,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41263,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+1630,int_stack+1270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35565,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+47917,int_stack+0,int_stack+45817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41893,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+49597,int_stack+47917,int_stack+46657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42733,10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+45817,int_stack+49597,int_stack+44557,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+22860,int_stack+22230,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43993,int_stack+23700,int_stack+22860,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+51697,int_stack+43993,int_stack+0,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+945,int_stack+2395,int_stack+2080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22230,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+53587,int_stack+2815,int_stack+2395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22860,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+54847,int_stack+53587,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+945,int_stack+3355,int_stack+2815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23700,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+56737,int_stack+945,int_stack+53587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43993,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+59257,int_stack+56737,int_stack+54847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51697,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+62407,int_stack+59257,int_stack+49597,210);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49597,int_stack+4156,int_stack+4030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33515, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49975,int_stack+4324,int_stack+4156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33641, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50479,int_stack+49975,int_stack+49597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39625, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+53587,int_stack+4540,int_stack+4324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33809, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+54235,int_stack+53587,int_stack+49975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40003, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+55243,int_stack+54235,int_stack+50479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40507, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53587,int_stack+5020,int_stack+4810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35075, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+54217,int_stack+5300,int_stack+5020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35285, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49597,int_stack+54217,int_stack+53587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41263, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56503,int_stack+5660,int_stack+5300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35565, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+57583,int_stack+56503,int_stack+54217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41893, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+59263,int_stack+57583,int_stack+49597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42733, 0.0, zero_stack,10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+945,int_stack+59263,int_stack+55243,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49597,int_stack+6425,int_stack+6110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22230, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+53587,int_stack+6845,int_stack+6425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22860, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+54847,int_stack+53587,int_stack+49597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+49597,int_stack+7385,int_stack+6845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23700, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+56737,int_stack+49597,int_stack+53587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43993, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4725,int_stack+56737,int_stack+54847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51697, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+68707,int_stack+4725,int_stack+59263,210);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4725,int_stack+8186,int_stack+8060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33515, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5103,int_stack+8354,int_stack+8186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33641, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5607,int_stack+5103,int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39625, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6363,int_stack+8570,int_stack+8354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33809, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7011,int_stack+6363,int_stack+5103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40003, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+53587,int_stack+7011,int_stack+5607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40507, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4725,int_stack+9050,int_stack+8840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35075, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5355,int_stack+9330,int_stack+9050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35285, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6195,int_stack+5355,int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41263, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7455,int_stack+9690,int_stack+9330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35565, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+54847,int_stack+7455,int_stack+5355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41893, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+49597,int_stack+54847,int_stack+6195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42733, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+54847,int_stack+49597,int_stack+53587,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53587,int_stack+10455,int_stack+10140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22230, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58627,int_stack+10875,int_stack+10455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22860, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+59887,int_stack+58627,int_stack+53587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4725,int_stack+11415,int_stack+10875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23700, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6345,int_stack+4725,int_stack+58627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43993, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8865,int_stack+6345,int_stack+59887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51697, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+75007,int_stack+8865,int_stack+49597,210);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49597,int_stack+12216,int_stack+12090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49975,int_stack+12384,int_stack+12216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50479,int_stack+49975,int_stack+49597, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+58627,int_stack+12600,int_stack+12384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+59275,int_stack+58627,int_stack+49975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+53587,int_stack+59275,int_stack+50479, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58627,int_stack+13080,int_stack+12870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59257,int_stack+13360,int_stack+13080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+60097,int_stack+59257,int_stack+58627, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+49597,int_stack+13720,int_stack+13360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4725,int_stack+49597,int_stack+59257, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+49597,int_stack+4725,int_stack+60097, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+58627,int_stack+49597,int_stack+53587,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53587,int_stack+14485,int_stack+14170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4725,int_stack+14905,int_stack+14485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5985,int_stack+4725,int_stack+53587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7875,int_stack+15445,int_stack+14905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9495,int_stack+7875,int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12015,int_stack+9495,int_stack+5985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+4725,int_stack+12015,int_stack+49597,210);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49597,int_stack+16246,int_stack+16120, 0.0, zero_stack, 1.0, int_stack+33515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49975,int_stack+16414,int_stack+16246, 0.0, zero_stack, 1.0, int_stack+33641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50479,int_stack+49975,int_stack+49597, 0.0, zero_stack, 1.0, int_stack+39625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11025,int_stack+16630,int_stack+16414, 0.0, zero_stack, 1.0, int_stack+33809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11673,int_stack+11025,int_stack+49975, 0.0, zero_stack, 1.0, int_stack+40003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+53587,int_stack+11673,int_stack+50479, 0.0, zero_stack, 1.0, int_stack+40507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11025,int_stack+17110,int_stack+16900, 0.0, zero_stack, 1.0, int_stack+35075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11655,int_stack+17390,int_stack+17110, 0.0, zero_stack, 1.0, int_stack+35285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12495,int_stack+11655,int_stack+11025, 0.0, zero_stack, 1.0, int_stack+41263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13755,int_stack+17750,int_stack+17390, 0.0, zero_stack, 1.0, int_stack+35565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+14835,int_stack+13755,int_stack+11655, 0.0, zero_stack, 1.0, int_stack+41893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+49597,int_stack+14835,int_stack+12495, 0.0, zero_stack, 1.0, int_stack+42733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+11025,int_stack+49597,int_stack+53587,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53587,int_stack+18515,int_stack+18200, 0.0, zero_stack, 1.0, int_stack+22230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14805,int_stack+18935,int_stack+18515, 0.0, zero_stack, 1.0, int_stack+22860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16065,int_stack+14805,int_stack+53587, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+81307,int_stack+19475,int_stack+18935, 0.0, zero_stack, 1.0, int_stack+23700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+82927,int_stack+81307,int_stack+14805, 0.0, zero_stack, 1.0, int_stack+43993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+85447,int_stack+82927,int_stack+16065, 0.0, zero_stack, 1.0, int_stack+51697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+88597,int_stack+85447,int_stack+49597,210);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49597,int_stack+20276,int_stack+20150, 1.0, int_stack+33515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49975,int_stack+20444,int_stack+20276, 1.0, int_stack+33641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50479,int_stack+49975,int_stack+49597, 1.0, int_stack+39625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+14805,int_stack+20660,int_stack+20444, 1.0, int_stack+33809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15453,int_stack+14805,int_stack+49975, 1.0, int_stack+40003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+53587,int_stack+15453,int_stack+50479, 1.0, int_stack+40507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14805,int_stack+21140,int_stack+20930, 1.0, int_stack+35075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15435,int_stack+21420,int_stack+21140, 1.0, int_stack+35285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16275,int_stack+15435,int_stack+14805, 1.0, int_stack+41263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17535,int_stack+21780,int_stack+21420, 1.0, int_stack+35565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18615,int_stack+17535,int_stack+15435, 1.0, int_stack+41893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+49597,int_stack+18615,int_stack+16275, 1.0, int_stack+42733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+14805,int_stack+49597,int_stack+53587,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53587,int_stack+23280,int_stack+22545, 1.0, int_stack+22230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18585,int_stack+24240,int_stack+23280, 1.0, int_stack+22860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19845,int_stack+18585,int_stack+53587, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+21735,int_stack+24780,int_stack+24240, 1.0, int_stack+23700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+81307,int_stack+21735,int_stack+18585, 1.0, int_stack+43993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+21735,int_stack+81307,int_stack+19845, 1.0, int_stack+51697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+81307,int_stack+21735,int_stack+49597,210);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+49597,int_stack+34025,int_stack+33809,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+50245,int_stack+49597,int_stack+40003,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+51253,int_stack+50245,int_stack+40507,6);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+49597,int_stack+35925,int_stack+35565,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+52513,int_stack+49597,int_stack+41893,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+18585,int_stack+52513,int_stack+42733,10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+20685,int_stack+18585,int_stack+51253,210);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+52513,int_stack+25581,int_stack+25455,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52891,int_stack+25749,int_stack+25581,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+53395,int_stack+52891,int_stack+52513,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+54151,int_stack+25965,int_stack+25749,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+49597,int_stack+54151,int_stack+52891,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+24465,int_stack+49597,int_stack+53395,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+49597,int_stack+26445,int_stack+26235,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+50227,int_stack+26725,int_stack+26445,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+52513,int_stack+50227,int_stack+49597,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+35075,int_stack+27085,int_stack+26725,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+25725,int_stack+35075,int_stack+50227,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+39625,int_stack+25725,int_stack+52513,10);
 /*--- compute (dp|hf) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+41725,int_stack+39625,int_stack+24465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+27850,int_stack+27535,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+24465,int_stack+28270,int_stack+27850,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+25725,int_stack+24465,int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+52513,int_stack+28810,int_stack+28270,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+94897,int_stack+52513,int_stack+24465,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+97417,int_stack+94897,int_stack+25725,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+100567,int_stack+97417,int_stack+39625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+39625,int_stack+29611,int_stack+29485,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+40003,int_stack+29779,int_stack+29611,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+40507,int_stack+40003,int_stack+39625,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+94897,int_stack+29995,int_stack+29779,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+95545,int_stack+94897,int_stack+40003,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+96553,int_stack+95545,int_stack+40507,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+94897,int_stack+30475,int_stack+30265,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+95527,int_stack+30755,int_stack+30475,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+39625,int_stack+95527,int_stack+94897,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+97813,int_stack+31115,int_stack+30755,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+24465,int_stack+97813,int_stack+95527,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+97813,int_stack+24465,int_stack+39625,10);
 /*--- compute (dp|hf) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+24465,int_stack+97813,int_stack+96553, 0.0, zero_stack, 1.0, int_stack+51253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+31880,int_stack+31565,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+39625,int_stack+32300,int_stack+31880,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+28245,int_stack+39625,int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+30135,int_stack+32840,int_stack+32300,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+31755,int_stack+30135,int_stack+39625,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+106867,int_stack+31755,int_stack+28245,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+110017,int_stack+106867,int_stack+97813, 0.0, zero_stack, 1.0, int_stack+18585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+106867,int_stack+34421,int_stack+34295,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+107245,int_stack+34589,int_stack+34421,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+107749,int_stack+107245,int_stack+106867,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+108505,int_stack+34805,int_stack+34589,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+28245,int_stack+108505,int_stack+107245,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+108505,int_stack+28245,int_stack+107749,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+28245,int_stack+36585,int_stack+36375,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+28875,int_stack+36865,int_stack+36585,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+29715,int_stack+28875,int_stack+28245,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+30975,int_stack+37225,int_stack+36865,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+32055,int_stack+30975,int_stack+28875,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+39625,int_stack+32055,int_stack+29715,10);
 /*--- compute (dp|hf) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+28245,int_stack+39625,int_stack+108505, 1.0, int_stack+51253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+37990,int_stack+37675,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+32025,int_stack+38410,int_stack+37990,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+33285,int_stack+32025,int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+35175,int_stack+38950,int_stack+38410,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+36795,int_stack+35175,int_stack+32025,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+106867,int_stack+36795,int_stack+33285,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+32025,int_stack+106867,int_stack+39625, 1.0, int_stack+18585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (dd|hf) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+116317,int_stack+62407,int_stack+45817,210);
     Libderiv->ABCD[11] = int_stack + 116317;
 /*--- compute (dd|hf) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+45505,int_stack+68707,int_stack+945,210);
     Libderiv->ABCD[10] = int_stack + 45505;
 /*--- compute (dd|hf) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+62407,int_stack+75007,int_stack+54847,210);
     Libderiv->ABCD[9] = int_stack + 62407;
 /*--- compute (dd|hf) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+69967,int_stack+4725,int_stack+58627,210);
     Libderiv->ABCD[8] = int_stack + 69967;
 /*--- compute (dd|hf) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+0,int_stack+88597,int_stack+11025,210);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (dd|hf) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+87607,int_stack+81307,int_stack+14805,210);
     Libderiv->ABCD[6] = int_stack + 87607;
 /*--- compute (dd|hf) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+77527,int_stack+100567,int_stack+41725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 77527;
 /*--- compute (dd|hf) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+7560,int_stack+110017,int_stack+24465, 0.0, zero_stack, 1.0, int_stack+20685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 7560;
 /*--- compute (dd|hf) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+95167,int_stack+32025,int_stack+28245, 1.0, int_stack+20685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 95167;

}
