/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ffhg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ff|hg) integrals */

void d1hrr_order_ffhg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][5][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][11] = int_stack + 210;
 Libderiv->deriv_classes[3][7][11] = int_stack + 490;
 Libderiv->deriv_classes[3][8][11] = int_stack + 850;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1300;
 Libderiv->deriv_classes[4][5][11] = int_stack + 1850;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2165;
 Libderiv->deriv_classes[4][7][11] = int_stack + 2585;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3125;
 Libderiv->deriv_classes[4][9][11] = int_stack + 3800;
 Libderiv->deriv_classes[5][5][11] = int_stack + 4625;
 Libderiv->deriv_classes[5][6][11] = int_stack + 5066;
 Libderiv->deriv_classes[5][7][11] = int_stack + 5654;
 Libderiv->deriv_classes[5][8][11] = int_stack + 6410;
 Libderiv->deriv_classes[5][9][11] = int_stack + 7355;
 Libderiv->deriv_classes[6][5][11] = int_stack + 8510;
 Libderiv->deriv_classes[6][6][11] = int_stack + 9098;
 Libderiv->deriv_classes[6][7][11] = int_stack + 9882;
 Libderiv->deriv_classes[6][8][11] = int_stack + 10890;
 Libderiv->deriv_classes[6][9][11] = int_stack + 12150;
 Libderiv->deriv_classes[3][5][10] = int_stack + 13690;
 Libderiv->deriv_classes[3][6][10] = int_stack + 13900;
 Libderiv->deriv_classes[3][7][10] = int_stack + 14180;
 Libderiv->deriv_classes[3][8][10] = int_stack + 14540;
 Libderiv->deriv_classes[3][9][10] = int_stack + 14990;
 Libderiv->deriv_classes[4][5][10] = int_stack + 15540;
 Libderiv->deriv_classes[4][6][10] = int_stack + 15855;
 Libderiv->deriv_classes[4][7][10] = int_stack + 16275;
 Libderiv->deriv_classes[4][8][10] = int_stack + 16815;
 Libderiv->deriv_classes[4][9][10] = int_stack + 17490;
 Libderiv->deriv_classes[5][5][10] = int_stack + 18315;
 Libderiv->deriv_classes[5][6][10] = int_stack + 18756;
 Libderiv->deriv_classes[5][7][10] = int_stack + 19344;
 Libderiv->deriv_classes[5][8][10] = int_stack + 20100;
 Libderiv->deriv_classes[5][9][10] = int_stack + 21045;
 Libderiv->deriv_classes[6][5][10] = int_stack + 22200;
 Libderiv->deriv_classes[6][6][10] = int_stack + 22788;
 Libderiv->deriv_classes[6][7][10] = int_stack + 23572;
 Libderiv->deriv_classes[6][8][10] = int_stack + 24580;
 Libderiv->deriv_classes[6][9][10] = int_stack + 25840;
 Libderiv->deriv_classes[3][5][9] = int_stack + 27380;
 Libderiv->deriv_classes[3][6][9] = int_stack + 27590;
 Libderiv->deriv_classes[3][7][9] = int_stack + 27870;
 Libderiv->deriv_classes[3][8][9] = int_stack + 28230;
 Libderiv->deriv_classes[3][9][9] = int_stack + 28680;
 Libderiv->deriv_classes[4][5][9] = int_stack + 29230;
 Libderiv->deriv_classes[4][6][9] = int_stack + 29545;
 Libderiv->deriv_classes[4][7][9] = int_stack + 29965;
 Libderiv->deriv_classes[4][8][9] = int_stack + 30505;
 Libderiv->deriv_classes[4][9][9] = int_stack + 31180;
 Libderiv->deriv_classes[5][5][9] = int_stack + 32005;
 Libderiv->deriv_classes[5][6][9] = int_stack + 32446;
 Libderiv->deriv_classes[5][7][9] = int_stack + 33034;
 Libderiv->deriv_classes[5][8][9] = int_stack + 33790;
 Libderiv->deriv_classes[5][9][9] = int_stack + 34735;
 Libderiv->deriv_classes[6][5][9] = int_stack + 35890;
 Libderiv->deriv_classes[6][6][9] = int_stack + 36478;
 Libderiv->deriv_classes[6][7][9] = int_stack + 37262;
 Libderiv->deriv_classes[6][8][9] = int_stack + 38270;
 Libderiv->deriv_classes[6][9][9] = int_stack + 39530;
 Libderiv->deriv_classes[3][5][8] = int_stack + 41070;
 Libderiv->deriv_classes[3][6][8] = int_stack + 41280;
 Libderiv->deriv_classes[3][7][8] = int_stack + 41560;
 Libderiv->deriv_classes[3][8][8] = int_stack + 41920;
 Libderiv->deriv_classes[3][9][8] = int_stack + 42370;
 Libderiv->deriv_classes[4][5][8] = int_stack + 42920;
 Libderiv->deriv_classes[4][6][8] = int_stack + 43235;
 Libderiv->deriv_classes[4][7][8] = int_stack + 43655;
 Libderiv->deriv_classes[4][8][8] = int_stack + 44195;
 Libderiv->deriv_classes[4][9][8] = int_stack + 44870;
 Libderiv->deriv_classes[5][5][8] = int_stack + 45695;
 Libderiv->deriv_classes[5][6][8] = int_stack + 46136;
 Libderiv->deriv_classes[5][7][8] = int_stack + 46724;
 Libderiv->deriv_classes[5][8][8] = int_stack + 47480;
 Libderiv->deriv_classes[5][9][8] = int_stack + 48425;
 Libderiv->deriv_classes[6][5][8] = int_stack + 49580;
 Libderiv->deriv_classes[6][6][8] = int_stack + 50168;
 Libderiv->deriv_classes[6][7][8] = int_stack + 50952;
 Libderiv->deriv_classes[6][8][8] = int_stack + 51960;
 Libderiv->deriv_classes[6][9][8] = int_stack + 53220;
 Libderiv->deriv_classes[3][5][7] = int_stack + 54760;
 Libderiv->deriv_classes[3][6][7] = int_stack + 54970;
 Libderiv->deriv_classes[3][7][7] = int_stack + 55250;
 Libderiv->deriv_classes[3][8][7] = int_stack + 55610;
 Libderiv->deriv_classes[3][9][7] = int_stack + 56060;
 Libderiv->deriv_classes[4][5][7] = int_stack + 56610;
 Libderiv->deriv_classes[4][6][7] = int_stack + 56925;
 Libderiv->deriv_classes[4][7][7] = int_stack + 57345;
 Libderiv->deriv_classes[4][8][7] = int_stack + 57885;
 Libderiv->deriv_classes[4][9][7] = int_stack + 58560;
 Libderiv->deriv_classes[5][5][7] = int_stack + 59385;
 Libderiv->deriv_classes[5][6][7] = int_stack + 59826;
 Libderiv->deriv_classes[5][7][7] = int_stack + 60414;
 Libderiv->deriv_classes[5][8][7] = int_stack + 61170;
 Libderiv->deriv_classes[5][9][7] = int_stack + 62115;
 Libderiv->deriv_classes[6][5][7] = int_stack + 63270;
 Libderiv->deriv_classes[6][6][7] = int_stack + 63858;
 Libderiv->deriv_classes[6][7][7] = int_stack + 64642;
 Libderiv->deriv_classes[6][8][7] = int_stack + 65650;
 Libderiv->deriv_classes[6][9][7] = int_stack + 66910;
 Libderiv->deriv_classes[3][5][6] = int_stack + 68450;
 Libderiv->deriv_classes[3][6][6] = int_stack + 68660;
 Libderiv->deriv_classes[3][7][6] = int_stack + 68940;
 Libderiv->deriv_classes[3][8][6] = int_stack + 69300;
 Libderiv->deriv_classes[3][9][6] = int_stack + 69750;
 Libderiv->deriv_classes[4][5][6] = int_stack + 70300;
 Libderiv->deriv_classes[4][6][6] = int_stack + 70615;
 Libderiv->deriv_classes[4][7][6] = int_stack + 71035;
 Libderiv->deriv_classes[4][8][6] = int_stack + 71575;
 Libderiv->deriv_classes[4][9][6] = int_stack + 72250;
 Libderiv->deriv_classes[5][5][6] = int_stack + 73075;
 Libderiv->deriv_classes[5][6][6] = int_stack + 73516;
 Libderiv->deriv_classes[5][7][6] = int_stack + 74104;
 Libderiv->deriv_classes[5][8][6] = int_stack + 74860;
 Libderiv->deriv_classes[5][9][6] = int_stack + 75805;
 Libderiv->dvrr_classes[6][5] = int_stack + 76960;
 Libderiv->deriv_classes[6][5][6] = int_stack + 77548;
 Libderiv->dvrr_classes[6][6] = int_stack + 78136;
 Libderiv->deriv_classes[6][6][6] = int_stack + 78920;
 Libderiv->dvrr_classes[6][7] = int_stack + 79704;
 Libderiv->deriv_classes[6][7][6] = int_stack + 80712;
 Libderiv->dvrr_classes[6][8] = int_stack + 81720;
 Libderiv->deriv_classes[6][8][6] = int_stack + 82980;
 Libderiv->deriv_classes[6][9][6] = int_stack + 84240;
 Libderiv->deriv_classes[3][5][2] = int_stack + 85780;
 Libderiv->deriv_classes[3][6][2] = int_stack + 85990;
 Libderiv->deriv_classes[3][7][2] = int_stack + 86270;
 Libderiv->deriv_classes[3][8][2] = int_stack + 86630;
 Libderiv->deriv_classes[3][9][2] = int_stack + 87080;
 Libderiv->deriv_classes[4][5][2] = int_stack + 87630;
 Libderiv->deriv_classes[4][6][2] = int_stack + 87945;
 Libderiv->deriv_classes[4][7][2] = int_stack + 88365;
 Libderiv->deriv_classes[4][8][2] = int_stack + 88905;
 Libderiv->deriv_classes[4][9][2] = int_stack + 89580;
 Libderiv->deriv_classes[5][5][2] = int_stack + 90405;
 Libderiv->deriv_classes[5][6][2] = int_stack + 90846;
 Libderiv->deriv_classes[5][7][2] = int_stack + 91434;
 Libderiv->deriv_classes[5][8][2] = int_stack + 92190;
 Libderiv->deriv_classes[5][9][2] = int_stack + 93135;
 Libderiv->deriv_classes[6][5][2] = int_stack + 94290;
 Libderiv->deriv_classes[6][6][2] = int_stack + 94878;
 Libderiv->deriv_classes[6][7][2] = int_stack + 95662;
 Libderiv->deriv_classes[6][8][2] = int_stack + 96670;
 Libderiv->deriv_classes[6][9][2] = int_stack + 97930;
 Libderiv->deriv_classes[3][5][1] = int_stack + 99470;
 Libderiv->deriv_classes[3][6][1] = int_stack + 99680;
 Libderiv->deriv_classes[3][7][1] = int_stack + 99960;
 Libderiv->deriv_classes[3][8][1] = int_stack + 100320;
 Libderiv->deriv_classes[3][9][1] = int_stack + 100770;
 Libderiv->deriv_classes[4][5][1] = int_stack + 101320;
 Libderiv->deriv_classes[4][6][1] = int_stack + 101635;
 Libderiv->deriv_classes[4][7][1] = int_stack + 102055;
 Libderiv->deriv_classes[4][8][1] = int_stack + 102595;
 Libderiv->deriv_classes[4][9][1] = int_stack + 103270;
 Libderiv->deriv_classes[5][5][1] = int_stack + 104095;
 Libderiv->deriv_classes[5][6][1] = int_stack + 104536;
 Libderiv->deriv_classes[5][7][1] = int_stack + 105124;
 Libderiv->deriv_classes[5][8][1] = int_stack + 105880;
 Libderiv->deriv_classes[5][9][1] = int_stack + 106825;
 Libderiv->deriv_classes[6][5][1] = int_stack + 107980;
 Libderiv->deriv_classes[6][6][1] = int_stack + 108568;
 Libderiv->deriv_classes[6][7][1] = int_stack + 109352;
 Libderiv->deriv_classes[6][8][1] = int_stack + 110360;
 Libderiv->deriv_classes[6][9][1] = int_stack + 111620;
 Libderiv->dvrr_classes[3][5] = int_stack + 113160;
 Libderiv->dvrr_classes[3][6] = int_stack + 113370;
 Libderiv->dvrr_classes[3][7] = int_stack + 113650;
 Libderiv->dvrr_classes[3][8] = int_stack + 114010;
 Libderiv->dvrr_classes[3][9] = int_stack + 114460;
 Libderiv->deriv_classes[3][5][0] = int_stack + 115010;
 Libderiv->deriv_classes[3][6][0] = int_stack + 115220;
 Libderiv->deriv_classes[3][7][0] = int_stack + 115500;
 Libderiv->deriv_classes[3][8][0] = int_stack + 115860;
 Libderiv->deriv_classes[3][9][0] = int_stack + 116310;
 Libderiv->dvrr_classes[4][5] = int_stack + 116860;
 Libderiv->dvrr_classes[4][6] = int_stack + 117175;
 Libderiv->dvrr_classes[4][7] = int_stack + 117595;
 Libderiv->dvrr_classes[4][8] = int_stack + 118135;
 Libderiv->dvrr_classes[4][9] = int_stack + 118810;
 Libderiv->deriv_classes[4][5][0] = int_stack + 119635;
 Libderiv->deriv_classes[4][6][0] = int_stack + 119950;
 Libderiv->deriv_classes[4][7][0] = int_stack + 120370;
 Libderiv->deriv_classes[4][8][0] = int_stack + 120910;
 Libderiv->deriv_classes[4][9][0] = int_stack + 121585;
 Libderiv->dvrr_classes[5][5] = int_stack + 122410;
 Libderiv->dvrr_classes[5][6] = int_stack + 122851;
 Libderiv->dvrr_classes[5][7] = int_stack + 123439;
 Libderiv->dvrr_classes[5][8] = int_stack + 124195;
 Libderiv->dvrr_classes[5][9] = int_stack + 125140;
 Libderiv->deriv_classes[5][5][0] = int_stack + 126295;
 Libderiv->deriv_classes[5][6][0] = int_stack + 126736;
 Libderiv->deriv_classes[5][7][0] = int_stack + 127324;
 Libderiv->deriv_classes[5][8][0] = int_stack + 128080;
 Libderiv->deriv_classes[5][9][0] = int_stack + 129025;
 Libderiv->deriv_classes[6][5][0] = int_stack + 130180;
 Libderiv->deriv_classes[6][6][0] = int_stack + 130768;
 Libderiv->deriv_classes[6][7][0] = int_stack + 131552;
 Libderiv->deriv_classes[6][8][0] = int_stack + 132560;
 Libderiv->deriv_classes[6][9][0] = int_stack + 133820;
 memset(int_stack,0,1082880);

 Libderiv->dvrr_stack = int_stack + 557100;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ffhg(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+135360,int_stack+113370,int_stack+113160,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+135990,int_stack+113650,int_stack+113370,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+136830,int_stack+135990,int_stack+135360,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+138090,int_stack+114010,int_stack+113650,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+139170,int_stack+138090,int_stack+135990,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+140850,int_stack+139170,int_stack+136830,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+142950,int_stack+210,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113160,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+143580,int_stack+490,int_stack+210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113370,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+144420,int_stack+143580,int_stack+142950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135360,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+145680,int_stack+850,int_stack+490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113650,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+146760,int_stack+145680,int_stack+143580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135990,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148440,int_stack+146760,int_stack+144420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136830,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+142950,int_stack+1300,int_stack+850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114010,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+150540,int_stack+142950,int_stack+145680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138090,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+142950,int_stack+150540,int_stack+146760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139170,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+150540,int_stack+142950,int_stack+148440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140850,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+142950,int_stack+117175,int_stack+116860,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143895,int_stack+117595,int_stack+117175,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+145155,int_stack+143895,int_stack+142950,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+147045,int_stack+118135,int_stack+117595,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+153690,int_stack+147045,int_stack+143895,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+156210,int_stack+153690,int_stack+145155,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148665,int_stack+2165,int_stack+1850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116860,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+2585,int_stack+2165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117175,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+159360,int_stack+0,int_stack+148665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148665,int_stack+3125,int_stack+2585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117595,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+161250,int_stack+148665,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143895,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+163770,int_stack+161250,int_stack+159360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145155,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+3800,int_stack+3125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118135,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+166920,int_stack+0,int_stack+148665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147045,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+166920,int_stack+161250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153690,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+166920,int_stack+0,int_stack+163770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156210,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+171645,int_stack+166920,int_stack+150540,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+122851,int_stack+122410,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+123439,int_stack+122851,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+148665,int_stack+1323,int_stack+0,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+151311,int_stack+124195,int_stack+123439,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+159360,int_stack+151311,int_stack+1323,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+181095,int_stack+159360,int_stack+148665,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3087,int_stack+5066,int_stack+4625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122410,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+162888,int_stack+5654,int_stack+5066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122851,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+185505,int_stack+162888,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164652,int_stack+6410,int_stack+5654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123439,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+188151,int_stack+164652,int_stack+162888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+191679,int_stack+188151,int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148665,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3087,int_stack+7355,int_stack+6410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124195,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+196089,int_stack+3087,int_stack+164652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151311,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+200625,int_stack+196089,int_stack+188151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159360,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+206505,int_stack+200625,int_stack+191679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181095,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+185505,int_stack+206505,int_stack+166920,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+213120,int_stack+185505,int_stack+171645,315);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3087,int_stack+78136,int_stack+76960,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4851,int_stack+79704,int_stack+78136,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+199680,int_stack+4851,int_stack+3087,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+203208,int_stack+81720,int_stack+79704,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+162888,int_stack+203208,int_stack+4851,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+167592,int_stack+162888,int_stack+199680,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+173472,int_stack+9098,int_stack+8510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76960,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+175236,int_stack+9882,int_stack+9098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78136,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+232020,int_stack+175236,int_stack+173472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3087,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+177588,int_stack+10890,int_stack+9882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79704,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+235548,int_stack+177588,int_stack+175236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4851,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+240252,int_stack+235548,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199680,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+173472,int_stack+12150,int_stack+10890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81720,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7203,int_stack+173472,int_stack+177588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203208,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+246132,int_stack+7203,int_stack+235548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162888,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+253972,int_stack+246132,int_stack+240252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167592,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+232020,int_stack+253972,int_stack+206505,315);
 /*--- compute (gd|hg) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+251865,int_stack+232020,int_stack+185505,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+185505,int_stack+13900,int_stack+13690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113160, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+186135,int_stack+14180,int_stack+13900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113370, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+186975,int_stack+186135,int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135360, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+188235,int_stack+14540,int_stack+14180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113650, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+189315,int_stack+188235,int_stack+186135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135990, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+190995,int_stack+189315,int_stack+186975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136830, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+185505,int_stack+14990,int_stack+14540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114010, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+193095,int_stack+185505,int_stack+188235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138090, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+185505,int_stack+193095,int_stack+189315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139170, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+193095,int_stack+185505,int_stack+190995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140850, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+185505,int_stack+15855,int_stack+15540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116860, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+186450,int_stack+16275,int_stack+15855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117175, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+187710,int_stack+186450,int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+189600,int_stack+16815,int_stack+16275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117595, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+196245,int_stack+189600,int_stack+186450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143895, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+232020,int_stack+196245,int_stack+187710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145155, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+185505,int_stack+17490,int_stack+16815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118135, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+235170,int_stack+185505,int_stack+189600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147045, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+185505,int_stack+235170,int_stack+196245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153690, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+235170,int_stack+185505,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156210, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+239895,int_stack+235170,int_stack+193095,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+232020,int_stack+18756,int_stack+18315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122410, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+233343,int_stack+19344,int_stack+18756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122851, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+185505,int_stack+233343,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+188151,int_stack+20100,int_stack+19344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123439, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+190419,int_stack+188151,int_stack+233343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+193947,int_stack+190419,int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148665, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+232020,int_stack+21045,int_stack+20100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124195, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7203,int_stack+232020,int_stack+188151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151311, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11739,int_stack+7203,int_stack+190419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159360, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+185505,int_stack+11739,int_stack+193947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181095, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+7203,int_stack+185505,int_stack+235170,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+280215,int_stack+7203,int_stack+239895,315);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+232020,int_stack+22788,int_stack+22200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76960, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+233784,int_stack+23572,int_stack+22788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78136, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+236136,int_stack+233784,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3087, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+239664,int_stack+24580,int_stack+23572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79704, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+242688,int_stack+239664,int_stack+233784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4851, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+192120,int_stack+242688,int_stack+236136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199680, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+232020,int_stack+25840,int_stack+24580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81720, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+173472,int_stack+232020,int_stack+239664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203208, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+232020,int_stack+173472,int_stack+242688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162888, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+239860,int_stack+232020,int_stack+192120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167592, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+299115,int_stack+239860,int_stack+185505,315);
 /*--- compute (gd|hg) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+318960,int_stack+299115,int_stack+7203,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7203,int_stack+27590,int_stack+27380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113160, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7833,int_stack+27870,int_stack+27590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113370, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8673,int_stack+7833,int_stack+7203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135360, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9933,int_stack+28230,int_stack+27870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113650, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11013,int_stack+9933,int_stack+7833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135990, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12693,int_stack+11013,int_stack+8673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136830, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7203,int_stack+28680,int_stack+28230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114010, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14793,int_stack+7203,int_stack+9933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138090, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7203,int_stack+14793,int_stack+11013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139170, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+14793,int_stack+7203,int_stack+12693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140850, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7203,int_stack+29545,int_stack+29230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116860, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8148,int_stack+29965,int_stack+29545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117175, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9408,int_stack+8148,int_stack+7203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11298,int_stack+30505,int_stack+29965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117595, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+17943,int_stack+11298,int_stack+8148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143895, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+20463,int_stack+17943,int_stack+9408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145155, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7203,int_stack+31180,int_stack+30505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118135, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+23613,int_stack+7203,int_stack+11298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147045, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7203,int_stack+23613,int_stack+17943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153690, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+23613,int_stack+7203,int_stack+20463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156210, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+299115,int_stack+23613,int_stack+14793,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7203,int_stack+32446,int_stack+32005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122410, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8526,int_stack+33034,int_stack+32446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122851, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10290,int_stack+8526,int_stack+7203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12936,int_stack+33790,int_stack+33034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123439, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15204,int_stack+12936,int_stack+8526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+18732,int_stack+15204,int_stack+10290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148665, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7203,int_stack+34735,int_stack+33790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124195, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+28338,int_stack+7203,int_stack+12936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151311, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7203,int_stack+28338,int_stack+15204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159360, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+28338,int_stack+7203,int_stack+18732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181095, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+185505,int_stack+28338,int_stack+23613,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+7203,int_stack+185505,int_stack+299115,315);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299115,int_stack+36478,int_stack+35890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76960, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300879,int_stack+37262,int_stack+36478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78136, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+303231,int_stack+300879,int_stack+299115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3087, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+306759,int_stack+38270,int_stack+37262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79704, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+309783,int_stack+306759,int_stack+300879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4851, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+232020,int_stack+309783,int_stack+303231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199680, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+299115,int_stack+39530,int_stack+38270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81720, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+34953,int_stack+299115,int_stack+306759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203208, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299115,int_stack+34953,int_stack+309783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162888, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+306955,int_stack+299115,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167592, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+232020,int_stack+306955,int_stack+28338,315);
 /*--- compute (gd|hg) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+347310,int_stack+232020,int_stack+185505,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+185505,int_stack+41280,int_stack+41070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+186135,int_stack+41560,int_stack+41280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+186975,int_stack+186135,int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+188235,int_stack+41920,int_stack+41560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+189315,int_stack+188235,int_stack+186135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+190995,int_stack+189315,int_stack+186975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+185505,int_stack+42370,int_stack+41920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+193095,int_stack+185505,int_stack+188235, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+185505,int_stack+193095,int_stack+189315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+193095,int_stack+185505,int_stack+190995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+185505,int_stack+43235,int_stack+42920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+186450,int_stack+43655,int_stack+43235, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+187710,int_stack+186450,int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+189600,int_stack+44195,int_stack+43655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+196245,int_stack+189600,int_stack+186450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+232020,int_stack+196245,int_stack+187710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+185505,int_stack+44870,int_stack+44195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+235170,int_stack+185505,int_stack+189600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+185505,int_stack+235170,int_stack+196245, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+235170,int_stack+185505,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+239895,int_stack+235170,int_stack+193095,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+232020,int_stack+46136,int_stack+45695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+233343,int_stack+46724,int_stack+46136, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+185505,int_stack+233343,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+188151,int_stack+47480,int_stack+46724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+190419,int_stack+188151,int_stack+233343, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+193947,int_stack+190419,int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+232020,int_stack+48425,int_stack+47480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+299115,int_stack+232020,int_stack+188151, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+303651,int_stack+299115,int_stack+190419, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+185505,int_stack+303651,int_stack+193947, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+299115,int_stack+185505,int_stack+235170,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+26103,int_stack+299115,int_stack+239895,315);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+313290,int_stack+50168,int_stack+49580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315054,int_stack+50952,int_stack+50168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+232020,int_stack+315054,int_stack+313290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+235548,int_stack+51960,int_stack+50952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+238572,int_stack+235548,int_stack+315054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+243276,int_stack+238572,int_stack+232020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+313290,int_stack+53220,int_stack+51960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+192120,int_stack+313290,int_stack+235548, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+45003,int_stack+192120,int_stack+238572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+232020,int_stack+45003,int_stack+243276, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+375660,int_stack+232020,int_stack+185505,315);
 /*--- compute (gd|hg) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+395505,int_stack+375660,int_stack+299115,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299115,int_stack+54970,int_stack+54760, 0.0, zero_stack, 1.0, int_stack+113160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+299745,int_stack+55250,int_stack+54970, 0.0, zero_stack, 1.0, int_stack+113370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+300585,int_stack+299745,int_stack+299115, 0.0, zero_stack, 1.0, int_stack+135360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+301845,int_stack+55610,int_stack+55250, 0.0, zero_stack, 1.0, int_stack+113650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+302925,int_stack+301845,int_stack+299745, 0.0, zero_stack, 1.0, int_stack+135990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+304605,int_stack+302925,int_stack+300585, 0.0, zero_stack, 1.0, int_stack+136830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+299115,int_stack+56060,int_stack+55610, 0.0, zero_stack, 1.0, int_stack+114010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+306705,int_stack+299115,int_stack+301845, 0.0, zero_stack, 1.0, int_stack+138090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299115,int_stack+306705,int_stack+302925, 0.0, zero_stack, 1.0, int_stack+139170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+306705,int_stack+299115,int_stack+304605, 0.0, zero_stack, 1.0, int_stack+140850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299115,int_stack+56925,int_stack+56610, 0.0, zero_stack, 1.0, int_stack+116860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300060,int_stack+57345,int_stack+56925, 0.0, zero_stack, 1.0, int_stack+117175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+301320,int_stack+300060,int_stack+299115, 0.0, zero_stack, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+303210,int_stack+57885,int_stack+57345, 0.0, zero_stack, 1.0, int_stack+117595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+309855,int_stack+303210,int_stack+300060, 0.0, zero_stack, 1.0, int_stack+143895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+312375,int_stack+309855,int_stack+301320, 0.0, zero_stack, 1.0, int_stack+145155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+299115,int_stack+58560,int_stack+57885, 0.0, zero_stack, 1.0, int_stack+118135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+315525,int_stack+299115,int_stack+303210, 0.0, zero_stack, 1.0, int_stack+147045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299115,int_stack+315525,int_stack+309855, 0.0, zero_stack, 1.0, int_stack+153690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+375660,int_stack+299115,int_stack+312375, 0.0, zero_stack, 1.0, int_stack+156210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+380385,int_stack+375660,int_stack+306705,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299115,int_stack+59826,int_stack+59385, 0.0, zero_stack, 1.0, int_stack+122410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300438,int_stack+60414,int_stack+59826, 0.0, zero_stack, 1.0, int_stack+122851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+302202,int_stack+300438,int_stack+299115, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+304848,int_stack+61170,int_stack+60414, 0.0, zero_stack, 1.0, int_stack+123439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+307116,int_stack+304848,int_stack+300438, 0.0, zero_stack, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+310644,int_stack+307116,int_stack+302202, 0.0, zero_stack, 1.0, int_stack+148665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+299115,int_stack+62115,int_stack+61170, 0.0, zero_stack, 1.0, int_stack+124195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+389835,int_stack+299115,int_stack+304848, 0.0, zero_stack, 1.0, int_stack+151311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299115,int_stack+389835,int_stack+307116, 0.0, zero_stack, 1.0, int_stack+159360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+185505,int_stack+299115,int_stack+310644, 0.0, zero_stack, 1.0, int_stack+181095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+299115,int_stack+185505,int_stack+375660,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+232020,int_stack+299115,int_stack+380385,315);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+375660,int_stack+63858,int_stack+63270, 0.0, zero_stack, 1.0, int_stack+76960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377424,int_stack+64642,int_stack+63858, 0.0, zero_stack, 1.0, int_stack+78136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+379776,int_stack+377424,int_stack+375660, 0.0, zero_stack, 1.0, int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+383304,int_stack+65650,int_stack+64642, 0.0, zero_stack, 1.0, int_stack+79704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+386328,int_stack+383304,int_stack+377424, 0.0, zero_stack, 1.0, int_stack+4851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+192120,int_stack+386328,int_stack+379776, 0.0, zero_stack, 1.0, int_stack+199680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+375660,int_stack+66910,int_stack+65650, 0.0, zero_stack, 1.0, int_stack+81720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+45003,int_stack+375660,int_stack+383304, 0.0, zero_stack, 1.0, int_stack+203208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+375660,int_stack+45003,int_stack+386328, 0.0, zero_stack, 1.0, int_stack+162888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+45003,int_stack+375660,int_stack+192120, 0.0, zero_stack, 1.0, int_stack+167592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+375660,int_stack+45003,int_stack+185505,315);
 /*--- compute (gd|hg) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+423855,int_stack+375660,int_stack+299115,315);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299115,int_stack+68660,int_stack+68450, 1.0, int_stack+113160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+299745,int_stack+68940,int_stack+68660, 1.0, int_stack+113370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+300585,int_stack+299745,int_stack+299115, 1.0, int_stack+135360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+301845,int_stack+69300,int_stack+68940, 1.0, int_stack+113650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+302925,int_stack+301845,int_stack+299745, 1.0, int_stack+135990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+304605,int_stack+302925,int_stack+300585, 1.0, int_stack+136830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+135360,int_stack+69750,int_stack+69300, 1.0, int_stack+114010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+299115,int_stack+135360,int_stack+301845, 1.0, int_stack+138090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+306705,int_stack+299115,int_stack+302925, 1.0, int_stack+139170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+299115,int_stack+306705,int_stack+304605, 1.0, int_stack+140850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+250920,int_stack+70615,int_stack+70300, 1.0, int_stack+116860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+302265,int_stack+71035,int_stack+70615, 1.0, int_stack+117175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+303525,int_stack+302265,int_stack+250920, 1.0, int_stack+142950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+305415,int_stack+71575,int_stack+71035, 1.0, int_stack+117595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+307035,int_stack+305415,int_stack+302265, 1.0, int_stack+143895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+309555,int_stack+307035,int_stack+303525, 1.0, int_stack+145155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+302265,int_stack+72250,int_stack+71575, 1.0, int_stack+118135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+142950,int_stack+302265,int_stack+305415, 1.0, int_stack+147045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+302265,int_stack+142950,int_stack+307035, 1.0, int_stack+153690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+312705,int_stack+302265,int_stack+309555, 1.0, int_stack+156210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+302265,int_stack+312705,int_stack+299115,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299115,int_stack+73516,int_stack+73075, 1.0, int_stack+122410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300438,int_stack+74104,int_stack+73516, 1.0, int_stack+122851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+142950,int_stack+300438,int_stack+299115, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+135360,int_stack+74860,int_stack+74104, 1.0, int_stack+123439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+375660,int_stack+135360,int_stack+300438, 1.0, int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+379188,int_stack+375660,int_stack+142950, 1.0, int_stack+148665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+142950,int_stack+75805,int_stack+74860, 1.0, int_stack+124195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+383598,int_stack+142950,int_stack+135360, 1.0, int_stack+151311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+388134,int_stack+383598,int_stack+375660, 1.0, int_stack+159360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+185505,int_stack+388134,int_stack+379188, 1.0, int_stack+181095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+375660,int_stack+185505,int_stack+312705,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+45003,int_stack+375660,int_stack+302265,315);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+389835,int_stack+78920,int_stack+77548, 1.0, int_stack+76960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+391599,int_stack+80712,int_stack+78920, 1.0, int_stack+78136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+142950,int_stack+391599,int_stack+389835, 1.0, int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+82980,int_stack+80712, 1.0, int_stack+79704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+299115,int_stack+0,int_stack+391599, 1.0, int_stack+4851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+303819,int_stack+299115,int_stack+142950, 1.0, int_stack+199680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+142950,int_stack+84240,int_stack+82980, 1.0, int_stack+81720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+309699,int_stack+142950,int_stack+0, 1.0, int_stack+203208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+192120,int_stack+309699,int_stack+299115, 1.0, int_stack+162888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+309699,int_stack+192120,int_stack+303819, 1.0, int_stack+167592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+192120,int_stack+309699,int_stack+185505,315);
 /*--- compute (gd|hg) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+452205,int_stack+192120,int_stack+375660,315);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+375660,int_stack+114460,int_stack+114010,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+377010,int_stack+375660,int_stack+138090,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+379170,int_stack+377010,int_stack+139170,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+375660,int_stack+379170,int_stack+140850,10);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+378810,int_stack+118810,int_stack+118135,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+380835,int_stack+378810,int_stack+147045,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+384075,int_stack+380835,int_stack+153690,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+378810,int_stack+384075,int_stack+156210,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+383535,int_stack+378810,int_stack+375660,315);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+185505,int_stack+125140,int_stack+124195,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+188340,int_stack+185505,int_stack+151311,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+192876,int_stack+188340,int_stack+159360,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+185505,int_stack+192876,int_stack+181095,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+192120,int_stack+185505,int_stack+378810,315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+299115,int_stack+192120,int_stack+383535,315);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+206295,int_stack+85990,int_stack+85780,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+206925,int_stack+86270,int_stack+85990,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+207765,int_stack+206925,int_stack+206295,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+209025,int_stack+86630,int_stack+86270,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+210105,int_stack+209025,int_stack+206925,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+392985,int_stack+210105,int_stack+207765,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+206295,int_stack+87080,int_stack+86630,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+206295,int_stack+209025,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+206295,int_stack+0,int_stack+210105,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+206295,int_stack+392985,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+318015,int_stack+87945,int_stack+87630,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+392985,int_stack+88365,int_stack+87945,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+206295,int_stack+392985,int_stack+318015,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+208185,int_stack+88905,int_stack+88365,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+209805,int_stack+208185,int_stack+392985,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3150,int_stack+209805,int_stack+206295,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+392985,int_stack+89580,int_stack+88905,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+135360,int_stack+392985,int_stack+208185,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+138600,int_stack+135360,int_stack+209805,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+206295,int_stack+138600,int_stack+3150,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+135360,int_stack+206295,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+90846,int_stack+90405,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+91434,int_stack+90846,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+144810,int_stack+92190,int_stack+91434,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+147078,int_stack+144810,int_stack+1323,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+150606,int_stack+147078,int_stack+3087,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+93135,int_stack+92190,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+155016,int_stack+0,int_stack+144810,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+155016,int_stack+147078,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+155016,int_stack+0,int_stack+150606,21);
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+161631,int_stack+155016,int_stack+206295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (fd|hg) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+63903,int_stack+161631,int_stack+135360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+135360,int_stack+94878,int_stack+94290,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+137124,int_stack+95662,int_stack+94878,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+139476,int_stack+137124,int_stack+135360,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+143004,int_stack+96670,int_stack+95662,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+146028,int_stack+143004,int_stack+137124,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+206295,int_stack+146028,int_stack+139476,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+135360,int_stack+97930,int_stack+96670,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+135360,int_stack+143004,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+135360,int_stack+0,int_stack+146028,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+143200,int_stack+135360,int_stack+206295,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+480555,int_stack+143200,int_stack+155016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (gd|hg) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+500400,int_stack+480555,int_stack+161631, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+480555,int_stack+99680,int_stack+99470,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+481185,int_stack+99960,int_stack+99680,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+482025,int_stack+481185,int_stack+480555,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+483285,int_stack+100320,int_stack+99960,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+484365,int_stack+483285,int_stack+481185,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+486045,int_stack+484365,int_stack+482025,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+480555,int_stack+100770,int_stack+100320,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+488145,int_stack+480555,int_stack+483285,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+480555,int_stack+488145,int_stack+484365,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+488145,int_stack+480555,int_stack+486045,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+318015,int_stack+101635,int_stack+101320,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+480555,int_stack+102055,int_stack+101635,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+481815,int_stack+480555,int_stack+318015,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+483705,int_stack+102595,int_stack+102055,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+392985,int_stack+483705,int_stack+480555,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+491295,int_stack+392985,int_stack+481815,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+480555,int_stack+103270,int_stack+102595,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+494445,int_stack+480555,int_stack+483705,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+480555,int_stack+494445,int_stack+392985,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+494445,int_stack+480555,int_stack+491295,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+135360,int_stack+494445,int_stack+488145, 0.0, zero_stack, 1.0, int_stack+375660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+480555,int_stack+104536,int_stack+104095,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+481878,int_stack+105124,int_stack+104536,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+483642,int_stack+481878,int_stack+480555,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+486288,int_stack+105880,int_stack+105124,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+488556,int_stack+486288,int_stack+481878,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+206295,int_stack+488556,int_stack+483642,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+480555,int_stack+106825,int_stack+105880,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+144810,int_stack+480555,int_stack+486288,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+480555,int_stack+144810,int_stack+488556,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+144810,int_stack+480555,int_stack+206295,21);
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+151425,int_stack+144810,int_stack+494445, 0.0, zero_stack, 1.0, int_stack+378810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (fd|hg) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+480555,int_stack+151425,int_stack+135360, 0.0, zero_stack, 1.0, int_stack+383535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+135360,int_stack+108568,int_stack+107980,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+137124,int_stack+109352,int_stack+108568,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+139476,int_stack+137124,int_stack+135360,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+206295,int_stack+110360,int_stack+109352,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+165600,int_stack+206295,int_stack+137124,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+170304,int_stack+165600,int_stack+139476,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+135360,int_stack+111620,int_stack+110360,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+176184,int_stack+135360,int_stack+206295,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+135360,int_stack+176184,int_stack+165600,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+176184,int_stack+135360,int_stack+170304,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+82803,int_stack+176184,int_stack+144810, 0.0, zero_stack, 1.0, int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (gd|hg) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+528750,int_stack+82803,int_stack+151425, 0.0, zero_stack, 1.0, int_stack+192120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+82803,int_stack+115220,int_stack+115010,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+83433,int_stack+115500,int_stack+115220,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+84273,int_stack+83433,int_stack+82803,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+85533,int_stack+115860,int_stack+115500,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+86613,int_stack+85533,int_stack+83433,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+88293,int_stack+86613,int_stack+84273,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+82803,int_stack+116310,int_stack+115860,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+90393,int_stack+82803,int_stack+85533,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+82803,int_stack+90393,int_stack+86613,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+90393,int_stack+82803,int_stack+88293,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+499455,int_stack+119950,int_stack+119635,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+82803,int_stack+120370,int_stack+119950,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+84063,int_stack+82803,int_stack+499455,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+85953,int_stack+120910,int_stack+120370,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+392985,int_stack+85953,int_stack+82803,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+93543,int_stack+392985,int_stack+84063,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+82803,int_stack+121585,int_stack+120910,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+96693,int_stack+82803,int_stack+85953,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+82803,int_stack+96693,int_stack+392985,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+96693,int_stack+82803,int_stack+93543,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+101418,int_stack+96693,int_stack+90393, 1.0, int_stack+375660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+375660,int_stack+126736,int_stack+126295,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+376983,int_stack+127324,int_stack+126736,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+82803,int_stack+376983,int_stack+375660,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+85449,int_stack+128080,int_stack+127324,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+87717,int_stack+85449,int_stack+376983,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+91245,int_stack+87717,int_stack+82803,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+375660,int_stack+129025,int_stack+128080,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+110868,int_stack+375660,int_stack+85449,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+115404,int_stack+110868,int_stack+87717,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+82803,int_stack+115404,int_stack+91245,21);
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+110868,int_stack+82803,int_stack+96693, 1.0, int_stack+378810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (fd|hg) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+135360,int_stack+110868,int_stack+101418, 1.0, int_stack+383535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+125043,int_stack+130768,int_stack+130180,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+126807,int_stack+131552,int_stack+130768,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+375660,int_stack+126807,int_stack+125043,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+379188,int_stack+132560,int_stack+131552,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+382212,int_stack+379188,int_stack+126807,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+125043,int_stack+382212,int_stack+375660,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+386916,int_stack+133820,int_stack+132560,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+89418,int_stack+386916,int_stack+379188,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+386916,int_stack+89418,int_stack+382212,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+89418,int_stack+386916,int_stack+125043,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+375660,int_stack+89418,int_stack+82803, 1.0, int_stack+185505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (gd|hg) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+154260,int_stack+375660,int_stack+110868, 1.0, int_stack+192120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (ff|hg) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+82803,int_stack+251865,int_stack+213120,315);
     Libderiv->ABCD[11] = int_stack + 82803;
 /*--- compute (ff|hg) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+182610,int_stack+318960,int_stack+280215,315);
     Libderiv->ABCD[10] = int_stack + 182610;
 /*--- compute (ff|hg) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+250920,int_stack+347310,int_stack+7203,315);
     Libderiv->ABCD[9] = int_stack + 250920;
 /*--- compute (ff|hg) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+318015,int_stack+395505,int_stack+26103,315);
     Libderiv->ABCD[8] = int_stack + 318015;
 /*--- compute (ff|hg) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+349515,int_stack+423855,int_stack+232020,315);
     Libderiv->ABCD[7] = int_stack + 349515;
 /*--- compute (ff|hg) ---*/
   hrr1_build_ff(Libderiv->AB,int_stack+214110,int_stack+452205,int_stack+45003,315);
     Libderiv->ABCD[6] = int_stack + 214110;
 /*--- compute (ff|hg) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+381015,int_stack+500400,int_stack+63903, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 381015;
 /*--- compute (ff|hg) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+412515,int_stack+528750,int_stack+480555, 0.0, zero_stack, 1.0, int_stack+299115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 412515;
 /*--- compute (ff|hg) ---*/
   d1hrr1_build_ff(Libderiv->AB,int_stack+444015,int_stack+154260,int_stack+135360, 1.0, int_stack+299115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 444015;

}
