/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gdhf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gd|hf) integrals */

void d1hrr_order_gdhf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][5][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][11] = int_stack + 315;
 Libderiv->deriv_classes[4][7][11] = int_stack + 735;
 Libderiv->deriv_classes[4][8][11] = int_stack + 1275;
 Libderiv->deriv_classes[5][5][11] = int_stack + 1950;
 Libderiv->deriv_classes[5][6][11] = int_stack + 2391;
 Libderiv->deriv_classes[5][7][11] = int_stack + 2979;
 Libderiv->deriv_classes[5][8][11] = int_stack + 3735;
 Libderiv->deriv_classes[6][5][11] = int_stack + 4680;
 Libderiv->deriv_classes[6][6][11] = int_stack + 5268;
 Libderiv->deriv_classes[6][7][11] = int_stack + 6052;
 Libderiv->deriv_classes[6][8][11] = int_stack + 7060;
 Libderiv->deriv_classes[4][5][10] = int_stack + 8320;
 Libderiv->deriv_classes[4][6][10] = int_stack + 8635;
 Libderiv->deriv_classes[4][7][10] = int_stack + 9055;
 Libderiv->deriv_classes[4][8][10] = int_stack + 9595;
 Libderiv->deriv_classes[5][5][10] = int_stack + 10270;
 Libderiv->deriv_classes[5][6][10] = int_stack + 10711;
 Libderiv->deriv_classes[5][7][10] = int_stack + 11299;
 Libderiv->deriv_classes[5][8][10] = int_stack + 12055;
 Libderiv->deriv_classes[6][5][10] = int_stack + 13000;
 Libderiv->deriv_classes[6][6][10] = int_stack + 13588;
 Libderiv->deriv_classes[6][7][10] = int_stack + 14372;
 Libderiv->deriv_classes[6][8][10] = int_stack + 15380;
 Libderiv->deriv_classes[4][5][9] = int_stack + 16640;
 Libderiv->deriv_classes[4][6][9] = int_stack + 16955;
 Libderiv->deriv_classes[4][7][9] = int_stack + 17375;
 Libderiv->deriv_classes[4][8][9] = int_stack + 17915;
 Libderiv->deriv_classes[5][5][9] = int_stack + 18590;
 Libderiv->deriv_classes[5][6][9] = int_stack + 19031;
 Libderiv->deriv_classes[5][7][9] = int_stack + 19619;
 Libderiv->deriv_classes[5][8][9] = int_stack + 20375;
 Libderiv->deriv_classes[6][5][9] = int_stack + 21320;
 Libderiv->deriv_classes[6][6][9] = int_stack + 21908;
 Libderiv->deriv_classes[6][7][9] = int_stack + 22692;
 Libderiv->deriv_classes[6][8][9] = int_stack + 23700;
 Libderiv->deriv_classes[4][5][8] = int_stack + 24960;
 Libderiv->deriv_classes[4][6][8] = int_stack + 25275;
 Libderiv->deriv_classes[4][7][8] = int_stack + 25695;
 Libderiv->deriv_classes[4][8][8] = int_stack + 26235;
 Libderiv->deriv_classes[5][5][8] = int_stack + 26910;
 Libderiv->deriv_classes[5][6][8] = int_stack + 27351;
 Libderiv->deriv_classes[5][7][8] = int_stack + 27939;
 Libderiv->deriv_classes[5][8][8] = int_stack + 28695;
 Libderiv->deriv_classes[6][5][8] = int_stack + 29640;
 Libderiv->deriv_classes[6][6][8] = int_stack + 30228;
 Libderiv->deriv_classes[6][7][8] = int_stack + 31012;
 Libderiv->deriv_classes[6][8][8] = int_stack + 32020;
 Libderiv->deriv_classes[4][5][7] = int_stack + 33280;
 Libderiv->deriv_classes[4][6][7] = int_stack + 33595;
 Libderiv->deriv_classes[4][7][7] = int_stack + 34015;
 Libderiv->deriv_classes[4][8][7] = int_stack + 34555;
 Libderiv->deriv_classes[5][5][7] = int_stack + 35230;
 Libderiv->deriv_classes[5][6][7] = int_stack + 35671;
 Libderiv->deriv_classes[5][7][7] = int_stack + 36259;
 Libderiv->deriv_classes[5][8][7] = int_stack + 37015;
 Libderiv->deriv_classes[6][5][7] = int_stack + 37960;
 Libderiv->deriv_classes[6][6][7] = int_stack + 38548;
 Libderiv->deriv_classes[6][7][7] = int_stack + 39332;
 Libderiv->deriv_classes[6][8][7] = int_stack + 40340;
 Libderiv->deriv_classes[4][5][6] = int_stack + 41600;
 Libderiv->deriv_classes[4][6][6] = int_stack + 41915;
 Libderiv->deriv_classes[4][7][6] = int_stack + 42335;
 Libderiv->deriv_classes[4][8][6] = int_stack + 42875;
 Libderiv->deriv_classes[5][5][6] = int_stack + 43550;
 Libderiv->deriv_classes[5][6][6] = int_stack + 43991;
 Libderiv->deriv_classes[5][7][6] = int_stack + 44579;
 Libderiv->deriv_classes[5][8][6] = int_stack + 45335;
 Libderiv->dvrr_classes[6][5] = int_stack + 46280;
 Libderiv->deriv_classes[6][5][6] = int_stack + 46868;
 Libderiv->dvrr_classes[6][6] = int_stack + 47456;
 Libderiv->deriv_classes[6][6][6] = int_stack + 48240;
 Libderiv->dvrr_classes[6][7] = int_stack + 49024;
 Libderiv->deriv_classes[6][7][6] = int_stack + 50032;
 Libderiv->deriv_classes[6][8][6] = int_stack + 51040;
 Libderiv->deriv_classes[4][5][2] = int_stack + 52300;
 Libderiv->deriv_classes[4][6][2] = int_stack + 52615;
 Libderiv->deriv_classes[4][7][2] = int_stack + 53035;
 Libderiv->deriv_classes[4][8][2] = int_stack + 53575;
 Libderiv->deriv_classes[5][5][2] = int_stack + 54250;
 Libderiv->deriv_classes[5][6][2] = int_stack + 54691;
 Libderiv->deriv_classes[5][7][2] = int_stack + 55279;
 Libderiv->deriv_classes[5][8][2] = int_stack + 56035;
 Libderiv->deriv_classes[6][5][2] = int_stack + 56980;
 Libderiv->deriv_classes[6][6][2] = int_stack + 57568;
 Libderiv->deriv_classes[6][7][2] = int_stack + 58352;
 Libderiv->deriv_classes[6][8][2] = int_stack + 59360;
 Libderiv->deriv_classes[4][5][1] = int_stack + 60620;
 Libderiv->deriv_classes[4][6][1] = int_stack + 60935;
 Libderiv->deriv_classes[4][7][1] = int_stack + 61355;
 Libderiv->deriv_classes[4][8][1] = int_stack + 61895;
 Libderiv->deriv_classes[5][5][1] = int_stack + 62570;
 Libderiv->deriv_classes[5][6][1] = int_stack + 63011;
 Libderiv->deriv_classes[5][7][1] = int_stack + 63599;
 Libderiv->deriv_classes[5][8][1] = int_stack + 64355;
 Libderiv->deriv_classes[6][5][1] = int_stack + 65300;
 Libderiv->deriv_classes[6][6][1] = int_stack + 65888;
 Libderiv->deriv_classes[6][7][1] = int_stack + 66672;
 Libderiv->deriv_classes[6][8][1] = int_stack + 67680;
 Libderiv->dvrr_classes[4][5] = int_stack + 68940;
 Libderiv->dvrr_classes[4][6] = int_stack + 69255;
 Libderiv->dvrr_classes[4][7] = int_stack + 69675;
 Libderiv->dvrr_classes[4][8] = int_stack + 70215;
 Libderiv->deriv_classes[4][5][0] = int_stack + 70890;
 Libderiv->deriv_classes[4][6][0] = int_stack + 71205;
 Libderiv->deriv_classes[4][7][0] = int_stack + 71625;
 Libderiv->deriv_classes[4][8][0] = int_stack + 72165;
 Libderiv->dvrr_classes[5][5] = int_stack + 72840;
 Libderiv->dvrr_classes[5][6] = int_stack + 73281;
 Libderiv->dvrr_classes[5][7] = int_stack + 73869;
 Libderiv->dvrr_classes[5][8] = int_stack + 74625;
 Libderiv->deriv_classes[5][5][0] = int_stack + 75570;
 Libderiv->deriv_classes[5][6][0] = int_stack + 76011;
 Libderiv->deriv_classes[5][7][0] = int_stack + 76599;
 Libderiv->deriv_classes[5][8][0] = int_stack + 77355;
 Libderiv->deriv_classes[6][5][0] = int_stack + 78300;
 Libderiv->deriv_classes[6][6][0] = int_stack + 78888;
 Libderiv->deriv_classes[6][7][0] = int_stack + 79672;
 Libderiv->deriv_classes[6][8][0] = int_stack + 80680;
 memset(int_stack,0,655520);

 Libderiv->dvrr_stack = int_stack + 295450;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gdhf(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+81940,int_stack+69255,int_stack+68940,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+82885,int_stack+69675,int_stack+69255,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+84145,int_stack+82885,int_stack+81940,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+86035,int_stack+315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68940,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+86980,int_stack+735,int_stack+315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69255,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+88240,int_stack+86980,int_stack+86035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81940,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+90130,int_stack+1275,int_stack+735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69675,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+91750,int_stack+90130,int_stack+86980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82885,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+94270,int_stack+91750,int_stack+88240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84145,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+86035,int_stack+73281,int_stack+72840,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+87358,int_stack+73869,int_stack+73281,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+89122,int_stack+87358,int_stack+86035,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+91768,int_stack+2391,int_stack+1950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72840,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+2979,int_stack+2391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73281,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+97420,int_stack+0,int_stack+91768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86035,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+91768,int_stack+3735,int_stack+2979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73869,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+100066,int_stack+91768,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87358,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+100066,int_stack+97420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89122,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+97420,int_stack+0,int_stack+94270,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+91768,int_stack+47456,int_stack+46280,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+93532,int_stack+49024,int_stack+47456,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+106870,int_stack+93532,int_stack+91768,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+110398,int_stack+5268,int_stack+4680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46280,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+112162,int_stack+6052,int_stack+5268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47456,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+114514,int_stack+112162,int_stack+110398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91768,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+118042,int_stack+7060,int_stack+6052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49024,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+121066,int_stack+118042,int_stack+112162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93532,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+125770,int_stack+121066,int_stack+114514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106870,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+110398,int_stack+125770,int_stack+0,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+8635,int_stack+8320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68940, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+9055,int_stack+8635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69255, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2205,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81940, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4095,int_stack+9595,int_stack+9055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69675, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5715,int_stack+4095,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82885, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+123628,int_stack+5715,int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84145, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+10711,int_stack+10270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72840, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+11299,int_stack+10711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73281, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86035, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5733,int_stack+12055,int_stack+11299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73869, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001,int_stack+5733,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87358, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+126778,int_stack+8001,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89122, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+0,int_stack+126778,int_stack+123628,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+123628,int_stack+13588,int_stack+13000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46280, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+14372,int_stack+13588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47456, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+131188,int_stack+9450,int_stack+123628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91768, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+123628,int_stack+15380,int_stack+14372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49024, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11802,int_stack+123628,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93532, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+134716,int_stack+11802,int_stack+131188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106870, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+140596,int_stack+134716,int_stack+126778,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+16955,int_stack+16640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68940, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10395,int_stack+17375,int_stack+16955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69255, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11655,int_stack+10395,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81940, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13545,int_stack+17915,int_stack+17375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69675, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15165,int_stack+13545,int_stack+10395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82885, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+123628,int_stack+15165,int_stack+11655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84145, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+19031,int_stack+18590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72840, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+19619,int_stack+19031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73281, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12537,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86035, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15183,int_stack+20375,int_stack+19619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73869, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+17451,int_stack+15183,int_stack+10773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87358, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+126778,int_stack+17451,int_stack+12537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89122, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9450,int_stack+126778,int_stack+123628,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+123628,int_stack+21908,int_stack+21320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46280, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18900,int_stack+22692,int_stack+21908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47456, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+131188,int_stack+18900,int_stack+123628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91768, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+123628,int_stack+23700,int_stack+22692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49024, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+134716,int_stack+123628,int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93532, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+18900,int_stack+134716,int_stack+131188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106870, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+153826,int_stack+18900,int_stack+126778,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+167056,int_stack+25275,int_stack+24960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18900,int_stack+25695,int_stack+25275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20160,int_stack+18900,int_stack+167056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+22050,int_stack+26235,int_stack+25695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+23670,int_stack+22050,int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+123628,int_stack+23670,int_stack+20160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+27351,int_stack+26910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+20223,int_stack+27939,int_stack+27351, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21987,int_stack+20223,int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24633,int_stack+28695,int_stack+27939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+126778,int_stack+24633,int_stack+20223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+24633,int_stack+126778,int_stack+21987, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+126778,int_stack+24633,int_stack+123628,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+123628,int_stack+30228,int_stack+29640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+136228,int_stack+31012,int_stack+30228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18900,int_stack+136228,int_stack+123628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+123628,int_stack+32020,int_stack+31012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+167056,int_stack+123628,int_stack+136228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+171760,int_stack+167056,int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+177640,int_stack+171760,int_stack+24633,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+33595,int_stack+33280, 0.0, zero_stack, 1.0, int_stack+68940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19845,int_stack+34015,int_stack+33595, 0.0, zero_stack, 1.0, int_stack+69255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21105,int_stack+19845,int_stack+18900, 0.0, zero_stack, 1.0, int_stack+81940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+22995,int_stack+34555,int_stack+34015, 0.0, zero_stack, 1.0, int_stack+69675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+24615,int_stack+22995,int_stack+19845, 0.0, zero_stack, 1.0, int_stack+82885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+123628,int_stack+24615,int_stack+21105, 0.0, zero_stack, 1.0, int_stack+84145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+35671,int_stack+35230, 0.0, zero_stack, 1.0, int_stack+72840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+20223,int_stack+36259,int_stack+35671, 0.0, zero_stack, 1.0, int_stack+73281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21987,int_stack+20223,int_stack+18900, 0.0, zero_stack, 1.0, int_stack+86035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24633,int_stack+37015,int_stack+36259, 0.0, zero_stack, 1.0, int_stack+73869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26901,int_stack+24633,int_stack+20223, 0.0, zero_stack, 1.0, int_stack+87358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+30429,int_stack+26901,int_stack+21987, 0.0, zero_stack, 1.0, int_stack+89122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+18900,int_stack+30429,int_stack+123628,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+123628,int_stack+38548,int_stack+37960, 0.0, zero_stack, 1.0, int_stack+46280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34839,int_stack+39332,int_stack+38548, 0.0, zero_stack, 1.0, int_stack+47456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+167056,int_stack+34839,int_stack+123628, 0.0, zero_stack, 1.0, int_stack+91768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+123628,int_stack+40340,int_stack+39332, 0.0, zero_stack, 1.0, int_stack+49024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+170584,int_stack+123628,int_stack+34839, 0.0, zero_stack, 1.0, int_stack+93532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+34839,int_stack+170584,int_stack+167056, 0.0, zero_stack, 1.0, int_stack+106870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+190870,int_stack+34839,int_stack+30429,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+167056,int_stack+41915,int_stack+41600, 1.0, int_stack+68940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+168001,int_stack+42335,int_stack+41915, 1.0, int_stack+69255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+169261,int_stack+168001,int_stack+167056, 1.0, int_stack+81940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+171151,int_stack+42875,int_stack+42335, 1.0, int_stack+69675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+172771,int_stack+171151,int_stack+168001, 1.0, int_stack+82885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+123628,int_stack+172771,int_stack+169261, 1.0, int_stack+84145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+167056,int_stack+43991,int_stack+43550, 1.0, int_stack+72840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+168379,int_stack+44579,int_stack+43991, 1.0, int_stack+73281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+170143,int_stack+168379,int_stack+167056, 1.0, int_stack+86035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+172789,int_stack+45335,int_stack+44579, 1.0, int_stack+73869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28350,int_stack+172789,int_stack+168379, 1.0, int_stack+87358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+172789,int_stack+28350,int_stack+170143, 1.0, int_stack+89122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+28350,int_stack+172789,int_stack+123628,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+123628,int_stack+48240,int_stack+46868, 1.0, int_stack+46280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37800,int_stack+50032,int_stack+48240, 1.0, int_stack+47456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+40152,int_stack+37800,int_stack+123628, 1.0, int_stack+91768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+123628,int_stack+51040,int_stack+50032, 1.0, int_stack+49024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43680,int_stack+123628,int_stack+37800, 1.0, int_stack+93532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+204100,int_stack+43680,int_stack+40152, 1.0, int_stack+106870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+37800,int_stack+204100,int_stack+172789,210);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+204100,int_stack+70215,int_stack+69675,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+205720,int_stack+204100,int_stack+82885,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+123628,int_stack+205720,int_stack+84145,15);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+204100,int_stack+74625,int_stack+73869,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+106870,int_stack+204100,int_stack+87358,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+204100,int_stack+106870,int_stack+89122,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+167056,int_stack+204100,int_stack+123628,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+106870,int_stack+52615,int_stack+52300,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+107815,int_stack+53035,int_stack+52615,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+208510,int_stack+107815,int_stack+106870,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+51030,int_stack+53575,int_stack+53035,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+72840,int_stack+51030,int_stack+107815,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+51030,int_stack+72840,int_stack+208510,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+208510,int_stack+54691,int_stack+54250,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+72840,int_stack+55279,int_stack+54691,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+106870,int_stack+72840,int_stack+208510,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+81940,int_stack+56035,int_stack+55279,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+84208,int_stack+81940,int_stack+72840,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+87736,int_stack+84208,int_stack+106870,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+208510,int_stack+87736,int_stack+51030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51030,int_stack+57568,int_stack+56980,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52794,int_stack+58352,int_stack+57568,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+106870,int_stack+52794,int_stack+51030,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+55146,int_stack+59360,int_stack+58352,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+81940,int_stack+55146,int_stack+52794,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+51030,int_stack+81940,int_stack+106870,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+217960,int_stack+51030,int_stack+87736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51030,int_stack+60935,int_stack+60620,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+51975,int_stack+61355,int_stack+60935,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+53235,int_stack+51975,int_stack+51030,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+55125,int_stack+61895,int_stack+61355,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+56745,int_stack+55125,int_stack+51975,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+59265,int_stack+56745,int_stack+53235,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51030,int_stack+63011,int_stack+62570,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52353,int_stack+63599,int_stack+63011,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+54117,int_stack+52353,int_stack+51030,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+56763,int_stack+64355,int_stack+63599,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+106870,int_stack+56763,int_stack+52353,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+81940,int_stack+106870,int_stack+54117,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+86350,int_stack+81940,int_stack+59265, 0.0, zero_stack, 1.0, int_stack+123628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+106870,int_stack+65888,int_stack+65300,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+51030,int_stack+66672,int_stack+65888,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+53382,int_stack+51030,int_stack+106870,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+106870,int_stack+67680,int_stack+66672,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+56910,int_stack+106870,int_stack+51030,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+61614,int_stack+56910,int_stack+53382,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+231190,int_stack+61614,int_stack+81940, 0.0, zero_stack, 1.0, int_stack+204100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+81940,int_stack+71205,int_stack+70890,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+82885,int_stack+71625,int_stack+71205,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+84145,int_stack+82885,int_stack+81940,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+95800,int_stack+72165,int_stack+71625,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+51030,int_stack+95800,int_stack+82885,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+53550,int_stack+51030,int_stack+84145,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51030,int_stack+76011,int_stack+75570,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+81940,int_stack+76599,int_stack+76011,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+83704,int_stack+81940,int_stack+51030,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+51030,int_stack+77355,int_stack+76599,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+106870,int_stack+51030,int_stack+81940,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+56700,int_stack+106870,int_stack+83704,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+61110,int_stack+56700,int_stack+53550, 1.0, int_stack+123628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+123628,int_stack+78888,int_stack+78300,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+106870,int_stack+79672,int_stack+78888,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+81940,int_stack+106870,int_stack+123628,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+123628,int_stack+80680,int_stack+79672,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+51030,int_stack+123628,int_stack+106870,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+70560,int_stack+51030,int_stack+81940,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+244420,int_stack+70560,int_stack+56700, 1.0, int_stack+204100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+257650,int_stack+110398,int_stack+97420,210);
     Libderiv->ABCD[11] = int_stack + 257650;
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+95800,int_stack+140596,int_stack+0,210);
     Libderiv->ABCD[10] = int_stack + 95800;
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+276550,int_stack+153826,int_stack+9450,210);
     Libderiv->ABCD[9] = int_stack + 276550;
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+177640,int_stack+126778,210);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+114700,int_stack+190870,int_stack+18900,210);
     Libderiv->ABCD[7] = int_stack + 114700;
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+133600,int_stack+37800,int_stack+28350,210);
     Libderiv->ABCD[6] = int_stack + 133600;
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+18900,int_stack+217960,int_stack+208510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 18900;
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+37800,int_stack+231190,int_stack+86350, 0.0, zero_stack, 1.0, int_stack+167056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 37800;
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+70560,int_stack+244420,int_stack+61110, 1.0, int_stack+167056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 70560;

}
