/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ipig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ip|ig) integrals */

void d1hrr_order_ipig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][9][11] = int_stack + 3052;
 Libderiv->deriv_classes[6][10][11] = int_stack + 4592;
 Libderiv->deriv_classes[7][6][11] = int_stack + 6440;
 Libderiv->deriv_classes[7][7][11] = int_stack + 7448;
 Libderiv->deriv_classes[7][8][11] = int_stack + 8744;
 Libderiv->deriv_classes[7][9][11] = int_stack + 10364;
 Libderiv->deriv_classes[7][10][11] = int_stack + 12344;
 Libderiv->deriv_classes[6][6][10] = int_stack + 14720;
 Libderiv->deriv_classes[6][7][10] = int_stack + 15504;
 Libderiv->deriv_classes[6][8][10] = int_stack + 16512;
 Libderiv->deriv_classes[6][9][10] = int_stack + 17772;
 Libderiv->deriv_classes[6][10][10] = int_stack + 19312;
 Libderiv->deriv_classes[7][6][10] = int_stack + 21160;
 Libderiv->deriv_classes[7][7][10] = int_stack + 22168;
 Libderiv->deriv_classes[7][8][10] = int_stack + 23464;
 Libderiv->deriv_classes[7][9][10] = int_stack + 25084;
 Libderiv->deriv_classes[7][10][10] = int_stack + 27064;
 Libderiv->deriv_classes[6][6][9] = int_stack + 29440;
 Libderiv->deriv_classes[6][7][9] = int_stack + 30224;
 Libderiv->deriv_classes[6][8][9] = int_stack + 31232;
 Libderiv->deriv_classes[6][9][9] = int_stack + 32492;
 Libderiv->deriv_classes[6][10][9] = int_stack + 34032;
 Libderiv->deriv_classes[7][6][9] = int_stack + 35880;
 Libderiv->deriv_classes[7][7][9] = int_stack + 36888;
 Libderiv->deriv_classes[7][8][9] = int_stack + 38184;
 Libderiv->deriv_classes[7][9][9] = int_stack + 39804;
 Libderiv->deriv_classes[7][10][9] = int_stack + 41784;
 Libderiv->deriv_classes[6][6][8] = int_stack + 44160;
 Libderiv->deriv_classes[6][7][8] = int_stack + 44944;
 Libderiv->deriv_classes[6][8][8] = int_stack + 45952;
 Libderiv->deriv_classes[6][9][8] = int_stack + 47212;
 Libderiv->deriv_classes[6][10][8] = int_stack + 48752;
 Libderiv->deriv_classes[7][6][8] = int_stack + 50600;
 Libderiv->deriv_classes[7][7][8] = int_stack + 51608;
 Libderiv->deriv_classes[7][8][8] = int_stack + 52904;
 Libderiv->deriv_classes[7][9][8] = int_stack + 54524;
 Libderiv->deriv_classes[7][10][8] = int_stack + 56504;
 Libderiv->deriv_classes[6][6][7] = int_stack + 58880;
 Libderiv->deriv_classes[6][7][7] = int_stack + 59664;
 Libderiv->deriv_classes[6][8][7] = int_stack + 60672;
 Libderiv->deriv_classes[6][9][7] = int_stack + 61932;
 Libderiv->deriv_classes[6][10][7] = int_stack + 63472;
 Libderiv->deriv_classes[7][6][7] = int_stack + 65320;
 Libderiv->deriv_classes[7][7][7] = int_stack + 66328;
 Libderiv->deriv_classes[7][8][7] = int_stack + 67624;
 Libderiv->deriv_classes[7][9][7] = int_stack + 69244;
 Libderiv->deriv_classes[7][10][7] = int_stack + 71224;
 Libderiv->deriv_classes[6][6][6] = int_stack + 73600;
 Libderiv->deriv_classes[6][7][6] = int_stack + 74384;
 Libderiv->deriv_classes[6][8][6] = int_stack + 75392;
 Libderiv->deriv_classes[6][9][6] = int_stack + 76652;
 Libderiv->deriv_classes[6][10][6] = int_stack + 78192;
 Libderiv->dvrr_classes[7][6] = int_stack + 80040;
 Libderiv->deriv_classes[7][6][6] = int_stack + 81048;
 Libderiv->dvrr_classes[7][7] = int_stack + 82056;
 Libderiv->deriv_classes[7][7][6] = int_stack + 83352;
 Libderiv->dvrr_classes[7][8] = int_stack + 84648;
 Libderiv->deriv_classes[7][8][6] = int_stack + 86268;
 Libderiv->dvrr_classes[7][9] = int_stack + 87888;
 Libderiv->deriv_classes[7][9][6] = int_stack + 89868;
 Libderiv->deriv_classes[7][10][6] = int_stack + 91848;
 Libderiv->deriv_classes[6][6][2] = int_stack + 94224;
 Libderiv->deriv_classes[6][7][2] = int_stack + 95008;
 Libderiv->deriv_classes[6][8][2] = int_stack + 96016;
 Libderiv->deriv_classes[6][9][2] = int_stack + 97276;
 Libderiv->deriv_classes[6][10][2] = int_stack + 98816;
 Libderiv->deriv_classes[7][6][2] = int_stack + 100664;
 Libderiv->deriv_classes[7][7][2] = int_stack + 101672;
 Libderiv->deriv_classes[7][8][2] = int_stack + 102968;
 Libderiv->deriv_classes[7][9][2] = int_stack + 104588;
 Libderiv->deriv_classes[7][10][2] = int_stack + 106568;
 Libderiv->deriv_classes[6][6][1] = int_stack + 108944;
 Libderiv->deriv_classes[6][7][1] = int_stack + 109728;
 Libderiv->deriv_classes[6][8][1] = int_stack + 110736;
 Libderiv->deriv_classes[6][9][1] = int_stack + 111996;
 Libderiv->deriv_classes[6][10][1] = int_stack + 113536;
 Libderiv->deriv_classes[7][6][1] = int_stack + 115384;
 Libderiv->deriv_classes[7][7][1] = int_stack + 116392;
 Libderiv->deriv_classes[7][8][1] = int_stack + 117688;
 Libderiv->deriv_classes[7][9][1] = int_stack + 119308;
 Libderiv->deriv_classes[7][10][1] = int_stack + 121288;
 Libderiv->dvrr_classes[6][6] = int_stack + 123664;
 Libderiv->dvrr_classes[6][7] = int_stack + 124448;
 Libderiv->dvrr_classes[6][8] = int_stack + 125456;
 Libderiv->dvrr_classes[6][9] = int_stack + 126716;
 Libderiv->dvrr_classes[6][10] = int_stack + 128256;
 Libderiv->deriv_classes[6][6][0] = int_stack + 130104;
 Libderiv->deriv_classes[6][7][0] = int_stack + 130888;
 Libderiv->deriv_classes[6][8][0] = int_stack + 131896;
 Libderiv->deriv_classes[6][9][0] = int_stack + 133156;
 Libderiv->deriv_classes[6][10][0] = int_stack + 134696;
 Libderiv->deriv_classes[7][6][0] = int_stack + 136544;
 Libderiv->deriv_classes[7][7][0] = int_stack + 137552;
 Libderiv->deriv_classes[7][8][0] = int_stack + 138848;
 Libderiv->deriv_classes[7][9][0] = int_stack + 140468;
 Libderiv->deriv_classes[7][10][0] = int_stack + 142448;
 memset(int_stack,0,1158592);

 Libderiv->dvrr_stack = int_stack + 424656;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ipig(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+144824,int_stack+124448,int_stack+123664,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+147176,int_stack+125456,int_stack+124448,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+150200,int_stack+147176,int_stack+144824,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+154904,int_stack+126716,int_stack+125456,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+158684,int_stack+154904,int_stack+147176,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+164732,int_stack+158684,int_stack+150200,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+172572,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123664,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+174924,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124448,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+177948,int_stack+174924,int_stack+172572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144824,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+182652,int_stack+3052,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125456,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+186432,int_stack+182652,int_stack+174924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147176,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+192480,int_stack+186432,int_stack+177948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150200,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+172572,int_stack+4592,int_stack+3052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126716,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+200320,int_stack+172572,int_stack+182652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154904,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+172572,int_stack+200320,int_stack+186432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158684,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+200320,int_stack+172572,int_stack+192480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164732,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+172572,int_stack+82056,int_stack+80040,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+175596,int_stack+84648,int_stack+82056,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+179484,int_stack+175596,int_stack+172572,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+185532,int_stack+87888,int_stack+84648,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+190392,int_stack+185532,int_stack+175596,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+212080,int_stack+190392,int_stack+179484,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+7448,int_stack+6440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80040,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3024,int_stack+8744,int_stack+7448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82056,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222160,int_stack+3024,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172572,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+228208,int_stack+10364,int_stack+8744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84648,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+233068,int_stack+228208,int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175596,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+233068,int_stack+222160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179484,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+222160,int_stack+12344,int_stack+10364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87888,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+240844,int_stack+222160,int_stack+228208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185532,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+250564,int_stack+240844,int_stack+233068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190392,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+222160,int_stack+250564,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212080,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+15504,int_stack+14720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123664, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+16512,int_stack+15504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124448, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144824, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+17772,int_stack+16512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125456, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+237280,int_stack+10080,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147176, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+243328,int_stack+237280,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150200, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+19312,int_stack+17772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126716, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+251168,int_stack+0,int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154904, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+251168,int_stack+237280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158684, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+251168,int_stack+0,int_stack+243328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164732, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+22168,int_stack+21160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80040, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3024,int_stack+23464,int_stack+22168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82056, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6912,int_stack+3024,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172572, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12960,int_stack+25084,int_stack+23464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84648, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+237280,int_stack+12960,int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175596, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+262928,int_stack+237280,int_stack+6912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179484, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+27064,int_stack+25084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87888, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+17820,int_stack+0,int_stack+12960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185532, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+17820,int_stack+237280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190392, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12960,int_stack+0,int_stack+262928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212080, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+262928,int_stack+30224,int_stack+29440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123664, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+265280,int_stack+31232,int_stack+30224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+268304,int_stack+265280,int_stack+262928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144824, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+32492,int_stack+31232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125456, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3780,int_stack+0,int_stack+265280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147176, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+237280,int_stack+3780,int_stack+268304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150200, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+262928,int_stack+34032,int_stack+32492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126716, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+28080,int_stack+262928,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154904, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+262928,int_stack+28080,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158684, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+262928,int_stack+237280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164732, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+237280,int_stack+36888,int_stack+35880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80040, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+240304,int_stack+38184,int_stack+36888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82056, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+244192,int_stack+240304,int_stack+237280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172572, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+262928,int_stack+39804,int_stack+38184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84648, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+28080,int_stack+262928,int_stack+240304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175596, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+267788,int_stack+28080,int_stack+244192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179484, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+237280,int_stack+41784,int_stack+39804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87888, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+277868,int_stack+237280,int_stack+262928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185532, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+237280,int_stack+277868,int_stack+28080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190392, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+28080,int_stack+237280,int_stack+267788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212080, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+237280,int_stack+44944,int_stack+44160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+239632,int_stack+45952,int_stack+44944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+242656,int_stack+239632,int_stack+237280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+247360,int_stack+47212,int_stack+45952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+262928,int_stack+247360,int_stack+239632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+268976,int_stack+262928,int_stack+242656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+237280,int_stack+48752,int_stack+47212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+276816,int_stack+237280,int_stack+247360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+237280,int_stack+276816,int_stack+262928, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+276816,int_stack+237280,int_stack+268976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+237280,int_stack+51608,int_stack+50600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+240304,int_stack+52904,int_stack+51608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+244192,int_stack+240304,int_stack+237280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+262928,int_stack+54524,int_stack+52904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+267788,int_stack+262928,int_stack+240304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43200,int_stack+267788,int_stack+244192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+237280,int_stack+56504,int_stack+54524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+288576,int_stack+237280,int_stack+262928, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+237280,int_stack+288576,int_stack+267788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+288576,int_stack+237280,int_stack+43200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+212080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43200,int_stack+59664,int_stack+58880, 0.0, zero_stack, 1.0, int_stack+123664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45552,int_stack+60672,int_stack+59664, 0.0, zero_stack, 1.0, int_stack+124448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+48576,int_stack+45552,int_stack+43200, 0.0, zero_stack, 1.0, int_stack+144824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+53280,int_stack+61932,int_stack+60672, 0.0, zero_stack, 1.0, int_stack+125456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+237280,int_stack+53280,int_stack+45552, 0.0, zero_stack, 1.0, int_stack+147176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+243328,int_stack+237280,int_stack+48576, 0.0, zero_stack, 1.0, int_stack+150200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+43200,int_stack+63472,int_stack+61932, 0.0, zero_stack, 1.0, int_stack+126716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+57060,int_stack+43200,int_stack+53280, 0.0, zero_stack, 1.0, int_stack+154904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+43200,int_stack+57060,int_stack+237280, 0.0, zero_stack, 1.0, int_stack+158684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+53280,int_stack+43200,int_stack+243328, 0.0, zero_stack, 1.0, int_stack+164732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43200,int_stack+66328,int_stack+65320, 0.0, zero_stack, 1.0, int_stack+80040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46224,int_stack+67624,int_stack+66328, 0.0, zero_stack, 1.0, int_stack+82056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+237280,int_stack+46224,int_stack+43200, 0.0, zero_stack, 1.0, int_stack+172572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+243328,int_stack+69244,int_stack+67624, 0.0, zero_stack, 1.0, int_stack+84648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+262928,int_stack+243328,int_stack+46224, 0.0, zero_stack, 1.0, int_stack+175596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43200,int_stack+262928,int_stack+237280, 0.0, zero_stack, 1.0, int_stack+179484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+237280,int_stack+71224,int_stack+69244, 0.0, zero_stack, 1.0, int_stack+87888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+303696,int_stack+237280,int_stack+243328, 0.0, zero_stack, 1.0, int_stack+185532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+237280,int_stack+303696,int_stack+262928, 0.0, zero_stack, 1.0, int_stack+190392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+303696,int_stack+237280,int_stack+43200, 0.0, zero_stack, 1.0, int_stack+212080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43200,int_stack+74384,int_stack+73600, 1.0, int_stack+123664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45552,int_stack+75392,int_stack+74384, 1.0, int_stack+124448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+48576,int_stack+45552,int_stack+43200, 1.0, int_stack+144824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+237280,int_stack+76652,int_stack+75392, 1.0, int_stack+125456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+241060,int_stack+237280,int_stack+45552, 1.0, int_stack+147176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+262928,int_stack+241060,int_stack+48576, 1.0, int_stack+150200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+144824,int_stack+78192,int_stack+76652, 1.0, int_stack+126716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+43200,int_stack+144824,int_stack+237280, 1.0, int_stack+154904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+144824,int_stack+43200,int_stack+241060, 1.0, int_stack+158684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+237280,int_stack+144824,int_stack+262928, 1.0, int_stack+164732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+262928,int_stack+83352,int_stack+81048, 1.0, int_stack+80040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+265952,int_stack+86268,int_stack+83352, 1.0, int_stack+82056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+269840,int_stack+265952,int_stack+262928, 1.0, int_stack+172572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+144824,int_stack+89868,int_stack+86268, 1.0, int_stack+84648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+43200,int_stack+144824,int_stack+265952, 1.0, int_stack+175596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+65040,int_stack+43200,int_stack+269840, 1.0, int_stack+179484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+172572,int_stack+91848,int_stack+89868, 1.0, int_stack+87888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+262928,int_stack+172572,int_stack+144824, 1.0, int_stack+185532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+172572,int_stack+262928,int_stack+43200, 1.0, int_stack+190392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+75120,int_stack+172572,int_stack+65040, 1.0, int_stack+212080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+212080,int_stack+128256,int_stack+126716,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+65040,int_stack+212080,int_stack+154904,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+212080,int_stack+65040,int_stack+158684,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+172572,int_stack+212080,int_stack+164732,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+212080,int_stack+95008,int_stack+94224,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+214432,int_stack+96016,int_stack+95008,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+217456,int_stack+214432,int_stack+212080,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+65040,int_stack+97276,int_stack+96016,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+68820,int_stack+65040,int_stack+214432,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+184332,int_stack+68820,int_stack+217456,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+212080,int_stack+98816,int_stack+97276,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+192172,int_stack+212080,int_stack+65040,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+212080,int_stack+192172,int_stack+68820,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+262928,int_stack+212080,int_stack+184332,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+184332,int_stack+101672,int_stack+100664,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+187356,int_stack+102968,int_stack+101672,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+191244,int_stack+187356,int_stack+184332,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+212080,int_stack+104588,int_stack+102968,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+65040,int_stack+212080,int_stack+187356,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+43200,int_stack+65040,int_stack+191244,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+184332,int_stack+106568,int_stack+104588,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+190272,int_stack+184332,int_stack+212080,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+144824,int_stack+190272,int_stack+65040,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+184332,int_stack+144824,int_stack+43200,36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43200,int_stack+109728,int_stack+108944,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+45552,int_stack+110736,int_stack+109728,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+48576,int_stack+45552,int_stack+43200,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+144824,int_stack+111996,int_stack+110736,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+148604,int_stack+144824,int_stack+45552,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+154652,int_stack+148604,int_stack+48576,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+43200,int_stack+113536,int_stack+111996,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+162492,int_stack+43200,int_stack+144824,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+43200,int_stack+162492,int_stack+148604,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+90240,int_stack+43200,int_stack+154652,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43200,int_stack+116392,int_stack+115384,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+46224,int_stack+117688,int_stack+116392,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+144824,int_stack+46224,int_stack+43200,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+150872,int_stack+119308,int_stack+117688,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+155732,int_stack+150872,int_stack+46224,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+43200,int_stack+155732,int_stack+144824,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+144824,int_stack+121288,int_stack+119308,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+65040,int_stack+144824,int_stack+150872,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+102000,int_stack+65040,int_stack+155732,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+144824,int_stack+102000,int_stack+43200,36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43200,int_stack+130888,int_stack+130104,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+45552,int_stack+131896,int_stack+130888,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+48576,int_stack+45552,int_stack+43200,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+102000,int_stack+133156,int_stack+131896,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+105780,int_stack+102000,int_stack+45552,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+111828,int_stack+105780,int_stack+48576,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+43200,int_stack+134696,int_stack+133156,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+119668,int_stack+43200,int_stack+102000,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+43200,int_stack+119668,int_stack+105780,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+119668,int_stack+43200,int_stack+111828,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43200,int_stack+137552,int_stack+136544,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+46224,int_stack+138848,int_stack+137552,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+131428,int_stack+46224,int_stack+43200,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+102000,int_stack+140468,int_stack+138848,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+106860,int_stack+102000,int_stack+46224,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+43200,int_stack+106860,int_stack+131428,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+131428,int_stack+142448,int_stack+140468,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+65040,int_stack+131428,int_stack+102000,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+131428,int_stack+65040,int_stack+106860,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+102000,int_stack+131428,int_stack+43200,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+318816,int_stack+222160,int_stack+200320,420);
     Libderiv->ABCD[11] = int_stack + 318816;
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+199452,int_stack+12960,int_stack+251168,420);
     Libderiv->ABCD[10] = int_stack + 199452;
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+354096,int_stack+28080,int_stack+0,420);
     Libderiv->ABCD[9] = int_stack + 354096;
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+0,int_stack+288576,int_stack+276816,420);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+389376,int_stack+303696,int_stack+53280,420);
     Libderiv->ABCD[7] = int_stack + 389376;
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+35280,int_stack+75120,int_stack+237280,420);
     Libderiv->ABCD[6] = int_stack + 35280;
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+274688,int_stack+184332,int_stack+262928, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 274688;
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+234732,int_stack+144824,int_stack+90240, 0.0, zero_stack, 1.0, int_stack+172572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 234732;
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+131428,int_stack+102000,int_stack+119668, 1.0, int_stack+172572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 131428;

}
