/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include "libint.h"
#include "hrr_header.h"

extern void vrr_order_llmm(Libint_t*, prim_data*);

  /* Computes quartets of (ll|mm) integrals */

REALTYPE *hrr_order_llmm(Libint_t *Libint, int num_prim_comb)
{
 prim_data *Data = Libint->PrimQuartet;
 REALTYPE *int_stack = Libint->int_stack;
 int i;

 Libint->vrr_classes[8][9] = int_stack + 0;
 Libint->vrr_classes[8][10] = int_stack + 2475;
 Libint->vrr_classes[8][11] = int_stack + 5445;
 Libint->vrr_classes[8][12] = int_stack + 8955;
 Libint->vrr_classes[8][13] = int_stack + 13050;
 Libint->vrr_classes[8][14] = int_stack + 17775;
 Libint->vrr_classes[8][15] = int_stack + 23175;
 Libint->vrr_classes[8][16] = int_stack + 29295;
 Libint->vrr_classes[8][17] = int_stack + 36180;
 Libint->vrr_classes[8][18] = int_stack + 43875;
 Libint->vrr_classes[9][9] = int_stack + 52425;
 Libint->vrr_classes[9][10] = int_stack + 55450;
 Libint->vrr_classes[9][11] = int_stack + 59080;
 Libint->vrr_classes[9][12] = int_stack + 63370;
 Libint->vrr_classes[9][13] = int_stack + 68375;
 Libint->vrr_classes[9][14] = int_stack + 74150;
 Libint->vrr_classes[9][15] = int_stack + 80750;
 Libint->vrr_classes[9][16] = int_stack + 88230;
 Libint->vrr_classes[9][17] = int_stack + 96645;
 Libint->vrr_classes[9][18] = int_stack + 106050;
 Libint->vrr_classes[10][9] = int_stack + 116500;
 Libint->vrr_classes[10][10] = int_stack + 120130;
 Libint->vrr_classes[10][11] = int_stack + 124486;
 Libint->vrr_classes[10][12] = int_stack + 129634;
 Libint->vrr_classes[10][13] = int_stack + 135640;
 Libint->vrr_classes[10][14] = int_stack + 142570;
 Libint->vrr_classes[10][15] = int_stack + 150490;
 Libint->vrr_classes[10][16] = int_stack + 159466;
 Libint->vrr_classes[10][17] = int_stack + 169564;
 Libint->vrr_classes[10][18] = int_stack + 180850;
 Libint->vrr_classes[11][9] = int_stack + 193390;
 Libint->vrr_classes[11][10] = int_stack + 197680;
 Libint->vrr_classes[11][11] = int_stack + 202828;
 Libint->vrr_classes[11][12] = int_stack + 208912;
 Libint->vrr_classes[11][13] = int_stack + 216010;
 Libint->vrr_classes[11][14] = int_stack + 224200;
 Libint->vrr_classes[11][15] = int_stack + 233560;
 Libint->vrr_classes[11][16] = int_stack + 244168;
 Libint->vrr_classes[11][17] = int_stack + 256102;
 Libint->vrr_classes[11][18] = int_stack + 269440;
 Libint->vrr_classes[12][9] = int_stack + 284260;
 Libint->vrr_classes[12][10] = int_stack + 289265;
 Libint->vrr_classes[12][11] = int_stack + 295271;
 Libint->vrr_classes[12][12] = int_stack + 302369;
 Libint->vrr_classes[12][13] = int_stack + 310650;
 Libint->vrr_classes[12][14] = int_stack + 320205;
 Libint->vrr_classes[12][15] = int_stack + 331125;
 Libint->vrr_classes[12][16] = int_stack + 343501;
 Libint->vrr_classes[12][17] = int_stack + 357424;
 Libint->vrr_classes[12][18] = int_stack + 372985;
 Libint->vrr_classes[13][9] = int_stack + 390275;
 Libint->vrr_classes[13][10] = int_stack + 396050;
 Libint->vrr_classes[13][11] = int_stack + 402980;
 Libint->vrr_classes[13][12] = int_stack + 411170;
 Libint->vrr_classes[13][13] = int_stack + 420725;
 Libint->vrr_classes[13][14] = int_stack + 431750;
 Libint->vrr_classes[13][15] = int_stack + 444350;
 Libint->vrr_classes[13][16] = int_stack + 458630;
 Libint->vrr_classes[13][17] = int_stack + 474695;
 Libint->vrr_classes[13][18] = int_stack + 492650;
 Libint->vrr_classes[14][9] = int_stack + 512600;
 Libint->vrr_classes[14][10] = int_stack + 519200;
 Libint->vrr_classes[14][11] = int_stack + 527120;
 Libint->vrr_classes[14][12] = int_stack + 536480;
 Libint->vrr_classes[14][13] = int_stack + 547400;
 Libint->vrr_classes[14][14] = int_stack + 560000;
 Libint->vrr_classes[14][15] = int_stack + 574400;
 Libint->vrr_classes[14][16] = int_stack + 590720;
 Libint->vrr_classes[14][17] = int_stack + 609080;
 Libint->vrr_classes[14][18] = int_stack + 629600;
 Libint->vrr_classes[15][9] = int_stack + 652400;
 Libint->vrr_classes[15][10] = int_stack + 659880;
 Libint->vrr_classes[15][11] = int_stack + 668856;
 Libint->vrr_classes[15][12] = int_stack + 679464;
 Libint->vrr_classes[15][13] = int_stack + 691840;
 Libint->vrr_classes[15][14] = int_stack + 706120;
 Libint->vrr_classes[15][15] = int_stack + 722440;
 Libint->vrr_classes[15][16] = int_stack + 740936;
 Libint->vrr_classes[15][17] = int_stack + 761744;
 Libint->vrr_classes[15][18] = int_stack + 785000;
 Libint->vrr_classes[16][9] = int_stack + 810840;
 Libint->vrr_classes[16][10] = int_stack + 819255;
 Libint->vrr_classes[16][11] = int_stack + 829353;
 Libint->vrr_classes[16][12] = int_stack + 841287;
 Libint->vrr_classes[16][13] = int_stack + 855210;
 Libint->vrr_classes[16][14] = int_stack + 871275;
 Libint->vrr_classes[16][15] = int_stack + 889635;
 Libint->vrr_classes[16][16] = int_stack + 910443;
 Libint->vrr_classes[16][17] = int_stack + 933852;
 Libint->vrr_classes[16][18] = int_stack + 960015;
 memset(int_stack,0,989085*sizeof(REALTYPE));

 Libint->vrr_stack = int_stack + 989085;
 for(i=0;i<num_prim_comb;i++) {
   vrr_order_llmm(Libint, Data);
   Data++;
 }
 /*--- compute (l0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+989085,int_stack+2475,int_stack+0,45);
 /*--- compute (l0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+996510,int_stack+5445,int_stack+2475,45);
 /*--- compute (l0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1005420,int_stack+996510,int_stack+989085,45);
 /*--- compute (l0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1020270,int_stack+8955,int_stack+5445,45);
 /*--- compute (l0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1030800,int_stack+1020270,int_stack+996510,45);
 /*--- compute (l0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1048620,int_stack+1030800,int_stack+1005420,45);
 /*--- compute (l0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+989085,int_stack+13050,int_stack+8955,45);
 /*--- compute (l0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1073370,int_stack+989085,int_stack+1020270,45);
 /*--- compute (l0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1094430,int_stack+1073370,int_stack+1030800,45);
 /*--- compute (l0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1001370,int_stack+1094430,int_stack+1048620,45);
 /*--- compute (l0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1038495,int_stack+17775,int_stack+13050,45);
 /*--- compute (l0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1124130,int_stack+1038495,int_stack+989085,45);
 /*--- compute (l0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1148700,int_stack+1124130,int_stack+1073370,45);
 /*--- compute (l0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1183800,int_stack+1148700,int_stack+1094430,45);
 /*--- compute (l0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1052670,int_stack+1183800,int_stack+1001370,45);
 /*--- compute (l0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+989085,int_stack+23175,int_stack+17775,45);
 /*--- compute (l0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1005285,int_stack+989085,int_stack+1038495,45);
 /*--- compute (l0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1228350,int_stack+1005285,int_stack+1124130,45);
 /*--- compute (l0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1269300,int_stack+1228350,int_stack+1148700,45);
 /*--- compute (l0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1104645,int_stack+1269300,int_stack+1183800,45);
 /*--- compute (l0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1321950,int_stack+1104645,int_stack+1052670,45);
 /*--- compute (l0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1033635,int_stack+29295,int_stack+23175,45);
 /*--- compute (l0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1051995,int_stack+1033635,int_stack+989085,45);
 /*--- compute (l0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1167015,int_stack+1051995,int_stack+1005285,45);
 /*--- compute (l0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1391250,int_stack+1167015,int_stack+1228350,45);
 /*--- compute (l0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1452675,int_stack+1391250,int_stack+1269300,45);
 /*--- compute (l0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1214265,int_stack+1452675,int_stack+1104645,45);
 /*--- compute (l0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+1526385,int_stack+1214265,int_stack+1321950,45);
 /*--- compute (l0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+989085,int_stack+36180,int_stack+29295,45);
 /*--- compute (l0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1084395,int_stack+989085,int_stack+1033635,45);
 /*--- compute (l0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1297425,int_stack+1084395,int_stack+1051995,45);
 /*--- compute (l0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1009740,int_stack+1297425,int_stack+1167015,45);
 /*--- compute (l0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1121115,int_stack+1009740,int_stack+1391250,45);
 /*--- compute (l0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1351425,int_stack+1121115,int_stack+1452675,45);
 /*--- compute (l0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1615485,int_stack+1351425,int_stack+1214265,45);
 /*--- compute (l0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+1722405,int_stack+1615485,int_stack+1526385,45);
 /*--- compute (l0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1207110,int_stack+43875,int_stack+36180,45);
 /*--- compute (l0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1230195,int_stack+1207110,int_stack+989085,45);
 /*--- compute (l0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1449705,int_stack+1230195,int_stack+1084395,45);
 /*--- compute (l0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1207110,int_stack+1449705,int_stack+1297425,45);
 /*--- compute (l0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1449705,int_stack+1207110,int_stack+1009740,45);
 /*--- compute (l0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1207110,int_stack+1449705,int_stack+1121115,45);
 /*--- compute (l0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1449705,int_stack+1207110,int_stack+1351425,45);
 /*--- compute (l0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+989085,int_stack+1449705,int_stack+1615485,45);
 /*--- compute (l0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1122735,int_stack+989085,int_stack+1722405,45);
 /*--- compute (m0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+989085,int_stack+55450,int_stack+52425,55);
 /*--- compute (m0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+998160,int_stack+59080,int_stack+55450,55);
 /*--- compute (m0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1009050,int_stack+998160,int_stack+989085,55);
 /*--- compute (m0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1027200,int_stack+63370,int_stack+59080,55);
 /*--- compute (m0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1040070,int_stack+1027200,int_stack+998160,55);
 /*--- compute (m0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1061850,int_stack+1040070,int_stack+1009050,55);
 /*--- compute (m0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+989085,int_stack+68375,int_stack+63370,55);
 /*--- compute (m0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1092100,int_stack+989085,int_stack+1027200,55);
 /*--- compute (m0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1258860,int_stack+1092100,int_stack+1040070,55);
 /*--- compute (m0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1004100,int_stack+1258860,int_stack+1061850,55);
 /*--- compute (m0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1049475,int_stack+74150,int_stack+68375,55);
 /*--- compute (m0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1295160,int_stack+1049475,int_stack+989085,55);
 /*--- compute (m0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1325190,int_stack+1295160,int_stack+1092100,55);
 /*--- compute (m0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1066800,int_stack+1325190,int_stack+1258860,55);
 /*--- compute (m0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1368090,int_stack+1066800,int_stack+1004100,55);
 /*--- compute (m0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1258860,int_stack+80750,int_stack+74150,55);
 /*--- compute (m0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+989085,int_stack+1258860,int_stack+1049475,55);
 /*--- compute (m0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1431615,int_stack+989085,int_stack+1295160,55);
 /*--- compute (m0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1481665,int_stack+1431615,int_stack+1325190,55);
 /*--- compute (m0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1278660,int_stack+1481665,int_stack+1066800,55);
 /*--- compute (m0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1023735,int_stack+1278660,int_stack+1368090,55);
 /*--- compute (m0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1354890,int_stack+88230,int_stack+80750,55);
 /*--- compute (m0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1377330,int_stack+1354890,int_stack+1258860,55);
 /*--- compute (m0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1546015,int_stack+1377330,int_stack+989085,55);
 /*--- compute (m0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1603765,int_stack+1546015,int_stack+1431615,55);
 /*--- compute (m0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1678840,int_stack+1603765,int_stack+1481665,55);
 /*--- compute (m0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1416930,int_stack+1678840,int_stack+1278660,55);
 /*--- compute (m0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+1768930,int_stack+1416930,int_stack+1023735,55);
 /*--- compute (m0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+989085,int_stack+96645,int_stack+88230,55);
 /*--- compute (m0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1014330,int_stack+989085,int_stack+1354890,55);
 /*--- compute (m0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1258860,int_stack+1014330,int_stack+1377330,55);
 /*--- compute (m0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1324860,int_stack+1258860,int_stack+1546015,55);
 /*--- compute (m0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1877830,int_stack+1324860,int_stack+1603765,55);
 /*--- compute (m0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1518570,int_stack+1877830,int_stack+1678840,55);
 /*--- compute (m0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1982935,int_stack+1518570,int_stack+1416930,55);
 /*--- compute (m0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+2113615,int_stack+1982935,int_stack+1768930,55);
 /*--- compute (m0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1059210,int_stack+106050,int_stack+96645,55);
 /*--- compute (m0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1411485,int_stack+1059210,int_stack+989085,55);
 /*--- compute (m0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1638690,int_stack+1411485,int_stack+1014330,55);
 /*--- compute (m0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1411485,int_stack+1638690,int_stack+1258860,55);
 /*--- compute (m0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1638690,int_stack+1411485,int_stack+1324860,55);
 /*--- compute (m0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1258860,int_stack+1638690,int_stack+1877830,55);
 /*--- compute (m0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1638690,int_stack+1258860,int_stack+1518570,55);
 /*--- compute (m0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+1258860,int_stack+1638690,int_stack+1982935,55);
 /*--- compute (m0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1422210,int_stack+1258860,int_stack+2113615,55);
 /*--- compute (lp|mm) ---*/
 hrr1_build_lp(Libint->AB,int_stack+1588585,int_stack+1422210,int_stack+1122735,3025);
 /*--- compute (n0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+1996960,int_stack+120130,int_stack+116500,66);
 /*--- compute (n0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+2007850,int_stack+124486,int_stack+120130,66);
 /*--- compute (n0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+2020918,int_stack+2007850,int_stack+1996960,66);
 /*--- compute (n0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+2042698,int_stack+129634,int_stack+124486,66);
 /*--- compute (n0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+2058142,int_stack+2042698,int_stack+2007850,66);
 /*--- compute (n0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+2084278,int_stack+2058142,int_stack+2020918,66);
 /*--- compute (n0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1996960,int_stack+135640,int_stack+129634,66);
 /*--- compute (n0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+2120578,int_stack+1996960,int_stack+2042698,66);
 /*--- compute (n0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+2151466,int_stack+2120578,int_stack+2058142,66);
 /*--- compute (n0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+2014978,int_stack+2151466,int_stack+2084278,66);
 /*--- compute (n0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+2069428,int_stack+142570,int_stack+135640,66);
 /*--- compute (n0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+2195026,int_stack+2069428,int_stack+1996960,66);
 /*--- compute (n0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+989085,int_stack+2195026,int_stack+2120578,66);
 /*--- compute (n0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1040565,int_stack+989085,int_stack+2151466,66);
 /*--- compute (n0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+2090218,int_stack+1040565,int_stack+2014978,66);
 /*--- compute (n0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1996960,int_stack+150490,int_stack+142570,66);
 /*--- compute (n0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+2020720,int_stack+1996960,int_stack+2069428,66);
 /*--- compute (n0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1105905,int_stack+2020720,int_stack+2195026,66);
 /*--- compute (n0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+2166448,int_stack+1105905,int_stack+989085,66);
 /*--- compute (n0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1165965,int_stack+2166448,int_stack+1040565,66);
 /*--- compute (n0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+989085,int_stack+1165965,int_stack+2090218,66);
 /*--- compute (n0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+2062300,int_stack+159466,int_stack+150490,66);
 /*--- compute (n0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+2089228,int_stack+2062300,int_stack+1996960,66);
 /*--- compute (n0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1257441,int_stack+2089228,int_stack+2020720,66);
 /*--- compute (n0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1326741,int_stack+1257441,int_stack+1105905,66);
 /*--- compute (n0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+0,int_stack+1326741,int_stack+2166448,66);
 /*--- compute (n0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+2136748,int_stack+0,int_stack+1165965,66);
 /*--- compute (n0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+1090725,int_stack+2136748,int_stack+989085,66);
 /*--- compute (n0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+989085,int_stack+169564,int_stack+159466,66);
 /*--- compute (n0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1019379,int_stack+989085,int_stack+2062300,66);
 /*--- compute (n0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1996960,int_stack+1019379,int_stack+2089228,66);
 /*--- compute (n0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2258716,int_stack+1996960,int_stack+1257441,66);
 /*--- compute (n0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+2362666,int_stack+2258716,int_stack+1326741,66);
 /*--- compute (n0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1221405,int_stack+2362666,int_stack+0,66);
 /*--- compute (n0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+0,int_stack+1221405,int_stack+2136748,66);
 /*--- compute (n0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+2076160,int_stack+0,int_stack+1090725,66);
 /*--- compute (n0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1073235,int_stack+180850,int_stack+169564,66);
 /*--- compute (n0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1107093,int_stack+1073235,int_stack+989085,66);
 /*--- compute (n0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+2488792,int_stack+1107093,int_stack+1019379,66);
 /*--- compute (n0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+989085,int_stack+2488792,int_stack+1996960,66);
 /*--- compute (n0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+2488792,int_stack+989085,int_stack+2258716,66);
 /*--- compute (n0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+989085,int_stack+2488792,int_stack+2362666,66);
 /*--- compute (n0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+2239510,int_stack+989085,int_stack+1221405,66);
 /*--- compute (n0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+989085,int_stack+2239510,int_stack+0,66);
 /*--- compute (n0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+2239510,int_stack+989085,int_stack+2076160,66);
 /*--- compute (mp|mm) ---*/
 hrr1_build_mp(Libint->AB,int_stack+2439160,int_stack+2239510,int_stack+1422210,3025);
 /*--- compute (ld|mm) ---*/
 hrr1_build_ld(Libint->AB,int_stack+2938285,int_stack+2439160,int_stack+1588585,3025);
 /*--- compute (o0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+989085,int_stack+197680,int_stack+193390,78);
 /*--- compute (o0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1001955,int_stack+202828,int_stack+197680,78);
 /*--- compute (o0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1017399,int_stack+1001955,int_stack+989085,78);
 /*--- compute (o0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1043139,int_stack+208912,int_stack+202828,78);
 /*--- compute (o0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1061391,int_stack+1043139,int_stack+1001955,78);
 /*--- compute (o0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1092279,int_stack+1061391,int_stack+1017399,78);
 /*--- compute (o0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+989085,int_stack+216010,int_stack+208912,78);
 /*--- compute (o0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1135179,int_stack+989085,int_stack+1043139,78);
 /*--- compute (o0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1171683,int_stack+1135179,int_stack+1061391,78);
 /*--- compute (o0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1010379,int_stack+1171683,int_stack+1092279,78);
 /*--- compute (o0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1074729,int_stack+224200,int_stack+216010,78);
 /*--- compute (o0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1223163,int_stack+1074729,int_stack+989085,78);
 /*--- compute (o0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1265751,int_stack+1223163,int_stack+1135179,78);
 /*--- compute (o0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1326591,int_stack+1265751,int_stack+1171683,78);
 /*--- compute (o0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1099299,int_stack+1326591,int_stack+1010379,78);
 /*--- compute (o0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+989085,int_stack+233560,int_stack+224200,78);
 /*--- compute (o0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1017165,int_stack+989085,int_stack+1074729,78);
 /*--- compute (o0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1403811,int_stack+1017165,int_stack+1223163,78);
 /*--- compute (o0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1474791,int_stack+1403811,int_stack+1265751,78);
 /*--- compute (o0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1189389,int_stack+1474791,int_stack+1326591,78);
 /*--- compute (o0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1566051,int_stack+1189389,int_stack+1099299,78);
 /*--- compute (o0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1066305,int_stack+244168,int_stack+233560,78);
 /*--- compute (o0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1098129,int_stack+1066305,int_stack+989085,78);
 /*--- compute (o0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1297497,int_stack+1098129,int_stack+1017165,78);
 /*--- compute (o0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1686171,int_stack+1297497,int_stack+1403811,78);
 /*--- compute (o0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1792641,int_stack+1686171,int_stack+1474791,78);
 /*--- compute (o0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1379397,int_stack+1792641,int_stack+1189389,78);
 /*--- compute (o0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+1920405,int_stack+1379397,int_stack+1566051,78);
 /*--- compute (o0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+989085,int_stack+256102,int_stack+244168,78);
 /*--- compute (o0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1154289,int_stack+989085,int_stack+1066305,78);
 /*--- compute (o0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1523541,int_stack+1154289,int_stack+1098129,78);
 /*--- compute (o0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1024887,int_stack+1523541,int_stack+1297497,78);
 /*--- compute (o0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1217937,int_stack+1024887,int_stack+1686171,78);
 /*--- compute (o0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1617141,int_stack+1217937,int_stack+1792641,78);
 /*--- compute (o0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+0,int_stack+1617141,int_stack+1379397,78);
 /*--- compute (o0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+3755035,int_stack+0,int_stack+1920405,78);
 /*--- compute (o0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1366995,int_stack+269440,int_stack+256102,78);
 /*--- compute (o0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1407009,int_stack+1366995,int_stack+989085,78);
 /*--- compute (o0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1787493,int_stack+1407009,int_stack+1154289,78);
 /*--- compute (o0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1366995,int_stack+1787493,int_stack+1523541,78);
 /*--- compute (o0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1787493,int_stack+1366995,int_stack+1024887,78);
 /*--- compute (o0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1366995,int_stack+1787493,int_stack+1217937,78);
 /*--- compute (o0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1787493,int_stack+1366995,int_stack+1617141,78);
 /*--- compute (o0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2006517,int_stack+1787493,int_stack+0,78);
 /*--- compute (o0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+0,int_stack+2006517,int_stack+3755035,78);
 /*--- compute (np|mm) ---*/
 hrr1_build_np(Libint->AB,int_stack+989085,int_stack+0,int_stack+2239510,3025);
 /*--- compute (md|mm) ---*/
 hrr1_build_md(Libint->AB,int_stack+3755035,int_stack+989085,int_stack+2439160,3025);
 /*--- compute (lf|mm) ---*/
 hrr1_build_lf(Libint->AB,int_stack+4753285,int_stack+3755035,int_stack+2938285,3025);
 /*--- compute (q0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+235950,int_stack+289265,int_stack+284260,91);
 /*--- compute (q0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+250965,int_stack+295271,int_stack+289265,91);
 /*--- compute (q0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1588035,int_stack+250965,int_stack+235950,91);
 /*--- compute (q0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+268983,int_stack+302369,int_stack+295271,91);
 /*--- compute (q0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1618065,int_stack+268983,int_stack+250965,91);
 /*--- compute (q0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1654101,int_stack+1618065,int_stack+1588035,91);
 /*--- compute (q0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1588035,int_stack+310650,int_stack+302369,91);
 /*--- compute (q0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1704151,int_stack+1588035,int_stack+268983,91);
 /*--- compute (q0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+235950,int_stack+1704151,int_stack+1618065,91);
 /*--- compute (q0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1746739,int_stack+235950,int_stack+1654101,91);
 /*--- compute (q0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1612878,int_stack+320205,int_stack+310650,91);
 /*--- compute (q0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1641543,int_stack+1612878,int_stack+1588035,91);
 /*--- compute (q0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1821814,int_stack+1641543,int_stack+1704151,91);
 /*--- compute (q0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1892794,int_stack+1821814,int_stack+235950,91);
 /*--- compute (q0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1982884,int_stack+1892794,int_stack+1746739,91);
 /*--- compute (q0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+235950,int_stack+331125,int_stack+320205,91);
 /*--- compute (q0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+268710,int_stack+235950,int_stack+1612878,91);
 /*--- compute (q0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1691229,int_stack+268710,int_stack+1641543,91);
 /*--- compute (q0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+2087989,int_stack+1691229,int_stack+1821814,91);
 /*--- compute (q0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+2194459,int_stack+2087989,int_stack+1892794,91);
 /*--- compute (q0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1774039,int_stack+2194459,int_stack+1982884,91);
 /*--- compute (q0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1588035,int_stack+343501,int_stack+331125,91);
 /*--- compute (q0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1625163,int_stack+1588035,int_stack+235950,91);
 /*--- compute (q0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1914179,int_stack+1625163,int_stack+268710,91);
 /*--- compute (q0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+2320585,int_stack+1914179,int_stack+1691229,91);
 /*--- compute (q0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+2444800,int_stack+2320585,int_stack+2087989,91);
 /*--- compute (q0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+2009729,int_stack+2444800,int_stack+2194459,91);
 /*--- compute (q0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+2593858,int_stack+2009729,int_stack+1774039,91);
 /*--- compute (q0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+235950,int_stack+357424,int_stack+343501,91);
 /*--- compute (q0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+277719,int_stack+235950,int_stack+1588035,91);
 /*--- compute (q0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1690683,int_stack+277719,int_stack+1625163,91);
 /*--- compute (q0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2774038,int_stack+1690683,int_stack+1914179,91);
 /*--- compute (q0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1799883,int_stack+2774038,int_stack+2320585,91);
 /*--- compute (q0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+2177897,int_stack+1799883,int_stack+2444800,91);
 /*--- compute (q0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+2376641,int_stack+2177897,int_stack+2009729,91);
 /*--- compute (q0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+2917363,int_stack+2376641,int_stack+2593858,91);
 /*--- compute (q0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1588035,int_stack+372985,int_stack+357424,91);
 /*--- compute (q0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1973784,int_stack+1588035,int_stack+235950,91);
 /*--- compute (q0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+2592857,int_stack+1973784,int_stack+277719,91);
 /*--- compute (q0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1973784,int_stack+2592857,int_stack+1690683,91);
 /*--- compute (q0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1588035,int_stack+1973784,int_stack+2774038,91);
 /*--- compute (q0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2592857,int_stack+1588035,int_stack+1799883,91);
 /*--- compute (q0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1588035,int_stack+2592857,int_stack+2177897,91);
 /*--- compute (q0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2592857,int_stack+1588035,int_stack+2376641,91);
 /*--- compute (q0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1588035,int_stack+2592857,int_stack+2917363,91);
 /*--- compute (op|mm) ---*/
 hrr1_build_op(Libint->AB,int_stack+1863310,int_stack+1588035,int_stack+0,3025);
 /*--- compute (nd|mm) ---*/
 hrr1_build_nd(Libint->AB,int_stack+6114535,int_stack+1863310,int_stack+989085,3025);
 /*--- compute (mf|mm) ---*/
 hrr1_build_mf(Libint->AB,int_stack+7312435,int_stack+6114535,int_stack+3755035,3025);
 /*--- compute (lg|mm) ---*/
 hrr1_build_lg(Libint->AB,int_stack+2571160,int_stack+7312435,int_stack+4753285,3025);
 /*--- compute (r0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+989085,int_stack+396050,int_stack+390275,105);
 /*--- compute (r0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1006410,int_stack+402980,int_stack+396050,105);
 /*--- compute (r0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1027200,int_stack+1006410,int_stack+989085,105);
 /*--- compute (r0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1061850,int_stack+411170,int_stack+402980,105);
 /*--- compute (r0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1086420,int_stack+1061850,int_stack+1006410,105);
 /*--- compute (r0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1128000,int_stack+1086420,int_stack+1027200,105);
 /*--- compute (r0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+989085,int_stack+420725,int_stack+411170,105);
 /*--- compute (r0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1185750,int_stack+989085,int_stack+1061850,105);
 /*--- compute (r0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1234890,int_stack+1185750,int_stack+1086420,105);
 /*--- compute (r0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1017750,int_stack+1234890,int_stack+1128000,105);
 /*--- compute (r0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1104375,int_stack+431750,int_stack+420725,105);
 /*--- compute (r0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1304190,int_stack+1104375,int_stack+989085,105);
 /*--- compute (r0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1361520,int_stack+1304190,int_stack+1185750,105);
 /*--- compute (r0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1443420,int_stack+1361520,int_stack+1234890,105);
 /*--- compute (r0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1137450,int_stack+1443420,int_stack+1017750,105);
 /*--- compute (r0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+989085,int_stack+444350,int_stack+431750,105);
 /*--- compute (r0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1026885,int_stack+989085,int_stack+1104375,105);
 /*--- compute (r0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+0,int_stack+1026885,int_stack+1304190,105);
 /*--- compute (r0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+95550,int_stack+0,int_stack+1361520,105);
 /*--- compute (r0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1258725,int_stack+95550,int_stack+1443420,105);
 /*--- compute (r0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1404255,int_stack+1258725,int_stack+1137450,105);
 /*--- compute (r0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1093035,int_stack+458630,int_stack+444350,105);
 /*--- compute (r0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1135875,int_stack+1093035,int_stack+989085,105);
 /*--- compute (r0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+218400,int_stack+1135875,int_stack+1026885,105);
 /*--- compute (r0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+4613035,int_stack+218400,int_stack+0,105);
 /*--- compute (r0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+4756360,int_stack+4613035,int_stack+95550,105);
 /*--- compute (r0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+0,int_stack+4756360,int_stack+1258725,105);
 /*--- compute (r0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+4928350,int_stack+0,int_stack+1404255,105);
 /*--- compute (r0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+989085,int_stack+474695,int_stack+458630,105);
 /*--- compute (r0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1211475,int_stack+989085,int_stack+1093035,105);
 /*--- compute (r0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1297155,int_stack+1211475,int_stack+1135875,105);
 /*--- compute (r0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1037280,int_stack+1297155,int_stack+218400,105);
 /*--- compute (r0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+194040,int_stack+1037280,int_stack+4613035,105);
 /*--- compute (r0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+5136250,int_stack+194040,int_stack+4756360,105);
 /*--- compute (r0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+4613035,int_stack+5136250,int_stack+0,105);
 /*--- compute (r0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+5365570,int_stack+4613035,int_stack+4928350,105);
 /*--- compute (r0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+0,int_stack+492650,int_stack+474695,105);
 /*--- compute (r0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+53865,int_stack+0,int_stack+989085,105);
 /*--- compute (r0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+4862515,int_stack+53865,int_stack+1211475,105);
 /*--- compute (r0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+0,int_stack+4862515,int_stack+1297155,105);
 /*--- compute (r0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+4862515,int_stack+0,int_stack+1037280,105);
 /*--- compute (r0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+989085,int_stack+4862515,int_stack+194040,105);
 /*--- compute (r0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+0,int_stack+989085,int_stack+5136250,105);
 /*--- compute (r0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+989085,int_stack+0,int_stack+4613035,105);
 /*--- compute (r0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+4613035,int_stack+989085,int_stack+5365570,105);
 /*--- compute (qp|mm) ---*/
 hrr1_build_qp(Libint->AB,int_stack+4930660,int_stack+4613035,int_stack+1588035,3025);
 /*--- compute (od|mm) ---*/
 hrr1_build_od(Libint->AB,int_stack+8976185,int_stack+4930660,int_stack+1863310,3025);
 /*--- compute (nf|mm) ---*/
 hrr1_build_nf(Libint->AB,int_stack+10391885,int_stack+8976185,int_stack+6114535,3025);
 /*--- compute (mg|mm) ---*/
 hrr1_build_mg(Libint->AB,int_stack+12388385,int_stack+10391885,int_stack+7312435,3025);
 /*--- compute (lh|mm) ---*/
 hrr1_build_lh(Libint->AB,int_stack+5756485,int_stack+12388385,int_stack+2571160,3025);
 /*--- compute (t0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+989085,int_stack+519200,int_stack+512600,120);
 /*--- compute (t0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1008885,int_stack+527120,int_stack+519200,120);
 /*--- compute (t0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1032645,int_stack+1008885,int_stack+989085,120);
 /*--- compute (t0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1072245,int_stack+536480,int_stack+527120,120);
 /*--- compute (t0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1100325,int_stack+1072245,int_stack+1008885,120);
 /*--- compute (t0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1147845,int_stack+1100325,int_stack+1032645,120);
 /*--- compute (t0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+989085,int_stack+547400,int_stack+536480,120);
 /*--- compute (t0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1213845,int_stack+989085,int_stack+1072245,120);
 /*--- compute (t0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1270005,int_stack+1213845,int_stack+1100325,120);
 /*--- compute (t0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1021845,int_stack+1270005,int_stack+1147845,120);
 /*--- compute (t0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1120845,int_stack+560000,int_stack+547400,120);
 /*--- compute (t0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1349205,int_stack+1120845,int_stack+989085,120);
 /*--- compute (t0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1414725,int_stack+1349205,int_stack+1213845,120);
 /*--- compute (t0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1508325,int_stack+1414725,int_stack+1270005,120);
 /*--- compute (t0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1158645,int_stack+1508325,int_stack+1021845,120);
 /*--- compute (t0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+989085,int_stack+574400,int_stack+560000,120);
 /*--- compute (t0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1032285,int_stack+989085,int_stack+1120845,120);
 /*--- compute (t0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1627125,int_stack+1032285,int_stack+1349205,120);
 /*--- compute (t0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1736325,int_stack+1627125,int_stack+1414725,120);
 /*--- compute (t0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1297245,int_stack+1736325,int_stack+1508325,120);
 /*--- compute (t0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1876725,int_stack+1297245,int_stack+1158645,120);
 /*--- compute (t0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1107885,int_stack+590720,int_stack+574400,120);
 /*--- compute (t0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1156845,int_stack+1107885,int_stack+989085,120);
 /*--- compute (t0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1463565,int_stack+1156845,int_stack+1032285,120);
 /*--- compute (t0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+2061525,int_stack+1463565,int_stack+1627125,120);
 /*--- compute (t0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+2225325,int_stack+2061525,int_stack+1736325,120);
 /*--- compute (t0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1589565,int_stack+2225325,int_stack+1297245,120);
 /*--- compute (t0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+2421885,int_stack+1589565,int_stack+1876725,120);
 /*--- compute (t0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+989085,int_stack+609080,int_stack+590720,120);
 /*--- compute (t0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1243245,int_stack+989085,int_stack+1107885,120);
 /*--- compute (t0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1811325,int_stack+1243245,int_stack+1156845,120);
 /*--- compute (t0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1044165,int_stack+1811325,int_stack+1463565,120);
 /*--- compute (t0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1341165,int_stack+1044165,int_stack+2061525,120);
 /*--- compute (t0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1955325,int_stack+1341165,int_stack+2225325,120);
 /*--- compute (t0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+2659485,int_stack+1955325,int_stack+1589565,120);
 /*--- compute (t0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+2944605,int_stack+2659485,int_stack+2421885,120);
 /*--- compute (t0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1570485,int_stack+629600,int_stack+609080,120);
 /*--- compute (t0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1632045,int_stack+1570485,int_stack+989085,120);
 /*--- compute (t0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+2217405,int_stack+1632045,int_stack+1243245,120);
 /*--- compute (t0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1570485,int_stack+2217405,int_stack+1811325,120);
 /*--- compute (t0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+2217405,int_stack+1570485,int_stack+1044165,120);
 /*--- compute (t0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1570485,int_stack+2217405,int_stack+1341165,120);
 /*--- compute (t0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+2217405,int_stack+1570485,int_stack+1955325,120);
 /*--- compute (t0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+989085,int_stack+2217405,int_stack+2659485,120);
 /*--- compute (t0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1345485,int_stack+989085,int_stack+2944605,120);
 /*--- compute (rp|mm) ---*/
 hrr1_build_rp(Libint->AB,int_stack+1708485,int_stack+1345485,int_stack+4613035,3025);
 /*--- compute (qd|mm) ---*/
 hrr1_build_qd(Libint->AB,int_stack+2661360,int_stack+1708485,int_stack+4930660,3025);
 /*--- compute (of|mm) ---*/
 hrr1_build_of(Libint->AB,int_stack+14884010,int_stack+2661360,int_stack+8976185,3025);
 /*--- compute (ng|mm) ---*/
 hrr1_build_ng(Libint->AB,int_stack+17243510,int_stack+14884010,int_stack+10391885,3025);
 /*--- compute (mh|mm) ---*/
 hrr1_build_mh(Libint->AB,int_stack+8615110,int_stack+17243510,int_stack+12388385,3025);
 /*--- compute (li|mm) ---*/
 hrr1_build_li(Libint->AB,int_stack+20238260,int_stack+8615110,int_stack+5756485,3025);
 /*--- compute (u0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+989085,int_stack+659880,int_stack+652400,136);
 /*--- compute (u0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1011525,int_stack+668856,int_stack+659880,136);
 /*--- compute (u0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1038453,int_stack+1011525,int_stack+989085,136);
 /*--- compute (u0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1083333,int_stack+679464,int_stack+668856,136);
 /*--- compute (u0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1115157,int_stack+1083333,int_stack+1011525,136);
 /*--- compute (u0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1169013,int_stack+1115157,int_stack+1038453,136);
 /*--- compute (u0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+989085,int_stack+691840,int_stack+679464,136);
 /*--- compute (u0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1243813,int_stack+989085,int_stack+1083333,136);
 /*--- compute (u0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+4313010,int_stack+1243813,int_stack+1115157,136);
 /*--- compute (u0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1026213,int_stack+4313010,int_stack+1169013,136);
 /*--- compute (u0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1138413,int_stack+706120,int_stack+691840,136);
 /*--- compute (u0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+4402770,int_stack+1138413,int_stack+989085,136);
 /*--- compute (u0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+4477026,int_stack+4402770,int_stack+1243813,136);
 /*--- compute (u0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1181253,int_stack+4477026,int_stack+4313010,136);
 /*--- compute (u0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+4583106,int_stack+1181253,int_stack+1026213,136);
 /*--- compute (u0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+4313010,int_stack+722440,int_stack+706120,136);
 /*--- compute (u0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+989085,int_stack+4313010,int_stack+1138413,136);
 /*--- compute (u0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+4740186,int_stack+989085,int_stack+4402770,136);
 /*--- compute (u0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+4863946,int_stack+4740186,int_stack+4477026,136);
 /*--- compute (u0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+4361970,int_stack+4863946,int_stack+1181253,136);
 /*--- compute (u0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1074765,int_stack+4361970,int_stack+4583106,136);
 /*--- compute (u0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+4550466,int_stack+740936,int_stack+722440,136);
 /*--- compute (u0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+4605954,int_stack+4550466,int_stack+4313010,136);
 /*--- compute (u0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+5023066,int_stack+4605954,int_stack+989085,136);
 /*--- compute (u0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+5165866,int_stack+5023066,int_stack+4740186,136);
 /*--- compute (u0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+5351506,int_stack+5165866,int_stack+4863946,136);
 /*--- compute (u0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+4703874,int_stack+5351506,int_stack+4361970,136);
 /*--- compute (u0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+5574274,int_stack+4703874,int_stack+1074765,136);
 /*--- compute (u0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+989085,int_stack+761744,int_stack+740936,136);
 /*--- compute (u0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1051509,int_stack+989085,int_stack+4550466,136);
 /*--- compute (u0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1162485,int_stack+1051509,int_stack+4605954,136);
 /*--- compute (u0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+4313010,int_stack+1162485,int_stack+5023066,136);
 /*--- compute (u0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+5843554,int_stack+4313010,int_stack+5165866,136);
 /*--- compute (u0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+4955202,int_stack+5843554,int_stack+5351506,136);
 /*--- compute (u0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+6103450,int_stack+4955202,int_stack+4703874,136);
 /*--- compute (u0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+4527210,int_stack+6103450,int_stack+5574274,136);
 /*--- compute (u0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+4863810,int_stack+785000,int_stack+761744,136);
 /*--- compute (u0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+5252226,int_stack+4863810,int_stack+989085,136);
 /*--- compute (u0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+5377074,int_stack+5252226,int_stack+1051509,136);
 /*--- compute (u0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+5562034,int_stack+5377074,int_stack+1162485,136);
 /*--- compute (u0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+5252226,int_stack+5562034,int_stack+4313010,136);
 /*--- compute (u0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+989085,int_stack+5252226,int_stack+5843554,136);
 /*--- compute (u0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+5252226,int_stack+989085,int_stack+4955202,136);
 /*--- compute (u0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+5634114,int_stack+5252226,int_stack+6103450,136);
 /*--- compute (u0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+6038034,int_stack+5634114,int_stack+4527210,136);
 /*--- compute (tp|mm) ---*/
 hrr1_build_tp(Libint->AB,int_stack+6449434,int_stack+6038034,int_stack+1345485,3025);
 /*--- compute (rd|mm) ---*/
 hrr1_build_rd(Libint->AB,int_stack+12108985,int_stack+6449434,int_stack+1708485,3025);
 /*--- compute (qf|mm) ---*/
 hrr1_build_qf(Libint->AB,int_stack+24049760,int_stack+12108985,int_stack+2661360,3025);
 /*--- compute (og|mm) ---*/
 hrr1_build_og(Libint->AB,int_stack+989085,int_stack+24049760,int_stack+14884010,3025);
 /*--- compute (nh|mm) ---*/
 hrr1_build_nh(Libint->AB,int_stack+26802510,int_stack+989085,int_stack+17243510,3025);
 /*--- compute (mi|mm) ---*/
 hrr1_build_mi(Libint->AB,int_stack+14014735,int_stack+26802510,int_stack+8615110,3025);
 /*--- compute (lk|mm) ---*/
 hrr1_build_lk(Libint->AB,int_stack+30995160,int_stack+14014735,int_stack+20238260,3025);
 /*--- compute (v0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+4528335,int_stack+819255,int_stack+810840,153);
 /*--- compute (v0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+4553580,int_stack+829353,int_stack+819255,153);
 /*--- compute (v0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+4583874,int_stack+4553580,int_stack+4528335,153);
 /*--- compute (v0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+4634364,int_stack+841287,int_stack+829353,153);
 /*--- compute (v0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+4670166,int_stack+4634364,int_stack+4553580,153);
 /*--- compute (v0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+4730754,int_stack+4670166,int_stack+4583874,153);
 /*--- compute (v0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+4528335,int_stack+855210,int_stack+841287,153);
 /*--- compute (v0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+4814904,int_stack+4528335,int_stack+4634364,153);
 /*--- compute (v0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+4886508,int_stack+4814904,int_stack+4670166,153);
 /*--- compute (v0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+4570104,int_stack+4886508,int_stack+4730754,153);
 /*--- compute (v0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+4696329,int_stack+871275,int_stack+855210,153);
 /*--- compute (v0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+4987488,int_stack+4696329,int_stack+4528335,153);
 /*--- compute (v0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+5071026,int_stack+4987488,int_stack+4814904,153);
 /*--- compute (v0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+5190366,int_stack+5071026,int_stack+4886508,153);
 /*--- compute (v0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+4744524,int_stack+5190366,int_stack+4570104,153);
 /*--- compute (v0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+4528335,int_stack+889635,int_stack+871275,153);
 /*--- compute (v0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+4583415,int_stack+4528335,int_stack+4696329,153);
 /*--- compute (v0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+5341836,int_stack+4583415,int_stack+4987488,153);
 /*--- compute (v0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+5481066,int_stack+5341836,int_stack+5071026,153);
 /*--- compute (v0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+4921239,int_stack+5481066,int_stack+5190366,153);
 /*--- compute (v0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+5660076,int_stack+4921239,int_stack+4744524,153);
 /*--- compute (v0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+4679805,int_stack+910443,int_stack+889635,153);
 /*--- compute (v0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+4742229,int_stack+4679805,int_stack+4528335,153);
 /*--- compute (v0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+5133297,int_stack+4742229,int_stack+4583415,153);
 /*--- compute (v0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+7538434,int_stack+5133297,int_stack+5341836,153);
 /*--- compute (v0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+7747279,int_stack+7538434,int_stack+5481066,153);
 /*--- compute (v0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+5293947,int_stack+7747279,int_stack+4921239,153);
 /*--- compute (v0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+7997893,int_stack+5293947,int_stack+5660076,153);
 /*--- compute (v0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+4528335,int_stack+933852,int_stack+910443,153);
 /*--- compute (v0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+4852389,int_stack+4528335,int_stack+4679805,153);
 /*--- compute (v0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+5576691,int_stack+4852389,int_stack+4742229,153);
 /*--- compute (v0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+4598562,int_stack+5576691,int_stack+5133297,153);
 /*--- compute (v0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+4977237,int_stack+4598562,int_stack+7538434,153);
 /*--- compute (v0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+8300833,int_stack+4977237,int_stack+7747279,153);
 /*--- compute (v0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+7538434,int_stack+8300833,int_stack+5293947,153);
 /*--- compute (v0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+8634985,int_stack+7538434,int_stack+7997893,153);
 /*--- compute (v0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+7901962,int_stack+960015,int_stack+933852,153);
 /*--- compute (v0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+7980451,int_stack+7901962,int_stack+4528335,153);
 /*--- compute (v0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+5269620,int_stack+7980451,int_stack+4852389,153);
 /*--- compute (v0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+7901962,int_stack+5269620,int_stack+5576691,153);
 /*--- compute (v0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+5269620,int_stack+7901962,int_stack+4598562,153);
 /*--- compute (v0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+7901962,int_stack+5269620,int_stack+4977237,153);
 /*--- compute (v0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+4528335,int_stack+7901962,int_stack+8300833,153);
 /*--- compute (v0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+7901962,int_stack+4528335,int_stack+7538434,153);
 /*--- compute (v0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+4528335,int_stack+7901962,int_stack+8634985,153);
 /*--- compute (up|mm) ---*/
 hrr1_build_up(Libint->AB,int_stack+7538434,int_stack+4528335,int_stack+6038034,3025);
 /*--- compute (td|mm) ---*/
 hrr1_build_td(Libint->AB,int_stack+8772634,int_stack+7538434,int_stack+6449434,3025);
 /*--- compute (rf|mm) ---*/
 hrr1_build_rf(Libint->AB,int_stack+4528335,int_stack+8772634,int_stack+12108985,3025);
 /*--- compute (qg|mm) ---*/
 hrr1_build_qg(Libint->AB,int_stack+7704585,int_stack+4528335,int_stack+24049760,3025);
 /*--- compute (oh|mm) ---*/
 hrr1_build_oh(Libint->AB,int_stack+18673235,int_stack+7704585,int_stack+989085,3025);
 /*--- compute (ni|mm) ---*/
 hrr1_build_ni(Libint->AB,int_stack+0,int_stack+18673235,int_stack+26802510,3025);
 /*--- compute (mk|mm) ---*/
 hrr1_build_mk(Libint->AB,int_stack+18673235,int_stack+0,int_stack+14014735,3025);
 /*--- compute (ll|mm) ---*/
 hrr1_build_ll(Libint->AB,int_stack+0,int_stack+18673235,int_stack+30995160,3025);
 return int_stack+0;}
