/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dphp(Libr12_t *, prim_data *);

  /* Computes (dp|hp) integrals for linear R12-methods */

void hrr_grt_order_dphp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][6] = int_stack + 126;
 Libr12->gvrr_classes[4][5] = int_stack + 294;
 Libr12->t2vrr_classes[3][5] = int_stack + 609;
 Libr12->t2vrr_classes[3][6] = int_stack + 819;
 Libr12->gvrr_classes[2][7] = int_stack + 1099;
 Libr12->t1vrr_classes[2][5] = int_stack + 1315;
 Libr12->t1vrr_classes[2][6] = int_stack + 1441;
 Libr12->t1vrr_classes[3][5] = int_stack + 1609;
 Libr12->t1vrr_classes[3][6] = int_stack + 1819;
 Libr12->rvrr_classes[2][5] = int_stack + 2099;
 Libr12->rvrr_classes[2][6] = int_stack + 2225;
 Libr12->rvrr_classes[3][5] = int_stack + 2393;
 Libr12->rvrr_classes[3][6] = int_stack + 2603;
 Libr12->gvrr_classes[2][5] = int_stack + 2883;
 Libr12->gvrr_classes[2][6] = int_stack + 3009;
 Libr12->gvrr_classes[3][5] = int_stack + 3177;
 Libr12->gvrr_classes[3][6] = int_stack + 3387;
 memset(int_stack,0,3667*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 3667;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dphp(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3667, int_stack+126, int_stack+0, int_stack+3009, int_stack+3177, int_stack+2883, 2, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4045, int_stack+819, int_stack+609, int_stack+3387, int_stack+294, int_stack+3177, 3, 0);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3009, int_stack+2883, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+378, int_stack+1099, int_stack+3009, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4675, int_stack+3387, int_stack+3177, 10);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2883, int_stack+1441, int_stack+1315, 6);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+882, int_stack+1819, int_stack+1609, 10);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+3261, int_stack+2225, int_stack+2099, 6);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1512, int_stack+2603, int_stack+2393, 10);
 /*--- compute (dp|[r12,T2]|hp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+5305, int_stack+4045, int_stack+3667, 63);
     Libr12->te_ptr[3] = int_stack + 5305;
 /*--- compute (dp|[r12,T1]|hp) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+6439, int_stack+882, int_stack+2883, int_stack+4675, int_stack+378, int_stack+0, 5, 1);
     Libr12->te_ptr[2] = int_stack + 6439;
 /*--- compute (dp||hp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+378, int_stack+1512, int_stack+3261, 63);
     Libr12->te_ptr[1] = int_stack + 378;
 /*--- compute (dp|hp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+1512, int_stack+4675, int_stack+0, 63);
     Libr12->te_ptr[0] = int_stack + 1512;

}
