/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_g0hd(Libr12_t *, prim_data *);

  /* Computes (g0|hd) integrals for linear R12-methods */

void hrr_grt_order_g0hd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[5][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 441;
 Libr12->gvrr_classes[5][6] = int_stack + 756;
 Libr12->t2vrr_classes[4][6] = int_stack + 1344;
 Libr12->t2vrr_classes[4][7] = int_stack + 1764;
 Libr12->t1vrr_classes[4][5] = int_stack + 2304;
 Libr12->t1vrr_classes[4][6] = int_stack + 2619;
 Libr12->t1vrr_classes[4][7] = int_stack + 3039;
 Libr12->rvrr_classes[4][5] = int_stack + 3579;
 Libr12->rvrr_classes[4][6] = int_stack + 3894;
 Libr12->rvrr_classes[4][7] = int_stack + 4314;
 Libr12->gvrr_classes[4][5] = int_stack + 4854;
 Libr12->gvrr_classes[4][6] = int_stack + 5169;
 Libr12->gvrr_classes[4][7] = int_stack + 5589;
 memset(int_stack,0,6129*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 6129;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_g0hd(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6129, int_stack+5169, int_stack+4854, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7074, int_stack+756, int_stack+0, 21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+8397, int_stack+5589, int_stack+5169, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9657, int_stack+1344, int_stack+441, int_stack+5169, int_stack+0, int_stack+4854, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10602, int_stack+1764, int_stack+1344, int_stack+5589, int_stack+756, int_stack+5169, 4, 0);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4854, int_stack+2619, int_stack+2304, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3039, int_stack+2619, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1260, int_stack+3894, int_stack+3579, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2205, int_stack+4314, int_stack+3894, 15);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11862, int_stack+10602, int_stack+9657, int_stack+8397, int_stack+7074, int_stack+6129, 4, 0);
     Libr12->te_ptr[3] = int_stack + 11862;
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+9657, int_stack+0, int_stack+4854, 15);
     Libr12->te_ptr[2] = int_stack + 9657;
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3465, int_stack+2205, int_stack+1260, 15);
     Libr12->te_ptr[1] = int_stack + 3465;
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+8397, int_stack+6129, 15);
     Libr12->te_ptr[0] = int_stack + 0;

}
