/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gghh(Libr12_t *, prim_data *);

  /* Computes (gg|hh) integrals for linear R12-methods */

void hrr_grt_order_gghh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][6] = int_stack + 315;
 Libr12->t2vrr_classes[4][7] = int_stack + 735;
 Libr12->t2vrr_classes[4][8] = int_stack + 1275;
 Libr12->t2vrr_classes[4][9] = int_stack + 1950;
 Libr12->t2vrr_classes[4][10] = int_stack + 2775;
 Libr12->t2vrr_classes[5][5] = int_stack + 3765;
 Libr12->t2vrr_classes[5][6] = int_stack + 4206;
 Libr12->t2vrr_classes[5][7] = int_stack + 4794;
 Libr12->t2vrr_classes[5][8] = int_stack + 5550;
 Libr12->t2vrr_classes[5][9] = int_stack + 6495;
 Libr12->t2vrr_classes[5][10] = int_stack + 7650;
 Libr12->t2vrr_classes[6][5] = int_stack + 9036;
 Libr12->t2vrr_classes[6][6] = int_stack + 9624;
 Libr12->t2vrr_classes[6][7] = int_stack + 10408;
 Libr12->t2vrr_classes[6][8] = int_stack + 11416;
 Libr12->t2vrr_classes[6][9] = int_stack + 12676;
 Libr12->t2vrr_classes[6][10] = int_stack + 14216;
 Libr12->t2vrr_classes[7][5] = int_stack + 16064;
 Libr12->t2vrr_classes[7][6] = int_stack + 16820;
 Libr12->t2vrr_classes[7][7] = int_stack + 17828;
 Libr12->t2vrr_classes[7][8] = int_stack + 19124;
 Libr12->t2vrr_classes[7][9] = int_stack + 20744;
 Libr12->t2vrr_classes[7][10] = int_stack + 22724;
 Libr12->gvrr_classes[9][5] = int_stack + 25100;
 Libr12->t2vrr_classes[8][5] = int_stack + 26255;
 Libr12->gvrr_classes[9][6] = int_stack + 27200;
 Libr12->t2vrr_classes[8][6] = int_stack + 28740;
 Libr12->gvrr_classes[9][7] = int_stack + 30000;
 Libr12->t2vrr_classes[8][7] = int_stack + 31980;
 Libr12->gvrr_classes[9][8] = int_stack + 33600;
 Libr12->t2vrr_classes[8][8] = int_stack + 36075;
 Libr12->gvrr_classes[9][9] = int_stack + 38100;
 Libr12->t2vrr_classes[8][9] = int_stack + 41125;
 Libr12->t2vrr_classes[8][10] = int_stack + 43600;
 Libr12->gvrr_classes[4][11] = int_stack + 46570;
 Libr12->t1vrr_classes[4][5] = int_stack + 47740;
 Libr12->t1vrr_classes[4][6] = int_stack + 48055;
 Libr12->t1vrr_classes[4][7] = int_stack + 48475;
 Libr12->t1vrr_classes[4][8] = int_stack + 49015;
 Libr12->t1vrr_classes[4][9] = int_stack + 49690;
 Libr12->t1vrr_classes[4][10] = int_stack + 50515;
 Libr12->gvrr_classes[5][11] = int_stack + 51505;
 Libr12->t1vrr_classes[5][5] = int_stack + 53143;
 Libr12->t1vrr_classes[5][6] = int_stack + 53584;
 Libr12->t1vrr_classes[5][7] = int_stack + 54172;
 Libr12->t1vrr_classes[5][8] = int_stack + 54928;
 Libr12->t1vrr_classes[5][9] = int_stack + 55873;
 Libr12->t1vrr_classes[5][10] = int_stack + 57028;
 Libr12->gvrr_classes[6][11] = int_stack + 58414;
 Libr12->t1vrr_classes[6][5] = int_stack + 60598;
 Libr12->t1vrr_classes[6][6] = int_stack + 61186;
 Libr12->t1vrr_classes[6][7] = int_stack + 61970;
 Libr12->t1vrr_classes[6][8] = int_stack + 62978;
 Libr12->t1vrr_classes[6][9] = int_stack + 64238;
 Libr12->t1vrr_classes[6][10] = int_stack + 65778;
 Libr12->gvrr_classes[7][11] = int_stack + 67626;
 Libr12->t1vrr_classes[7][5] = int_stack + 70434;
 Libr12->t1vrr_classes[7][6] = int_stack + 71190;
 Libr12->t1vrr_classes[7][7] = int_stack + 72198;
 Libr12->t1vrr_classes[7][8] = int_stack + 73494;
 Libr12->t1vrr_classes[7][9] = int_stack + 75114;
 Libr12->t1vrr_classes[7][10] = int_stack + 77094;
 Libr12->t1vrr_classes[8][5] = int_stack + 79470;
 Libr12->t1vrr_classes[8][6] = int_stack + 80415;
 Libr12->t1vrr_classes[8][7] = int_stack + 81675;
 Libr12->t1vrr_classes[8][8] = int_stack + 83295;
 Libr12->t1vrr_classes[8][9] = int_stack + 85320;
 Libr12->t1vrr_classes[8][10] = int_stack + 87795;
 Libr12->rvrr_classes[4][5] = int_stack + 90765;
 Libr12->rvrr_classes[4][6] = int_stack + 91080;
 Libr12->rvrr_classes[4][7] = int_stack + 91500;
 Libr12->rvrr_classes[4][8] = int_stack + 92040;
 Libr12->rvrr_classes[4][9] = int_stack + 92715;
 Libr12->rvrr_classes[4][10] = int_stack + 93540;
 Libr12->rvrr_classes[5][5] = int_stack + 94530;
 Libr12->rvrr_classes[5][6] = int_stack + 94971;
 Libr12->rvrr_classes[5][7] = int_stack + 95559;
 Libr12->rvrr_classes[5][8] = int_stack + 96315;
 Libr12->rvrr_classes[5][9] = int_stack + 97260;
 Libr12->rvrr_classes[5][10] = int_stack + 98415;
 Libr12->rvrr_classes[6][5] = int_stack + 99801;
 Libr12->rvrr_classes[6][6] = int_stack + 100389;
 Libr12->rvrr_classes[6][7] = int_stack + 101173;
 Libr12->rvrr_classes[6][8] = int_stack + 102181;
 Libr12->rvrr_classes[6][9] = int_stack + 103441;
 Libr12->rvrr_classes[6][10] = int_stack + 104981;
 Libr12->rvrr_classes[7][5] = int_stack + 106829;
 Libr12->rvrr_classes[7][6] = int_stack + 107585;
 Libr12->rvrr_classes[7][7] = int_stack + 108593;
 Libr12->rvrr_classes[7][8] = int_stack + 109889;
 Libr12->rvrr_classes[7][9] = int_stack + 111509;
 Libr12->rvrr_classes[7][10] = int_stack + 113489;
 Libr12->rvrr_classes[8][5] = int_stack + 115865;
 Libr12->rvrr_classes[8][6] = int_stack + 116810;
 Libr12->rvrr_classes[8][7] = int_stack + 118070;
 Libr12->rvrr_classes[8][8] = int_stack + 119690;
 Libr12->rvrr_classes[8][9] = int_stack + 121715;
 Libr12->rvrr_classes[8][10] = int_stack + 124190;
 Libr12->gvrr_classes[4][5] = int_stack + 127160;
 Libr12->gvrr_classes[4][6] = int_stack + 127475;
 Libr12->gvrr_classes[4][7] = int_stack + 127895;
 Libr12->gvrr_classes[4][8] = int_stack + 128435;
 Libr12->gvrr_classes[4][9] = int_stack + 129110;
 Libr12->gvrr_classes[4][10] = int_stack + 129935;
 Libr12->gvrr_classes[5][5] = int_stack + 130925;
 Libr12->gvrr_classes[5][6] = int_stack + 131366;
 Libr12->gvrr_classes[5][7] = int_stack + 131954;
 Libr12->gvrr_classes[5][8] = int_stack + 132710;
 Libr12->gvrr_classes[5][9] = int_stack + 133655;
 Libr12->gvrr_classes[5][10] = int_stack + 134810;
 Libr12->gvrr_classes[6][5] = int_stack + 136196;
 Libr12->gvrr_classes[6][6] = int_stack + 136784;
 Libr12->gvrr_classes[6][7] = int_stack + 137568;
 Libr12->gvrr_classes[6][8] = int_stack + 138576;
 Libr12->gvrr_classes[6][9] = int_stack + 139836;
 Libr12->gvrr_classes[6][10] = int_stack + 141376;
 Libr12->gvrr_classes[7][5] = int_stack + 143224;
 Libr12->gvrr_classes[7][6] = int_stack + 143980;
 Libr12->gvrr_classes[7][7] = int_stack + 144988;
 Libr12->gvrr_classes[7][8] = int_stack + 146284;
 Libr12->gvrr_classes[7][9] = int_stack + 147904;
 Libr12->gvrr_classes[7][10] = int_stack + 149884;
 Libr12->gvrr_classes[8][5] = int_stack + 152260;
 Libr12->gvrr_classes[8][6] = int_stack + 153205;
 Libr12->gvrr_classes[8][7] = int_stack + 154465;
 Libr12->gvrr_classes[8][8] = int_stack + 156085;
 Libr12->gvrr_classes[8][9] = int_stack + 158110;
 Libr12->gvrr_classes[8][10] = int_stack + 160585;
 memset(int_stack,0,163555*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 163555;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gghh(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+163555, int_stack+127475, int_stack+127160, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+164500, int_stack+127895, int_stack+127475, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+165760, int_stack+164500, int_stack+163555, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+167650, int_stack+128435, int_stack+127895, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+169270, int_stack+167650, int_stack+164500, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+171790, int_stack+169270, int_stack+165760, 15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+174940, int_stack+129110, int_stack+128435, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+176965, int_stack+174940, int_stack+167650, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+180205, int_stack+176965, int_stack+169270, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+184405, int_stack+180205, int_stack+171790, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+189130, int_stack+131366, int_stack+130925, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+190453, int_stack+131954, int_stack+131366, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+192217, int_stack+190453, int_stack+189130, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+194863, int_stack+132710, int_stack+131954, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+197131, int_stack+194863, int_stack+190453, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+200659, int_stack+197131, int_stack+192217, 21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+205069, int_stack+133655, int_stack+132710, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+207904, int_stack+205069, int_stack+194863, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+212440, int_stack+207904, int_stack+197131, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+218320, int_stack+212440, int_stack+200659, 21);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+224935, int_stack+129935, int_stack+129110, 15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+227410, int_stack+224935, int_stack+174940, 15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+231460, int_stack+227410, int_stack+176965, 15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+236860, int_stack+231460, int_stack+180205, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+243160, int_stack+315, int_stack+0, int_stack+127475, int_stack+130925, int_stack+127160, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+244105, int_stack+735, int_stack+315, int_stack+127895, int_stack+131366, int_stack+127475, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+245365, int_stack+244105, int_stack+243160, int_stack+164500, int_stack+189130, int_stack+163555, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+247255, int_stack+1275, int_stack+735, int_stack+128435, int_stack+131954, int_stack+127895, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+248875, int_stack+247255, int_stack+244105, int_stack+167650, int_stack+190453, int_stack+164500, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+251395, int_stack+248875, int_stack+245365, int_stack+169270, int_stack+192217, int_stack+165760, 4, 0);
 /*--- compute (g0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+163555, int_stack+1950, int_stack+1275, int_stack+129110, int_stack+132710, int_stack+128435, 4, 0);
 /*--- compute (g0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+243160, int_stack+163555, int_stack+247255, int_stack+174940, int_stack+194863, int_stack+167650, 4, 0);
 /*--- compute (g0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+254545, int_stack+243160, int_stack+248875, int_stack+176965, int_stack+197131, int_stack+169270, 4, 0);
 /*--- compute (g0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+165580, int_stack+254545, int_stack+251395, int_stack+180205, int_stack+200659, int_stack+171790, 4, 0);
 /*--- compute (g0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+170305, int_stack+2775, int_stack+1950, int_stack+129935, int_stack+133655, int_stack+129110, 4, 0);
 /*--- compute (g0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+246400, int_stack+170305, int_stack+163555, int_stack+224935, int_stack+205069, int_stack+174940, 4, 0);
 /*--- compute (g0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+170305, int_stack+246400, int_stack+243160, int_stack+227410, int_stack+207904, int_stack+176965, 4, 0);
 /*--- compute (g0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+243160, int_stack+170305, int_stack+254545, int_stack+231460, int_stack+212440, int_stack+180205, 4, 0);
 /*--- compute (g0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+170305, int_stack+243160, int_stack+165580, int_stack+236860, int_stack+218320, int_stack+184405, 4, 0);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+243160, int_stack+136784, int_stack+136196, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+244924, int_stack+137568, int_stack+136784, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+247276, int_stack+244924, int_stack+243160, 28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+250804, int_stack+138576, int_stack+137568, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+253828, int_stack+250804, int_stack+244924, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+176920, int_stack+253828, int_stack+247276, 28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+163555, int_stack+139836, int_stack+138576, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+258532, int_stack+163555, int_stack+250804, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+264580, int_stack+258532, int_stack+253828, 28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+272420, int_stack+264580, int_stack+176920, 28);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+134810, int_stack+133655, 21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+281240, int_stack+0, int_stack+205069, 21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+286910, int_stack+281240, int_stack+207904, 21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+294470, int_stack+286910, int_stack+212440, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+182800, int_stack+4206, int_stack+3765, int_stack+131366, int_stack+136196, int_stack+130925, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+167335, int_stack+4794, int_stack+4206, int_stack+131954, int_stack+136784, int_stack+131366, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+127160, int_stack+167335, int_stack+182800, int_stack+190453, int_stack+243160, int_stack+189130, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+303290, int_stack+5550, int_stack+4794, int_stack+132710, int_stack+137568, int_stack+131954, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+305558, int_stack+303290, int_stack+167335, int_stack+194863, int_stack+244924, int_stack+190453, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+309086, int_stack+305558, int_stack+127160, int_stack+197131, int_stack+247276, int_stack+192217, 5, 0);
 /*--- compute (h0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+167335, int_stack+6495, int_stack+5550, int_stack+133655, int_stack+138576, int_stack+132710, 5, 0);
 /*--- compute (h0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+189130, int_stack+167335, int_stack+303290, int_stack+205069, int_stack+250804, int_stack+194863, 5, 0);
 /*--- compute (h0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+313496, int_stack+189130, int_stack+305558, int_stack+207904, int_stack+253828, int_stack+197131, 5, 0);
 /*--- compute (h0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+193666, int_stack+313496, int_stack+309086, int_stack+212440, int_stack+176920, int_stack+200659, 5, 0);
 /*--- compute (h0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+303290, int_stack+7650, int_stack+6495, int_stack+134810, int_stack+139836, int_stack+133655, 5, 0);
 /*--- compute (h0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+306755, int_stack+303290, int_stack+167335, int_stack+0, int_stack+163555, int_stack+205069, 5, 0);
 /*--- compute (h0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+200281, int_stack+306755, int_stack+189130, int_stack+281240, int_stack+258532, int_stack+207904, 5, 0);
 /*--- compute (h0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+303290, int_stack+200281, int_stack+313496, int_stack+286910, int_stack+264580, int_stack+212440, 5, 0);
 /*--- compute (h0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+200281, int_stack+303290, int_stack+193666, int_stack+294470, int_stack+272420, int_stack+218320, 5, 0);
 /*--- compute (gp|[r12,T2]|hh) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+303290, int_stack+200281, int_stack+170305, 441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+209542, int_stack+143980, int_stack+143224, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+211810, int_stack+144988, int_stack+143980, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+189130, int_stack+211810, int_stack+209542, 36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+193666, int_stack+146284, int_stack+144988, 36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+167335, int_stack+193666, int_stack+211810, 36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+323135, int_stack+167335, int_stack+189130, 36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+3465, int_stack+147904, int_stack+146284, 36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+330695, int_stack+3465, int_stack+193666, 36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+338471, int_stack+330695, int_stack+167335, 36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+348551, int_stack+338471, int_stack+323135, 36);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+359891, int_stack+141376, int_stack+139836, 28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+364511, int_stack+359891, int_stack+163555, 28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+372071, int_stack+364511, int_stack+258532, 28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+382151, int_stack+372071, int_stack+264580, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+214834, int_stack+9624, int_stack+9036, int_stack+136784, int_stack+143224, int_stack+136196, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+197554, int_stack+10408, int_stack+9624, int_stack+137568, int_stack+143980, int_stack+136784, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+173383, int_stack+197554, int_stack+214834, int_stack+244924, int_stack+209542, int_stack+243160, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+214834, int_stack+11416, int_stack+10408, int_stack+138576, int_stack+144988, int_stack+137568, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+393911, int_stack+214834, int_stack+197554, int_stack+250804, int_stack+211810, int_stack+244924, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+398615, int_stack+393911, int_stack+173383, int_stack+253828, int_stack+189130, int_stack+247276, 6, 0);
 /*--- compute (i0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+243160, int_stack+12676, int_stack+11416, int_stack+139836, int_stack+146284, int_stack+138576, 6, 0);
 /*--- compute (i0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+404495, int_stack+243160, int_stack+214834, int_stack+163555, int_stack+193666, int_stack+250804, 6, 0);
 /*--- compute (i0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+410543, int_stack+404495, int_stack+393911, int_stack+258532, int_stack+167335, int_stack+253828, 6, 0);
 /*--- compute (i0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+246940, int_stack+410543, int_stack+398615, int_stack+264580, int_stack+323135, int_stack+176920, 6, 0);
 /*--- compute (i0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+393911, int_stack+14216, int_stack+12676, int_stack+141376, int_stack+147904, int_stack+139836, 6, 0);
 /*--- compute (i0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+173383, int_stack+393911, int_stack+243160, int_stack+359891, int_stack+3465, int_stack+163555, 6, 0);
 /*--- compute (i0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+393911, int_stack+173383, int_stack+404495, int_stack+364511, int_stack+330695, int_stack+258532, 6, 0);
 /*--- compute (i0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+418383, int_stack+393911, int_stack+410543, int_stack+372071, int_stack+338471, int_stack+264580, 6, 0);
 /*--- compute (i0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+393911, int_stack+418383, int_stack+246940, int_stack+382151, int_stack+348551, int_stack+272420, 6, 0);
 /*--- compute (hp|[r12,T2]|hh) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+243160, int_stack+393911, int_stack+200281, 441);
 /*--- compute (gd|[r12,T2]|hh) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+406259, int_stack+243160, int_stack+303290, 441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+303290, int_stack+153205, int_stack+152260, 45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+163555, int_stack+154465, int_stack+153205, 45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+306125, int_stack+163555, int_stack+303290, 45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+311795, int_stack+156085, int_stack+154465, 45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+173383, int_stack+311795, int_stack+163555, 45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+197554, int_stack+173383, int_stack+306125, 45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+316655, int_stack+158110, int_stack+156085, 45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+445949, int_stack+316655, int_stack+311795, 45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+455669, int_stack+445949, int_stack+173383, 45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+468269, int_stack+455669, int_stack+197554, 45);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+8325, int_stack+149884, int_stack+147904, 36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+482444, int_stack+8325, int_stack+3465, 36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+492164, int_stack+482444, int_stack+330695, 36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+505124, int_stack+492164, int_stack+338471, 36);
 /*--- compute (k0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+180943, int_stack+16820, int_stack+16064, int_stack+143980, int_stack+152260, int_stack+143224, 7, 0);
 /*--- compute (k0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+214834, int_stack+17828, int_stack+16820, int_stack+144988, int_stack+153205, int_stack+143980, 7, 0);
 /*--- compute (k0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+136196, int_stack+214834, int_stack+180943, int_stack+211810, int_stack+303290, int_stack+209542, 7, 0);
 /*--- compute (k0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+207004, int_stack+19124, int_stack+17828, int_stack+146284, int_stack+154465, int_stack+144988, 7, 0);
 /*--- compute (k0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+520244, int_stack+207004, int_stack+214834, int_stack+193666, int_stack+163555, int_stack+211810, 7, 0);
 /*--- compute (k0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+526292, int_stack+520244, int_stack+136196, int_stack+167335, int_stack+306125, int_stack+189130, 7, 0);
 /*--- compute (k0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+136196, int_stack+20744, int_stack+19124, int_stack+147904, int_stack+156085, int_stack+146284, 7, 0);
 /*--- compute (k0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+533852, int_stack+136196, int_stack+207004, int_stack+3465, int_stack+311795, int_stack+193666, 7, 0);
 /*--- compute (k0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+207004, int_stack+533852, int_stack+520244, int_stack+330695, int_stack+173383, int_stack+167335, 7, 0);
 /*--- compute (k0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+541628, int_stack+207004, int_stack+526292, int_stack+338471, int_stack+197554, int_stack+323135, 7, 0);
 /*--- compute (k0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+167335, int_stack+22724, int_stack+20744, int_stack+149884, int_stack+158110, int_stack+147904, 7, 0);
 /*--- compute (k0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+520244, int_stack+167335, int_stack+136196, int_stack+8325, int_stack+316655, int_stack+3465, 7, 0);
 /*--- compute (k0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+552968, int_stack+520244, int_stack+533852, int_stack+482444, int_stack+445949, int_stack+330695, 7, 0);
 /*--- compute (k0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+520244, int_stack+552968, int_stack+207004, int_stack+492164, int_stack+455669, int_stack+338471, 7, 0);
 /*--- compute (k0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+322730, int_stack+520244, int_stack+541628, int_stack+505124, int_stack+468269, int_stack+348551, 7, 0);
 /*--- compute (ip|[r12,T2]|hh) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+520244, int_stack+322730, int_stack+393911, 441);
 /*--- compute (hd|[r12,T2]|hh) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+557288, int_stack+520244, int_stack+243160, 441);
 /*--- compute (gf|[r12,T2]|hh) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+612854, int_stack+557288, int_stack+406259, 441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+243160, int_stack+27200, int_stack+25100, 55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+246625, int_stack+30000, int_stack+27200, 55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+251245, int_stack+246625, int_stack+243160, 55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+258175, int_stack+33600, int_stack+30000, 55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+393911, int_stack+258175, int_stack+246625, 55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+403151, int_stack+393911, int_stack+251245, 55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+264115, int_stack+38100, int_stack+33600, 55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+414701, int_stack+264115, int_stack+258175, 55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+426581, int_stack+414701, int_stack+393911, 55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+679004, int_stack+426581, int_stack+403151, 55);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+207004, int_stack+160585, int_stack+158110, 45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+696329, int_stack+207004, int_stack+316655, 45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+708479, int_stack+696329, int_stack+445949, 45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+724679, int_stack+708479, int_stack+455669, 45);
 /*--- compute (l0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+441981, int_stack+28740, int_stack+26255, int_stack+153205, int_stack+25100, int_stack+152260, 8, 0);
 /*--- compute (l0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+214429, int_stack+31980, int_stack+28740, int_stack+154465, int_stack+27200, int_stack+153205, 8, 0);
 /*--- compute (l0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+167335, int_stack+214429, int_stack+441981, int_stack+163555, int_stack+243160, int_stack+303290, 8, 0);
 /*--- compute (l0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3465, int_stack+36075, int_stack+31980, int_stack+156085, int_stack+30000, int_stack+154465, 8, 0);
 /*--- compute (l0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+189130, int_stack+3465, int_stack+214429, int_stack+311795, int_stack+246625, int_stack+163555, 8, 0);
 /*--- compute (l0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+338606, int_stack+189130, int_stack+167335, int_stack+173383, int_stack+251245, int_stack+306125, 8, 0);
 /*--- compute (l0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+163555, int_stack+41125, int_stack+36075, int_stack+158110, int_stack+33600, int_stack+156085, 8, 0);
 /*--- compute (l0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+243160, int_stack+163555, int_stack+3465, int_stack+316655, int_stack+258175, int_stack+311795, 8, 0);
 /*--- compute (l0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+303290, int_stack+243160, int_stack+189130, int_stack+445949, int_stack+393911, int_stack+173383, 8, 0);
 /*--- compute (l0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+169630, int_stack+303290, int_stack+338606, int_stack+455669, int_stack+403151, int_stack+197554, 8, 0);
 /*--- compute (l0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+338606, int_stack+43600, int_stack+41125, int_stack+160585, int_stack+38100, int_stack+158110, 8, 0);
 /*--- compute (l0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+393911, int_stack+338606, int_stack+163555, int_stack+207004, int_stack+264115, int_stack+316655, 8, 0);
 /*--- compute (l0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+189130, int_stack+393911, int_stack+243160, int_stack+696329, int_stack+414701, int_stack+445949, 8, 0);
 /*--- compute (l0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+243160, int_stack+189130, int_stack+303290, int_stack+708479, int_stack+426581, int_stack+455669, 8, 0);
 /*--- compute (l0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+189130, int_stack+243160, int_stack+169630, int_stack+724679, int_stack+679004, int_stack+468269, 8, 0);
 /*--- compute (kp|[r12,T2]|hh) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+393911, int_stack+189130, int_stack+322730, 441);
 /*--- compute (id|[r12,T2]|hh) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+743579, int_stack+393911, int_stack+520244, 441);
 /*--- compute (hf|[r12,T2]|hh) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+817667, int_stack+743579, int_stack+557288, 441);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+743579, int_stack+236860, int_stack+184405, 15);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+750194, int_stack+294470, int_stack+218320, 21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+759455, int_stack+750194, int_stack+743579, 441);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+779300, int_stack+382151, int_stack+272420, 28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+520244, int_stack+779300, int_stack+750194, 441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+548027, int_stack+520244, int_stack+759455, 441);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+791648, int_stack+505124, int_stack+348551, 36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+393911, int_stack+791648, int_stack+779300, 441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+303290, int_stack+393911, int_stack+520244, 441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+152260, int_stack+303290, int_stack+548027, 441);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+807524, int_stack+46570, int_stack+129935, 15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+810494, int_stack+807524, int_stack+224935, 15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+587717, int_stack+810494, int_stack+227410, 15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+807524, int_stack+587717, int_stack+231460, 15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+587717, int_stack+807524, int_stack+236860, 15);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+807524, int_stack+51505, int_stack+134810, 21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+807524, int_stack+0, 21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+807524, int_stack+596537, int_stack+281240, 21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+807524, int_stack+286910, 21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+430955, int_stack+596537, int_stack+294470, 21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+679004, int_stack+430955, int_stack+587717, 588);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+58414, int_stack+141376, 28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+602081, int_stack+596537, int_stack+359891, 28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+443303, int_stack+602081, int_stack+364511, 28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+443303, int_stack+372071, 28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+443303, int_stack+596537, int_stack+382151, 28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+218410, int_stack+443303, int_stack+430955, 588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+910277, int_stack+218410, int_stack+679004, 588);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+67626, int_stack+149884, 36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+705464, int_stack+596537, int_stack+8325, 36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+705464, int_stack+482444, 36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+596537, int_stack+492164, 36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+482444, int_stack+0, int_stack+505124, 36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+963197, int_stack+482444, int_stack+443303, 588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+1012589, int_stack+963197, int_stack+218410, 588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+1086677, int_stack+1012589, int_stack+910277, 588);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+0, int_stack+724679, int_stack+468269, 45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+255454, int_stack+0, int_stack+791648, 441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+1174877, int_stack+255454, int_stack+393911, 441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+1248965, int_stack+1174877, int_stack+303290, 441);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19845, int_stack+48055, int_stack+47740, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+20790, int_stack+48475, int_stack+48055, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+22050, int_stack+20790, int_stack+19845, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+23940, int_stack+49015, int_stack+48475, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+25560, int_stack+23940, int_stack+20790, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+28080, int_stack+25560, int_stack+22050, 15);
 /*--- compute (g0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+19845, int_stack+49690, int_stack+49015, 15);
 /*--- compute (g0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+31230, int_stack+19845, int_stack+23940, 15);
 /*--- compute (g0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+34470, int_stack+31230, int_stack+25560, 15);
 /*--- compute (g0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+21870, int_stack+34470, int_stack+28080, 15);
 /*--- compute (g0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+26595, int_stack+50515, int_stack+49690, 15);
 /*--- compute (g0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+38670, int_stack+26595, int_stack+19845, 15);
 /*--- compute (g0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+42720, int_stack+38670, int_stack+31230, 15);
 /*--- compute (g0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+26595, int_stack+42720, int_stack+34470, 15);
 /*--- compute (g0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+32895, int_stack+26595, int_stack+21870, 15);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19845, int_stack+53584, int_stack+53143, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+21168, int_stack+54172, int_stack+53584, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+22932, int_stack+21168, int_stack+19845, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+25578, int_stack+54928, int_stack+54172, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+27846, int_stack+25578, int_stack+21168, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+39510, int_stack+27846, int_stack+22932, 21);
 /*--- compute (h0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+19845, int_stack+55873, int_stack+54928, 21);
 /*--- compute (h0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+43920, int_stack+19845, int_stack+25578, 21);
 /*--- compute (h0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+48456, int_stack+43920, int_stack+27846, 21);
 /*--- compute (h0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+22680, int_stack+48456, int_stack+39510, 21);
 /*--- compute (h0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+39510, int_stack+57028, int_stack+55873, 21);
 /*--- compute (h0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+54336, int_stack+39510, int_stack+19845, 21);
 /*--- compute (h0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+54336, int_stack+43920, 21);
 /*--- compute (h0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+39510, int_stack+596537, int_stack+48456, 21);
 /*--- compute (h0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+596537, int_stack+39510, int_stack+22680, 21);
 /*--- compute (gp|[r12,T1]|hh) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+39510, int_stack+596537, int_stack+32895, int_stack+750194, int_stack+587717, int_stack+743579, 5, 5);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+587717, int_stack+61186, int_stack+60598, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+589481, int_stack+61970, int_stack+61186, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+591833, int_stack+589481, int_stack+587717, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+605798, int_stack+62978, int_stack+61970, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+19845, int_stack+605798, int_stack+589481, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+24549, int_stack+19845, int_stack+591833, 28);
 /*--- compute (i0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+587717, int_stack+64238, int_stack+62978, 28);
 /*--- compute (i0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+30429, int_stack+587717, int_stack+605798, 28);
 /*--- compute (i0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+503612, int_stack+30429, int_stack+19845, 28);
 /*--- compute (i0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+705464, int_stack+503612, int_stack+24549, 28);
 /*--- compute (i0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+19845, int_stack+65778, int_stack+64238, 28);
 /*--- compute (i0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+59355, int_stack+19845, int_stack+587717, 28);
 /*--- compute (i0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+19845, int_stack+59355, int_stack+30429, 28);
 /*--- compute (i0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+714284, int_stack+19845, int_stack+503612, 28);
 /*--- compute (i0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+503612, int_stack+714284, int_stack+705464, 28);
 /*--- compute (hp|[r12,T1]|hh) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+705464, int_stack+503612, int_stack+596537, int_stack+779300, int_stack+430955, int_stack+750194, 5, 5);
 /*--- compute (gd|[r12,T1]|hh) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+1341575, int_stack+705464, int_stack+39510, int_stack+520244, int_stack+679004, int_stack+759455, 5, 5);
 /*--- compute (k0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+679004, int_stack+71190, int_stack+70434, 36);
 /*--- compute (k0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+681272, int_stack+72198, int_stack+71190, 36);
 /*--- compute (k0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+684296, int_stack+681272, int_stack+679004, 36);
 /*--- compute (k0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+688832, int_stack+73494, int_stack+72198, 36);
 /*--- compute (k0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+692720, int_stack+688832, int_stack+681272, 36);
 /*--- compute (k0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+430955, int_stack+692720, int_stack+684296, 36);
 /*--- compute (k0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+679004, int_stack+75114, int_stack+73494, 36);
 /*--- compute (k0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+733247, int_stack+679004, int_stack+688832, 36);
 /*--- compute (k0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+741023, int_stack+733247, int_stack+692720, 36);
 /*--- compute (k0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+683864, int_stack+741023, int_stack+430955, 36);
 /*--- compute (k0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+430955, int_stack+77094, int_stack+75114, 36);
 /*--- compute (k0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+695204, int_stack+430955, int_stack+679004, 36);
 /*--- compute (k0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+751103, int_stack+695204, int_stack+733247, 36);
 /*--- compute (k0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+764063, int_stack+751103, int_stack+741023, 36);
 /*--- compute (k0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+733247, int_stack+764063, int_stack+683864, 36);
 /*--- compute (ip|[r12,T1]|hh) ---*/
   t1hrr1_build_ip(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+19845, int_stack+733247, int_stack+503612, int_stack+791648, int_stack+443303, int_stack+779300, 5, 5);
 /*--- compute (hd|[r12,T1]|hh) ---*/
   t1hrr1_build_hd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+1381265, int_stack+19845, int_stack+705464, int_stack+393911, int_stack+218410, int_stack+520244, 5, 5);
 /*--- compute (gf|[r12,T1]|hh) ---*/
   t1hrr1_build_gf(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+1436831, int_stack+1381265, int_stack+1341575, int_stack+303290, int_stack+910277, int_stack+548027, 5, 5);
 /*--- compute (l0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+910277, int_stack+80415, int_stack+79470, 45);
 /*--- compute (l0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+913112, int_stack+81675, int_stack+80415, 45);
 /*--- compute (l0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+916892, int_stack+913112, int_stack+910277, 45);
 /*--- compute (l0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+922562, int_stack+83295, int_stack+81675, 45);
 /*--- compute (l0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+927422, int_stack+922562, int_stack+913112, 45);
 /*--- compute (l0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+934982, int_stack+927422, int_stack+916892, 45);
 /*--- compute (l0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+910277, int_stack+85320, int_stack+83295, 45);
 /*--- compute (l0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+944432, int_stack+910277, int_stack+922562, 45);
 /*--- compute (l0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+1341575, int_stack+944432, int_stack+927422, 45);
 /*--- compute (l0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+916352, int_stack+1341575, int_stack+934982, 45);
 /*--- compute (l0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+930527, int_stack+87795, int_stack+85320, 45);
 /*--- compute (l0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+1354175, int_stack+930527, int_stack+910277, 45);
 /*--- compute (l0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+218410, int_stack+1354175, int_stack+944432, 45);
 /*--- compute (l0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+1354175, int_stack+218410, int_stack+1341575, 45);
 /*--- compute (l0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+218410, int_stack+1354175, int_stack+916352, 45);
 /*--- compute (kp|[r12,T1]|hh) ---*/
   t1hrr1_build_kp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+910277, int_stack+218410, int_stack+733247, int_stack+0, int_stack+482444, int_stack+791648, 5, 5);
 /*--- compute (id|[r12,T1]|hh) ---*/
   t1hrr1_build_id(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+679004, int_stack+910277, int_stack+19845, int_stack+255454, int_stack+963197, int_stack+393911, 5, 5);
 /*--- compute (hf|[r12,T1]|hh) ---*/
   t1hrr1_build_hf(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+910277, int_stack+679004, int_stack+1381265, int_stack+1174877, int_stack+1012589, int_stack+303290, 5, 5);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1174877, int_stack+91080, int_stack+90765, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1175822, int_stack+91500, int_stack+91080, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1177082, int_stack+1175822, int_stack+1174877, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+1178972, int_stack+92040, int_stack+91500, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+1180592, int_stack+1178972, int_stack+1175822, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+1183112, int_stack+1180592, int_stack+1177082, 15);
 /*--- compute (g0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+1174877, int_stack+92715, int_stack+92040, 15);
 /*--- compute (g0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+1186262, int_stack+1174877, int_stack+1178972, 15);
 /*--- compute (g0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+1189502, int_stack+1186262, int_stack+1180592, 15);
 /*--- compute (g0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+1176902, int_stack+1189502, int_stack+1183112, 15);
 /*--- compute (g0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+1181627, int_stack+93540, int_stack+92715, 15);
 /*--- compute (g0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+1193702, int_stack+1181627, int_stack+1174877, 15);
 /*--- compute (g0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+1197752, int_stack+1193702, int_stack+1186262, 15);
 /*--- compute (g0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+1181627, int_stack+1197752, int_stack+1189502, 15);
 /*--- compute (g0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+1187927, int_stack+1181627, int_stack+1176902, 15);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1174877, int_stack+94971, int_stack+94530, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1176200, int_stack+95559, int_stack+94971, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1177964, int_stack+1176200, int_stack+1174877, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+1180610, int_stack+96315, int_stack+95559, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+1182878, int_stack+1180610, int_stack+1176200, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+1194542, int_stack+1182878, int_stack+1177964, 21);
 /*--- compute (h0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+1174877, int_stack+97260, int_stack+96315, 21);
 /*--- compute (h0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+1198952, int_stack+1174877, int_stack+1180610, 21);
 /*--- compute (h0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+1203488, int_stack+1198952, int_stack+1182878, 21);
 /*--- compute (h0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+1177712, int_stack+1203488, int_stack+1194542, 21);
 /*--- compute (h0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+1194542, int_stack+98415, int_stack+97260, 21);
 /*--- compute (h0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+1209368, int_stack+1194542, int_stack+1174877, 21);
 /*--- compute (h0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+1215038, int_stack+1209368, int_stack+1198952, 21);
 /*--- compute (h0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+1194542, int_stack+1215038, int_stack+1203488, 21);
 /*--- compute (h0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+1203362, int_stack+1194542, int_stack+1177712, 21);
 /*--- compute (gp||hh) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+1212623, int_stack+1203362, int_stack+1187927, 441);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1174877, int_stack+100389, int_stack+99801, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1176641, int_stack+101173, int_stack+100389, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1178993, int_stack+1176641, int_stack+1174877, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+1182521, int_stack+102181, int_stack+101173, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+1185545, int_stack+1182521, int_stack+1176641, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+1190249, int_stack+1185545, int_stack+1178993, 28);
 /*--- compute (i0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+1174877, int_stack+103441, int_stack+102181, 28);
 /*--- compute (i0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+1196129, int_stack+1174877, int_stack+1182521, 28);
 /*--- compute (i0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+1232468, int_stack+1196129, int_stack+1185545, 28);
 /*--- compute (i0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+1178657, int_stack+1232468, int_stack+1190249, 28);
 /*--- compute (i0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+1187477, int_stack+104981, int_stack+103441, 28);
 /*--- compute (i0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+1240308, int_stack+1187477, int_stack+1174877, 28);
 /*--- compute (i0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+679004, int_stack+1240308, int_stack+1196129, 28);
 /*--- compute (i0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+1187477, int_stack+679004, int_stack+1232468, 28);
 /*--- compute (i0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+1232468, int_stack+1187477, int_stack+1178657, 28);
 /*--- compute (hp||hh) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+679004, int_stack+1232468, int_stack+1203362, 441);
 /*--- compute (gd||hh) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+706787, int_stack+679004, int_stack+1212623, 441);
 /*--- compute (k0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1244816, int_stack+107585, int_stack+106829, 36);
 /*--- compute (k0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+746477, int_stack+108593, int_stack+107585, 36);
 /*--- compute (k0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+749501, int_stack+746477, int_stack+1244816, 36);
 /*--- compute (k0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+1244816, int_stack+109889, int_stack+108593, 36);
 /*--- compute (k0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+754037, int_stack+1244816, int_stack+746477, 36);
 /*--- compute (k0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+760085, int_stack+754037, int_stack+749501, 36);
 /*--- compute (k0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+746477, int_stack+111509, int_stack+109889, 36);
 /*--- compute (k0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+767645, int_stack+746477, int_stack+1244816, 36);
 /*--- compute (k0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+775421, int_stack+767645, int_stack+754037, 36);
 /*--- compute (k0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+785501, int_stack+775421, int_stack+760085, 36);
 /*--- compute (k0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+751337, int_stack+113489, int_stack+111509, 36);
 /*--- compute (k0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+757277, int_stack+751337, int_stack+746477, 36);
 /*--- compute (k0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+796841, int_stack+757277, int_stack+767645, 36);
 /*--- compute (k0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+746477, int_stack+796841, int_stack+775421, 36);
 /*--- compute (k0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+796841, int_stack+746477, int_stack+785501, 36);
 /*--- compute (ip||hh) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+746477, int_stack+796841, int_stack+1232468, 441);
 /*--- compute (hd||hh) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+1174877, int_stack+746477, int_stack+679004, 441);
 /*--- compute (gf||hh) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+1002887, int_stack+1174877, int_stack+706787, 441);
 /*--- compute (l0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+679004, int_stack+116810, int_stack+115865, 45);
 /*--- compute (l0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+681839, int_stack+118070, int_stack+116810, 45);
 /*--- compute (l0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+685619, int_stack+681839, int_stack+679004, 45);
 /*--- compute (l0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+691289, int_stack+119690, int_stack+118070, 45);
 /*--- compute (l0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+696149, int_stack+691289, int_stack+681839, 45);
 /*--- compute (l0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+703709, int_stack+696149, int_stack+685619, 45);
 /*--- compute (l0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+679004, int_stack+121715, int_stack+119690, 45);
 /*--- compute (l0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+713159, int_stack+679004, int_stack+691289, 45);
 /*--- compute (l0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+722879, int_stack+713159, int_stack+696149, 45);
 /*--- compute (l0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+685079, int_stack+722879, int_stack+703709, 45);
 /*--- compute (l0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+699254, int_stack+124190, int_stack+121715, 45);
 /*--- compute (l0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+783521, int_stack+699254, int_stack+679004, 45);
 /*--- compute (l0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+1230443, int_stack+783521, int_stack+713159, 45);
 /*--- compute (l0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+699254, int_stack+1230443, int_stack+722879, 45);
 /*--- compute (l0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+718154, int_stack+699254, int_stack+685079, 45);
 /*--- compute (kp||hh) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+718154, int_stack+796841, 441);
 /*--- compute (id||hh) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+47628, int_stack+0, int_stack+746477, 441);
 /*--- compute (hf||hh) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+679004, int_stack+47628, int_stack+1174877, 441);
 /*--- compute (gg|[r12,T2]|hh) ---*/
   hrr1_build_gg(Libr12->ShellQuartet.AB,int_stack+0, int_stack+817667, int_stack+612854, 441);
     Libr12->te_ptr[3] = int_stack + 0;
 /*--- compute (gg|[r12,T1]|hh) ---*/
   t1hrr1_build_gg(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+771614, int_stack+910277, int_stack+1436831, int_stack+1248965, int_stack+1086677, int_stack+152260, 5, 5);
     Libr12->te_ptr[2] = int_stack + 771614;
 /*--- compute (gg||hh) ---*/
   hrr1_build_gg(Libr12->ShellQuartet.AB,int_stack+870839, int_stack+679004, int_stack+1002887, 441);
     Libr12->te_ptr[1] = int_stack + 870839;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libr12->ShellQuartet.AB,int_stack+970064, int_stack+1248965, int_stack+152260, 441);
     Libr12->te_ptr[0] = int_stack + 970064;

}
