/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gpgd(Libr12_t *, prim_data *);

  /* Computes (gp|gd) integrals for linear R12-methods */

void hrr_grt_order_gpgd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][4] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 225;
 Libr12->t2vrr_classes[4][6] = int_stack + 540;
 Libr12->gvrr_classes[6][4] = int_stack + 960;
 Libr12->t2vrr_classes[5][4] = int_stack + 1380;
 Libr12->gvrr_classes[6][5] = int_stack + 1695;
 Libr12->t2vrr_classes[5][5] = int_stack + 2283;
 Libr12->t2vrr_classes[5][6] = int_stack + 2724;
 Libr12->gvrr_classes[4][7] = int_stack + 3312;
 Libr12->t1vrr_classes[4][4] = int_stack + 3852;
 Libr12->t1vrr_classes[4][5] = int_stack + 4077;
 Libr12->t1vrr_classes[4][6] = int_stack + 4392;
 Libr12->t1vrr_classes[5][4] = int_stack + 4812;
 Libr12->t1vrr_classes[5][5] = int_stack + 5127;
 Libr12->t1vrr_classes[5][6] = int_stack + 5568;
 Libr12->rvrr_classes[4][4] = int_stack + 6156;
 Libr12->rvrr_classes[4][5] = int_stack + 6381;
 Libr12->rvrr_classes[4][6] = int_stack + 6696;
 Libr12->rvrr_classes[5][4] = int_stack + 7116;
 Libr12->rvrr_classes[5][5] = int_stack + 7431;
 Libr12->rvrr_classes[5][6] = int_stack + 7872;
 Libr12->gvrr_classes[4][4] = int_stack + 8460;
 Libr12->gvrr_classes[4][5] = int_stack + 8685;
 Libr12->gvrr_classes[4][6] = int_stack + 9000;
 Libr12->gvrr_classes[5][4] = int_stack + 9420;
 Libr12->gvrr_classes[5][5] = int_stack + 9735;
 Libr12->gvrr_classes[5][6] = int_stack + 10176;
 memset(int_stack,0,10764*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 10764;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gpgd(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+10764, int_stack+8685, int_stack+8460, 15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11439, int_stack+9735, int_stack+9420, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+12384, int_stack+9000, int_stack+8685, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13329, int_stack+225, int_stack+0, int_stack+8685, int_stack+9420, int_stack+8460, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14004, int_stack+540, int_stack+225, int_stack+9000, int_stack+9735, int_stack+8685, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14949, int_stack+14004, int_stack+13329, int_stack+12384, int_stack+11439, int_stack+10764, 4, 0);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13329, int_stack+1695, int_stack+960, 28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+16299, int_stack+10176, int_stack+9735, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2283, int_stack+1380, int_stack+9735, int_stack+960, int_stack+9420, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17622, int_stack+2724, int_stack+2283, int_stack+10176, int_stack+1695, int_stack+9735, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+945, int_stack+17622, int_stack+0, int_stack+16299, int_stack+13329, int_stack+11439, 5, 0);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+13329, int_stack+12384, int_stack+10764, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+17622, int_stack+3312, int_stack+9000, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8460, int_stack+17622, int_stack+12384, 15);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+17622, int_stack+16299, int_stack+11439, 21);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+16299, int_stack+4077, int_stack+3852, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4392, int_stack+4077, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+10350, int_stack+0, int_stack+16299, 15);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+5127, int_stack+4812, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+16299, int_stack+5568, int_stack+5127, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2835, int_stack+16299, int_stack+0, 21);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6381, int_stack+6156, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+16299, int_stack+6696, int_stack+6381, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+11700, int_stack+16299, int_stack+0, 15);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7431, int_stack+7116, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+16299, int_stack+7872, int_stack+7431, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+4725, int_stack+16299, int_stack+0, 21);
 /*--- compute (gp|[r12,T2]|gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+19512, int_stack+945, int_stack+14949, 90);
     Libr12->te_ptr[3] = int_stack + 19512;
 /*--- compute (gp|[r12,T1]|gd) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+23562, int_stack+2835, int_stack+10350, int_stack+17622, int_stack+8460, int_stack+13329, 4, 2);
     Libr12->te_ptr[2] = int_stack + 23562;
 /*--- compute (gp||gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+4725, int_stack+11700, 90);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+4050, int_stack+17622, int_stack+13329, 90);
     Libr12->te_ptr[0] = int_stack + 4050;

}
