/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_h0gd(Libr12_t *, prim_data *);

  /* Computes (h0|gd) integrals for linear R12-methods */

void hrr_grt_order_h0gd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[6][4] = int_stack + 0;
 Libr12->t2vrr_classes[5][4] = int_stack + 420;
 Libr12->gvrr_classes[6][5] = int_stack + 735;
 Libr12->t2vrr_classes[5][5] = int_stack + 1323;
 Libr12->t2vrr_classes[5][6] = int_stack + 1764;
 Libr12->t1vrr_classes[5][4] = int_stack + 2352;
 Libr12->t1vrr_classes[5][5] = int_stack + 2667;
 Libr12->t1vrr_classes[5][6] = int_stack + 3108;
 Libr12->rvrr_classes[5][4] = int_stack + 3696;
 Libr12->rvrr_classes[5][5] = int_stack + 4011;
 Libr12->rvrr_classes[5][6] = int_stack + 4452;
 Libr12->gvrr_classes[5][4] = int_stack + 5040;
 Libr12->gvrr_classes[5][5] = int_stack + 5355;
 Libr12->gvrr_classes[5][6] = int_stack + 5796;
 memset(int_stack,0,6384*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 6384;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_h0gd(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6384, int_stack+5355, int_stack+5040, 21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7329, int_stack+735, int_stack+0, 28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8589, int_stack+5796, int_stack+5355, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9912, int_stack+1323, int_stack+420, int_stack+5355, int_stack+0, int_stack+5040, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10857, int_stack+1764, int_stack+1323, int_stack+5796, int_stack+735, int_stack+5355, 5, 0);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5040, int_stack+2667, int_stack+2352, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3108, int_stack+2667, 21);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1323, int_stack+4011, int_stack+3696, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+4452, int_stack+4011, 21);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12180, int_stack+10857, int_stack+9912, int_stack+8589, int_stack+7329, int_stack+6384, 5, 0);
     Libr12->te_ptr[3] = int_stack + 12180;
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+9912, int_stack+0, int_stack+5040, 21);
     Libr12->te_ptr[2] = int_stack + 9912;
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3591, int_stack+2268, int_stack+1323, 21);
     Libr12->te_ptr[1] = int_stack + 3591;
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+8589, int_stack+6384, 21);
     Libr12->te_ptr[0] = int_stack + 0;

}
