/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_hdgg(Libr12_t *, prim_data *);

  /* Computes (hd|gg) integrals for linear R12-methods */

void hrr_grt_order_hdgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[5][4] = int_stack + 0;
 Libr12->t2vrr_classes[5][5] = int_stack + 315;
 Libr12->t2vrr_classes[5][6] = int_stack + 756;
 Libr12->t2vrr_classes[5][7] = int_stack + 1344;
 Libr12->t2vrr_classes[5][8] = int_stack + 2100;
 Libr12->t2vrr_classes[6][4] = int_stack + 3045;
 Libr12->t2vrr_classes[6][5] = int_stack + 3465;
 Libr12->t2vrr_classes[6][6] = int_stack + 4053;
 Libr12->t2vrr_classes[6][7] = int_stack + 4837;
 Libr12->t2vrr_classes[6][8] = int_stack + 5845;
 Libr12->gvrr_classes[8][4] = int_stack + 7105;
 Libr12->t2vrr_classes[7][4] = int_stack + 7780;
 Libr12->gvrr_classes[8][5] = int_stack + 8320;
 Libr12->t2vrr_classes[7][5] = int_stack + 9265;
 Libr12->gvrr_classes[8][6] = int_stack + 10021;
 Libr12->t2vrr_classes[7][6] = int_stack + 11281;
 Libr12->gvrr_classes[8][7] = int_stack + 12289;
 Libr12->t2vrr_classes[7][7] = int_stack + 13909;
 Libr12->t2vrr_classes[7][8] = int_stack + 15205;
 Libr12->gvrr_classes[5][9] = int_stack + 16825;
 Libr12->t1vrr_classes[5][4] = int_stack + 17980;
 Libr12->t1vrr_classes[5][5] = int_stack + 18295;
 Libr12->t1vrr_classes[5][6] = int_stack + 18736;
 Libr12->t1vrr_classes[5][7] = int_stack + 19324;
 Libr12->t1vrr_classes[5][8] = int_stack + 20080;
 Libr12->gvrr_classes[6][9] = int_stack + 21025;
 Libr12->t1vrr_classes[6][4] = int_stack + 22565;
 Libr12->t1vrr_classes[6][5] = int_stack + 22985;
 Libr12->t1vrr_classes[6][6] = int_stack + 23573;
 Libr12->t1vrr_classes[6][7] = int_stack + 24357;
 Libr12->t1vrr_classes[6][8] = int_stack + 25365;
 Libr12->t1vrr_classes[7][4] = int_stack + 26625;
 Libr12->t1vrr_classes[7][5] = int_stack + 27165;
 Libr12->t1vrr_classes[7][6] = int_stack + 27921;
 Libr12->t1vrr_classes[7][7] = int_stack + 28929;
 Libr12->t1vrr_classes[7][8] = int_stack + 30225;
 Libr12->rvrr_classes[5][4] = int_stack + 31845;
 Libr12->rvrr_classes[5][5] = int_stack + 32160;
 Libr12->rvrr_classes[5][6] = int_stack + 32601;
 Libr12->rvrr_classes[5][7] = int_stack + 33189;
 Libr12->rvrr_classes[5][8] = int_stack + 33945;
 Libr12->rvrr_classes[6][4] = int_stack + 34890;
 Libr12->rvrr_classes[6][5] = int_stack + 35310;
 Libr12->rvrr_classes[6][6] = int_stack + 35898;
 Libr12->rvrr_classes[6][7] = int_stack + 36682;
 Libr12->rvrr_classes[6][8] = int_stack + 37690;
 Libr12->rvrr_classes[7][4] = int_stack + 38950;
 Libr12->rvrr_classes[7][5] = int_stack + 39490;
 Libr12->rvrr_classes[7][6] = int_stack + 40246;
 Libr12->rvrr_classes[7][7] = int_stack + 41254;
 Libr12->rvrr_classes[7][8] = int_stack + 42550;
 Libr12->gvrr_classes[5][4] = int_stack + 44170;
 Libr12->gvrr_classes[5][5] = int_stack + 44485;
 Libr12->gvrr_classes[5][6] = int_stack + 44926;
 Libr12->gvrr_classes[5][7] = int_stack + 45514;
 Libr12->gvrr_classes[5][8] = int_stack + 46270;
 Libr12->gvrr_classes[6][4] = int_stack + 47215;
 Libr12->gvrr_classes[6][5] = int_stack + 47635;
 Libr12->gvrr_classes[6][6] = int_stack + 48223;
 Libr12->gvrr_classes[6][7] = int_stack + 49007;
 Libr12->gvrr_classes[6][8] = int_stack + 50015;
 Libr12->gvrr_classes[7][4] = int_stack + 51275;
 Libr12->gvrr_classes[7][5] = int_stack + 51815;
 Libr12->gvrr_classes[7][6] = int_stack + 52571;
 Libr12->gvrr_classes[7][7] = int_stack + 53579;
 Libr12->gvrr_classes[7][8] = int_stack + 54875;
 memset(int_stack,0,56495*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 56495;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_hdgg(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+56495, int_stack+44485, int_stack+44170, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+57440, int_stack+44926, int_stack+44485, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+58763, int_stack+57440, int_stack+56495, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+60653, int_stack+45514, int_stack+44926, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+62417, int_stack+60653, int_stack+57440, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+65063, int_stack+62417, int_stack+58763, 21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+68213, int_stack+47635, int_stack+47215, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+69473, int_stack+48223, int_stack+47635, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+71237, int_stack+69473, int_stack+68213, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+73757, int_stack+49007, int_stack+48223, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+76109, int_stack+73757, int_stack+69473, 28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+79637, int_stack+76109, int_stack+71237, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+83837, int_stack+46270, int_stack+45514, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+86105, int_stack+83837, int_stack+60653, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+89633, int_stack+86105, int_stack+62417, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94043, int_stack+315, int_stack+0, int_stack+44485, int_stack+47215, int_stack+44170, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94988, int_stack+756, int_stack+315, int_stack+44926, int_stack+47635, int_stack+44485, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+96311, int_stack+94988, int_stack+94043, int_stack+57440, int_stack+68213, int_stack+56495, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+98201, int_stack+1344, int_stack+756, int_stack+45514, int_stack+48223, int_stack+44926, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+99965, int_stack+98201, int_stack+94988, int_stack+60653, int_stack+69473, int_stack+57440, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+102611, int_stack+99965, int_stack+96311, int_stack+62417, int_stack+71237, int_stack+58763, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56495, int_stack+2100, int_stack+1344, int_stack+46270, int_stack+49007, int_stack+45514, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94043, int_stack+56495, int_stack+98201, int_stack+83837, int_stack+73757, int_stack+60653, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56495, int_stack+94043, int_stack+99965, int_stack+86105, int_stack+76109, int_stack+62417, 5, 0);
 /*--- compute (h0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94043, int_stack+56495, int_stack+102611, int_stack+89633, int_stack+79637, int_stack+65063, 5, 0);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+56495, int_stack+51815, int_stack+51275, 36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+58115, int_stack+52571, int_stack+51815, 36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+60383, int_stack+58115, int_stack+56495, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+98768, int_stack+53579, int_stack+52571, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+101792, int_stack+98768, int_stack+58115, 36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+106328, int_stack+101792, int_stack+60383, 36);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+50015, int_stack+49007, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+111728, int_stack+0, int_stack+73757, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+116432, int_stack+111728, int_stack+76109, 28);
 /*--- compute (i0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+63623, int_stack+3465, int_stack+3045, int_stack+47635, int_stack+51275, int_stack+47215, 6, 0);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44170, int_stack+4053, int_stack+3465, int_stack+48223, int_stack+51815, int_stack+47635, 6, 0);
 /*--- compute (i0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+122312, int_stack+44170, int_stack+63623, int_stack+69473, int_stack+56495, int_stack+68213, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+124832, int_stack+4837, int_stack+4053, int_stack+49007, int_stack+52571, int_stack+48223, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+127184, int_stack+124832, int_stack+44170, int_stack+73757, int_stack+58115, int_stack+69473, 6, 0);
 /*--- compute (i0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+130712, int_stack+127184, int_stack+122312, int_stack+76109, int_stack+60383, int_stack+71237, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68213, int_stack+5845, int_stack+4837, int_stack+50015, int_stack+53579, int_stack+49007, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+134912, int_stack+68213, int_stack+124832, int_stack+0, int_stack+98768, int_stack+73757, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68213, int_stack+134912, int_stack+127184, int_stack+111728, int_stack+101792, int_stack+76109, 6, 0);
 /*--- compute (i0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+122312, int_stack+68213, int_stack+130712, int_stack+116432, int_stack+106328, int_stack+79637, 6, 0);
 /*--- compute (hp|[r12,T2]|gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+128612, int_stack+122312, int_stack+94043, 225);
 /*--- compute (l0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+94043, int_stack+8320, int_stack+7105, 45);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+68213, int_stack+10021, int_stack+8320, 45);
 /*--- compute (l0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+71048, int_stack+68213, int_stack+94043, 45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+75098, int_stack+12289, int_stack+10021, 45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+142787, int_stack+75098, int_stack+68213, 45);
 /*--- compute (l0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+148457, int_stack+142787, int_stack+71048, 45);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+3024, int_stack+54875, int_stack+53579, 36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+155207, int_stack+3024, int_stack+98768, 36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+161255, int_stack+155207, int_stack+101792, 36);
 /*--- compute (k0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+96068, int_stack+9265, int_stack+7780, int_stack+51815, int_stack+7105, int_stack+51275, 7, 0);
 /*--- compute (k0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+47215, int_stack+11281, int_stack+9265, int_stack+52571, int_stack+8320, int_stack+51815, 7, 0);
 /*--- compute (k0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+168815, int_stack+47215, int_stack+96068, int_stack+58115, int_stack+94043, int_stack+56495, 7, 0);
 /*--- compute (k0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94043, int_stack+13909, int_stack+11281, int_stack+53579, int_stack+10021, int_stack+52571, 7, 0);
 /*--- compute (k0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6912, int_stack+94043, int_stack+47215, int_stack+98768, int_stack+68213, int_stack+58115, 7, 0);
 /*--- compute (k0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+172055, int_stack+6912, int_stack+168815, int_stack+101792, int_stack+71048, int_stack+60383, 7, 0);
 /*--- compute (k0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68213, int_stack+15205, int_stack+13909, int_stack+54875, int_stack+12289, int_stack+53579, 7, 0);
 /*--- compute (k0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51275, int_stack+68213, int_stack+94043, int_stack+3024, int_stack+75098, int_stack+98768, 7, 0);
 /*--- compute (k0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+94043, int_stack+51275, int_stack+6912, int_stack+155207, int_stack+142787, int_stack+101792, 7, 0);
 /*--- compute (k0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51275, int_stack+94043, int_stack+172055, int_stack+161255, int_stack+148457, int_stack+106328, 7, 0);
 /*--- compute (ip|[r12,T2]|gg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+168815, int_stack+51275, int_stack+122312, 225);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+122312, int_stack+89633, int_stack+65063, 21);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+51275, int_stack+116432, int_stack+79637, 28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+57575, int_stack+51275, int_stack+122312, 225);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+16825, int_stack+46270, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+74585, int_stack+71750, int_stack+83837, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+79121, int_stack+74585, int_stack+86105, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+79121, int_stack+89633, 21);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+78365, int_stack+21025, int_stack+50015, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+82145, int_stack+78365, int_stack+0, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+0, int_stack+82145, int_stack+111728, 28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+7840, int_stack+0, int_stack+116432, 28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+78365, int_stack+7840, int_stack+71750, 315);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+111728, int_stack+161255, int_stack+106328, 36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+142787, int_stack+111728, int_stack+51275, 225);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+18295, int_stack+17980, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+945, int_stack+18736, int_stack+18295, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+945, int_stack+0, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+4158, int_stack+19324, int_stack+18736, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+16660, int_stack+4158, int_stack+945, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+98210, int_stack+16660, int_stack+2268, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+20080, int_stack+19324, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+101360, int_stack+0, int_stack+4158, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+101360, int_stack+16660, 21);
 /*--- compute (h0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+16660, int_stack+0, int_stack+98210, 21);
 /*--- compute (i0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+98210, int_stack+22985, int_stack+22565, 28);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+99470, int_stack+23573, int_stack+22985, 28);
 /*--- compute (i0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+101234, int_stack+99470, int_stack+98210, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+103754, int_stack+24357, int_stack+23573, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+106106, int_stack+103754, int_stack+99470, 28);
 /*--- compute (i0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+106106, int_stack+101234, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+98210, int_stack+25365, int_stack+24357, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+21385, int_stack+98210, int_stack+103754, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+98210, int_stack+21385, int_stack+106106, 28);
 /*--- compute (i0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+104090, int_stack+98210, int_stack+0, 28);
 /*--- compute (hp|[r12,T1]|gg) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+187715, int_stack+104090, int_stack+16660, int_stack+51275, int_stack+71750, int_stack+122312, 4, 4);
 /*--- compute (k0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+27165, int_stack+26625, 36);
 /*--- compute (k0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+73370, int_stack+27921, int_stack+27165, 36);
 /*--- compute (k0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+16660, int_stack+73370, int_stack+71750, 36);
 /*--- compute (k0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19900, int_stack+28929, int_stack+27921, 36);
 /*--- compute (k0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+22924, int_stack+19900, int_stack+73370, 36);
 /*--- compute (k0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+22924, int_stack+16660, 36);
 /*--- compute (k0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+30225, int_stack+28929, 36);
 /*--- compute (k0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+119828, int_stack+0, int_stack+19900, 36);
 /*--- compute (k0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+119828, int_stack+22924, 36);
 /*--- compute (k0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+119828, int_stack+0, int_stack+71750, 36);
 /*--- compute (ip|[r12,T1]|gg) ---*/
   t1hrr1_build_ip(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+201890, int_stack+119828, int_stack+104090, int_stack+111728, int_stack+7840, int_stack+51275, 4, 4);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+32160, int_stack+31845, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+72695, int_stack+32601, int_stack+32160, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+74018, int_stack+72695, int_stack+71750, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+75908, int_stack+33189, int_stack+32601, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+75908, int_stack+72695, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+2646, int_stack+0, int_stack+74018, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+33945, int_stack+33189, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+5796, int_stack+71750, int_stack+75908, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+5796, int_stack+0, 21);
 /*--- compute (h0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+5796, int_stack+71750, int_stack+2646, 21);
 /*--- compute (i0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+35310, int_stack+34890, 28);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+73010, int_stack+35898, int_stack+35310, 28);
 /*--- compute (i0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+74774, int_stack+73010, int_stack+71750, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+36682, int_stack+35898, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10521, int_stack+0, int_stack+73010, 28);
 /*--- compute (i0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+14049, int_stack+10521, int_stack+74774, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+37690, int_stack+36682, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+18249, int_stack+71750, int_stack+0, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+18249, int_stack+10521, 28);
 /*--- compute (i0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+18249, int_stack+71750, int_stack+14049, 28);
 /*--- compute (hp||gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+24549, int_stack+18249, int_stack+5796, 225);
 /*--- compute (k0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+39490, int_stack+38950, 36);
 /*--- compute (k0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+73370, int_stack+40246, int_stack+39490, 36);
 /*--- compute (k0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+73370, int_stack+71750, 36);
 /*--- compute (k0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3240, int_stack+41254, int_stack+40246, 36);
 /*--- compute (k0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6264, int_stack+3240, int_stack+73370, 36);
 /*--- compute (k0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+71750, int_stack+6264, int_stack+0, 36);
 /*--- compute (k0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+10800, int_stack+42550, int_stack+41254, 36);
 /*--- compute (k0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38724, int_stack+10800, int_stack+3240, 36);
 /*--- compute (k0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+44772, int_stack+38724, int_stack+6264, 36);
 /*--- compute (k0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+44772, int_stack+71750, 36);
 /*--- compute (ip||gg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+98210, int_stack+0, int_stack+18249, 225);
 /*--- compute (hd|[r12,T2]|gg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+220790, int_stack+168815, int_stack+128612, 225);
     Libr12->te_ptr[3] = int_stack + 220790;
 /*--- compute (hd|[r12,T1]|gg) ---*/
   t1hrr1_build_hd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+249140, int_stack+201890, int_stack+187715, int_stack+142787, int_stack+78365, int_stack+57575, 4, 4);
     Libr12->te_ptr[2] = int_stack + 249140;
 /*--- compute (hd||gg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+161687, int_stack+98210, int_stack+24549, 225);
     Libr12->te_ptr[1] = int_stack + 161687;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+142787, int_stack+57575, 225);
     Libr12->te_ptr[0] = int_stack + 0;

}
