/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_hphh(Libr12_t *, prim_data *);

  /* Computes (hp|hh) integrals for linear R12-methods */

void hrr_grt_order_hphh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[5][5] = int_stack + 0;
 Libr12->t2vrr_classes[5][6] = int_stack + 441;
 Libr12->t2vrr_classes[5][7] = int_stack + 1029;
 Libr12->t2vrr_classes[5][8] = int_stack + 1785;
 Libr12->t2vrr_classes[5][9] = int_stack + 2730;
 Libr12->t2vrr_classes[5][10] = int_stack + 3885;
 Libr12->gvrr_classes[7][5] = int_stack + 5271;
 Libr12->t2vrr_classes[6][5] = int_stack + 6027;
 Libr12->gvrr_classes[7][6] = int_stack + 6615;
 Libr12->t2vrr_classes[6][6] = int_stack + 7623;
 Libr12->gvrr_classes[7][7] = int_stack + 8407;
 Libr12->t2vrr_classes[6][7] = int_stack + 9703;
 Libr12->gvrr_classes[7][8] = int_stack + 10711;
 Libr12->t2vrr_classes[6][8] = int_stack + 12331;
 Libr12->gvrr_classes[7][9] = int_stack + 13591;
 Libr12->t2vrr_classes[6][9] = int_stack + 15571;
 Libr12->t2vrr_classes[6][10] = int_stack + 17111;
 Libr12->gvrr_classes[5][11] = int_stack + 18959;
 Libr12->t1vrr_classes[5][5] = int_stack + 20597;
 Libr12->t1vrr_classes[5][6] = int_stack + 21038;
 Libr12->t1vrr_classes[5][7] = int_stack + 21626;
 Libr12->t1vrr_classes[5][8] = int_stack + 22382;
 Libr12->t1vrr_classes[5][9] = int_stack + 23327;
 Libr12->t1vrr_classes[5][10] = int_stack + 24482;
 Libr12->t1vrr_classes[6][5] = int_stack + 25868;
 Libr12->t1vrr_classes[6][6] = int_stack + 26456;
 Libr12->t1vrr_classes[6][7] = int_stack + 27240;
 Libr12->t1vrr_classes[6][8] = int_stack + 28248;
 Libr12->t1vrr_classes[6][9] = int_stack + 29508;
 Libr12->t1vrr_classes[6][10] = int_stack + 31048;
 Libr12->rvrr_classes[5][5] = int_stack + 32896;
 Libr12->rvrr_classes[5][6] = int_stack + 33337;
 Libr12->rvrr_classes[5][7] = int_stack + 33925;
 Libr12->rvrr_classes[5][8] = int_stack + 34681;
 Libr12->rvrr_classes[5][9] = int_stack + 35626;
 Libr12->rvrr_classes[5][10] = int_stack + 36781;
 Libr12->rvrr_classes[6][5] = int_stack + 38167;
 Libr12->rvrr_classes[6][6] = int_stack + 38755;
 Libr12->rvrr_classes[6][7] = int_stack + 39539;
 Libr12->rvrr_classes[6][8] = int_stack + 40547;
 Libr12->rvrr_classes[6][9] = int_stack + 41807;
 Libr12->rvrr_classes[6][10] = int_stack + 43347;
 Libr12->gvrr_classes[5][5] = int_stack + 45195;
 Libr12->gvrr_classes[5][6] = int_stack + 45636;
 Libr12->gvrr_classes[5][7] = int_stack + 46224;
 Libr12->gvrr_classes[5][8] = int_stack + 46980;
 Libr12->gvrr_classes[5][9] = int_stack + 47925;
 Libr12->gvrr_classes[5][10] = int_stack + 49080;
 Libr12->gvrr_classes[6][5] = int_stack + 50466;
 Libr12->gvrr_classes[6][6] = int_stack + 51054;
 Libr12->gvrr_classes[6][7] = int_stack + 51838;
 Libr12->gvrr_classes[6][8] = int_stack + 52846;
 Libr12->gvrr_classes[6][9] = int_stack + 54106;
 Libr12->gvrr_classes[6][10] = int_stack + 55646;
 memset(int_stack,0,57494*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 57494;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_hphh(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+57494, int_stack+45636, int_stack+45195, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+58817, int_stack+46224, int_stack+45636, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+60581, int_stack+58817, int_stack+57494, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+63227, int_stack+46980, int_stack+46224, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+65495, int_stack+63227, int_stack+58817, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+69023, int_stack+65495, int_stack+60581, 21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+73433, int_stack+47925, int_stack+46980, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+76268, int_stack+73433, int_stack+63227, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+80804, int_stack+76268, int_stack+65495, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+86684, int_stack+80804, int_stack+69023, 21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+93299, int_stack+51054, int_stack+50466, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+95063, int_stack+51838, int_stack+51054, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+97415, int_stack+95063, int_stack+93299, 28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+100943, int_stack+52846, int_stack+51838, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+103967, int_stack+100943, int_stack+95063, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+108671, int_stack+103967, int_stack+97415, 28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+114551, int_stack+54106, int_stack+52846, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+118331, int_stack+114551, int_stack+100943, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+124379, int_stack+118331, int_stack+103967, 28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+132219, int_stack+124379, int_stack+108671, 28);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+141039, int_stack+49080, int_stack+47925, 21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+144504, int_stack+141039, int_stack+73433, 21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+150174, int_stack+144504, int_stack+76268, 21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+157734, int_stack+150174, int_stack+80804, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+166554, int_stack+441, int_stack+0, int_stack+45636, int_stack+50466, int_stack+45195, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+167877, int_stack+1029, int_stack+441, int_stack+46224, int_stack+51054, int_stack+45636, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+169641, int_stack+167877, int_stack+166554, int_stack+58817, int_stack+93299, int_stack+57494, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+172287, int_stack+1785, int_stack+1029, int_stack+46980, int_stack+51838, int_stack+46224, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+174555, int_stack+172287, int_stack+167877, int_stack+63227, int_stack+95063, int_stack+58817, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+178083, int_stack+174555, int_stack+169641, int_stack+65495, int_stack+97415, int_stack+60581, 5, 0);
 /*--- compute (h0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57494, int_stack+2730, int_stack+1785, int_stack+47925, int_stack+52846, int_stack+46980, 5, 0);
 /*--- compute (h0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+166554, int_stack+57494, int_stack+172287, int_stack+73433, int_stack+100943, int_stack+63227, 5, 0);
 /*--- compute (h0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+182493, int_stack+166554, int_stack+174555, int_stack+76268, int_stack+103967, int_stack+65495, 5, 0);
 /*--- compute (h0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+60329, int_stack+182493, int_stack+178083, int_stack+80804, int_stack+108671, int_stack+69023, 5, 0);
 /*--- compute (h0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66944, int_stack+3885, int_stack+2730, int_stack+49080, int_stack+54106, int_stack+47925, 5, 0);
 /*--- compute (h0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+171090, int_stack+66944, int_stack+57494, int_stack+141039, int_stack+114551, int_stack+73433, 5, 0);
 /*--- compute (h0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66944, int_stack+171090, int_stack+166554, int_stack+144504, int_stack+118331, int_stack+76268, 5, 0);
 /*--- compute (h0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+166554, int_stack+66944, int_stack+182493, int_stack+150174, int_stack+124379, int_stack+80804, 5, 0);
 /*--- compute (h0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66944, int_stack+166554, int_stack+60329, int_stack+157734, int_stack+132219, int_stack+86684, 5, 0);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+166554, int_stack+6615, int_stack+5271, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+168822, int_stack+8407, int_stack+6615, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+171846, int_stack+168822, int_stack+166554, 36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+176382, int_stack+10711, int_stack+8407, 36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+180270, int_stack+176382, int_stack+168822, 36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+76205, int_stack+180270, int_stack+171846, 36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+57494, int_stack+13591, int_stack+10711, 36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+186318, int_stack+57494, int_stack+176382, 36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+194094, int_stack+186318, int_stack+180270, 36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+204174, int_stack+194094, int_stack+76205, 36);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+55646, int_stack+54106, 28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+215514, int_stack+0, int_stack+114551, 28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+223074, int_stack+215514, int_stack+118331, 28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+233154, int_stack+223074, int_stack+124379, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+83765, int_stack+7623, int_stack+6027, int_stack+51054, int_stack+5271, int_stack+50466, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+62354, int_stack+9703, int_stack+7623, int_stack+51838, int_stack+6615, int_stack+51054, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+45195, int_stack+62354, int_stack+83765, int_stack+95063, int_stack+166554, int_stack+93299, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4620, int_stack+12331, int_stack+9703, int_stack+52846, int_stack+8407, int_stack+51838, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+244914, int_stack+4620, int_stack+62354, int_stack+100943, int_stack+168822, int_stack+95063, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+249618, int_stack+244914, int_stack+45195, int_stack+103967, int_stack+171846, int_stack+97415, 6, 0);
 /*--- compute (i0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+45195, int_stack+15571, int_stack+12331, int_stack+54106, int_stack+10711, int_stack+52846, 6, 0);
 /*--- compute (i0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+93299, int_stack+45195, int_stack+4620, int_stack+114551, int_stack+176382, int_stack+100943, 6, 0);
 /*--- compute (i0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4620, int_stack+93299, int_stack+244914, int_stack+118331, int_stack+180270, int_stack+103967, 6, 0);
 /*--- compute (i0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+99347, int_stack+4620, int_stack+249618, int_stack+124379, int_stack+76205, int_stack+108671, 6, 0);
 /*--- compute (i0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+76205, int_stack+17111, int_stack+15571, int_stack+55646, int_stack+13591, int_stack+54106, 6, 0);
 /*--- compute (i0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+244914, int_stack+76205, int_stack+45195, int_stack+0, int_stack+57494, int_stack+114551, 6, 0);
 /*--- compute (i0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+76205, int_stack+244914, int_stack+93299, int_stack+215514, int_stack+186318, int_stack+118331, 6, 0);
 /*--- compute (i0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+108167, int_stack+76205, int_stack+4620, int_stack+223074, int_stack+194094, int_stack+124379, 6, 0);
 /*--- compute (i0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+215514, int_stack+108167, int_stack+99347, int_stack+233154, int_stack+204174, int_stack+132219, 6, 0);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+76205, int_stack+157734, int_stack+86684, 21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+85466, int_stack+18959, int_stack+49080, 21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+89624, int_stack+85466, int_stack+141039, 21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+96554, int_stack+89624, int_stack+144504, 21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+106004, int_stack+96554, int_stack+150174, 21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+141039, int_stack+106004, int_stack+157734, 21);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+153387, int_stack+233154, int_stack+132219, 28);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+165735, int_stack+21038, int_stack+20597, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+167058, int_stack+21626, int_stack+21038, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+168822, int_stack+167058, int_stack+165735, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+171468, int_stack+22382, int_stack+21626, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+173736, int_stack+171468, int_stack+167058, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+177264, int_stack+173736, int_stack+168822, 21);
 /*--- compute (h0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+165735, int_stack+23327, int_stack+22382, 21);
 /*--- compute (h0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+181674, int_stack+165735, int_stack+171468, 21);
 /*--- compute (h0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+186210, int_stack+181674, int_stack+173736, 21);
 /*--- compute (h0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+168570, int_stack+186210, int_stack+177264, 21);
 /*--- compute (h0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+175185, int_stack+24482, int_stack+23327, 21);
 /*--- compute (h0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+192090, int_stack+175185, int_stack+165735, 21);
 /*--- compute (h0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+197760, int_stack+192090, int_stack+181674, 21);
 /*--- compute (h0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+175185, int_stack+197760, int_stack+186210, 21);
 /*--- compute (h0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+184005, int_stack+175185, int_stack+168570, 21);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+165735, int_stack+26456, int_stack+25868, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+167499, int_stack+27240, int_stack+26456, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+169851, int_stack+167499, int_stack+165735, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+173379, int_stack+28248, int_stack+27240, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+176403, int_stack+173379, int_stack+167499, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+193266, int_stack+176403, int_stack+169851, 28);
 /*--- compute (i0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+165735, int_stack+29508, int_stack+28248, 28);
 /*--- compute (i0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+199146, int_stack+165735, int_stack+173379, 28);
 /*--- compute (i0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+205194, int_stack+199146, int_stack+176403, 28);
 /*--- compute (i0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+169515, int_stack+205194, int_stack+193266, 28);
 /*--- compute (i0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+193266, int_stack+31048, int_stack+29508, 28);
 /*--- compute (i0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+85466, int_stack+193266, int_stack+165735, 28);
 /*--- compute (i0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+93026, int_stack+85466, int_stack+199146, 28);
 /*--- compute (i0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+193266, int_stack+93026, int_stack+205194, 28);
 /*--- compute (i0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+85466, int_stack+193266, int_stack+169515, 28);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+193266, int_stack+33337, int_stack+32896, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+194589, int_stack+33925, int_stack+33337, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+196353, int_stack+194589, int_stack+193266, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+198999, int_stack+34681, int_stack+33925, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+201267, int_stack+198999, int_stack+194589, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+204795, int_stack+201267, int_stack+196353, 21);
 /*--- compute (h0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+193266, int_stack+35626, int_stack+34681, 21);
 /*--- compute (h0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+209205, int_stack+193266, int_stack+198999, 21);
 /*--- compute (h0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+97814, int_stack+209205, int_stack+201267, 21);
 /*--- compute (h0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+196101, int_stack+97814, int_stack+204795, 21);
 /*--- compute (h0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+202716, int_stack+36781, int_stack+35626, 21);
 /*--- compute (h0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+103694, int_stack+202716, int_stack+193266, 21);
 /*--- compute (h0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+109364, int_stack+103694, int_stack+209205, 21);
 /*--- compute (h0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+202716, int_stack+109364, int_stack+97814, 21);
 /*--- compute (h0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+97814, int_stack+202716, int_stack+196101, 21);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+107075, int_stack+38755, int_stack+38167, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+108839, int_stack+39539, int_stack+38755, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+111191, int_stack+108839, int_stack+107075, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+114719, int_stack+40547, int_stack+39539, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+117743, int_stack+114719, int_stack+108839, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+122447, int_stack+117743, int_stack+111191, 28);
 /*--- compute (i0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+107075, int_stack+41807, int_stack+40547, 28);
 /*--- compute (i0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+128327, int_stack+107075, int_stack+114719, 28);
 /*--- compute (i0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+193266, int_stack+128327, int_stack+117743, 28);
 /*--- compute (i0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+110855, int_stack+193266, int_stack+122447, 28);
 /*--- compute (i0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+119675, int_stack+43347, int_stack+41807, 28);
 /*--- compute (i0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+201106, int_stack+119675, int_stack+107075, 28);
 /*--- compute (i0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+165735, int_stack+201106, int_stack+128327, 28);
 /*--- compute (i0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+201106, int_stack+165735, int_stack+193266, 28);
 /*--- compute (i0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+165735, int_stack+201106, int_stack+110855, 28);
 /*--- compute (hp|[r12,T2]|hh) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+107075, int_stack+215514, int_stack+66944, 441);
     Libr12->te_ptr[3] = int_stack + 107075;
 /*--- compute (hp|[r12,T1]|hh) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+193266, int_stack+85466, int_stack+184005, int_stack+153387, int_stack+141039, int_stack+76205, 5, 5);
     Libr12->te_ptr[2] = int_stack + 193266;
 /*--- compute (hp||hh) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+221049, int_stack+165735, int_stack+97814, 441);
     Libr12->te_ptr[1] = int_stack + 221049;
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+153387, int_stack+76205, 441);
     Libr12->te_ptr[0] = int_stack + 0;

}
