/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_fdhp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+6, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+49, r12vrr_stack+12, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+12, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+68, r12vrr_stack+3, r12vrr_stack+12, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+74, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+84, r12vrr_stack+39, r12vrr_stack+74, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+114, r12vrr_stack+58, r12vrr_stack+39, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+144, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+21);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+204, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+219, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+234, r12vrr_stack+219, r12vrr_stack+204, NULL, NULL, r12vrr_stack+39);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+279, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+282, r12vrr_stack+279, r12vrr_stack+49, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+52, r12vrr_stack+279, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+58, r12vrr_stack+282, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+313, r12vrr_stack+298, r12vrr_stack+219, NULL, NULL, r12vrr_stack+58);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+12, r12vrr_stack+49, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+358, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+3, r12vrr_stack+12, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+368, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+6, r12vrr_stack+68, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+383, r12vrr_stack+204, r12vrr_stack+368, NULL, NULL, r12vrr_stack+74);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+428, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+84);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+518, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+114);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+608, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+144);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+758, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+767, r12vrr_stack+6, r12vrr_stack+68, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+785, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+758);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+821, r12vrr_stack+74, r12vrr_stack+358, NULL, NULL, r12vrr_stack+68);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+851, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+767);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+911, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+785);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+114, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+117, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+127, r12vrr_stack+358, r12vrr_stack+117, r12vrr_stack+68, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1011, r12vrr_stack+368, r12vrr_stack+127, NULL, NULL, r12vrr_stack+358);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1056, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+821);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1146, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+851);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1296, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+911);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1521, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+39, r12vrr_stack+74, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1542, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1563, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+74, r12vrr_stack+358, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1584, r12vrr_stack+1521, r12vrr_stack+1563, NULL, NULL, r12vrr_stack+368);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1647, r12vrr_stack+1542, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1710, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+383);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+288, r12vrr_stack+58, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+1542, NULL, NULL, r12vrr_stack+219);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+234);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+234, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+237, r12vrr_stack+114, r12vrr_stack+234, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+15, r12vrr_stack+237, r12vrr_stack+49, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+243, r12vrr_stack+117, r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+258, r12vrr_stack+127, r12vrr_stack+243, r12vrr_stack+358, r12vrr_stack+117, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2046, r12vrr_stack+1563, r12vrr_stack+258, NULL, NULL, r12vrr_stack+127);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2109, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+1011);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2235, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1056);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+428);
 tmp = r12vrr_stack + 2445;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1146);
 tmp = r12vrr_stack + 2655;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2970, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+204, r12vrr_stack+368, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2998, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+219, r12vrr_stack+204, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3026, r12vrr_stack+2998, r12vrr_stack+2970, NULL, NULL, r12vrr_stack+1521);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3110, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+298, r12vrr_stack+219, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3138, r12vrr_stack+3110, r12vrr_stack+2998, NULL, NULL, r12vrr_stack+1542);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+204, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+368, r12vrr_stack+127, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3222, r12vrr_stack+2970, r12vrr_stack+204, NULL, NULL, r12vrr_stack+1563);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3306, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2998, r12vrr_stack+2970, r12vrr_stack+1584);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+3110, r12vrr_stack+2998, r12vrr_stack+1647);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+1710);
 tmp = r12vrr_stack + 3642;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1647, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1650, r12vrr_stack+234, r12vrr_stack+1647, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+237, r12vrr_stack+1650, r12vrr_stack+114, r12vrr_stack+234, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1656, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+237, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1671, r12vrr_stack+243, r12vrr_stack+1656, r12vrr_stack+117, r12vrr_stack+58, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3922, r12vrr_stack+258, r12vrr_stack+1671, r12vrr_stack+127, r12vrr_stack+243, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3950, r12vrr_stack+204, r12vrr_stack+3922, NULL, NULL, r12vrr_stack+258);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4034, r12vrr_stack+3222, r12vrr_stack+3950, r12vrr_stack+2970, r12vrr_stack+204, r12vrr_stack+2046);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4202, r12vrr_stack+3306, r12vrr_stack+4034, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2109);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+4202, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+2235);
 tmp = r12vrr_stack + 4482;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4902, r12vrr_stack+2970, r12vrr_stack+204, r12vrr_stack+1521, r12vrr_stack+1563, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4938, r12vrr_stack+2998, r12vrr_stack+2970, r12vrr_stack+1542, r12vrr_stack+1521, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4974, r12vrr_stack+4938, r12vrr_stack+4902, NULL, NULL, r12vrr_stack+2970);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5082, r12vrr_stack+3110, r12vrr_stack+2998, r12vrr_stack+1836, r12vrr_stack+1542, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5118, r12vrr_stack+5082, r12vrr_stack+4938, NULL, NULL, r12vrr_stack+2998);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2970, r12vrr_stack+204, r12vrr_stack+3922, r12vrr_stack+1563, r12vrr_stack+258, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5226, r12vrr_stack+4902, r12vrr_stack+2970, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5334, r12vrr_stack+4974, r12vrr_stack+5226, r12vrr_stack+4938, r12vrr_stack+4902, r12vrr_stack+3222);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5550, r12vrr_stack+5118, r12vrr_stack+4974, r12vrr_stack+5082, r12vrr_stack+4938, r12vrr_stack+3026);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+5334, r12vrr_stack+5118, r12vrr_stack+4974, r12vrr_stack+3306);
 tmp = r12vrr_stack + 5766;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+114, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+4938, r12vrr_stack+3, r12vrr_stack+12, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1692, r12vrr_stack+758, r12vrr_stack+4938, r12vrr_stack+0, r12vrr_stack+3, r12vrr_stack+114);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+4947, r12vrr_stack+68, r12vrr_stack+52, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+5082, r12vrr_stack+767, r12vrr_stack+4947, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+4938);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+5118, r12vrr_stack+785, r12vrr_stack+5082, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+1692);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+5178, r12vrr_stack+358, r12vrr_stack+117, NULL, NULL, r12vrr_stack+52);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3006, r12vrr_stack+821, r12vrr_stack+5178, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+4947);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+6126, r12vrr_stack+851, r12vrr_stack+3006, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+5082);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+6226, r12vrr_stack+911, r12vrr_stack+6126, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+5118);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+142, r12vrr_stack+127, r12vrr_stack+243, NULL, NULL, r12vrr_stack+117);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+6376, r12vrr_stack+1011, r12vrr_stack+142, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+5178);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+6466, r12vrr_stack+1056, r12vrr_stack+6376, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+3006);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+6616, r12vrr_stack+1146, r12vrr_stack+6466, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+6126);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+6841, r12vrr_stack+1296, r12vrr_stack+6616, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+6226);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+368, r12vrr_stack+258, r12vrr_stack+1671, NULL, NULL, r12vrr_stack+243);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+7156, r12vrr_stack+2046, r12vrr_stack+368, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+142);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+7282, r12vrr_stack+2109, r12vrr_stack+7156, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+6376);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+7492, r12vrr_stack+2235, r12vrr_stack+7282, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+6466);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7807, r12vrr_stack+2655, r12vrr_stack+7492, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+6616);
 tmp = r12vrr_stack + 7807;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+1647, r12vrr_stack+0, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1710, r12vrr_stack+1650, r12vrr_stack+6, r12vrr_stack+234, r12vrr_stack+1647, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1720, r12vrr_stack+39, r12vrr_stack+1710, r12vrr_stack+237, r12vrr_stack+1650, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1735, r12vrr_stack+1656, r12vrr_stack+1720, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1756, r12vrr_stack+1671, r12vrr_stack+1735, r12vrr_stack+243, r12vrr_stack+1656, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+431, r12vrr_stack+3922, r12vrr_stack+1756, NULL, NULL, r12vrr_stack+1671);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+8248, r12vrr_stack+3950, r12vrr_stack+431, r12vrr_stack+204, r12vrr_stack+3922, r12vrr_stack+368);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+8416, r12vrr_stack+4034, r12vrr_stack+8248, r12vrr_stack+3222, r12vrr_stack+3950, r12vrr_stack+7156);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+8696, r12vrr_stack+4202, r12vrr_stack+8416, r12vrr_stack+3306, r12vrr_stack+4034, r12vrr_stack+7282);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+9116, r12vrr_stack+4482, r12vrr_stack+8696, r12vrr_stack+3642, r12vrr_stack+4202, r12vrr_stack+7492);
 tmp = r12vrr_stack + 9116;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3222, r12vrr_stack+3922, r12vrr_stack+1756, r12vrr_stack+258, r12vrr_stack+1671, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3258, r12vrr_stack+2970, r12vrr_stack+3222, NULL, NULL, r12vrr_stack+3922);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9704, r12vrr_stack+5226, r12vrr_stack+3258, r12vrr_stack+4902, r12vrr_stack+2970, r12vrr_stack+3950);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9920, r12vrr_stack+5334, r12vrr_stack+9704, r12vrr_stack+4974, r12vrr_stack+5226, r12vrr_stack+4034);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10280, r12vrr_stack+5766, r12vrr_stack+9920, r12vrr_stack+5550, r12vrr_stack+5334, r12vrr_stack+4202);
 tmp = r12vrr_stack + 10280;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+515, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+4902, r12vrr_stack+114, r12vrr_stack+515, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+4908, r12vrr_stack+12, r12vrr_stack+49, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+21, r12vrr_stack+4938, r12vrr_stack+4908, r12vrr_stack+3, r12vrr_stack+12, r12vrr_stack+515);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+3366, r12vrr_stack+1692, r12vrr_stack+21, r12vrr_stack+758, r12vrr_stack+4938, r12vrr_stack+4902);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1692, r12vrr_stack+52, r12vrr_stack+15, NULL, NULL, r12vrr_stack+49);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+3396, r12vrr_stack+4947, r12vrr_stack+1692, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+4908);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+4965, r12vrr_stack+5082, r12vrr_stack+3396, r12vrr_stack+767, r12vrr_stack+4947, r12vrr_stack+21);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+1521, r12vrr_stack+5118, r12vrr_stack+4965, r12vrr_stack+785, r12vrr_stack+5082, r12vrr_stack+3366);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+3366, r12vrr_stack+117, r12vrr_stack+58, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+4902, r12vrr_stack+5178, r12vrr_stack+3366, r12vrr_stack+358, r12vrr_stack+117, r12vrr_stack+1692);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+5025, r12vrr_stack+3006, r12vrr_stack+4902, r12vrr_stack+821, r12vrr_stack+5178, r12vrr_stack+3396);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+10820, r12vrr_stack+6126, r12vrr_stack+5025, r12vrr_stack+851, r12vrr_stack+3006, r12vrr_stack+4965);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+10970, r12vrr_stack+6226, r12vrr_stack+10820, r12vrr_stack+911, r12vrr_stack+6126, r12vrr_stack+1521);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1521, r12vrr_stack+243, r12vrr_stack+1656, NULL, NULL, r12vrr_stack+58);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+6126, r12vrr_stack+142, r12vrr_stack+1521, r12vrr_stack+127, r12vrr_stack+243, r12vrr_stack+3366);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+6216, r12vrr_stack+6376, r12vrr_stack+6126, r12vrr_stack+1011, r12vrr_stack+142, r12vrr_stack+4902);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+758, r12vrr_stack+6466, r12vrr_stack+6216, r12vrr_stack+1056, r12vrr_stack+6376, r12vrr_stack+5025);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+4902, r12vrr_stack+6616, r12vrr_stack+758, r12vrr_stack+1146, r12vrr_stack+6466, r12vrr_stack+10820);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+11180, r12vrr_stack+6841, r12vrr_stack+4902, r12vrr_stack+1296, r12vrr_stack+6616, r12vrr_stack+10970);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+10820, r12vrr_stack+1671, r12vrr_stack+1735, NULL, NULL, r12vrr_stack+1656);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+10883, r12vrr_stack+368, r12vrr_stack+10820, r12vrr_stack+258, r12vrr_stack+1671, r12vrr_stack+1521);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6366, r12vrr_stack+7156, r12vrr_stack+10883, r12vrr_stack+2046, r12vrr_stack+368, r12vrr_stack+6126);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+11600, r12vrr_stack+7282, r12vrr_stack+6366, r12vrr_stack+2109, r12vrr_stack+7156, r12vrr_stack+6216);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+11915, r12vrr_stack+7492, r12vrr_stack+11600, r12vrr_stack+2235, r12vrr_stack+7282, r12vrr_stack+758);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+12356, r12vrr_stack+7807, r12vrr_stack+11915, r12vrr_stack+2655, r12vrr_stack+7492, r12vrr_stack+4902);
 tmp = r12vrr_stack + 12356;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+515, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+4902, r12vrr_stack+0, r12vrr_stack+515, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+4908, r12vrr_stack+6, r12vrr_stack+4902, r12vrr_stack+1647, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+4918, r12vrr_stack+1710, r12vrr_stack+4908, r12vrr_stack+1650, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+0, r12vrr_stack+1720, r12vrr_stack+4918, r12vrr_stack+39, r12vrr_stack+1710, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1692, r12vrr_stack+1735, r12vrr_stack+0, r12vrr_stack+1656, r12vrr_stack+1720, NULL);

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+0, r12vrr_stack+1756, r12vrr_stack+1692, NULL, NULL, r12vrr_stack+1735);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+84, r12vrr_stack+431, r12vrr_stack+0, r12vrr_stack+3922, r12vrr_stack+1756, r12vrr_stack+10820);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4902, r12vrr_stack+8248, r12vrr_stack+84, r12vrr_stack+3950, r12vrr_stack+431, r12vrr_stack+10883);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+758, r12vrr_stack+8416, r12vrr_stack+4902, r12vrr_stack+4034, r12vrr_stack+8248, r12vrr_stack+6366);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+7156, r12vrr_stack+8696, r12vrr_stack+758, r12vrr_stack+4202, r12vrr_stack+8416, r12vrr_stack+11600);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+12944, r12vrr_stack+9116, r12vrr_stack+7156, r12vrr_stack+4482, r12vrr_stack+8696, r12vrr_stack+11915);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7156, r12vrr_stack+1756, r12vrr_stack+1692, r12vrr_stack+1671, r12vrr_stack+1735, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3366, r12vrr_stack+3222, r12vrr_stack+7156, NULL, NULL, r12vrr_stack+1756);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7156, r12vrr_stack+3258, r12vrr_stack+3366, r12vrr_stack+2970, r12vrr_stack+3222, r12vrr_stack+431);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10820, r12vrr_stack+9704, r12vrr_stack+7156, r12vrr_stack+5226, r12vrr_stack+3258, r12vrr_stack+8248);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7156, r12vrr_stack+9920, r12vrr_stack+10820, r12vrr_stack+5334, r12vrr_stack+9704, r12vrr_stack+8416);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11600, r12vrr_stack+10280, r12vrr_stack+7156, r12vrr_stack+5766, r12vrr_stack+9920, r12vrr_stack+8696);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+7156, &(Data->ss_r12_ss), NULL, r12vrr_stack+279, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+7159, r12vrr_stack+7156, &(Data->ss_r12_ss), r12vrr_stack+282, r12vrr_stack+279, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+7165, r12vrr_stack+7159, r12vrr_stack+7156, r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+279, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+7175, r12vrr_stack+7165, r12vrr_stack+7159, r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+282, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+7190, r12vrr_stack+7175, r12vrr_stack+7165, r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+288, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+7211, r12vrr_stack+7190, NULL, r12vrr_stack+1857, r12vrr_stack+1836, NULL, r12vrr_stack+298);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+7274, r12vrr_stack+7211, r12vrr_stack+7190, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+313);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+7400, r12vrr_stack+7274, r12vrr_stack+7211, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+518);
 tmp = r12vrr_stack + 7400;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+1521, r12vrr_stack+7400, r12vrr_stack+7274, r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+608);
 tmp = r12vrr_stack + 1521;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+7211, r12vrr_stack+7190, r12vrr_stack+7175, r12vrr_stack+3110, r12vrr_stack+1836, r12vrr_stack+298, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+7239, r12vrr_stack+7211, NULL, r12vrr_stack+3138, r12vrr_stack+3110, NULL, r12vrr_stack+1836);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+7610, r12vrr_stack+7239, r12vrr_stack+7211, r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+3110, r12vrr_stack+1857);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+9704, r12vrr_stack+7610, r12vrr_stack+7239, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+1920);
 tmp = r12vrr_stack + 9704;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+8248, r12vrr_stack+9704, r12vrr_stack+7610, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+2445);
 tmp = r12vrr_stack + 8248;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7156, r12vrr_stack+2445, r12vrr_stack+3642, r12vrr_stack+2655, r12vrr_stack+1296, r12vrr_stack+608);
 tmp = r12vrr_stack + 7156;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9984, r12vrr_stack+3642, r12vrr_stack+5766, r12vrr_stack+4482, r12vrr_stack+2655, r12vrr_stack+2445);
 tmp = r12vrr_stack + 9984;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+10820, r12vrr_stack+2655, r12vrr_stack+4482, r12vrr_stack+7807, r12vrr_stack+6841, r12vrr_stack+1296);
 tmp = r12vrr_stack + 10820;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8668, r12vrr_stack+4482, r12vrr_stack+10280, r12vrr_stack+9116, r12vrr_stack+7807, r12vrr_stack+2655);
 tmp = r12vrr_stack + 8668;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2970, r12vrr_stack+7807, r12vrr_stack+9116, r12vrr_stack+12356, r12vrr_stack+11180, r12vrr_stack+6841);
 tmp = r12vrr_stack + 2970;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4902, r12vrr_stack+9116, r12vrr_stack+11600, r12vrr_stack+12944, r12vrr_stack+12356, r12vrr_stack+7807);
 tmp = r12vrr_stack + 4902;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11135, r12vrr_stack+2445, r12vrr_stack+2655, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+1920);
 tmp = r12vrr_stack + 11135;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1836, r12vrr_stack+3642, r12vrr_stack+4482, r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+3474);
 tmp = r12vrr_stack + 1836;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2116, r12vrr_stack+2655, r12vrr_stack+7807, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+2445);
 tmp = r12vrr_stack + 2116;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3922, r12vrr_stack+4482, r12vrr_stack+9116, r12vrr_stack+10280, r12vrr_stack+5766, r12vrr_stack+3642);
 tmp = r12vrr_stack + 3922;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5490, r12vrr_stack+7807, r12vrr_stack+12356, r12vrr_stack+9116, r12vrr_stack+4482, r12vrr_stack+2655);
 tmp = r12vrr_stack + 5490;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+12356, r12vrr_stack+9116, r12vrr_stack+12944, r12vrr_stack+11600, r12vrr_stack+10280, r12vrr_stack+4482);
 tmp = r12vrr_stack + 12356;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+12944, r12vrr_stack+1521, r12vrr_stack+7400, r12vrr_stack+7807, r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+1296);
 tmp = r12vrr_stack + 12944;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+13385, r12vrr_stack+8248, r12vrr_stack+9704, r12vrr_stack+9116, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+2655);
 tmp = r12vrr_stack + 13385;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];


}

