/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_gphg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gp|hg) integrals */

void d12hrr_order_gphg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][9][11] = int_stack + 0;
 Libderiv->deriv_classes[5][9][10] = int_stack + 1155;
 Libderiv->deriv_classes[5][9][9] = int_stack + 2310;
 Libderiv->deriv_classes[5][9][8] = int_stack + 3465;
 Libderiv->deriv_classes[5][9][7] = int_stack + 4620;
 Libderiv->dvrr_classes[5][8] = int_stack + 5775;
 Libderiv->deriv_classes[5][9][6] = int_stack + 6720;
 Libderiv->deriv_classes[5][9][2] = int_stack + 7875;
 Libderiv->deriv_classes[5][9][1] = int_stack + 9030;
 Libderiv->dvrr_classes[4][9] = int_stack + 10185;
 Libderiv->deriv_classes[5][9][0] = int_stack + 11010;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 12165;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 12480;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 12900;
 Libderiv->deriv2_classes[4][8][143] = int_stack + 13440;
 Libderiv->deriv2_classes[4][9][143] = int_stack + 14115;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 14940;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 15381;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 15969;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 16725;
 Libderiv->deriv2_classes[5][9][143] = int_stack + 17670;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 18825;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 19140;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 19560;
 Libderiv->deriv2_classes[4][8][131] = int_stack + 20100;
 Libderiv->deriv2_classes[4][9][131] = int_stack + 20775;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 21600;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 22041;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 22629;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 23385;
 Libderiv->deriv2_classes[5][9][131] = int_stack + 24330;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 25485;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 25800;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 26220;
 Libderiv->deriv2_classes[4][8][130] = int_stack + 26760;
 Libderiv->deriv2_classes[4][9][130] = int_stack + 27435;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 28260;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 28701;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 29289;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 30045;
 Libderiv->deriv2_classes[5][9][130] = int_stack + 30990;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 32145;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 32460;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 32880;
 Libderiv->deriv2_classes[4][8][119] = int_stack + 33420;
 Libderiv->deriv2_classes[4][9][119] = int_stack + 34095;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 34920;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 35361;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 35949;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 36705;
 Libderiv->deriv2_classes[5][9][119] = int_stack + 37650;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 38805;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 39120;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 39540;
 Libderiv->deriv2_classes[4][8][118] = int_stack + 40080;
 Libderiv->deriv2_classes[4][9][118] = int_stack + 40755;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 41580;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 42021;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 42609;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 43365;
 Libderiv->deriv2_classes[5][9][118] = int_stack + 44310;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 45465;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 45780;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 46200;
 Libderiv->deriv2_classes[4][8][117] = int_stack + 46740;
 Libderiv->deriv2_classes[4][9][117] = int_stack + 47415;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 48240;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 48681;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 49269;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 50025;
 Libderiv->deriv2_classes[5][9][117] = int_stack + 50970;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 52125;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 52440;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 52860;
 Libderiv->deriv2_classes[4][8][107] = int_stack + 53400;
 Libderiv->deriv2_classes[4][9][107] = int_stack + 54075;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 54900;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 55341;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 55929;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 56685;
 Libderiv->deriv2_classes[5][9][107] = int_stack + 57630;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 58785;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 59100;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 59520;
 Libderiv->deriv2_classes[4][8][106] = int_stack + 60060;
 Libderiv->deriv2_classes[4][9][106] = int_stack + 60735;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 61560;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 62001;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 62589;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 63345;
 Libderiv->deriv2_classes[5][9][106] = int_stack + 64290;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 65445;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 65760;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 66180;
 Libderiv->deriv2_classes[4][8][105] = int_stack + 66720;
 Libderiv->deriv2_classes[4][9][105] = int_stack + 67395;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 68220;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 68661;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 69249;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 70005;
 Libderiv->deriv2_classes[5][9][105] = int_stack + 70950;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 72105;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 72420;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 72840;
 Libderiv->deriv2_classes[4][8][104] = int_stack + 73380;
 Libderiv->deriv2_classes[4][9][104] = int_stack + 74055;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 74880;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 75321;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 75909;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 76665;
 Libderiv->deriv2_classes[5][9][104] = int_stack + 77610;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 78765;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 79080;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 79500;
 Libderiv->deriv2_classes[4][8][95] = int_stack + 80040;
 Libderiv->deriv2_classes[4][9][95] = int_stack + 80715;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 81540;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 81981;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 82569;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 83325;
 Libderiv->deriv2_classes[5][9][95] = int_stack + 84270;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 85425;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 85740;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 86160;
 Libderiv->deriv2_classes[4][8][94] = int_stack + 86700;
 Libderiv->deriv2_classes[4][9][94] = int_stack + 87375;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 88200;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 88641;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 89229;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 89985;
 Libderiv->deriv2_classes[5][9][94] = int_stack + 90930;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 92085;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 92400;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 92820;
 Libderiv->deriv2_classes[4][8][93] = int_stack + 93360;
 Libderiv->deriv2_classes[4][9][93] = int_stack + 94035;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 94860;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 95301;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 95889;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 96645;
 Libderiv->deriv2_classes[5][9][93] = int_stack + 97590;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 98745;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 99060;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 99480;
 Libderiv->deriv2_classes[4][8][92] = int_stack + 100020;
 Libderiv->deriv2_classes[4][9][92] = int_stack + 100695;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 101520;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 101961;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 102549;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 103305;
 Libderiv->deriv2_classes[5][9][92] = int_stack + 104250;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 105405;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 105720;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 106140;
 Libderiv->deriv2_classes[4][8][91] = int_stack + 106680;
 Libderiv->deriv2_classes[4][9][91] = int_stack + 107355;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 108180;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 108621;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 109209;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 109965;
 Libderiv->deriv2_classes[5][9][91] = int_stack + 110910;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 112065;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 112380;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 112800;
 Libderiv->deriv2_classes[4][8][83] = int_stack + 113340;
 Libderiv->deriv2_classes[4][9][83] = int_stack + 114015;
 Libderiv->deriv_classes[5][5][11] = int_stack + 114840;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 115281;
 Libderiv->deriv_classes[5][6][11] = int_stack + 115722;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 116310;
 Libderiv->deriv_classes[5][7][11] = int_stack + 116898;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 117654;
 Libderiv->deriv_classes[5][8][11] = int_stack + 118410;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 119355;
 Libderiv->deriv2_classes[5][9][83] = int_stack + 120300;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 121455;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 121770;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 122190;
 Libderiv->deriv2_classes[4][8][82] = int_stack + 122730;
 Libderiv->deriv2_classes[4][9][82] = int_stack + 123405;
 Libderiv->deriv_classes[5][5][10] = int_stack + 124230;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 124671;
 Libderiv->deriv_classes[5][6][10] = int_stack + 125112;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 125700;
 Libderiv->deriv_classes[5][7][10] = int_stack + 126288;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 127044;
 Libderiv->deriv_classes[5][8][10] = int_stack + 127800;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 128745;
 Libderiv->deriv2_classes[5][9][82] = int_stack + 129690;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 130845;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 131160;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 131580;
 Libderiv->deriv2_classes[4][8][81] = int_stack + 132120;
 Libderiv->deriv2_classes[4][9][81] = int_stack + 132795;
 Libderiv->deriv_classes[5][5][9] = int_stack + 133620;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 134061;
 Libderiv->deriv_classes[5][6][9] = int_stack + 134502;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 135090;
 Libderiv->deriv_classes[5][7][9] = int_stack + 135678;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 136434;
 Libderiv->deriv_classes[5][8][9] = int_stack + 137190;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 138135;
 Libderiv->deriv2_classes[5][9][81] = int_stack + 139080;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 140235;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 140550;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 140970;
 Libderiv->deriv2_classes[4][8][80] = int_stack + 141510;
 Libderiv->deriv2_classes[4][9][80] = int_stack + 142185;
 Libderiv->deriv_classes[5][5][8] = int_stack + 143010;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 143451;
 Libderiv->deriv_classes[5][6][8] = int_stack + 143892;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 144480;
 Libderiv->deriv_classes[5][7][8] = int_stack + 145068;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 145824;
 Libderiv->deriv_classes[5][8][8] = int_stack + 146580;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 147525;
 Libderiv->deriv2_classes[5][9][80] = int_stack + 148470;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 149625;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 149940;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 150360;
 Libderiv->deriv2_classes[4][8][79] = int_stack + 150900;
 Libderiv->deriv2_classes[4][9][79] = int_stack + 151575;
 Libderiv->deriv_classes[5][5][7] = int_stack + 152400;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 152841;
 Libderiv->deriv_classes[5][6][7] = int_stack + 153282;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 153870;
 Libderiv->deriv_classes[5][7][7] = int_stack + 154458;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 155214;
 Libderiv->deriv_classes[5][8][7] = int_stack + 155970;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 156915;
 Libderiv->deriv2_classes[5][9][79] = int_stack + 157860;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 159015;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 159330;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 159750;
 Libderiv->deriv2_classes[4][8][78] = int_stack + 160290;
 Libderiv->deriv2_classes[4][9][78] = int_stack + 160965;
 Libderiv->dvrr_classes[5][5] = int_stack + 161790;
 Libderiv->deriv_classes[5][5][6] = int_stack + 162231;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 162672;
 Libderiv->dvrr_classes[5][6] = int_stack + 163113;
 Libderiv->deriv_classes[5][6][6] = int_stack + 163701;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 164289;
 Libderiv->dvrr_classes[5][7] = int_stack + 164877;
 Libderiv->deriv_classes[5][7][6] = int_stack + 165633;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 166389;
 Libderiv->deriv_classes[5][8][6] = int_stack + 167145;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 168090;
 Libderiv->deriv2_classes[5][9][78] = int_stack + 169035;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 170190;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 170505;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 170925;
 Libderiv->deriv2_classes[4][8][35] = int_stack + 171465;
 Libderiv->deriv2_classes[4][9][35] = int_stack + 172140;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 172965;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 173406;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 173994;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 174750;
 Libderiv->deriv2_classes[5][9][35] = int_stack + 175695;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 176850;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 177165;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 177585;
 Libderiv->deriv2_classes[4][8][34] = int_stack + 178125;
 Libderiv->deriv2_classes[4][9][34] = int_stack + 178800;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 179625;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 180066;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 180654;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 181410;
 Libderiv->deriv2_classes[5][9][34] = int_stack + 182355;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 183510;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 183825;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 184245;
 Libderiv->deriv2_classes[4][8][33] = int_stack + 184785;
 Libderiv->deriv2_classes[4][9][33] = int_stack + 185460;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 186285;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 186726;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 187314;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 188070;
 Libderiv->deriv2_classes[5][9][33] = int_stack + 189015;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 190170;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 190485;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 190905;
 Libderiv->deriv2_classes[4][8][32] = int_stack + 191445;
 Libderiv->deriv2_classes[4][9][32] = int_stack + 192120;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 192945;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 193386;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 193974;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 194730;
 Libderiv->deriv2_classes[5][9][32] = int_stack + 195675;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 196830;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 197145;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 197565;
 Libderiv->deriv2_classes[4][8][31] = int_stack + 198105;
 Libderiv->deriv2_classes[4][9][31] = int_stack + 198780;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 199605;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 200046;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 200634;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 201390;
 Libderiv->deriv2_classes[5][9][31] = int_stack + 202335;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 203490;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 203805;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 204225;
 Libderiv->deriv2_classes[4][8][30] = int_stack + 204765;
 Libderiv->deriv2_classes[4][9][30] = int_stack + 205440;
 Libderiv->deriv_classes[5][5][2] = int_stack + 206265;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 206706;
 Libderiv->deriv_classes[5][6][2] = int_stack + 207147;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 207735;
 Libderiv->deriv_classes[5][7][2] = int_stack + 208323;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 209079;
 Libderiv->deriv_classes[5][8][2] = int_stack + 209835;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 210780;
 Libderiv->deriv2_classes[5][9][30] = int_stack + 211725;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 212880;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 213195;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 213615;
 Libderiv->deriv2_classes[4][8][26] = int_stack + 214155;
 Libderiv->deriv2_classes[4][9][26] = int_stack + 214830;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 215655;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 216096;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 216684;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 217440;
 Libderiv->deriv2_classes[5][9][26] = int_stack + 218385;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 219540;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 219855;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 220275;
 Libderiv->deriv2_classes[4][8][23] = int_stack + 220815;
 Libderiv->deriv2_classes[4][9][23] = int_stack + 221490;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 222315;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 222756;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 223344;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 224100;
 Libderiv->deriv2_classes[5][9][23] = int_stack + 225045;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 226200;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 226515;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 226935;
 Libderiv->deriv2_classes[4][8][22] = int_stack + 227475;
 Libderiv->deriv2_classes[4][9][22] = int_stack + 228150;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 228975;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 229416;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 230004;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 230760;
 Libderiv->deriv2_classes[5][9][22] = int_stack + 231705;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 232860;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 233175;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 233595;
 Libderiv->deriv2_classes[4][8][21] = int_stack + 234135;
 Libderiv->deriv2_classes[4][9][21] = int_stack + 234810;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 235635;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 236076;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 236664;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 237420;
 Libderiv->deriv2_classes[5][9][21] = int_stack + 238365;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 239520;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 239835;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 240255;
 Libderiv->deriv2_classes[4][8][20] = int_stack + 240795;
 Libderiv->deriv2_classes[4][9][20] = int_stack + 241470;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 242295;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 242736;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 243324;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 244080;
 Libderiv->deriv2_classes[5][9][20] = int_stack + 245025;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 246180;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 246495;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 246915;
 Libderiv->deriv2_classes[4][8][19] = int_stack + 247455;
 Libderiv->deriv2_classes[4][9][19] = int_stack + 248130;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 248955;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 249396;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 249984;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 250740;
 Libderiv->deriv2_classes[5][9][19] = int_stack + 251685;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 252840;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 253155;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 253575;
 Libderiv->deriv2_classes[4][8][18] = int_stack + 254115;
 Libderiv->deriv2_classes[4][9][18] = int_stack + 254790;
 Libderiv->deriv_classes[5][5][1] = int_stack + 255615;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 256056;
 Libderiv->deriv_classes[5][6][1] = int_stack + 256497;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 257085;
 Libderiv->deriv_classes[5][7][1] = int_stack + 257673;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 258429;
 Libderiv->deriv_classes[5][8][1] = int_stack + 259185;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 260130;
 Libderiv->deriv2_classes[5][9][18] = int_stack + 261075;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 262230;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 262545;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 262965;
 Libderiv->deriv2_classes[4][8][14] = int_stack + 263505;
 Libderiv->deriv2_classes[4][9][14] = int_stack + 264180;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 265005;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 265446;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 266034;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 266790;
 Libderiv->deriv2_classes[5][9][14] = int_stack + 267735;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 268890;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 269205;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 269625;
 Libderiv->deriv2_classes[4][8][13] = int_stack + 270165;
 Libderiv->deriv2_classes[4][9][13] = int_stack + 270840;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 271665;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 272106;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 272694;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 273450;
 Libderiv->deriv2_classes[5][9][13] = int_stack + 274395;
 Libderiv->deriv_classes[4][5][11] = int_stack + 275550;
 Libderiv->deriv_classes[4][6][11] = int_stack + 275865;
 Libderiv->deriv_classes[4][7][11] = int_stack + 276285;
 Libderiv->deriv_classes[4][8][11] = int_stack + 276825;
 Libderiv->deriv_classes[4][9][11] = int_stack + 277500;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 278325;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 278640;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 279060;
 Libderiv->deriv2_classes[4][8][11] = int_stack + 279600;
 Libderiv->deriv2_classes[4][9][11] = int_stack + 280275;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 281100;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 281541;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 282129;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 282885;
 Libderiv->deriv2_classes[5][9][11] = int_stack + 283830;
 Libderiv->deriv_classes[4][5][10] = int_stack + 284985;
 Libderiv->deriv_classes[4][6][10] = int_stack + 285300;
 Libderiv->deriv_classes[4][7][10] = int_stack + 285720;
 Libderiv->deriv_classes[4][8][10] = int_stack + 286260;
 Libderiv->deriv_classes[4][9][10] = int_stack + 286935;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 287760;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 288075;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 288495;
 Libderiv->deriv2_classes[4][8][10] = int_stack + 289035;
 Libderiv->deriv2_classes[4][9][10] = int_stack + 289710;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 290535;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 290976;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 291564;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 292320;
 Libderiv->deriv2_classes[5][9][10] = int_stack + 293265;
 Libderiv->deriv_classes[4][5][9] = int_stack + 294420;
 Libderiv->deriv_classes[4][6][9] = int_stack + 294735;
 Libderiv->deriv_classes[4][7][9] = int_stack + 295155;
 Libderiv->deriv_classes[4][8][9] = int_stack + 295695;
 Libderiv->deriv_classes[4][9][9] = int_stack + 296370;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 297195;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 297510;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 297930;
 Libderiv->deriv2_classes[4][8][9] = int_stack + 298470;
 Libderiv->deriv2_classes[4][9][9] = int_stack + 299145;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 299970;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 300411;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 300999;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 301755;
 Libderiv->deriv2_classes[5][9][9] = int_stack + 302700;
 Libderiv->deriv_classes[4][5][8] = int_stack + 303855;
 Libderiv->deriv_classes[4][6][8] = int_stack + 304170;
 Libderiv->deriv_classes[4][7][8] = int_stack + 304590;
 Libderiv->deriv_classes[4][8][8] = int_stack + 305130;
 Libderiv->deriv_classes[4][9][8] = int_stack + 305805;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 306630;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 306945;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 307365;
 Libderiv->deriv2_classes[4][8][8] = int_stack + 307905;
 Libderiv->deriv2_classes[4][9][8] = int_stack + 308580;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 309405;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 309846;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 310434;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 311190;
 Libderiv->deriv2_classes[5][9][8] = int_stack + 312135;
 Libderiv->deriv_classes[4][5][7] = int_stack + 313290;
 Libderiv->deriv_classes[4][6][7] = int_stack + 313605;
 Libderiv->deriv_classes[4][7][7] = int_stack + 314025;
 Libderiv->deriv_classes[4][8][7] = int_stack + 314565;
 Libderiv->deriv_classes[4][9][7] = int_stack + 315240;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 316065;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 316380;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 316800;
 Libderiv->deriv2_classes[4][8][7] = int_stack + 317340;
 Libderiv->deriv2_classes[4][9][7] = int_stack + 318015;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 318840;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 319281;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 319869;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 320625;
 Libderiv->deriv2_classes[5][9][7] = int_stack + 321570;
 Libderiv->dvrr_classes[4][5] = int_stack + 322725;
 Libderiv->deriv_classes[4][5][6] = int_stack + 323040;
 Libderiv->dvrr_classes[4][6] = int_stack + 323355;
 Libderiv->deriv_classes[4][6][6] = int_stack + 323775;
 Libderiv->dvrr_classes[4][7] = int_stack + 324195;
 Libderiv->deriv_classes[4][7][6] = int_stack + 324735;
 Libderiv->dvrr_classes[4][8] = int_stack + 325275;
 Libderiv->deriv_classes[4][8][6] = int_stack + 325950;
 Libderiv->deriv_classes[4][9][6] = int_stack + 326625;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 327450;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 327765;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 328185;
 Libderiv->deriv2_classes[4][8][6] = int_stack + 328725;
 Libderiv->deriv2_classes[4][9][6] = int_stack + 329400;
 Libderiv->deriv_classes[5][5][0] = int_stack + 330225;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 330666;
 Libderiv->deriv_classes[5][6][0] = int_stack + 331107;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 331695;
 Libderiv->deriv_classes[5][7][0] = int_stack + 332283;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 333039;
 Libderiv->deriv_classes[5][8][0] = int_stack + 333795;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 334740;
 Libderiv->deriv2_classes[5][9][6] = int_stack + 335685;
 Libderiv->deriv_classes[4][5][2] = int_stack + 336840;
 Libderiv->deriv_classes[4][6][2] = int_stack + 337155;
 Libderiv->deriv_classes[4][7][2] = int_stack + 337575;
 Libderiv->deriv_classes[4][8][2] = int_stack + 338115;
 Libderiv->deriv_classes[4][9][2] = int_stack + 338790;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 339615;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 339930;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 340350;
 Libderiv->deriv2_classes[4][8][2] = int_stack + 340890;
 Libderiv->deriv2_classes[4][9][2] = int_stack + 341565;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 342390;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 342831;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 343419;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 344175;
 Libderiv->deriv2_classes[5][9][2] = int_stack + 345120;
 Libderiv->deriv_classes[4][5][1] = int_stack + 346275;
 Libderiv->deriv_classes[4][6][1] = int_stack + 346590;
 Libderiv->deriv_classes[4][7][1] = int_stack + 347010;
 Libderiv->deriv_classes[4][8][1] = int_stack + 347550;
 Libderiv->deriv_classes[4][9][1] = int_stack + 348225;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 349050;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 349365;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 349785;
 Libderiv->deriv2_classes[4][8][1] = int_stack + 350325;
 Libderiv->deriv2_classes[4][9][1] = int_stack + 351000;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 351825;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 352266;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 352854;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 353610;
 Libderiv->deriv2_classes[5][9][1] = int_stack + 354555;
 Libderiv->deriv_classes[4][5][0] = int_stack + 355710;
 Libderiv->deriv_classes[4][6][0] = int_stack + 356025;
 Libderiv->deriv_classes[4][7][0] = int_stack + 356445;
 Libderiv->deriv_classes[4][8][0] = int_stack + 356985;
 Libderiv->deriv_classes[4][9][0] = int_stack + 357660;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 358485;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 358800;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 359220;
 Libderiv->deriv2_classes[4][8][0] = int_stack + 359760;
 Libderiv->deriv2_classes[4][9][0] = int_stack + 360435;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 361260;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 361701;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 362289;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 363045;
 Libderiv->deriv2_classes[5][9][0] = int_stack + 363990;
 memset(int_stack,0,2921160);

 Libderiv->dvrr_stack = int_stack + 971004;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_gphg(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+365145,int_stack+323355,int_stack+322725,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+366090,int_stack+324195,int_stack+323355,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+367350,int_stack+366090,int_stack+365145,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+369240,int_stack+325275,int_stack+324195,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+370860,int_stack+369240,int_stack+366090,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+373380,int_stack+370860,int_stack+367350,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+376530,int_stack+275865,int_stack+275550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322725,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377475,int_stack+276285,int_stack+275865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323355,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+378735,int_stack+377475,int_stack+376530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365145,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+380625,int_stack+276825,int_stack+276285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324195,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+382245,int_stack+380625,int_stack+377475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366090,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+384765,int_stack+382245,int_stack+378735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367350,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+387915,int_stack+277500,int_stack+276825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325275,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+389940,int_stack+387915,int_stack+380625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369240,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+393180,int_stack+389940,int_stack+382245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370860,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+387915,int_stack+393180,int_stack+384765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373380,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+392640,int_stack+163113,int_stack+161790,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+393963,int_stack+164877,int_stack+163113,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+395727,int_stack+393963,int_stack+392640,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+398373,int_stack+5775,int_stack+164877,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+400641,int_stack+398373,int_stack+393963,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+404169,int_stack+400641,int_stack+395727,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+408579,int_stack+115722,int_stack+114840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161790,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+409902,int_stack+116898,int_stack+115722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163113,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+411666,int_stack+409902,int_stack+408579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392640,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+414312,int_stack+118410,int_stack+116898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164877,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+416580,int_stack+414312,int_stack+409902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393963,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+420108,int_stack+416580,int_stack+411666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395727,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+424518,int_stack+0,int_stack+118410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5775,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+427353,int_stack+424518,int_stack+414312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398373,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+431889,int_stack+427353,int_stack+416580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400641,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+424518,int_stack+431889,int_stack+420108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404169,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+431133,int_stack+285300,int_stack+284985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322725, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+432078,int_stack+285720,int_stack+285300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323355, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+433338,int_stack+432078,int_stack+431133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365145, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+435228,int_stack+286260,int_stack+285720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324195, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+436848,int_stack+435228,int_stack+432078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366090, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+439368,int_stack+436848,int_stack+433338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367350, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+442518,int_stack+286935,int_stack+286260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325275, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+444543,int_stack+442518,int_stack+435228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369240, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+447783,int_stack+444543,int_stack+436848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370860, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+442518,int_stack+447783,int_stack+439368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373380, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+447243,int_stack+125112,int_stack+124230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161790, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+448566,int_stack+126288,int_stack+125112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163113, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+450330,int_stack+448566,int_stack+447243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392640, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+452976,int_stack+127800,int_stack+126288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164877, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+455244,int_stack+452976,int_stack+448566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393963, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+458772,int_stack+455244,int_stack+450330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395727, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+463182,int_stack+1155,int_stack+127800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5775, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+466017,int_stack+463182,int_stack+452976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398373, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+470553,int_stack+466017,int_stack+455244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400641, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+463182,int_stack+470553,int_stack+458772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404169, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469797,int_stack+294735,int_stack+294420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322725, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+470742,int_stack+295155,int_stack+294735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323355, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472002,int_stack+470742,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473892,int_stack+295695,int_stack+295155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324195, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+475512,int_stack+473892,int_stack+470742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366090, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+478032,int_stack+475512,int_stack+472002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367350, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+296370,int_stack+295695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325275, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+481182,int_stack+0,int_stack+473892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369240, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+484422,int_stack+481182,int_stack+475512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370860, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+488622,int_stack+484422,int_stack+478032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373380, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+481182,int_stack+134502,int_stack+133620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161790, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+482505,int_stack+135678,int_stack+134502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163113, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484269,int_stack+482505,int_stack+481182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392640, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+137190,int_stack+135678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164877, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+493347,int_stack+0,int_stack+482505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393963, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+496875,int_stack+493347,int_stack+484269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395727, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+501285,int_stack+2310,int_stack+137190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5775, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+504120,int_stack+501285,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398373, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+508656,int_stack+504120,int_stack+493347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400641, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+501285,int_stack+508656,int_stack+496875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404169, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+507900,int_stack+304170,int_stack+303855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+508845,int_stack+304590,int_stack+304170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+510105,int_stack+508845,int_stack+507900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+511995,int_stack+305130,int_stack+304590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+513615,int_stack+511995,int_stack+508845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+516135,int_stack+513615,int_stack+510105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+519285,int_stack+305805,int_stack+305130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+521310,int_stack+519285,int_stack+511995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+524550,int_stack+521310,int_stack+513615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+519285,int_stack+524550,int_stack+516135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+524010,int_stack+143892,int_stack+143010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+525333,int_stack+145068,int_stack+143892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+527097,int_stack+525333,int_stack+524010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+529743,int_stack+146580,int_stack+145068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+532011,int_stack+529743,int_stack+525333, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+535539,int_stack+532011,int_stack+527097, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+539949,int_stack+3465,int_stack+146580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+542784,int_stack+539949,int_stack+529743, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+547320,int_stack+542784,int_stack+532011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+539949,int_stack+547320,int_stack+535539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+546564,int_stack+313605,int_stack+313290, 0.0, zero_stack, 1.0, int_stack+322725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+547509,int_stack+314025,int_stack+313605, 0.0, zero_stack, 1.0, int_stack+323355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+548769,int_stack+547509,int_stack+546564, 0.0, zero_stack, 1.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550659,int_stack+314565,int_stack+314025, 0.0, zero_stack, 1.0, int_stack+324195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+552279,int_stack+550659,int_stack+547509, 0.0, zero_stack, 1.0, int_stack+366090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+554799,int_stack+552279,int_stack+548769, 0.0, zero_stack, 1.0, int_stack+367350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2268,int_stack+315240,int_stack+314565, 0.0, zero_stack, 1.0, int_stack+325275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+557949,int_stack+2268,int_stack+550659, 0.0, zero_stack, 1.0, int_stack+369240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+561189,int_stack+557949,int_stack+552279, 0.0, zero_stack, 1.0, int_stack+370860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+565389,int_stack+561189,int_stack+554799, 0.0, zero_stack, 1.0, int_stack+373380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+557949,int_stack+153282,int_stack+152400, 0.0, zero_stack, 1.0, int_stack+161790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+559272,int_stack+154458,int_stack+153282, 0.0, zero_stack, 1.0, int_stack+163113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+561036,int_stack+559272,int_stack+557949, 0.0, zero_stack, 1.0, int_stack+392640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2268,int_stack+155970,int_stack+154458, 0.0, zero_stack, 1.0, int_stack+164877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+570114,int_stack+2268,int_stack+559272, 0.0, zero_stack, 1.0, int_stack+393963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+573642,int_stack+570114,int_stack+561036, 0.0, zero_stack, 1.0, int_stack+395727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+578052,int_stack+4620,int_stack+155970, 0.0, zero_stack, 1.0, int_stack+5775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+580887,int_stack+578052,int_stack+2268, 0.0, zero_stack, 1.0, int_stack+398373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+585423,int_stack+580887,int_stack+570114, 0.0, zero_stack, 1.0, int_stack+400641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+578052,int_stack+585423,int_stack+573642, 0.0, zero_stack, 1.0, int_stack+404169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+584667,int_stack+323775,int_stack+323040, 1.0, int_stack+322725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+585612,int_stack+324735,int_stack+323775, 1.0, int_stack+323355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+586872,int_stack+585612,int_stack+584667, 1.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+588762,int_stack+325950,int_stack+324735, 1.0, int_stack+324195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+590382,int_stack+588762,int_stack+585612, 1.0, int_stack+366090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+592902,int_stack+590382,int_stack+586872, 1.0, int_stack+367350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+365145,int_stack+326625,int_stack+325950, 1.0, int_stack+325275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+596052,int_stack+365145,int_stack+588762, 1.0, int_stack+369240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+599292,int_stack+596052,int_stack+590382, 1.0, int_stack+370860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+603492,int_stack+599292,int_stack+592902, 1.0, int_stack+373380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596052,int_stack+163701,int_stack+162231, 1.0, int_stack+161790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+597375,int_stack+165633,int_stack+163701, 1.0, int_stack+163113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+599139,int_stack+597375,int_stack+596052, 1.0, int_stack+392640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+365145,int_stack+167145,int_stack+165633, 1.0, int_stack+164877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+608217,int_stack+365145,int_stack+597375, 1.0, int_stack+393963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+611745,int_stack+608217,int_stack+599139, 1.0, int_stack+395727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+392640,int_stack+6720,int_stack+167145, 1.0, int_stack+5775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+616155,int_stack+392640,int_stack+365145, 1.0, int_stack+398373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+392640,int_stack+616155,int_stack+608217, 1.0, int_stack+400641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+616155,int_stack+392640,int_stack+611745, 1.0, int_stack+404169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+392640,int_stack+10185,int_stack+325275,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+394665,int_stack+392640,int_stack+369240,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+397905,int_stack+394665,int_stack+370860,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+392640,int_stack+397905,int_stack+373380,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+397365,int_stack+337155,int_stack+336840,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+398310,int_stack+337575,int_stack+337155,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+399570,int_stack+398310,int_stack+397365,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+401460,int_stack+338115,int_stack+337575,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+403080,int_stack+401460,int_stack+398310,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+367413,int_stack+403080,int_stack+399570,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+405600,int_stack+338790,int_stack+338115,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+370563,int_stack+405600,int_stack+401460,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+622770,int_stack+370563,int_stack+403080,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+370563,int_stack+622770,int_stack+367413,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+622770,int_stack+207147,int_stack+206265,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+624093,int_stack+208323,int_stack+207147,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+405600,int_stack+624093,int_stack+622770,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4536,int_stack+209835,int_stack+208323,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+625857,int_stack+4536,int_stack+624093,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+625857,int_stack+405600,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+633795,int_stack+7875,int_stack+209835,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+636630,int_stack+633795,int_stack+4536,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+641166,int_stack+636630,int_stack+625857,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+633795,int_stack+641166,int_stack+629385,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+640410,int_stack+346590,int_stack+346275,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+641355,int_stack+347010,int_stack+346590,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+642615,int_stack+641355,int_stack+640410,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+644505,int_stack+347550,int_stack+347010,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+646125,int_stack+644505,int_stack+641355,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+648645,int_stack+646125,int_stack+642615,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6804,int_stack+348225,int_stack+347550,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+651795,int_stack+6804,int_stack+644505,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+655035,int_stack+651795,int_stack+646125,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+659235,int_stack+655035,int_stack+648645,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+651795,int_stack+256497,int_stack+255615,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+653118,int_stack+257673,int_stack+256497,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+654882,int_stack+653118,int_stack+651795,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+663960,int_stack+259185,int_stack+257673,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+666228,int_stack+663960,int_stack+653118,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+669756,int_stack+666228,int_stack+654882,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+674166,int_stack+9030,int_stack+259185,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+677001,int_stack+674166,int_stack+663960,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+681537,int_stack+677001,int_stack+666228,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+674166,int_stack+681537,int_stack+669756,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+680781,int_stack+356025,int_stack+355710,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+681726,int_stack+356445,int_stack+356025,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+682986,int_stack+681726,int_stack+680781,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+684876,int_stack+356985,int_stack+356445,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6804,int_stack+684876,int_stack+681726,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+686496,int_stack+6804,int_stack+682986,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+689646,int_stack+357660,int_stack+356985,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+691671,int_stack+689646,int_stack+684876,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+694911,int_stack+691671,int_stack+6804,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+689646,int_stack+694911,int_stack+686496,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+694371,int_stack+331107,int_stack+330225,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+695694,int_stack+332283,int_stack+331107,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+697458,int_stack+695694,int_stack+694371,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+700104,int_stack+333795,int_stack+332283,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+702372,int_stack+700104,int_stack+695694,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+705900,int_stack+702372,int_stack+697458,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+710310,int_stack+11010,int_stack+333795,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+713145,int_stack+710310,int_stack+700104,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+717681,int_stack+713145,int_stack+702372,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+710310,int_stack+717681,int_stack+705900,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+12480,int_stack+12165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+275550,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+12900,int_stack+12480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+275865,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+376530,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+13440,int_stack+12900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+276285,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9324,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+377475,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+722640,int_stack+9324,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+378735,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+14115,int_stack+13440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+276825,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+725790,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+380625,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+725790,int_stack+9324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+382245,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9324,int_stack+716925,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+384765,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+15381,int_stack+14940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+114840,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+15969,int_stack+15381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+115722,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+408579,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+16725,int_stack+15969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+116898,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+409902,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+411666,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+17670,int_stack+16725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+118410,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14049,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+414312,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+14049,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+416580,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+732864,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+420108,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+19140,int_stack+18825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275550, 1.0, int_stack+284985,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+19560,int_stack+19140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275865, 1.0, int_stack+285300,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376530, 1.0, int_stack+431133,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+20100,int_stack+19560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276285, 1.0, int_stack+285720,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377475, 1.0, int_stack+432078,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378735, 1.0, int_stack+433338,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+20775,int_stack+20100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276825, 1.0, int_stack+286260,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380625, 1.0, int_stack+435228,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382245, 1.0, int_stack+436848,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+14049,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384765, 1.0, int_stack+439368,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+22041,int_stack+21600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114840, 1.0, int_stack+124230,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+22629,int_stack+22041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115722, 1.0, int_stack+125112,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408579, 1.0, int_stack+447243,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+23385,int_stack+22629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116898, 1.0, int_stack+126288,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409902, 1.0, int_stack+448566,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411666, 1.0, int_stack+450330,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+24330,int_stack+23385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118410, 1.0, int_stack+127800,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+18774,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414312, 1.0, int_stack+452976,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+18774,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416580, 1.0, int_stack+455244,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+18774,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420108, 1.0, int_stack+458772,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+25800,int_stack+25485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+284985, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+26220,int_stack+25800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+285300, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+431133, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+26760,int_stack+26220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+285720, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+432078, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+433338, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+27435,int_stack+26760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+286260, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+435228, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+436848, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+739479,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+439368, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+28701,int_stack+28260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+124230, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+29289,int_stack+28701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+125112, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+447243, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+30045,int_stack+29289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+126288, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+448566, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+450330, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+30990,int_stack+30045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+127800, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+25389,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+452976, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+25389,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+455244, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+25389,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+458772, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+32460,int_stack+32145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275550, 0.0, zero_stack, 1.0, int_stack+294420,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+32880,int_stack+32460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275865, 0.0, zero_stack, 1.0, int_stack+294735,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376530, 0.0, zero_stack, 1.0, int_stack+469797,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+33420,int_stack+32880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276285, 0.0, zero_stack, 1.0, int_stack+295155,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377475, 0.0, zero_stack, 1.0, int_stack+470742,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378735, 0.0, zero_stack, 1.0, int_stack+472002,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+34095,int_stack+33420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276825, 0.0, zero_stack, 1.0, int_stack+295695,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380625, 0.0, zero_stack, 1.0, int_stack+473892,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382245, 0.0, zero_stack, 1.0, int_stack+475512,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+744204,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384765, 0.0, zero_stack, 1.0, int_stack+478032,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+35361,int_stack+34920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114840, 0.0, zero_stack, 1.0, int_stack+133620,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+35949,int_stack+35361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115722, 0.0, zero_stack, 1.0, int_stack+134502,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408579, 0.0, zero_stack, 1.0, int_stack+481182,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+36705,int_stack+35949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116898, 0.0, zero_stack, 1.0, int_stack+135678,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409902, 0.0, zero_stack, 1.0, int_stack+482505,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411666, 0.0, zero_stack, 1.0, int_stack+484269,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+37650,int_stack+36705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118410, 0.0, zero_stack, 1.0, int_stack+137190,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32004,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414312, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+32004,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416580, 0.0, zero_stack, 1.0, int_stack+493347,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+32004,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420108, 0.0, zero_stack, 1.0, int_stack+496875,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+39120,int_stack+38805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284985, 1.0, int_stack+294420, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+39540,int_stack+39120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285300, 1.0, int_stack+294735, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431133, 1.0, int_stack+469797, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+40080,int_stack+39540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285720, 1.0, int_stack+295155, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432078, 1.0, int_stack+470742, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433338, 1.0, int_stack+472002, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+40755,int_stack+40080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286260, 1.0, int_stack+295695, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435228, 1.0, int_stack+473892, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436848, 1.0, int_stack+475512, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+748929,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+439368, 1.0, int_stack+478032, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+42021,int_stack+41580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124230, 1.0, int_stack+133620, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+42609,int_stack+42021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125112, 1.0, int_stack+134502, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447243, 1.0, int_stack+481182, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+43365,int_stack+42609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126288, 1.0, int_stack+135678, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448566, 1.0, int_stack+482505, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450330, 1.0, int_stack+484269, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+44310,int_stack+43365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127800, 1.0, int_stack+137190, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+38619,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452976, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+38619,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455244, 1.0, int_stack+493347, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+38619,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458772, 1.0, int_stack+496875, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+45780,int_stack+45465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+294420, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+46200,int_stack+45780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+294735, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+469797, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+46740,int_stack+46200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+295155, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+470742, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+472002, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+47415,int_stack+46740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+295695, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+473892, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+475512, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+753654,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+478032, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+48681,int_stack+48240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+133620, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+49269,int_stack+48681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+134502, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+481182, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+50025,int_stack+49269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+135678, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+482505, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+484269, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+50970,int_stack+50025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+137190, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+45234,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+45234,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+493347, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+45234,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+496875, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+52440,int_stack+52125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303855,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+52860,int_stack+52440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304170,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507900,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+53400,int_stack+52860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304590,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508845,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510105,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+54075,int_stack+53400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305130,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511995,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382245, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513615,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+758379,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516135,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+55341,int_stack+54900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143010,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+55929,int_stack+55341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115722, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143892,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408579, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524010,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+56685,int_stack+55929, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116898, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145068,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525333,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527097,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+57630,int_stack+56685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146580,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+51849,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414312, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529743,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+51849,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532011,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+51849,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535539,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+59100,int_stack+58785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284985, 0.0, zero_stack, 1.0, int_stack+303855, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+59520,int_stack+59100, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285300, 0.0, zero_stack, 1.0, int_stack+304170, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431133, 0.0, zero_stack, 1.0, int_stack+507900, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+60060,int_stack+59520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285720, 0.0, zero_stack, 1.0, int_stack+304590, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432078, 0.0, zero_stack, 1.0, int_stack+508845, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433338, 0.0, zero_stack, 1.0, int_stack+510105, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+60735,int_stack+60060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286260, 0.0, zero_stack, 1.0, int_stack+305130, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435228, 0.0, zero_stack, 1.0, int_stack+511995, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436848, 0.0, zero_stack, 1.0, int_stack+513615, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+763104,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+439368, 0.0, zero_stack, 1.0, int_stack+516135, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+62001,int_stack+61560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124230, 0.0, zero_stack, 1.0, int_stack+143010, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+62589,int_stack+62001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125112, 0.0, zero_stack, 1.0, int_stack+143892, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447243, 0.0, zero_stack, 1.0, int_stack+524010, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+63345,int_stack+62589, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126288, 0.0, zero_stack, 1.0, int_stack+145068, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448566, 0.0, zero_stack, 1.0, int_stack+525333, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450330, 0.0, zero_stack, 1.0, int_stack+527097, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+64290,int_stack+63345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127800, 0.0, zero_stack, 1.0, int_stack+146580, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+58464,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452976, 0.0, zero_stack, 1.0, int_stack+529743, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+58464,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455244, 0.0, zero_stack, 1.0, int_stack+532011, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+58464,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458772, 0.0, zero_stack, 1.0, int_stack+535539, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+65760,int_stack+65445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294420, 1.0, int_stack+303855, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+66180,int_stack+65760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294735, 1.0, int_stack+304170, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469797, 1.0, int_stack+507900, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+66720,int_stack+66180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295155, 1.0, int_stack+304590, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470742, 1.0, int_stack+508845, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472002, 1.0, int_stack+510105, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+67395,int_stack+66720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295695, 1.0, int_stack+305130, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+473892, 1.0, int_stack+511995, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475512, 1.0, int_stack+513615, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+767829,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478032, 1.0, int_stack+516135, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+68661,int_stack+68220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133620, 1.0, int_stack+143010, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+69249,int_stack+68661, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134502, 1.0, int_stack+143892, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481182, 1.0, int_stack+524010, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+70005,int_stack+69249, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135678, 1.0, int_stack+145068, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482505, 1.0, int_stack+525333, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484269, 1.0, int_stack+527097, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+70950,int_stack+70005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137190, 1.0, int_stack+146580, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65079,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+529743, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+65079,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493347, 1.0, int_stack+532011, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+65079,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496875, 1.0, int_stack+535539, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+72420,int_stack+72105, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+303855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+72840,int_stack+72420, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+304170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+507900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+73380,int_stack+72840, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+304590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+508845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+510105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+74055,int_stack+73380, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+305130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+511995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+513615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+772554,int_stack+716925,int_stack+725160, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+516135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+75321,int_stack+74880, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+143010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+75909,int_stack+75321, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+143892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+524010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+76665,int_stack+75909, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+145068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+525333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+527097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+77610,int_stack+76665, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+146580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+71694,int_stack+716925,int_stack+722658, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+529743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+71694,int_stack+724926, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+532011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+71694,int_stack+716925,int_stack+728454, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+535539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+79080,int_stack+78765, 0.0, zero_stack, 1.0, int_stack+275550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313290,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+79500,int_stack+79080, 0.0, zero_stack, 1.0, int_stack+275865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313605,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+376530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546564,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+80040,int_stack+79500, 0.0, zero_stack, 1.0, int_stack+276285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314025,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 1.0, int_stack+377475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547509,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 1.0, int_stack+378735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548769,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+80715,int_stack+80040, 0.0, zero_stack, 1.0, int_stack+276825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314565,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 1.0, int_stack+380625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550659,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 1.0, int_stack+382245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552279,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+777279,int_stack+716925,int_stack+725160, 0.0, zero_stack, 1.0, int_stack+384765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554799,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+81981,int_stack+81540, 0.0, zero_stack, 1.0, int_stack+114840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152400,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+82569,int_stack+81981, 0.0, zero_stack, 1.0, int_stack+115722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153282,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+408579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557949,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+83325,int_stack+82569, 0.0, zero_stack, 1.0, int_stack+116898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154458,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 1.0, int_stack+409902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559272,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 1.0, int_stack+411666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561036,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+84270,int_stack+83325, 0.0, zero_stack, 1.0, int_stack+118410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155970,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+78309,int_stack+716925,int_stack+722658, 0.0, zero_stack, 1.0, int_stack+414312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+78309,int_stack+724926, 0.0, zero_stack, 1.0, int_stack+416580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+570114,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+78309,int_stack+716925,int_stack+728454, 0.0, zero_stack, 1.0, int_stack+420108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573642,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+85740,int_stack+85425, 0.0, zero_stack, 1.0, int_stack+284985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313290, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+86160,int_stack+85740, 0.0, zero_stack, 1.0, int_stack+285300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313605, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+431133, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546564, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+86700,int_stack+86160, 0.0, zero_stack, 1.0, int_stack+285720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314025, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 1.0, int_stack+432078, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547509, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 1.0, int_stack+433338, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548769, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+87375,int_stack+86700, 0.0, zero_stack, 1.0, int_stack+286260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314565, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 1.0, int_stack+435228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550659, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 1.0, int_stack+436848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552279, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+782004,int_stack+716925,int_stack+725160, 0.0, zero_stack, 1.0, int_stack+439368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554799, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+88641,int_stack+88200, 0.0, zero_stack, 1.0, int_stack+124230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152400, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+89229,int_stack+88641, 0.0, zero_stack, 1.0, int_stack+125112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153282, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+447243, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557949, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+89985,int_stack+89229, 0.0, zero_stack, 1.0, int_stack+126288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154458, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 1.0, int_stack+448566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559272, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 1.0, int_stack+450330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561036, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+90930,int_stack+89985, 0.0, zero_stack, 1.0, int_stack+127800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155970, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+84924,int_stack+716925,int_stack+722658, 0.0, zero_stack, 1.0, int_stack+452976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+84924,int_stack+724926, 0.0, zero_stack, 1.0, int_stack+455244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+570114, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+84924,int_stack+716925,int_stack+728454, 0.0, zero_stack, 1.0, int_stack+458772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573642, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+92400,int_stack+92085, 0.0, zero_stack, 1.0, int_stack+294420, 0.0, zero_stack, 1.0, int_stack+313290, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+92820,int_stack+92400, 0.0, zero_stack, 1.0, int_stack+294735, 0.0, zero_stack, 1.0, int_stack+313605, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+469797, 0.0, zero_stack, 1.0, int_stack+546564, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+93360,int_stack+92820, 0.0, zero_stack, 1.0, int_stack+295155, 0.0, zero_stack, 1.0, int_stack+314025, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 1.0, int_stack+470742, 0.0, zero_stack, 1.0, int_stack+547509, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 1.0, int_stack+472002, 0.0, zero_stack, 1.0, int_stack+548769, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+94035,int_stack+93360, 0.0, zero_stack, 1.0, int_stack+295695, 0.0, zero_stack, 1.0, int_stack+314565, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 1.0, int_stack+473892, 0.0, zero_stack, 1.0, int_stack+550659, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 1.0, int_stack+475512, 0.0, zero_stack, 1.0, int_stack+552279, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+786729,int_stack+716925,int_stack+725160, 0.0, zero_stack, 1.0, int_stack+478032, 0.0, zero_stack, 1.0, int_stack+554799, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+95301,int_stack+94860, 0.0, zero_stack, 1.0, int_stack+133620, 0.0, zero_stack, 1.0, int_stack+152400, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+95889,int_stack+95301, 0.0, zero_stack, 1.0, int_stack+134502, 0.0, zero_stack, 1.0, int_stack+153282, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+481182, 0.0, zero_stack, 1.0, int_stack+557949, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+96645,int_stack+95889, 0.0, zero_stack, 1.0, int_stack+135678, 0.0, zero_stack, 1.0, int_stack+154458, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 1.0, int_stack+482505, 0.0, zero_stack, 1.0, int_stack+559272, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 1.0, int_stack+484269, 0.0, zero_stack, 1.0, int_stack+561036, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+97590,int_stack+96645, 0.0, zero_stack, 1.0, int_stack+137190, 0.0, zero_stack, 1.0, int_stack+155970, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+91539,int_stack+716925,int_stack+722658, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+91539,int_stack+724926, 0.0, zero_stack, 1.0, int_stack+493347, 0.0, zero_stack, 1.0, int_stack+570114, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+91539,int_stack+716925,int_stack+728454, 0.0, zero_stack, 1.0, int_stack+496875, 0.0, zero_stack, 1.0, int_stack+573642, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+99060,int_stack+98745, 0.0, zero_stack, 1.0, int_stack+303855, 1.0, int_stack+313290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+99480,int_stack+99060, 0.0, zero_stack, 1.0, int_stack+304170, 1.0, int_stack+313605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+507900, 1.0, int_stack+546564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+100020,int_stack+99480, 0.0, zero_stack, 1.0, int_stack+304590, 1.0, int_stack+314025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 1.0, int_stack+508845, 1.0, int_stack+547509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 1.0, int_stack+510105, 1.0, int_stack+548769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+100695,int_stack+100020, 0.0, zero_stack, 1.0, int_stack+305130, 1.0, int_stack+314565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 1.0, int_stack+511995, 1.0, int_stack+550659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 1.0, int_stack+513615, 1.0, int_stack+552279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+791454,int_stack+716925,int_stack+725160, 0.0, zero_stack, 1.0, int_stack+516135, 1.0, int_stack+554799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+101961,int_stack+101520, 0.0, zero_stack, 1.0, int_stack+143010, 1.0, int_stack+152400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+102549,int_stack+101961, 0.0, zero_stack, 1.0, int_stack+143892, 1.0, int_stack+153282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 1.0, int_stack+524010, 1.0, int_stack+557949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+103305,int_stack+102549, 0.0, zero_stack, 1.0, int_stack+145068, 1.0, int_stack+154458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 1.0, int_stack+525333, 1.0, int_stack+559272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 1.0, int_stack+527097, 1.0, int_stack+561036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+104250,int_stack+103305, 0.0, zero_stack, 1.0, int_stack+146580, 1.0, int_stack+155970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+98154,int_stack+716925,int_stack+722658, 0.0, zero_stack, 1.0, int_stack+529743, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+98154,int_stack+724926, 0.0, zero_stack, 1.0, int_stack+532011, 1.0, int_stack+570114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+98154,int_stack+716925,int_stack+728454, 0.0, zero_stack, 1.0, int_stack+535539, 1.0, int_stack+573642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+105720,int_stack+105405, 0.0, zero_stack, 2.0, int_stack+313290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+106140,int_stack+105720, 0.0, zero_stack, 2.0, int_stack+313605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 0.0, zero_stack, 2.0, int_stack+546564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+106680,int_stack+106140, 0.0, zero_stack, 2.0, int_stack+314025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 0.0, zero_stack, 2.0, int_stack+547509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 0.0, zero_stack, 2.0, int_stack+548769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+107355,int_stack+106680, 0.0, zero_stack, 2.0, int_stack+314565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 0.0, zero_stack, 2.0, int_stack+550659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 0.0, zero_stack, 2.0, int_stack+552279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+796179,int_stack+716925,int_stack+725160, 0.0, zero_stack, 2.0, int_stack+554799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+108621,int_stack+108180, 0.0, zero_stack, 2.0, int_stack+152400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+109209,int_stack+108621, 0.0, zero_stack, 2.0, int_stack+153282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 0.0, zero_stack, 2.0, int_stack+557949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+109965,int_stack+109209, 0.0, zero_stack, 2.0, int_stack+154458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 0.0, zero_stack, 2.0, int_stack+559272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 0.0, zero_stack, 2.0, int_stack+561036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+110910,int_stack+109965, 0.0, zero_stack, 2.0, int_stack+155970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+104769,int_stack+716925,int_stack+722658, 0.0, zero_stack, 2.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+104769,int_stack+724926, 0.0, zero_stack, 2.0, int_stack+570114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+104769,int_stack+716925,int_stack+728454, 0.0, zero_stack, 2.0, int_stack+573642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+112380,int_stack+112065, 1.0, int_stack+275550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323040,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+112800,int_stack+112380, 1.0, int_stack+275865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323775,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 1.0, int_stack+376530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584667,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+113340,int_stack+112800, 1.0, int_stack+276285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324735,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 1.0, int_stack+377475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585612,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 1.0, int_stack+378735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586872,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+114015,int_stack+113340, 1.0, int_stack+276825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325950,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+728310,int_stack+716925,int_stack+721020, 1.0, int_stack+380625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588762,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+728310,int_stack+722640, 1.0, int_stack+382245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+590382,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+375288,int_stack+716925,int_stack+725160, 1.0, int_stack+384765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+592902,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+116310,int_stack+115281, 1.0, int_stack+114840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162231,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718248,int_stack+117654,int_stack+116310, 1.0, int_stack+115722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163701,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+720012,int_stack+718248,int_stack+716925, 1.0, int_stack+408579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596052,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+722658,int_stack+119355,int_stack+117654, 1.0, int_stack+116898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165633,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+724926,int_stack+722658,int_stack+718248, 1.0, int_stack+409902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597375,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+728454,int_stack+724926,int_stack+720012, 1.0, int_stack+411666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599139,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+716925,int_stack+120300,int_stack+119355, 1.0, int_stack+118410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167145,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111384,int_stack+716925,int_stack+722658, 1.0, int_stack+414312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365145,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716925,int_stack+111384,int_stack+724926, 1.0, int_stack+416580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608217,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+111384,int_stack+716925,int_stack+728454, 1.0, int_stack+420108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611745,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716925,int_stack+121770,int_stack+121455, 1.0, int_stack+284985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323040, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+717870,int_stack+122190,int_stack+121770, 1.0, int_stack+285300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323775, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+719130,int_stack+717870,int_stack+716925, 1.0, int_stack+431133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584667, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+721020,int_stack+122730,int_stack+122190, 1.0, int_stack+285720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324735, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+722640,int_stack+721020,int_stack+717870, 1.0, int_stack+432078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585612, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725160,int_stack+722640,int_stack+719130, 1.0, int_stack+433338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586872, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+431133,int_stack+123405,int_stack+122730, 1.0, int_stack+286260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325950, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+716925,int_stack+431133,int_stack+721020, 1.0, int_stack+435228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588762, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+431133,int_stack+716925,int_stack+722640, 1.0, int_stack+436848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+590382, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+716925,int_stack+431133,int_stack+725160, 1.0, int_stack+439368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+592902, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+431133,int_stack+125700,int_stack+124671, 1.0, int_stack+124230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162231, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+432456,int_stack+127044,int_stack+125700, 1.0, int_stack+125112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163701, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+434220,int_stack+432456,int_stack+431133, 1.0, int_stack+447243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596052, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+436866,int_stack+128745,int_stack+127044, 1.0, int_stack+126288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165633, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+721650,int_stack+436866,int_stack+432456, 1.0, int_stack+448566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597375, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+725178,int_stack+721650,int_stack+434220, 1.0, int_stack+450330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599139, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+447243,int_stack+129690,int_stack+128745, 1.0, int_stack+127800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167145, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+431133,int_stack+447243,int_stack+436866, 1.0, int_stack+452976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365145, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+447243,int_stack+431133,int_stack+721650, 1.0, int_stack+455244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608217, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+431133,int_stack+447243,int_stack+725178, 1.0, int_stack+458772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611745, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+447243,int_stack+131160,int_stack+130845, 1.0, int_stack+294420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323040, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+448188,int_stack+131580,int_stack+131160, 1.0, int_stack+294735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323775, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+449448,int_stack+448188,int_stack+447243, 1.0, int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584667, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+451338,int_stack+132120,int_stack+131580, 1.0, int_stack+295155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324735, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+452958,int_stack+451338,int_stack+448188, 1.0, int_stack+470742, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585612, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+455478,int_stack+452958,int_stack+449448, 1.0, int_stack+472002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586872, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469797,int_stack+132795,int_stack+132120, 1.0, int_stack+295695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325950, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+447243,int_stack+469797,int_stack+451338, 1.0, int_stack+473892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588762, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+447243,int_stack+452958, 1.0, int_stack+475512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+590382, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+447243,int_stack+469797,int_stack+455478, 1.0, int_stack+478032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+592902, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469797,int_stack+135090,int_stack+134061, 1.0, int_stack+133620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162231, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471120,int_stack+136434,int_stack+135090, 1.0, int_stack+134502, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163701, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472884,int_stack+471120,int_stack+469797, 1.0, int_stack+481182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596052, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475530,int_stack+138135,int_stack+136434, 1.0, int_stack+135678, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165633, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477798,int_stack+475530,int_stack+471120, 1.0, int_stack+482505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597375, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+451968,int_stack+477798,int_stack+472884, 1.0, int_stack+484269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599139, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469797,int_stack+139080,int_stack+138135, 1.0, int_stack+137190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167145, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+481326,int_stack+469797,int_stack+475530, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+481326,int_stack+477798, 1.0, int_stack+493347, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608217, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+475677,int_stack+469797,int_stack+451968, 1.0, int_stack+496875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611745, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+451968,int_stack+140550,int_stack+140235, 1.0, int_stack+303855, 0.0, zero_stack, 1.0, int_stack+323040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+452913,int_stack+140970,int_stack+140550, 1.0, int_stack+304170, 0.0, zero_stack, 1.0, int_stack+323775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+454173,int_stack+452913,int_stack+451968, 1.0, int_stack+507900, 0.0, zero_stack, 1.0, int_stack+584667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+456063,int_stack+141510,int_stack+140970, 1.0, int_stack+304590, 0.0, zero_stack, 1.0, int_stack+324735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+457683,int_stack+456063,int_stack+452913, 1.0, int_stack+508845, 0.0, zero_stack, 1.0, int_stack+585612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+469797,int_stack+457683,int_stack+454173, 1.0, int_stack+510105, 0.0, zero_stack, 1.0, int_stack+586872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+507900,int_stack+142185,int_stack+141510, 1.0, int_stack+305130, 0.0, zero_stack, 1.0, int_stack+325950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+451968,int_stack+507900,int_stack+456063, 1.0, int_stack+511995, 0.0, zero_stack, 1.0, int_stack+588762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+507900,int_stack+451968,int_stack+457683, 1.0, int_stack+513615, 0.0, zero_stack, 1.0, int_stack+590382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+451968,int_stack+507900,int_stack+469797, 1.0, int_stack+516135, 0.0, zero_stack, 1.0, int_stack+592902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469797,int_stack+144480,int_stack+143451, 1.0, int_stack+143010, 0.0, zero_stack, 1.0, int_stack+162231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471120,int_stack+145824,int_stack+144480, 1.0, int_stack+143892, 0.0, zero_stack, 1.0, int_stack+163701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472884,int_stack+471120,int_stack+469797, 1.0, int_stack+524010, 0.0, zero_stack, 1.0, int_stack+596052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+147525,int_stack+145824, 1.0, int_stack+145068, 0.0, zero_stack, 1.0, int_stack+165633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+507900,int_stack+0,int_stack+471120, 1.0, int_stack+525333, 0.0, zero_stack, 1.0, int_stack+597375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+511428,int_stack+507900,int_stack+472884, 1.0, int_stack+527097, 0.0, zero_stack, 1.0, int_stack+599139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+524010,int_stack+148470,int_stack+147525, 1.0, int_stack+146580, 0.0, zero_stack, 1.0, int_stack+167145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469797,int_stack+524010,int_stack+0, 1.0, int_stack+529743, 0.0, zero_stack, 1.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+524010,int_stack+469797,int_stack+507900, 1.0, int_stack+532011, 0.0, zero_stack, 1.0, int_stack+608217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+493347,int_stack+524010,int_stack+511428, 1.0, int_stack+535539, 0.0, zero_stack, 1.0, int_stack+611745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+524010,int_stack+149940,int_stack+149625, 1.0, int_stack+313290, 1.0, int_stack+323040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+524955,int_stack+150360,int_stack+149940, 1.0, int_stack+313605, 1.0, int_stack+323775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+526215,int_stack+524955,int_stack+524010, 1.0, int_stack+546564, 1.0, int_stack+584667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+528105,int_stack+150900,int_stack+150360, 1.0, int_stack+314025, 1.0, int_stack+324735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529725,int_stack+528105,int_stack+524955, 1.0, int_stack+547509, 1.0, int_stack+585612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+532245,int_stack+529725,int_stack+526215, 1.0, int_stack+548769, 1.0, int_stack+586872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+546564,int_stack+151575,int_stack+150900, 1.0, int_stack+314565, 1.0, int_stack+325950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+524010,int_stack+546564,int_stack+528105, 1.0, int_stack+550659, 1.0, int_stack+588762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+546564,int_stack+524010,int_stack+529725, 1.0, int_stack+552279, 1.0, int_stack+590382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+524010,int_stack+546564,int_stack+532245, 1.0, int_stack+554799, 1.0, int_stack+592902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+499962,int_stack+153870,int_stack+152841, 1.0, int_stack+152400, 1.0, int_stack+162231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+546564,int_stack+155214,int_stack+153870, 1.0, int_stack+153282, 1.0, int_stack+163701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+548328,int_stack+546564,int_stack+499962, 1.0, int_stack+557949, 1.0, int_stack+596052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+156915,int_stack+155214, 1.0, int_stack+154458, 1.0, int_stack+165633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+550974,int_stack+0,int_stack+546564, 1.0, int_stack+559272, 1.0, int_stack+597375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+554502,int_stack+550974,int_stack+548328, 1.0, int_stack+561036, 1.0, int_stack+599139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+546564,int_stack+157860,int_stack+156915, 1.0, int_stack+155970, 1.0, int_stack+167145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+558912,int_stack+546564,int_stack+0, 1.0, int_stack+2268, 1.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+558912,int_stack+550974, 1.0, int_stack+570114, 1.0, int_stack+608217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+546564,int_stack+469797,int_stack+554502, 1.0, int_stack+573642, 1.0, int_stack+611745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469797,int_stack+159330,int_stack+159015, 2.0, int_stack+323040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+470742,int_stack+159750,int_stack+159330, 2.0, int_stack+323775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472002,int_stack+470742,int_stack+469797, 2.0, int_stack+584667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473892,int_stack+160290,int_stack+159750, 2.0, int_stack+324735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+570114,int_stack+473892,int_stack+470742, 2.0, int_stack+585612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+572634,int_stack+570114,int_stack+472002, 2.0, int_stack+586872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+584667,int_stack+160965,int_stack+160290, 2.0, int_stack+325950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469797,int_stack+584667,int_stack+473892, 2.0, int_stack+588762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+584667,int_stack+469797,int_stack+570114, 2.0, int_stack+590382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+322725,int_stack+584667,int_stack+572634, 2.0, int_stack+592902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+499962,int_stack+164289,int_stack+162672, 2.0, int_stack+162231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+584667,int_stack+166389,int_stack+164289, 2.0, int_stack+163701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+586431,int_stack+584667,int_stack+499962, 2.0, int_stack+596052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+589077,int_stack+168090,int_stack+166389, 2.0, int_stack+165633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+591345,int_stack+589077,int_stack+584667, 2.0, int_stack+597375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+570114,int_stack+591345,int_stack+586431, 2.0, int_stack+599139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+584667,int_stack+169035,int_stack+168090, 2.0, int_stack+167145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+584667,int_stack+589077, 2.0, int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+0,int_stack+591345, 2.0, int_stack+608217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+584667,int_stack+469797,int_stack+570114, 2.0, int_stack+611745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570114,int_stack+170505,int_stack+170190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336840,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571059,int_stack+170925,int_stack+170505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337155,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+572319,int_stack+571059,int_stack+570114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397365,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+574209,int_stack+171465,int_stack+170925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337575,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+469797,int_stack+574209,int_stack+571059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398310,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+472317,int_stack+469797,int_stack+572319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399570,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+570114,int_stack+172140,int_stack+171465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338115,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+608217,int_stack+570114,int_stack+574209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401460,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+570114,int_stack+608217,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403080,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+608217,int_stack+570114,int_stack+472317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367413,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+499962,int_stack+173406,int_stack+172965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206265,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570114,int_stack+173994,int_stack+173406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207147,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+571878,int_stack+570114,int_stack+499962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622770,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+365145,int_stack+174750,int_stack+173994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208323,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+574524,int_stack+365145,int_stack+570114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624093,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+469797,int_stack+574524,int_stack+571878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405600,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+570114,int_stack+175695,int_stack+174750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209835,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+570114,int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4536,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+591282,int_stack+0,int_stack+574524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625857,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+570114,int_stack+591282,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629385,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469797,int_stack+177165,int_stack+176850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336840, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+470742,int_stack+177585,int_stack+177165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337155, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472002,int_stack+470742,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397365, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473892,int_stack+178125,int_stack+177585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337575, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+591282,int_stack+473892,int_stack+470742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398310, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+593802,int_stack+591282,int_stack+472002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399570, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469797,int_stack+178800,int_stack+178125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338115, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+596952,int_stack+469797,int_stack+473892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401460, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+596952,int_stack+591282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403080, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+596952,int_stack+469797,int_stack+593802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367413, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+180066,int_stack+179625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206265, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+469797,int_stack+180654,int_stack+180066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207147, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+471561,int_stack+469797,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622770, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+365145,int_stack+181410,int_stack+180654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208323, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+591282,int_stack+365145,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624093, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+591282,int_stack+471561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405600, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469797,int_stack+182355,int_stack+181410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209835, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+553179,int_stack+469797,int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4536, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+553179,int_stack+591282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625857, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+553179,int_stack+469797,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629385, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+183825,int_stack+183510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336840, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+184245,int_stack+183825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337155, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2205,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397365, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+469797,int_stack+184785,int_stack+184245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337575, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+471417,int_stack+469797,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398310, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+591282,int_stack+471417,int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399570, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+185460,int_stack+184785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338115, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+559794,int_stack+0,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401460, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+559794,int_stack+471417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403080, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+559794,int_stack+0,int_stack+591282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367413, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+186726,int_stack+186285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206265, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+591282,int_stack+187314,int_stack+186726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207147, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+593046,int_stack+591282,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622770, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+365145,int_stack+188070,int_stack+187314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208323, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+365145,int_stack+591282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624093, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+469797,int_stack+0,int_stack+593046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405600, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+591282,int_stack+189015,int_stack+188070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209835, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+528735,int_stack+591282,int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4536, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+533271,int_stack+528735,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625857, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+507900,int_stack+533271,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629385, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469797,int_stack+190485,int_stack+190170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+470742,int_stack+190905,int_stack+190485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472002,int_stack+470742,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473892,int_stack+191445,int_stack+190905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+473892,int_stack+470742, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+0,int_stack+472002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469797,int_stack+192120,int_stack+191445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+531885,int_stack+469797,int_stack+473892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+531885,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+531885,int_stack+469797,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+193386,int_stack+192945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+193974,int_stack+193386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+469797,int_stack+528735,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+365145,int_stack+194730,int_stack+193974, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+365145,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+591282,int_stack+0,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469797,int_stack+195675,int_stack+194730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+514515,int_stack+469797,int_stack+365145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469797,int_stack+514515,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+721650,int_stack+469797,int_stack+591282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+591282,int_stack+197145,int_stack+196830, 0.0, zero_stack, 1.0, int_stack+336840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+592227,int_stack+197565,int_stack+197145, 0.0, zero_stack, 1.0, int_stack+337155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+593487,int_stack+592227,int_stack+591282, 0.0, zero_stack, 1.0, int_stack+397365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+469797,int_stack+198105,int_stack+197565, 0.0, zero_stack, 1.0, int_stack+337575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+471417,int_stack+469797,int_stack+592227, 0.0, zero_stack, 1.0, int_stack+398310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+471417,int_stack+593487, 0.0, zero_stack, 1.0, int_stack+399570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+591282,int_stack+198780,int_stack+198105, 0.0, zero_stack, 1.0, int_stack+338115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+593307,int_stack+591282,int_stack+469797, 0.0, zero_stack, 1.0, int_stack+401460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+593307,int_stack+471417, 0.0, zero_stack, 1.0, int_stack+403080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+469797,int_stack+0,int_stack+528735, 0.0, zero_stack, 1.0, int_stack+367413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+200046,int_stack+199605, 0.0, zero_stack, 1.0, int_stack+206265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+200634,int_stack+200046, 0.0, zero_stack, 1.0, int_stack+207147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+528735,int_stack+576729, 0.0, zero_stack, 1.0, int_stack+622770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+365145,int_stack+201390,int_stack+200634, 0.0, zero_stack, 1.0, int_stack+208323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+591282,int_stack+365145,int_stack+528735, 0.0, zero_stack, 1.0, int_stack+624093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+514515,int_stack+591282,int_stack+0, 0.0, zero_stack, 1.0, int_stack+405600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+202335,int_stack+201390, 0.0, zero_stack, 1.0, int_stack+209835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+456693,int_stack+0,int_stack+365145, 0.0, zero_stack, 1.0, int_stack+4536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+482292,int_stack+456693,int_stack+591282, 0.0, zero_stack, 1.0, int_stack+625857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+117999,int_stack+482292,int_stack+514515, 0.0, zero_stack, 1.0, int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+514515,int_stack+203805,int_stack+203490, 1.0, int_stack+336840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+515460,int_stack+204225,int_stack+203805, 1.0, int_stack+337155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+516720,int_stack+515460,int_stack+514515, 1.0, int_stack+397365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+482292,int_stack+204765,int_stack+204225, 1.0, int_stack+337575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+483912,int_stack+482292,int_stack+515460, 1.0, int_stack+398310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+483912,int_stack+516720, 1.0, int_stack+399570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+397365,int_stack+205440,int_stack+204765, 1.0, int_stack+338115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+514515,int_stack+397365,int_stack+482292, 1.0, int_stack+401460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+397365,int_stack+514515,int_stack+483912, 1.0, int_stack+403080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+514515,int_stack+397365,int_stack+528735, 1.0, int_stack+367413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+207735,int_stack+206706, 1.0, int_stack+206265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+209079,int_stack+207735, 1.0, int_stack+207147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+397365,int_stack+528735,int_stack+576729, 1.0, int_stack+622770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+400011,int_stack+210780,int_stack+209079, 1.0, int_stack+208323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+482292,int_stack+400011,int_stack+528735, 1.0, int_stack+624093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+591282,int_stack+482292,int_stack+397365, 1.0, int_stack+405600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+211725,int_stack+210780, 1.0, int_stack+209835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+528735,int_stack+400011, 1.0, int_stack+4536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+397365,int_stack+0,int_stack+482292, 1.0, int_stack+625857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+622770,int_stack+397365,int_stack+591282, 1.0, int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+629385,int_stack+213195,int_stack+212880,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+630330,int_stack+213615,int_stack+213195,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+631590,int_stack+630330,int_stack+629385,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+591282,int_stack+214155,int_stack+213615,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+592902,int_stack+591282,int_stack+630330,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+592902,int_stack+631590,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+214830,int_stack+214155,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+397365,int_stack+629385,int_stack+591282,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+629385,int_stack+397365,int_stack+592902,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+397365,int_stack+629385,int_stack+528735,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+216096,int_stack+215655,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+216684,int_stack+216096,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+629385,int_stack+528735,int_stack+576729,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+217440,int_stack+216684,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+404358,int_stack+402090,int_stack+528735,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+407886,int_stack+404358,int_stack+629385,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+218385,int_stack+217440,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+412296,int_stack+629385,int_stack+402090,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+416832,int_stack+412296,int_stack+404358,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+416832,int_stack+407886,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+402090,int_stack+219855,int_stack+219540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346275,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403035,int_stack+220275,int_stack+219855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346590,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+404295,int_stack+403035,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640410,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+406185,int_stack+220815,int_stack+220275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347010,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+407805,int_stack+406185,int_stack+403035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641355,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+407805,int_stack+404295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642615,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+402090,int_stack+221490,int_stack+220815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347550,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+410325,int_stack+402090,int_stack+406185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644505,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+410325,int_stack+407805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646125,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+406290,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648645,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+222756,int_stack+222315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255615,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+223344,int_stack+222756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256497,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+402090,int_stack+528735,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651795,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+411015,int_stack+224100,int_stack+223344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257673,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+413283,int_stack+411015,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653118,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+413283,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654882,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+402090,int_stack+225045,int_stack+224100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259185,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+416811,int_stack+402090,int_stack+411015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663960,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+482292,int_stack+416811,int_stack+413283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666228,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+411015,int_stack+482292,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669756,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+629385,int_stack+226515,int_stack+226200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346275, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630330,int_stack+226935,int_stack+226515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346590, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+631590,int_stack+630330,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640410, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+482292,int_stack+227475,int_stack+226935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347010, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+483912,int_stack+482292,int_stack+630330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641355, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+483912,int_stack+631590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642615, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+228150,int_stack+227475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347550, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+417630,int_stack+629385,int_stack+482292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644505, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+417630,int_stack+483912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646125, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+417630,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648645, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+229416,int_stack+228975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255615, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+230004,int_stack+229416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256497, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+402090,int_stack+528735,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651795, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+482292,int_stack+230760,int_stack+230004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257673, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+484560,int_stack+482292,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653118, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+484560,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654882, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+402090,int_stack+231705,int_stack+230760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259185, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+591282,int_stack+402090,int_stack+482292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663960, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+456693,int_stack+591282,int_stack+484560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666228, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+124614,int_stack+456693,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669756, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+629385,int_stack+233175,int_stack+232860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346275, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630330,int_stack+233595,int_stack+233175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346590, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+631590,int_stack+630330,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640410, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+456693,int_stack+234135,int_stack+233595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347010, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+458313,int_stack+456693,int_stack+630330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641355, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+458313,int_stack+631590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642615, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+234810,int_stack+234135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347550, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+591282,int_stack+629385,int_stack+456693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644505, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+591282,int_stack+458313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646125, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+591282,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648645, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+236076,int_stack+235635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255615, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+236664,int_stack+236076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256497, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+402090,int_stack+528735,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651795, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+456693,int_stack+237420,int_stack+236664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257673, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+458961,int_stack+456693,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653118, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+458961,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654882, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+402090,int_stack+238365,int_stack+237420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259185, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+482292,int_stack+402090,int_stack+456693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663960, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+131229,int_stack+482292,int_stack+458961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666228, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+137109,int_stack+131229,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669756, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+239835,int_stack+239520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+240255,int_stack+239835, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+131229,int_stack+240795,int_stack+240255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+132849,int_stack+131229,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+132849,int_stack+630645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+241470,int_stack+240795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+482292,int_stack+629385,int_stack+131229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+482292,int_stack+132849, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+482292,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+242736,int_stack+242295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528735,int_stack+243324,int_stack+242736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+402090,int_stack+528735,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+131229,int_stack+244080,int_stack+243324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+133497,int_stack+131229,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+133497,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+402090,int_stack+245025,int_stack+244080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+456693,int_stack+402090,int_stack+131229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+143724,int_stack+456693,int_stack+133497, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+149604,int_stack+143724,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+246495,int_stack+246180, 0.0, zero_stack, 1.0, int_stack+346275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+246915,int_stack+246495, 0.0, zero_stack, 1.0, int_stack+346590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 0.0, zero_stack, 1.0, int_stack+640410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+143724,int_stack+247455,int_stack+246915, 0.0, zero_stack, 1.0, int_stack+347010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+145344,int_stack+143724,int_stack+629385, 0.0, zero_stack, 1.0, int_stack+641355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+145344,int_stack+630645, 0.0, zero_stack, 1.0, int_stack+642615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+248130,int_stack+247455, 0.0, zero_stack, 1.0, int_stack+347550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+456693,int_stack+629385,int_stack+143724, 0.0, zero_stack, 1.0, int_stack+644505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+456693,int_stack+145344, 0.0, zero_stack, 1.0, int_stack+646125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+456693,int_stack+402090,int_stack+528735, 0.0, zero_stack, 1.0, int_stack+648645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+249396,int_stack+248955, 0.0, zero_stack, 1.0, int_stack+255615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+249984,int_stack+249396, 0.0, zero_stack, 1.0, int_stack+256497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 0.0, zero_stack, 1.0, int_stack+651795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+250740,int_stack+249984, 0.0, zero_stack, 1.0, int_stack+257673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+143724,int_stack+402090,int_stack+461418, 0.0, zero_stack, 1.0, int_stack+653118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+143724,int_stack+528735, 0.0, zero_stack, 1.0, int_stack+654882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+251685,int_stack+250740, 0.0, zero_stack, 1.0, int_stack+259185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+131229,int_stack+528735,int_stack+402090, 0.0, zero_stack, 1.0, int_stack+663960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+156219,int_stack+131229,int_stack+143724, 0.0, zero_stack, 1.0, int_stack+666228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+162099,int_stack+156219,int_stack+629385, 0.0, zero_stack, 1.0, int_stack+669756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+253155,int_stack+252840, 1.0, int_stack+346275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+253575,int_stack+253155, 1.0, int_stack+346590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 1.0, int_stack+640410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+156219,int_stack+254115,int_stack+253575, 1.0, int_stack+347010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+157839,int_stack+156219,int_stack+629385, 1.0, int_stack+641355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+157839,int_stack+630645, 1.0, int_stack+642615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+254790,int_stack+254115, 1.0, int_stack+347550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+640410,int_stack+629385,int_stack+156219, 1.0, int_stack+644505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+640410,int_stack+157839, 1.0, int_stack+646125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+640410,int_stack+402090,int_stack+528735, 1.0, int_stack+648645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+257085,int_stack+256056, 1.0, int_stack+255615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+258429,int_stack+257085, 1.0, int_stack+256497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 1.0, int_stack+651795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+260130,int_stack+258429, 1.0, int_stack+257673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+645135,int_stack+402090,int_stack+461418, 1.0, int_stack+653118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+645135,int_stack+528735, 1.0, int_stack+654882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+261075,int_stack+260130, 1.0, int_stack+259185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+648663,int_stack+528735,int_stack+402090, 1.0, int_stack+663960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+156219,int_stack+648663,int_stack+645135, 1.0, int_stack+666228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+645135,int_stack+156219,int_stack+629385, 1.0, int_stack+669756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+262545,int_stack+262230,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+262965,int_stack+262545,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+156219,int_stack+263505,int_stack+262965,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+157839,int_stack+156219,int_stack+629385,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+157839,int_stack+630645,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+264180,int_stack+263505,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+651750,int_stack+629385,int_stack+156219,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+651750,int_stack+157839,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+651750,int_stack+402090,int_stack+528735,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+265446,int_stack+265005,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+266034,int_stack+265446,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+266790,int_stack+266034,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+156219,int_stack+402090,int_stack+461418,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+156219,int_stack+528735,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+267735,int_stack+266790,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+663960,int_stack+528735,int_stack+402090,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143724,int_stack+663960,int_stack+156219,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+663960,int_stack+143724,int_stack+629385,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+269205,int_stack+268890,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+269625,int_stack+269205,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+143724,int_stack+270165,int_stack+269625,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+145344,int_stack+143724,int_stack+629385,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+145344,int_stack+630645,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+270840,int_stack+270165,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+156219,int_stack+629385,int_stack+143724,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+156219,int_stack+145344,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+156219,int_stack+402090,int_stack+528735,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+272106,int_stack+271665,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+272694,int_stack+272106,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+273450,int_stack+272694,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+143724,int_stack+402090,int_stack+461418,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+143724,int_stack+528735,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+274395,int_stack+273450,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+131229,int_stack+528735,int_stack+402090,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+168714,int_stack+131229,int_stack+143724,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+174594,int_stack+168714,int_stack+629385,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+278640,int_stack+278325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355710,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+279060,int_stack+278640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356025,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680781,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+168714,int_stack+279600,int_stack+279060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356445,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+170334,int_stack+168714,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+681726,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+170334,int_stack+630645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682986,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+280275,int_stack+279600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356985,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+143724,int_stack+629385,int_stack+168714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684876,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+143724,int_stack+170334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6804,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+143724,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686496,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+281541,int_stack+281100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330225,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+282129,int_stack+281541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331107,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+694371,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+282885,int_stack+282129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332283,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+168714,int_stack+402090,int_stack+461418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+695694,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+168714,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697458,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+283830,int_stack+282885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333795,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+131229,int_stack+528735,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+700104,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+181209,int_stack+131229,int_stack+168714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702372,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+187089,int_stack+181209,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705900,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+288075,int_stack+287760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355710, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+288495,int_stack+288075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356025, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680781, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+181209,int_stack+289035,int_stack+288495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356445, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+182829,int_stack+181209,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+681726, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+182829,int_stack+630645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682986, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+289710,int_stack+289035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356985, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+168714,int_stack+629385,int_stack+181209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684876, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+168714,int_stack+182829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6804, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+168714,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686496, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+290976,int_stack+290535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330225, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+291564,int_stack+290976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331107, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+694371, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+292320,int_stack+291564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332283, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+181209,int_stack+402090,int_stack+461418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+695694, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+181209,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697458, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+293265,int_stack+292320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333795, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+131229,int_stack+528735,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+700104, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+193704,int_stack+131229,int_stack+181209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702372, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+199584,int_stack+193704,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705900, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+297510,int_stack+297195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355710, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+297930,int_stack+297510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356025, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680781, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+193704,int_stack+298470,int_stack+297930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356445, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+195324,int_stack+193704,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+681726, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+195324,int_stack+630645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682986, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+299145,int_stack+298470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356985, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+181209,int_stack+629385,int_stack+193704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684876, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+181209,int_stack+195324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6804, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+181209,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686496, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+300411,int_stack+299970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330225, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+300999,int_stack+300411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331107, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+694371, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+301755,int_stack+300999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332283, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+193704,int_stack+402090,int_stack+461418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+695694, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+193704,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697458, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+302700,int_stack+301755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333795, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+131229,int_stack+528735,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+700104, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+206199,int_stack+131229,int_stack+193704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702372, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+212079,int_stack+206199,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705900, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+306945,int_stack+306630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+307365,int_stack+306945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+206199,int_stack+307905,int_stack+307365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+207819,int_stack+206199,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+681726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+207819,int_stack+630645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+308580,int_stack+307905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+193704,int_stack+629385,int_stack+206199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+193704,int_stack+207819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+193704,int_stack+402090,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+309846,int_stack+309405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+310434,int_stack+309846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+694371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+311190,int_stack+310434, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+206199,int_stack+402090,int_stack+461418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+695694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+206199,int_stack+528735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+312135,int_stack+311190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+131229,int_stack+528735,int_stack+402090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+700104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+218694,int_stack+131229,int_stack+206199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+224574,int_stack+218694,int_stack+629385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+316380,int_stack+316065, 0.0, zero_stack, 1.0, int_stack+355710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+316800,int_stack+316380, 0.0, zero_stack, 1.0, int_stack+356025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 0.0, zero_stack, 1.0, int_stack+680781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+218694,int_stack+317340,int_stack+316800, 0.0, zero_stack, 1.0, int_stack+356445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+220314,int_stack+218694,int_stack+629385, 0.0, zero_stack, 1.0, int_stack+681726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+220314,int_stack+630645, 0.0, zero_stack, 1.0, int_stack+682986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+318015,int_stack+317340, 0.0, zero_stack, 1.0, int_stack+356985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206199,int_stack+629385,int_stack+218694, 0.0, zero_stack, 1.0, int_stack+684876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+206199,int_stack+220314, 0.0, zero_stack, 1.0, int_stack+6804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+206199,int_stack+402090,int_stack+528735, 0.0, zero_stack, 1.0, int_stack+686496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+319281,int_stack+318840, 0.0, zero_stack, 1.0, int_stack+330225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+319869,int_stack+319281, 0.0, zero_stack, 1.0, int_stack+331107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 0.0, zero_stack, 1.0, int_stack+694371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+320625,int_stack+319869, 0.0, zero_stack, 1.0, int_stack+332283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+218694,int_stack+402090,int_stack+461418, 0.0, zero_stack, 1.0, int_stack+695694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+218694,int_stack+528735, 0.0, zero_stack, 1.0, int_stack+697458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+321570,int_stack+320625, 0.0, zero_stack, 1.0, int_stack+333795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+131229,int_stack+528735,int_stack+402090, 0.0, zero_stack, 1.0, int_stack+700104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+231189,int_stack+131229,int_stack+218694, 0.0, zero_stack, 1.0, int_stack+702372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+237069,int_stack+231189,int_stack+629385, 0.0, zero_stack, 1.0, int_stack+705900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+327765,int_stack+327450, 1.0, int_stack+355710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+328185,int_stack+327765, 1.0, int_stack+356025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007, 1.0, int_stack+680781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+231189,int_stack+328725,int_stack+328185, 1.0, int_stack+356445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+232809,int_stack+231189,int_stack+629385, 1.0, int_stack+681726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+232809,int_stack+630645, 1.0, int_stack+682986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+329400,int_stack+328725, 1.0, int_stack+356985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+680781,int_stack+629385,int_stack+231189, 1.0, int_stack+684876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+680781,int_stack+232809, 1.0, int_stack+6804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+680781,int_stack+402090,int_stack+528735, 1.0, int_stack+686496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+331695,int_stack+330666, 1.0, int_stack+330225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+333039,int_stack+331695, 1.0, int_stack+331107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729, 1.0, int_stack+694371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+334740,int_stack+333039, 1.0, int_stack+332283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+685506,int_stack+402090,int_stack+461418, 1.0, int_stack+695694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+685506,int_stack+528735, 1.0, int_stack+697458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+335685,int_stack+334740, 1.0, int_stack+333795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+694371,int_stack+528735,int_stack+402090, 1.0, int_stack+700104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+231189,int_stack+694371,int_stack+685506, 1.0, int_stack+702372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+694371,int_stack+231189,int_stack+629385, 1.0, int_stack+705900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+339930,int_stack+339615,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+340350,int_stack+339930,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+231189,int_stack+340890,int_stack+340350,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+232809,int_stack+231189,int_stack+629385,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+232809,int_stack+630645,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+341565,int_stack+340890,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+685506,int_stack+629385,int_stack+231189,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+685506,int_stack+232809,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+231189,int_stack+402090,int_stack+528735,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+342831,int_stack+342390,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+343419,int_stack+342831,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+344175,int_stack+343419,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+685506,int_stack+402090,int_stack+461418,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+685506,int_stack+528735,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+345120,int_stack+344175,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+700986,int_stack+528735,int_stack+402090,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+218694,int_stack+700986,int_stack+685506,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+700986,int_stack+218694,int_stack+629385,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+349365,int_stack+349050,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+349785,int_stack+349365,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+218694,int_stack+350325,int_stack+349785,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+220314,int_stack+218694,int_stack+629385,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+220314,int_stack+630645,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+351000,int_stack+350325,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+685506,int_stack+629385,int_stack+218694,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+685506,int_stack+220314,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+218694,int_stack+402090,int_stack+528735,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+352266,int_stack+351825,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+352854,int_stack+352266,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+353610,int_stack+352854,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+685506,int_stack+402090,int_stack+461418,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+685506,int_stack+528735,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+354555,int_stack+353610,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+327450,int_stack+528735,int_stack+402090,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+131229,int_stack+327450,int_stack+685506,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+327450,int_stack+131229,int_stack+629385,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+596007,int_stack+358800,int_stack+358485,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629385,int_stack+359220,int_stack+358800,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+630645,int_stack+629385,int_stack+596007,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+131229,int_stack+359760,int_stack+359220,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+132849,int_stack+131229,int_stack+629385,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+528735,int_stack+132849,int_stack+630645,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+629385,int_stack+360435,int_stack+359760,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+685506,int_stack+629385,int_stack+131229,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+402090,int_stack+685506,int_stack+132849,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+131229,int_stack+402090,int_stack+528735,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+576729,int_stack+361701,int_stack+361260,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+461418,int_stack+362289,int_stack+361701,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+528735,int_stack+461418,int_stack+576729,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+402090,int_stack+363045,int_stack+362289,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+685506,int_stack+402090,int_stack+461418,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+629385,int_stack+685506,int_stack+528735,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+528735,int_stack+363990,int_stack+363045,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+334065,int_stack+528735,int_stack+402090,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+338601,int_stack+334065,int_stack+685506,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+344481,int_stack+338601,int_stack+629385,21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+351096,int_stack+424518,int_stack+387915,315);
     Libderiv->ABCD[11] = int_stack + 351096;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+243684,int_stack+463182,int_stack+442518,315);
     Libderiv->ABCD[10] = int_stack + 243684;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+257859,int_stack+501285,int_stack+488622,315);
     Libderiv->ABCD[9] = int_stack + 257859;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+272034,int_stack+539949,int_stack+519285,315);
     Libderiv->ABCD[8] = int_stack + 272034;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+286209,int_stack+578052,int_stack+565389,315);
     Libderiv->ABCD[7] = int_stack + 286209;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+300384,int_stack+616155,int_stack+603492,315);
     Libderiv->ABCD[6] = int_stack + 300384;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+800904,int_stack+633795,int_stack+370563, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 800904;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+815079,int_stack+674166,int_stack+659235, 0.0, zero_stack, 1.0, int_stack+392640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 815079;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+829254,int_stack+710310,int_stack+689646, 1.0, int_stack+392640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 829254;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+843429,int_stack+732864,int_stack+9324,315);
     Libderiv->ABCD[155] = int_stack + 843429;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+857604,int_stack+18774,int_stack+14049,315);
     Libderiv->ABCD[143] = int_stack + 857604;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+6615,int_stack+25389,int_stack+739479,315);
     Libderiv->ABCD[142] = int_stack + 6615;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+728265,int_stack+32004,int_stack+744204,315);
     Libderiv->ABCD[131] = int_stack + 728265;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+20790,int_stack+38619,int_stack+748929,315);
     Libderiv->ABCD[130] = int_stack + 20790;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+871779,int_stack+45234,int_stack+753654,315);
     Libderiv->ABCD[129] = int_stack + 871779;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+34965,int_stack+51849,int_stack+758379,315);
     Libderiv->ABCD[119] = int_stack + 34965;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+742440,int_stack+58464,int_stack+763104,315);
     Libderiv->ABCD[118] = int_stack + 742440;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+49140,int_stack+65079,int_stack+767829,315);
     Libderiv->ABCD[117] = int_stack + 49140;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+756615,int_stack+71694,int_stack+772554,315);
     Libderiv->ABCD[116] = int_stack + 756615;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+63315,int_stack+78309,int_stack+777279,315);
     Libderiv->ABCD[107] = int_stack + 63315;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+885954,int_stack+84924,int_stack+782004,315);
     Libderiv->ABCD[106] = int_stack + 885954;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+770790,int_stack+91539,int_stack+786729,315);
     Libderiv->ABCD[105] = int_stack + 770790;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+77490,int_stack+98154,int_stack+791454,315);
     Libderiv->ABCD[104] = int_stack + 77490;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+900129,int_stack+104769,int_stack+796179,315);
     Libderiv->ABCD[103] = int_stack + 900129;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+91665,int_stack+111384,int_stack+375288,315);
     Libderiv->ABCD[95] = int_stack + 91665;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+784965,int_stack+431133,int_stack+716925,315);
     Libderiv->ABCD[94] = int_stack + 784965;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+422355,int_stack+475677,int_stack+447243,315);
     Libderiv->ABCD[93] = int_stack + 422355;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+914304,int_stack+493347,int_stack+451968,315);
     Libderiv->ABCD[92] = int_stack + 914304;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+493347,int_stack+546564,int_stack+524010,315);
     Libderiv->ABCD[91] = int_stack + 493347;
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+536610,int_stack+584667,int_stack+322725,315);
     Libderiv->ABCD[90] = int_stack + 536610;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+576729,int_stack+570114,int_stack+608217, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[47] = int_stack + 576729;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+608217,int_stack+553179,int_stack+596952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[46] = int_stack + 608217;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+928479,int_stack+507900,int_stack+559794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[45] = int_stack + 928479;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+550785,int_stack+721650,int_stack+531885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[44] = int_stack + 550785;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+707601,int_stack+117999,int_stack+469797, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+565389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[43] = int_stack + 707601;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+461418,int_stack+622770,int_stack+514515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[42] = int_stack + 461418;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+622392,int_stack+0,int_stack+397365, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+370563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[38] = int_stack + 622392;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+105840,int_stack+411015,int_stack+406290, 0.0, zero_stack, 1.0, int_stack+387915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[35] = int_stack + 105840;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+392640,int_stack+124614,int_stack+417630, 0.0, zero_stack, 1.0, int_stack+442518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[34] = int_stack + 392640;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+406815,int_stack+137109,int_stack+591282, 0.0, zero_stack, 1.0, int_stack+488622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[33] = int_stack + 406815;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+942654,int_stack+149604,int_stack+482292, 0.0, zero_stack, 1.0, int_stack+519285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[32] = int_stack + 942654;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+956829,int_stack+162099,int_stack+456693, 0.0, zero_stack, 1.0, int_stack+565389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[31] = int_stack + 956829;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+447243,int_stack+645135,int_stack+640410, 0.0, zero_stack, 1.0, int_stack+603492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[30] = int_stack + 447243;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+636567,int_stack+663960,int_stack+651750, 0.0, zero_stack, 1.0, int_stack+370563, 1.0, int_stack+659235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[26] = int_stack + 636567;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+663960,int_stack+174594,int_stack+156219, 0.0, zero_stack, 2.0, int_stack+659235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[25] = int_stack + 663960;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+148449,int_stack+187089,int_stack+143724, 1.0, int_stack+387915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[23] = int_stack + 148449;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+375288,int_stack+199584,int_stack+168714, 1.0, int_stack+442518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[22] = int_stack + 375288;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+162624,int_stack+212079,int_stack+181209, 1.0, int_stack+488622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[21] = int_stack + 162624;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+475593,int_stack+224574,int_stack+193704, 1.0, int_stack+519285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[20] = int_stack + 475593;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+507522,int_stack+237069,int_stack+206199, 1.0, int_stack+565389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[19] = int_stack + 507522;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+521697,int_stack+694371,int_stack+680781, 1.0, int_stack+603492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[18] = int_stack + 521697;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+590904,int_stack+700986,int_stack+231189, 1.0, int_stack+370563, 0.0, zero_stack, 1.0, int_stack+689646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[14] = int_stack + 590904;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+223419,int_stack+327450,int_stack+218694, 1.0, int_stack+659235, 1.0, int_stack+689646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[13] = int_stack + 223419;
 /*--- compute (gp|hg) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+176799,int_stack+344481,int_stack+131229, 2.0, int_stack+689646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[12] = int_stack + 176799;

}
