/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hfhf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hf|hf) integrals */

void d12hrr_order_hfhf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[8][8][11] = int_stack + 0;
 Libderiv->deriv_classes[8][8][10] = int_stack + 2025;
 Libderiv->deriv_classes[8][8][9] = int_stack + 4050;
 Libderiv->deriv_classes[8][8][8] = int_stack + 6075;
 Libderiv->deriv_classes[8][8][7] = int_stack + 8100;
 Libderiv->dvrr_classes[8][7] = int_stack + 10125;
 Libderiv->deriv_classes[8][8][6] = int_stack + 11745;
 Libderiv->deriv_classes[8][8][2] = int_stack + 13770;
 Libderiv->deriv_classes[8][8][1] = int_stack + 15795;
 Libderiv->dvrr_classes[7][8] = int_stack + 17820;
 Libderiv->deriv_classes[8][8][0] = int_stack + 19440;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 21465;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 21906;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 22494;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 23250;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 24195;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 24783;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 25567;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 26575;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 27835;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 28591;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 29599;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 30895;
 Libderiv->deriv2_classes[8][5][143] = int_stack + 32515;
 Libderiv->deriv2_classes[8][6][143] = int_stack + 33460;
 Libderiv->deriv2_classes[8][7][143] = int_stack + 34720;
 Libderiv->deriv2_classes[8][8][143] = int_stack + 36340;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 38365;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 38806;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 39394;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 40150;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 41095;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 41683;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 42467;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 43475;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 44735;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 45491;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 46499;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 47795;
 Libderiv->deriv2_classes[8][5][131] = int_stack + 49415;
 Libderiv->deriv2_classes[8][6][131] = int_stack + 50360;
 Libderiv->deriv2_classes[8][7][131] = int_stack + 51620;
 Libderiv->deriv2_classes[8][8][131] = int_stack + 53240;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 55265;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 55706;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 56294;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 57050;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 57995;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 58583;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 59367;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 60375;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 61635;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 62391;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 63399;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 64695;
 Libderiv->deriv2_classes[8][5][130] = int_stack + 66315;
 Libderiv->deriv2_classes[8][6][130] = int_stack + 67260;
 Libderiv->deriv2_classes[8][7][130] = int_stack + 68520;
 Libderiv->deriv2_classes[8][8][130] = int_stack + 70140;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 72165;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 72606;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 73194;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 73950;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 74895;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 75483;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 76267;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 77275;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 78535;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 79291;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 80299;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 81595;
 Libderiv->deriv2_classes[8][5][119] = int_stack + 83215;
 Libderiv->deriv2_classes[8][6][119] = int_stack + 84160;
 Libderiv->deriv2_classes[8][7][119] = int_stack + 85420;
 Libderiv->deriv2_classes[8][8][119] = int_stack + 87040;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 89065;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 89506;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 90094;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 90850;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 91795;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 92383;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 93167;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 94175;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 95435;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 96191;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 97199;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 98495;
 Libderiv->deriv2_classes[8][5][118] = int_stack + 100115;
 Libderiv->deriv2_classes[8][6][118] = int_stack + 101060;
 Libderiv->deriv2_classes[8][7][118] = int_stack + 102320;
 Libderiv->deriv2_classes[8][8][118] = int_stack + 103940;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 105965;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 106406;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 106994;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 107750;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 108695;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 109283;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 110067;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 111075;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 112335;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 113091;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 114099;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 115395;
 Libderiv->deriv2_classes[8][5][117] = int_stack + 117015;
 Libderiv->deriv2_classes[8][6][117] = int_stack + 117960;
 Libderiv->deriv2_classes[8][7][117] = int_stack + 119220;
 Libderiv->deriv2_classes[8][8][117] = int_stack + 120840;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 122865;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 123306;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 123894;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 124650;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 125595;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 126183;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 126967;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 127975;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 129235;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 129991;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 130999;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 132295;
 Libderiv->deriv2_classes[8][5][107] = int_stack + 133915;
 Libderiv->deriv2_classes[8][6][107] = int_stack + 134860;
 Libderiv->deriv2_classes[8][7][107] = int_stack + 136120;
 Libderiv->deriv2_classes[8][8][107] = int_stack + 137740;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 139765;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 140206;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 140794;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 141550;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 142495;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 143083;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 143867;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 144875;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 146135;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 146891;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 147899;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 149195;
 Libderiv->deriv2_classes[8][5][106] = int_stack + 150815;
 Libderiv->deriv2_classes[8][6][106] = int_stack + 151760;
 Libderiv->deriv2_classes[8][7][106] = int_stack + 153020;
 Libderiv->deriv2_classes[8][8][106] = int_stack + 154640;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 156665;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 157106;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 157694;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 158450;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 159395;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 159983;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 160767;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 161775;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 163035;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 163791;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 164799;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 166095;
 Libderiv->deriv2_classes[8][5][105] = int_stack + 167715;
 Libderiv->deriv2_classes[8][6][105] = int_stack + 168660;
 Libderiv->deriv2_classes[8][7][105] = int_stack + 169920;
 Libderiv->deriv2_classes[8][8][105] = int_stack + 171540;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 173565;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 174006;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 174594;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 175350;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 176295;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 176883;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 177667;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 178675;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 179935;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 180691;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 181699;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 182995;
 Libderiv->deriv2_classes[8][5][104] = int_stack + 184615;
 Libderiv->deriv2_classes[8][6][104] = int_stack + 185560;
 Libderiv->deriv2_classes[8][7][104] = int_stack + 186820;
 Libderiv->deriv2_classes[8][8][104] = int_stack + 188440;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 190465;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 190906;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 191494;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 192250;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 193195;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 193783;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 194567;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 195575;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 196835;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 197591;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 198599;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 199895;
 Libderiv->deriv2_classes[8][5][95] = int_stack + 201515;
 Libderiv->deriv2_classes[8][6][95] = int_stack + 202460;
 Libderiv->deriv2_classes[8][7][95] = int_stack + 203720;
 Libderiv->deriv2_classes[8][8][95] = int_stack + 205340;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 207365;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 207806;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 208394;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 209150;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 210095;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 210683;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 211467;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 212475;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 213735;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 214491;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 215499;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 216795;
 Libderiv->deriv2_classes[8][5][94] = int_stack + 218415;
 Libderiv->deriv2_classes[8][6][94] = int_stack + 219360;
 Libderiv->deriv2_classes[8][7][94] = int_stack + 220620;
 Libderiv->deriv2_classes[8][8][94] = int_stack + 222240;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 224265;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 224706;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 225294;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 226050;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 226995;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 227583;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 228367;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 229375;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 230635;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 231391;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 232399;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 233695;
 Libderiv->deriv2_classes[8][5][93] = int_stack + 235315;
 Libderiv->deriv2_classes[8][6][93] = int_stack + 236260;
 Libderiv->deriv2_classes[8][7][93] = int_stack + 237520;
 Libderiv->deriv2_classes[8][8][93] = int_stack + 239140;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 241165;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 241606;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 242194;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 242950;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 243895;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 244483;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 245267;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 246275;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 247535;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 248291;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 249299;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 250595;
 Libderiv->deriv2_classes[8][5][92] = int_stack + 252215;
 Libderiv->deriv2_classes[8][6][92] = int_stack + 253160;
 Libderiv->deriv2_classes[8][7][92] = int_stack + 254420;
 Libderiv->deriv2_classes[8][8][92] = int_stack + 256040;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 258065;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 258506;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 259094;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 259850;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 260795;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 261383;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 262167;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 263175;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 264435;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 265191;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 266199;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 267495;
 Libderiv->deriv2_classes[8][5][91] = int_stack + 269115;
 Libderiv->deriv2_classes[8][6][91] = int_stack + 270060;
 Libderiv->deriv2_classes[8][7][91] = int_stack + 271320;
 Libderiv->deriv2_classes[8][8][91] = int_stack + 272940;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 274965;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 275406;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 275994;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 276750;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 277695;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 278283;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 279067;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 280075;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 281335;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 282091;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 283099;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 284395;
 Libderiv->deriv_classes[8][5][11] = int_stack + 286015;
 Libderiv->deriv2_classes[8][5][83] = int_stack + 286960;
 Libderiv->deriv_classes[8][6][11] = int_stack + 287905;
 Libderiv->deriv2_classes[8][6][83] = int_stack + 289165;
 Libderiv->deriv_classes[8][7][11] = int_stack + 290425;
 Libderiv->deriv2_classes[8][7][83] = int_stack + 292045;
 Libderiv->deriv2_classes[8][8][83] = int_stack + 293665;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 295690;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 296131;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 296719;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 297475;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 298420;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 299008;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 299792;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 300800;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 302060;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 302816;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 303824;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 305120;
 Libderiv->deriv_classes[8][5][10] = int_stack + 306740;
 Libderiv->deriv2_classes[8][5][82] = int_stack + 307685;
 Libderiv->deriv_classes[8][6][10] = int_stack + 308630;
 Libderiv->deriv2_classes[8][6][82] = int_stack + 309890;
 Libderiv->deriv_classes[8][7][10] = int_stack + 311150;
 Libderiv->deriv2_classes[8][7][82] = int_stack + 312770;
 Libderiv->deriv2_classes[8][8][82] = int_stack + 314390;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 316415;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 316856;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 317444;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 318200;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 319145;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 319733;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 320517;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 321525;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 322785;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 323541;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 324549;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 325845;
 Libderiv->deriv_classes[8][5][9] = int_stack + 327465;
 Libderiv->deriv2_classes[8][5][81] = int_stack + 328410;
 Libderiv->deriv_classes[8][6][9] = int_stack + 329355;
 Libderiv->deriv2_classes[8][6][81] = int_stack + 330615;
 Libderiv->deriv_classes[8][7][9] = int_stack + 331875;
 Libderiv->deriv2_classes[8][7][81] = int_stack + 333495;
 Libderiv->deriv2_classes[8][8][81] = int_stack + 335115;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 337140;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 337581;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 338169;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 338925;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 339870;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 340458;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 341242;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 342250;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 343510;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 344266;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 345274;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 346570;
 Libderiv->deriv_classes[8][5][8] = int_stack + 348190;
 Libderiv->deriv2_classes[8][5][80] = int_stack + 349135;
 Libderiv->deriv_classes[8][6][8] = int_stack + 350080;
 Libderiv->deriv2_classes[8][6][80] = int_stack + 351340;
 Libderiv->deriv_classes[8][7][8] = int_stack + 352600;
 Libderiv->deriv2_classes[8][7][80] = int_stack + 354220;
 Libderiv->deriv2_classes[8][8][80] = int_stack + 355840;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 357865;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 358306;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 358894;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 359650;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 360595;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 361183;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 361967;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 362975;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 364235;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 364991;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 365999;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 367295;
 Libderiv->deriv_classes[8][5][7] = int_stack + 368915;
 Libderiv->deriv2_classes[8][5][79] = int_stack + 369860;
 Libderiv->deriv_classes[8][6][7] = int_stack + 370805;
 Libderiv->deriv2_classes[8][6][79] = int_stack + 372065;
 Libderiv->deriv_classes[8][7][7] = int_stack + 373325;
 Libderiv->deriv2_classes[8][7][79] = int_stack + 374945;
 Libderiv->deriv2_classes[8][8][79] = int_stack + 376565;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 378590;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 379031;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 379619;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 380375;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 381320;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 381908;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 382692;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 383700;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 384960;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 385716;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 386724;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 388020;
 Libderiv->dvrr_classes[8][5] = int_stack + 389640;
 Libderiv->deriv_classes[8][5][6] = int_stack + 390585;
 Libderiv->deriv2_classes[8][5][78] = int_stack + 391530;
 Libderiv->dvrr_classes[8][6] = int_stack + 392475;
 Libderiv->deriv_classes[8][6][6] = int_stack + 393735;
 Libderiv->deriv2_classes[8][6][78] = int_stack + 394995;
 Libderiv->deriv_classes[8][7][6] = int_stack + 396255;
 Libderiv->deriv2_classes[8][7][78] = int_stack + 397875;
 Libderiv->deriv2_classes[8][8][78] = int_stack + 399495;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 401520;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 401961;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 402549;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 403305;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 404250;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 404838;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 405622;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 406630;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 407890;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 408646;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 409654;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 410950;
 Libderiv->deriv2_classes[8][5][35] = int_stack + 412570;
 Libderiv->deriv2_classes[8][6][35] = int_stack + 413515;
 Libderiv->deriv2_classes[8][7][35] = int_stack + 414775;
 Libderiv->deriv2_classes[8][8][35] = int_stack + 416395;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 418420;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 418861;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 419449;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 420205;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 421150;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 421738;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 422522;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 423530;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 424790;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 425546;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 426554;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 427850;
 Libderiv->deriv2_classes[8][5][34] = int_stack + 429470;
 Libderiv->deriv2_classes[8][6][34] = int_stack + 430415;
 Libderiv->deriv2_classes[8][7][34] = int_stack + 431675;
 Libderiv->deriv2_classes[8][8][34] = int_stack + 433295;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 435320;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 435761;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 436349;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 437105;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 438050;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 438638;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 439422;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 440430;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 441690;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 442446;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 443454;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 444750;
 Libderiv->deriv2_classes[8][5][33] = int_stack + 446370;
 Libderiv->deriv2_classes[8][6][33] = int_stack + 447315;
 Libderiv->deriv2_classes[8][7][33] = int_stack + 448575;
 Libderiv->deriv2_classes[8][8][33] = int_stack + 450195;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 452220;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 452661;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 453249;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 454005;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 454950;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 455538;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 456322;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 457330;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 458590;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 459346;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 460354;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 461650;
 Libderiv->deriv2_classes[8][5][32] = int_stack + 463270;
 Libderiv->deriv2_classes[8][6][32] = int_stack + 464215;
 Libderiv->deriv2_classes[8][7][32] = int_stack + 465475;
 Libderiv->deriv2_classes[8][8][32] = int_stack + 467095;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 469120;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 469561;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 470149;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 470905;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 471850;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 472438;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 473222;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 474230;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 475490;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 476246;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 477254;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 478550;
 Libderiv->deriv2_classes[8][5][31] = int_stack + 480170;
 Libderiv->deriv2_classes[8][6][31] = int_stack + 481115;
 Libderiv->deriv2_classes[8][7][31] = int_stack + 482375;
 Libderiv->deriv2_classes[8][8][31] = int_stack + 483995;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 486020;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 486461;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 487049;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 487805;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 488750;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 489338;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 490122;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 491130;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 492390;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 493146;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 494154;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 495450;
 Libderiv->deriv_classes[8][5][2] = int_stack + 497070;
 Libderiv->deriv2_classes[8][5][30] = int_stack + 498015;
 Libderiv->deriv_classes[8][6][2] = int_stack + 498960;
 Libderiv->deriv2_classes[8][6][30] = int_stack + 500220;
 Libderiv->deriv_classes[8][7][2] = int_stack + 501480;
 Libderiv->deriv2_classes[8][7][30] = int_stack + 503100;
 Libderiv->deriv2_classes[8][8][30] = int_stack + 504720;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 506745;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 507186;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 507774;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 508530;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 509475;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 510063;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 510847;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 511855;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 513115;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 513871;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 514879;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 516175;
 Libderiv->deriv2_classes[8][5][26] = int_stack + 517795;
 Libderiv->deriv2_classes[8][6][26] = int_stack + 518740;
 Libderiv->deriv2_classes[8][7][26] = int_stack + 520000;
 Libderiv->deriv2_classes[8][8][26] = int_stack + 521620;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 523645;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 524086;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 524674;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 525430;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 526375;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 526963;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 527747;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 528755;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 530015;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 530771;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 531779;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 533075;
 Libderiv->deriv2_classes[8][5][23] = int_stack + 534695;
 Libderiv->deriv2_classes[8][6][23] = int_stack + 535640;
 Libderiv->deriv2_classes[8][7][23] = int_stack + 536900;
 Libderiv->deriv2_classes[8][8][23] = int_stack + 538520;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 540545;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 540986;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 541574;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 542330;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 543275;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 543863;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 544647;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 545655;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 546915;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 547671;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 548679;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 549975;
 Libderiv->deriv2_classes[8][5][22] = int_stack + 551595;
 Libderiv->deriv2_classes[8][6][22] = int_stack + 552540;
 Libderiv->deriv2_classes[8][7][22] = int_stack + 553800;
 Libderiv->deriv2_classes[8][8][22] = int_stack + 555420;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 557445;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 557886;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 558474;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 559230;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 560175;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 560763;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 561547;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 562555;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 563815;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 564571;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 565579;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 566875;
 Libderiv->deriv2_classes[8][5][21] = int_stack + 568495;
 Libderiv->deriv2_classes[8][6][21] = int_stack + 569440;
 Libderiv->deriv2_classes[8][7][21] = int_stack + 570700;
 Libderiv->deriv2_classes[8][8][21] = int_stack + 572320;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 574345;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 574786;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 575374;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 576130;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 577075;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 577663;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 578447;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 579455;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 580715;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 581471;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 582479;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 583775;
 Libderiv->deriv2_classes[8][5][20] = int_stack + 585395;
 Libderiv->deriv2_classes[8][6][20] = int_stack + 586340;
 Libderiv->deriv2_classes[8][7][20] = int_stack + 587600;
 Libderiv->deriv2_classes[8][8][20] = int_stack + 589220;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 591245;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 591686;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 592274;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 593030;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 593975;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 594563;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 595347;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 596355;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 597615;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 598371;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 599379;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 600675;
 Libderiv->deriv2_classes[8][5][19] = int_stack + 602295;
 Libderiv->deriv2_classes[8][6][19] = int_stack + 603240;
 Libderiv->deriv2_classes[8][7][19] = int_stack + 604500;
 Libderiv->deriv2_classes[8][8][19] = int_stack + 606120;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 608145;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 608586;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 609174;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 609930;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 610875;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 611463;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 612247;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 613255;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 614515;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 615271;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 616279;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 617575;
 Libderiv->deriv_classes[8][5][1] = int_stack + 619195;
 Libderiv->deriv2_classes[8][5][18] = int_stack + 620140;
 Libderiv->deriv_classes[8][6][1] = int_stack + 621085;
 Libderiv->deriv2_classes[8][6][18] = int_stack + 622345;
 Libderiv->deriv_classes[8][7][1] = int_stack + 623605;
 Libderiv->deriv2_classes[8][7][18] = int_stack + 625225;
 Libderiv->deriv2_classes[8][8][18] = int_stack + 626845;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 628870;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 629311;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 629899;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 630655;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 631600;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 632188;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 632972;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 633980;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 635240;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 635996;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 637004;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 638300;
 Libderiv->deriv2_classes[8][5][14] = int_stack + 639920;
 Libderiv->deriv2_classes[8][6][14] = int_stack + 640865;
 Libderiv->deriv2_classes[8][7][14] = int_stack + 642125;
 Libderiv->deriv2_classes[8][8][14] = int_stack + 643745;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 645770;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 646211;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 646799;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 647555;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 648500;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 649088;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 649872;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 650880;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 652140;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 652896;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 653904;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 655200;
 Libderiv->deriv2_classes[8][5][13] = int_stack + 656820;
 Libderiv->deriv2_classes[8][6][13] = int_stack + 657765;
 Libderiv->deriv2_classes[8][7][13] = int_stack + 659025;
 Libderiv->deriv2_classes[8][8][13] = int_stack + 660645;
 Libderiv->deriv_classes[5][5][11] = int_stack + 662670;
 Libderiv->deriv_classes[5][6][11] = int_stack + 663111;
 Libderiv->deriv_classes[5][7][11] = int_stack + 663699;
 Libderiv->deriv_classes[5][8][11] = int_stack + 664455;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 665400;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 665841;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 666429;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 667185;
 Libderiv->deriv_classes[6][5][11] = int_stack + 668130;
 Libderiv->deriv_classes[6][6][11] = int_stack + 668718;
 Libderiv->deriv_classes[6][7][11] = int_stack + 669502;
 Libderiv->deriv_classes[6][8][11] = int_stack + 670510;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 671770;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 672358;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 673142;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 674150;
 Libderiv->deriv_classes[7][5][11] = int_stack + 675410;
 Libderiv->deriv_classes[7][6][11] = int_stack + 676166;
 Libderiv->deriv_classes[7][7][11] = int_stack + 677174;
 Libderiv->deriv_classes[7][8][11] = int_stack + 678470;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 680090;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 680846;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 681854;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 683150;
 Libderiv->deriv2_classes[8][5][11] = int_stack + 684770;
 Libderiv->deriv2_classes[8][6][11] = int_stack + 685715;
 Libderiv->deriv2_classes[8][7][11] = int_stack + 686975;
 Libderiv->deriv2_classes[8][8][11] = int_stack + 688595;
 Libderiv->deriv_classes[5][5][10] = int_stack + 690620;
 Libderiv->deriv_classes[5][6][10] = int_stack + 691061;
 Libderiv->deriv_classes[5][7][10] = int_stack + 691649;
 Libderiv->deriv_classes[5][8][10] = int_stack + 692405;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 693350;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 693791;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 694379;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 695135;
 Libderiv->deriv_classes[6][5][10] = int_stack + 696080;
 Libderiv->deriv_classes[6][6][10] = int_stack + 696668;
 Libderiv->deriv_classes[6][7][10] = int_stack + 697452;
 Libderiv->deriv_classes[6][8][10] = int_stack + 698460;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 699720;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 700308;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 701092;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 702100;
 Libderiv->deriv_classes[7][5][10] = int_stack + 703360;
 Libderiv->deriv_classes[7][6][10] = int_stack + 704116;
 Libderiv->deriv_classes[7][7][10] = int_stack + 705124;
 Libderiv->deriv_classes[7][8][10] = int_stack + 706420;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 708040;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 708796;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 709804;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 711100;
 Libderiv->deriv2_classes[8][5][10] = int_stack + 712720;
 Libderiv->deriv2_classes[8][6][10] = int_stack + 713665;
 Libderiv->deriv2_classes[8][7][10] = int_stack + 714925;
 Libderiv->deriv2_classes[8][8][10] = int_stack + 716545;
 Libderiv->deriv_classes[5][5][9] = int_stack + 718570;
 Libderiv->deriv_classes[5][6][9] = int_stack + 719011;
 Libderiv->deriv_classes[5][7][9] = int_stack + 719599;
 Libderiv->deriv_classes[5][8][9] = int_stack + 720355;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 721300;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 721741;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 722329;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 723085;
 Libderiv->deriv_classes[6][5][9] = int_stack + 724030;
 Libderiv->deriv_classes[6][6][9] = int_stack + 724618;
 Libderiv->deriv_classes[6][7][9] = int_stack + 725402;
 Libderiv->deriv_classes[6][8][9] = int_stack + 726410;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 727670;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 728258;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 729042;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 730050;
 Libderiv->deriv_classes[7][5][9] = int_stack + 731310;
 Libderiv->deriv_classes[7][6][9] = int_stack + 732066;
 Libderiv->deriv_classes[7][7][9] = int_stack + 733074;
 Libderiv->deriv_classes[7][8][9] = int_stack + 734370;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 735990;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 736746;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 737754;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 739050;
 Libderiv->deriv2_classes[8][5][9] = int_stack + 740670;
 Libderiv->deriv2_classes[8][6][9] = int_stack + 741615;
 Libderiv->deriv2_classes[8][7][9] = int_stack + 742875;
 Libderiv->deriv2_classes[8][8][9] = int_stack + 744495;
 Libderiv->deriv_classes[5][5][8] = int_stack + 746520;
 Libderiv->deriv_classes[5][6][8] = int_stack + 746961;
 Libderiv->deriv_classes[5][7][8] = int_stack + 747549;
 Libderiv->deriv_classes[5][8][8] = int_stack + 748305;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 749250;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 749691;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 750279;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 751035;
 Libderiv->deriv_classes[6][5][8] = int_stack + 751980;
 Libderiv->deriv_classes[6][6][8] = int_stack + 752568;
 Libderiv->deriv_classes[6][7][8] = int_stack + 753352;
 Libderiv->deriv_classes[6][8][8] = int_stack + 754360;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 755620;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 756208;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 756992;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 758000;
 Libderiv->deriv_classes[7][5][8] = int_stack + 759260;
 Libderiv->deriv_classes[7][6][8] = int_stack + 760016;
 Libderiv->deriv_classes[7][7][8] = int_stack + 761024;
 Libderiv->deriv_classes[7][8][8] = int_stack + 762320;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 763940;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 764696;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 765704;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 767000;
 Libderiv->deriv2_classes[8][5][8] = int_stack + 768620;
 Libderiv->deriv2_classes[8][6][8] = int_stack + 769565;
 Libderiv->deriv2_classes[8][7][8] = int_stack + 770825;
 Libderiv->deriv2_classes[8][8][8] = int_stack + 772445;
 Libderiv->deriv_classes[5][5][7] = int_stack + 774470;
 Libderiv->deriv_classes[5][6][7] = int_stack + 774911;
 Libderiv->deriv_classes[5][7][7] = int_stack + 775499;
 Libderiv->deriv_classes[5][8][7] = int_stack + 776255;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 777200;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 777641;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 778229;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 778985;
 Libderiv->deriv_classes[6][5][7] = int_stack + 779930;
 Libderiv->deriv_classes[6][6][7] = int_stack + 780518;
 Libderiv->deriv_classes[6][7][7] = int_stack + 781302;
 Libderiv->deriv_classes[6][8][7] = int_stack + 782310;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 783570;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 784158;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 784942;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 785950;
 Libderiv->deriv_classes[7][5][7] = int_stack + 787210;
 Libderiv->deriv_classes[7][6][7] = int_stack + 787966;
 Libderiv->deriv_classes[7][7][7] = int_stack + 788974;
 Libderiv->deriv_classes[7][8][7] = int_stack + 790270;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 791890;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 792646;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 793654;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 794950;
 Libderiv->deriv2_classes[8][5][7] = int_stack + 796570;
 Libderiv->deriv2_classes[8][6][7] = int_stack + 797515;
 Libderiv->deriv2_classes[8][7][7] = int_stack + 798775;
 Libderiv->deriv2_classes[8][8][7] = int_stack + 800395;
 Libderiv->deriv_classes[5][5][6] = int_stack + 802420;
 Libderiv->deriv_classes[5][6][6] = int_stack + 802861;
 Libderiv->deriv_classes[5][7][6] = int_stack + 803449;
 Libderiv->deriv_classes[5][8][6] = int_stack + 804205;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 805150;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 805591;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 806179;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 806935;
 Libderiv->deriv_classes[6][5][6] = int_stack + 807880;
 Libderiv->deriv_classes[6][6][6] = int_stack + 808468;
 Libderiv->deriv_classes[6][7][6] = int_stack + 809252;
 Libderiv->deriv_classes[6][8][6] = int_stack + 810260;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 811520;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 812108;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 812892;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 813900;
 Libderiv->dvrr_classes[7][5] = int_stack + 815160;
 Libderiv->deriv_classes[7][5][6] = int_stack + 815916;
 Libderiv->dvrr_classes[7][6] = int_stack + 816672;
 Libderiv->deriv_classes[7][6][6] = int_stack + 817680;
 Libderiv->dvrr_classes[7][7] = int_stack + 818688;
 Libderiv->deriv_classes[7][7][6] = int_stack + 819984;
 Libderiv->deriv_classes[7][8][6] = int_stack + 821280;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 822900;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 823656;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 824664;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 825960;
 Libderiv->deriv_classes[8][5][0] = int_stack + 827580;
 Libderiv->deriv2_classes[8][5][6] = int_stack + 828525;
 Libderiv->deriv_classes[8][6][0] = int_stack + 829470;
 Libderiv->deriv2_classes[8][6][6] = int_stack + 830730;
 Libderiv->deriv_classes[8][7][0] = int_stack + 831990;
 Libderiv->deriv2_classes[8][7][6] = int_stack + 833610;
 Libderiv->deriv2_classes[8][8][6] = int_stack + 835230;
 Libderiv->deriv_classes[5][5][2] = int_stack + 837255;
 Libderiv->deriv_classes[5][6][2] = int_stack + 837696;
 Libderiv->deriv_classes[5][7][2] = int_stack + 838284;
 Libderiv->deriv_classes[5][8][2] = int_stack + 839040;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 839985;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 840426;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 841014;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 841770;
 Libderiv->deriv_classes[6][5][2] = int_stack + 842715;
 Libderiv->deriv_classes[6][6][2] = int_stack + 843303;
 Libderiv->deriv_classes[6][7][2] = int_stack + 844087;
 Libderiv->deriv_classes[6][8][2] = int_stack + 845095;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 846355;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 846943;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 847727;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 848735;
 Libderiv->deriv_classes[7][5][2] = int_stack + 849995;
 Libderiv->deriv_classes[7][6][2] = int_stack + 850751;
 Libderiv->deriv_classes[7][7][2] = int_stack + 851759;
 Libderiv->deriv_classes[7][8][2] = int_stack + 853055;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 854675;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 855431;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 856439;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 857735;
 Libderiv->deriv2_classes[8][5][2] = int_stack + 859355;
 Libderiv->deriv2_classes[8][6][2] = int_stack + 860300;
 Libderiv->deriv2_classes[8][7][2] = int_stack + 861560;
 Libderiv->deriv2_classes[8][8][2] = int_stack + 863180;
 Libderiv->deriv_classes[5][5][1] = int_stack + 865205;
 Libderiv->deriv_classes[5][6][1] = int_stack + 865646;
 Libderiv->deriv_classes[5][7][1] = int_stack + 866234;
 Libderiv->deriv_classes[5][8][1] = int_stack + 866990;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 867935;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 868376;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 868964;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 869720;
 Libderiv->deriv_classes[6][5][1] = int_stack + 870665;
 Libderiv->deriv_classes[6][6][1] = int_stack + 871253;
 Libderiv->deriv_classes[6][7][1] = int_stack + 872037;
 Libderiv->deriv_classes[6][8][1] = int_stack + 873045;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 874305;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 874893;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 875677;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 876685;
 Libderiv->deriv_classes[7][5][1] = int_stack + 877945;
 Libderiv->deriv_classes[7][6][1] = int_stack + 878701;
 Libderiv->deriv_classes[7][7][1] = int_stack + 879709;
 Libderiv->deriv_classes[7][8][1] = int_stack + 881005;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 882625;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 883381;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 884389;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 885685;
 Libderiv->deriv2_classes[8][5][1] = int_stack + 887305;
 Libderiv->deriv2_classes[8][6][1] = int_stack + 888250;
 Libderiv->deriv2_classes[8][7][1] = int_stack + 889510;
 Libderiv->deriv2_classes[8][8][1] = int_stack + 891130;
 Libderiv->dvrr_classes[5][5] = int_stack + 893155;
 Libderiv->dvrr_classes[5][6] = int_stack + 893596;
 Libderiv->dvrr_classes[5][7] = int_stack + 894184;
 Libderiv->dvrr_classes[5][8] = int_stack + 894940;
 Libderiv->deriv_classes[5][5][0] = int_stack + 895885;
 Libderiv->deriv_classes[5][6][0] = int_stack + 896326;
 Libderiv->deriv_classes[5][7][0] = int_stack + 896914;
 Libderiv->deriv_classes[5][8][0] = int_stack + 897670;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 898615;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 899056;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 899644;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 900400;
 Libderiv->dvrr_classes[6][5] = int_stack + 901345;
 Libderiv->dvrr_classes[6][6] = int_stack + 901933;
 Libderiv->dvrr_classes[6][7] = int_stack + 902717;
 Libderiv->dvrr_classes[6][8] = int_stack + 903725;
 Libderiv->deriv_classes[6][5][0] = int_stack + 904985;
 Libderiv->deriv_classes[6][6][0] = int_stack + 905573;
 Libderiv->deriv_classes[6][7][0] = int_stack + 906357;
 Libderiv->deriv_classes[6][8][0] = int_stack + 907365;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 908625;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 909213;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 909997;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 911005;
 Libderiv->deriv_classes[7][5][0] = int_stack + 912265;
 Libderiv->deriv_classes[7][6][0] = int_stack + 913021;
 Libderiv->deriv_classes[7][7][0] = int_stack + 914029;
 Libderiv->deriv_classes[7][8][0] = int_stack + 915325;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 916945;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 917701;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 918709;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 920005;
 Libderiv->deriv2_classes[8][5][0] = int_stack + 921625;
 Libderiv->deriv2_classes[8][6][0] = int_stack + 922570;
 Libderiv->deriv2_classes[8][7][0] = int_stack + 923830;
 Libderiv->deriv2_classes[8][8][0] = int_stack + 925450;
 memset(int_stack,0,7419800);

 Libderiv->dvrr_stack = int_stack + 3998521;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hfhf(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+927475,int_stack+893596,int_stack+893155,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+928798,int_stack+894184,int_stack+893596,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+930562,int_stack+928798,int_stack+927475,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+933208,int_stack+663111,int_stack+662670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893155,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+934531,int_stack+663699,int_stack+663111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893596,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+936295,int_stack+934531,int_stack+933208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+938941,int_stack+664455,int_stack+663699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894184,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+941209,int_stack+938941,int_stack+934531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+928798,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+944737,int_stack+941209,int_stack+936295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930562,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+938941,int_stack+901933,int_stack+901345,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+940705,int_stack+902717,int_stack+901933,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+949147,int_stack+940705,int_stack+938941,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+952675,int_stack+668718,int_stack+668130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901345,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+954439,int_stack+669502,int_stack+668718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901933,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+956791,int_stack+954439,int_stack+952675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+960319,int_stack+670510,int_stack+669502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902717,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+963343,int_stack+960319,int_stack+954439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940705,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+968047,int_stack+963343,int_stack+956791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+973927,int_stack+968047,int_stack+944737,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+960319,int_stack+816672,int_stack+815160,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+962587,int_stack+818688,int_stack+816672,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+987157,int_stack+962587,int_stack+960319,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+965611,int_stack+676166,int_stack+675410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815160,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+991693,int_stack+677174,int_stack+676166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816672,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+994717,int_stack+991693,int_stack+965611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+999253,int_stack+678470,int_stack+677174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818688,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1003141,int_stack+999253,int_stack+991693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962587,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1009189,int_stack+1003141,int_stack+994717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1016749,int_stack+1009189,int_stack+968047,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1034389,int_stack+1016749,int_stack+973927,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+999253,int_stack+392475,int_stack+389640,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1002088,int_stack+10125,int_stack+392475,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1060849,int_stack+1002088,int_stack+999253,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1005868,int_stack+287905,int_stack+286015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389640,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1066519,int_stack+290425,int_stack+287905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392475,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1070299,int_stack+1066519,int_stack+1005868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1075969,int_stack+0,int_stack+290425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1080829,int_stack+1075969,int_stack+1066519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1002088,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1088389,int_stack+1080829,int_stack+1070299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1097839,int_stack+1088389,int_stack+1009189,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1120519,int_stack+1097839,int_stack+1016749,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1075969,int_stack+691061,int_stack+690620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893155, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1077292,int_stack+691649,int_stack+691061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893596, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1079056,int_stack+1077292,int_stack+1075969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1081702,int_stack+692405,int_stack+691649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894184, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1083970,int_stack+1081702,int_stack+1077292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+928798, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1087498,int_stack+1083970,int_stack+1079056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930562, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1081702,int_stack+696668,int_stack+696080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901345, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1083466,int_stack+697452,int_stack+696668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901933, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1091908,int_stack+1083466,int_stack+1081702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1095436,int_stack+698460,int_stack+697452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902717, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1098460,int_stack+1095436,int_stack+1083466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940705, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1103164,int_stack+1098460,int_stack+1091908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1155799,int_stack+1103164,int_stack+1087498,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1095436,int_stack+704116,int_stack+703360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815160, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1097704,int_stack+705124,int_stack+704116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816672, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1109044,int_stack+1097704,int_stack+1095436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1113580,int_stack+706420,int_stack+705124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818688, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1169029,int_stack+1113580,int_stack+1097704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962587, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1175077,int_stack+1169029,int_stack+1109044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1182637,int_stack+1175077,int_stack+1103164,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1200277,int_stack+1182637,int_stack+1155799,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1169029,int_stack+308630,int_stack+306740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389640, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1113580,int_stack+311150,int_stack+308630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392475, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1226737,int_stack+1113580,int_stack+1169029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1232407,int_stack+2025,int_stack+311150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1237267,int_stack+1232407,int_stack+1113580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1002088, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1244827,int_stack+1237267,int_stack+1226737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1254277,int_stack+1244827,int_stack+1175077,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1276957,int_stack+1254277,int_stack+1182637,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1232407,int_stack+719011,int_stack+718570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893155, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1233730,int_stack+719599,int_stack+719011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893596, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235494,int_stack+1233730,int_stack+1232407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1238140,int_stack+720355,int_stack+719599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894184, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1240408,int_stack+1238140,int_stack+1233730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+928798, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1243936,int_stack+1240408,int_stack+1235494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930562, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1238140,int_stack+724618,int_stack+724030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901345, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1239904,int_stack+725402,int_stack+724618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901933, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1248346,int_stack+1239904,int_stack+1238140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1251874,int_stack+726410,int_stack+725402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902717, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1254898,int_stack+1251874,int_stack+1239904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940705, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1259602,int_stack+1254898,int_stack+1248346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1312237,int_stack+1259602,int_stack+1243936,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1251874,int_stack+732066,int_stack+731310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815160, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1254142,int_stack+733074,int_stack+732066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816672, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1265482,int_stack+1254142,int_stack+1251874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1270018,int_stack+734370,int_stack+733074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818688, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1325467,int_stack+1270018,int_stack+1254142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962587, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1331515,int_stack+1325467,int_stack+1265482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1339075,int_stack+1331515,int_stack+1259602,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1356715,int_stack+1339075,int_stack+1312237,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1325467,int_stack+329355,int_stack+327465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389640, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1270018,int_stack+331875,int_stack+329355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392475, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1383175,int_stack+1270018,int_stack+1325467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1388845,int_stack+4050,int_stack+331875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1393705,int_stack+1388845,int_stack+1270018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1002088, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1401265,int_stack+1393705,int_stack+1383175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1410715,int_stack+1401265,int_stack+1331515,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1433395,int_stack+1410715,int_stack+1339075,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1388845,int_stack+746961,int_stack+746520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1390168,int_stack+747549,int_stack+746961, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1391932,int_stack+1390168,int_stack+1388845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1394578,int_stack+748305,int_stack+747549, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1396846,int_stack+1394578,int_stack+1390168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+928798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1400374,int_stack+1396846,int_stack+1391932, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1394578,int_stack+752568,int_stack+751980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1396342,int_stack+753352,int_stack+752568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+901933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1404784,int_stack+1396342,int_stack+1394578, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1408312,int_stack+754360,int_stack+753352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1411336,int_stack+1408312,int_stack+1396342, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1416040,int_stack+1411336,int_stack+1404784, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1468675,int_stack+1416040,int_stack+1400374,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1408312,int_stack+760016,int_stack+759260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1410580,int_stack+761024,int_stack+760016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1421920,int_stack+1410580,int_stack+1408312, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1426456,int_stack+762320,int_stack+761024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+1426456,int_stack+1410580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1481905,int_stack+0,int_stack+1421920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1489465,int_stack+1481905,int_stack+1416040,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1507105,int_stack+1489465,int_stack+1468675,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+350080,int_stack+348190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1426456,int_stack+352600,int_stack+350080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1533565,int_stack+1426456,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1539235,int_stack+6075,int_stack+352600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1544095,int_stack+1539235,int_stack+1426456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1002088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1551655,int_stack+1544095,int_stack+1533565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1561105,int_stack+1551655,int_stack+1481905,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1583785,int_stack+1561105,int_stack+1489465,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1539235,int_stack+774911,int_stack+774470, 0.0, zero_stack, 1.0, int_stack+893155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1540558,int_stack+775499,int_stack+774911, 0.0, zero_stack, 1.0, int_stack+893596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1542322,int_stack+1540558,int_stack+1539235, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1544968,int_stack+776255,int_stack+775499, 0.0, zero_stack, 1.0, int_stack+894184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1547236,int_stack+1544968,int_stack+1540558, 0.0, zero_stack, 1.0, int_stack+928798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1550764,int_stack+1547236,int_stack+1542322, 0.0, zero_stack, 1.0, int_stack+930562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1544968,int_stack+780518,int_stack+779930, 0.0, zero_stack, 1.0, int_stack+901345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1546732,int_stack+781302,int_stack+780518, 0.0, zero_stack, 1.0, int_stack+901933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1555174,int_stack+1546732,int_stack+1544968, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1558702,int_stack+782310,int_stack+781302, 0.0, zero_stack, 1.0, int_stack+902717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1561726,int_stack+1558702,int_stack+1546732, 0.0, zero_stack, 1.0, int_stack+940705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1566430,int_stack+1561726,int_stack+1555174, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1619065,int_stack+1566430,int_stack+1550764,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1558702,int_stack+787966,int_stack+787210, 0.0, zero_stack, 1.0, int_stack+815160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1560970,int_stack+788974,int_stack+787966, 0.0, zero_stack, 1.0, int_stack+816672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1572310,int_stack+1560970,int_stack+1558702, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1576846,int_stack+790270,int_stack+788974, 0.0, zero_stack, 1.0, int_stack+818688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1632295,int_stack+1576846,int_stack+1560970, 0.0, zero_stack, 1.0, int_stack+962587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1638343,int_stack+1632295,int_stack+1572310, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1645903,int_stack+1638343,int_stack+1566430,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1663543,int_stack+1645903,int_stack+1619065,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1632295,int_stack+370805,int_stack+368915, 0.0, zero_stack, 1.0, int_stack+389640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1576846,int_stack+373325,int_stack+370805, 0.0, zero_stack, 1.0, int_stack+392475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1690003,int_stack+1576846,int_stack+1632295, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2835,int_stack+8100,int_stack+373325, 0.0, zero_stack, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1695673,int_stack+2835,int_stack+1576846, 0.0, zero_stack, 1.0, int_stack+1002088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1703233,int_stack+1695673,int_stack+1690003, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1712683,int_stack+1703233,int_stack+1638343,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1735363,int_stack+1712683,int_stack+1645903,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1695673,int_stack+802861,int_stack+802420, 1.0, int_stack+893155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1696996,int_stack+803449,int_stack+802861, 1.0, int_stack+893596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1698760,int_stack+1696996,int_stack+1695673, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1701406,int_stack+804205,int_stack+803449, 1.0, int_stack+894184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1703674,int_stack+1701406,int_stack+1696996, 1.0, int_stack+928798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1707202,int_stack+1703674,int_stack+1698760, 1.0, int_stack+930562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1701406,int_stack+808468,int_stack+807880, 1.0, int_stack+901345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1703170,int_stack+809252,int_stack+808468, 1.0, int_stack+901933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1711612,int_stack+1703170,int_stack+1701406, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1715140,int_stack+810260,int_stack+809252, 1.0, int_stack+902717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1718164,int_stack+1715140,int_stack+1703170, 1.0, int_stack+940705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1722868,int_stack+1718164,int_stack+1711612, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1770643,int_stack+1722868,int_stack+1707202,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1715140,int_stack+817680,int_stack+815916, 1.0, int_stack+815160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1717408,int_stack+819984,int_stack+817680, 1.0, int_stack+816672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1728748,int_stack+1717408,int_stack+1715140, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2835,int_stack+821280,int_stack+819984, 1.0, int_stack+818688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1783873,int_stack+2835,int_stack+1717408, 1.0, int_stack+962587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1789921,int_stack+1783873,int_stack+1728748, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1797481,int_stack+1789921,int_stack+1722868,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1815121,int_stack+1797481,int_stack+1770643,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1783873,int_stack+393735,int_stack+390585, 1.0, int_stack+389640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2835,int_stack+396255,int_stack+393735, 1.0, int_stack+392475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+2835,int_stack+1783873, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1847251,int_stack+11745,int_stack+396255, 1.0, int_stack+10125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1852111,int_stack+1847251,int_stack+2835, 1.0, int_stack+1002088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1859671,int_stack+1852111,int_stack+1841581, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1869121,int_stack+1859671,int_stack+1789921,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1891801,int_stack+1869121,int_stack+1797481,210);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+960319,int_stack+894940,int_stack+894184,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1060849,int_stack+960319,int_stack+928798,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1847251,int_stack+1060849,int_stack+930562,21);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1060849,int_stack+903725,int_stack+902717,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1851661,int_stack+1060849,int_stack+940705,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1856365,int_stack+1851661,int_stack+949147,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1862245,int_stack+1856365,int_stack+1847251,210);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1851661,int_stack+17820,int_stack+818688,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1875475,int_stack+1851661,int_stack+962587,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1881523,int_stack+1875475,int_stack+987157,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1881523,int_stack+1856365,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1944721,int_stack+1927081,int_stack+1862245,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+987157,int_stack+837696,int_stack+837255,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+988480,int_stack+838284,int_stack+837696,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1875475,int_stack+988480,int_stack+987157,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1878121,int_stack+839040,int_stack+838284,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+949147,int_stack+1878121,int_stack+988480,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1851661,int_stack+949147,int_stack+1875475,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+843303,int_stack+842715,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1878121,int_stack+844087,int_stack+843303,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1060849,int_stack+1878121,int_stack+949147,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+960319,int_stack+845095,int_stack+844087,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+999253,int_stack+960319,int_stack+1878121,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6615,int_stack+999253,int_stack+1060849,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1971181,int_stack+6615,int_stack+1851661, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+999253,int_stack+850751,int_stack+849995,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1001521,int_stack+851759,int_stack+850751,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+960319,int_stack+1001521,int_stack+999253,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+938941,int_stack+853055,int_stack+851759,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+938941,int_stack+1001521,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1990459,int_stack+1984411,int_stack+960319,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1998019,int_stack+1990459,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2015659,int_stack+1998019,int_stack+1971181, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1862245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1984411,int_stack+498960,int_stack+497070,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+938941,int_stack+501480,int_stack+498960,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+927475,int_stack+938941,int_stack+1984411,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2042119,int_stack+13770,int_stack+501480,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2046979,int_stack+2042119,int_stack+938941,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2054539,int_stack+2046979,int_stack+927475,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2063989,int_stack+2054539,int_stack+1990459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1881523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2086669,int_stack+2063989,int_stack+1998019, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1004545,int_stack+865646,int_stack+865205,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+950911,int_stack+866234,int_stack+865646,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2042119,int_stack+950911,int_stack+1004545,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2044765,int_stack+866990,int_stack+866234,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2047033,int_stack+2044765,int_stack+950911,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2050561,int_stack+2047033,int_stack+2042119,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2044765,int_stack+871253,int_stack+870665,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2046529,int_stack+872037,int_stack+871253,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2054971,int_stack+2046529,int_stack+2044765,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2058499,int_stack+873045,int_stack+872037,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2061523,int_stack+2058499,int_stack+2046529,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2066227,int_stack+2061523,int_stack+2054971,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2072107,int_stack+2066227,int_stack+2050561, 0.0, zero_stack, 1.0, int_stack+1847251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2058499,int_stack+878701,int_stack+877945,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2060767,int_stack+879709,int_stack+878701,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2121949,int_stack+2060767,int_stack+2058499,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2126485,int_stack+881005,int_stack+879709,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2130373,int_stack+2126485,int_stack+2060767,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2136421,int_stack+2130373,int_stack+2121949,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2143981,int_stack+2136421,int_stack+2066227, 0.0, zero_stack, 1.0, int_stack+1856365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2161621,int_stack+2143981,int_stack+2072107, 0.0, zero_stack, 1.0, int_stack+1862245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2126485,int_stack+621085,int_stack+619195,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2129320,int_stack+623605,int_stack+621085,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+2129320,int_stack+2126485,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2193751,int_stack+15795,int_stack+623605,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2198611,int_stack+2193751,int_stack+2129320,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2206171,int_stack+2198611,int_stack+2188081,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2215621,int_stack+2206171,int_stack+2136421, 0.0, zero_stack, 1.0, int_stack+1881523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2238301,int_stack+2215621,int_stack+2143981, 0.0, zero_stack, 1.0, int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2193751,int_stack+896326,int_stack+895885,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2195074,int_stack+896914,int_stack+896326,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2196838,int_stack+2195074,int_stack+2193751,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2199484,int_stack+897670,int_stack+896914,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2201752,int_stack+2199484,int_stack+2195074,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2205280,int_stack+2201752,int_stack+2196838,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2199484,int_stack+905573,int_stack+904985,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2201248,int_stack+906357,int_stack+905573,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2209690,int_stack+2201248,int_stack+2199484,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2213218,int_stack+907365,int_stack+906357,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2216242,int_stack+2213218,int_stack+2201248,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2220946,int_stack+2216242,int_stack+2209690,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2273581,int_stack+2220946,int_stack+2205280, 1.0, int_stack+1847251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1847251,int_stack+913021,int_stack+912265,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2213218,int_stack+914029,int_stack+913021,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2216242,int_stack+2213218,int_stack+1847251,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2226826,int_stack+915325,int_stack+914029,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2230714,int_stack+2226826,int_stack+2213218,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2286811,int_stack+2230714,int_stack+2216242,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2294371,int_stack+2286811,int_stack+2220946, 1.0, int_stack+1856365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2312011,int_stack+2294371,int_stack+2273581, 1.0, int_stack+1862245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2226826,int_stack+829470,int_stack+827580,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2229661,int_stack+831990,int_stack+829470,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1856071,int_stack+2229661,int_stack+2226826,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+19440,int_stack+831990,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1861741,int_stack+2233441,int_stack+2229661,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2338471,int_stack+1861741,int_stack+1856071,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2347921,int_stack+2338471,int_stack+2286811, 1.0, int_stack+1881523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2370601,int_stack+2347921,int_stack+2294371, 1.0, int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+21906,int_stack+21465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+662670,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+22494,int_stack+21906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+663111,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+933208,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+23250,int_stack+22494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+663699,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+934531,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+936295,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+24783,int_stack+24195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+668130,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+25567,int_stack+24783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+668718,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+952675,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+26575,int_stack+25567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+669502,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+954439,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+956791,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+28591,int_stack+27835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+675410,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+29599,int_stack+28591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+676166,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+965611,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+30895,int_stack+29599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+677174,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+991693,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+994717,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2405881,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+33460,int_stack+32515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+286015,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+34720,int_stack+33460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+287905,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1005868,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+36340,int_stack+34720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+290425,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1066519,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1070299,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2432341,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+38806,int_stack+38365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+662670, 1.0, int_stack+690620,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+39394,int_stack+38806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663111, 1.0, int_stack+691061,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+933208, 1.0, int_stack+1075969,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+40150,int_stack+39394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663699, 1.0, int_stack+691649,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934531, 1.0, int_stack+1077292,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+936295, 1.0, int_stack+1079056,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+41683,int_stack+41095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668130, 1.0, int_stack+696080,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+42467,int_stack+41683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668718, 1.0, int_stack+696668,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952675, 1.0, int_stack+1081702,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+43475,int_stack+42467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669502, 1.0, int_stack+697452,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+954439, 1.0, int_stack+1083466,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+956791, 1.0, int_stack+1091908,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+45491,int_stack+44735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675410, 1.0, int_stack+703360,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+46499,int_stack+45491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676166, 1.0, int_stack+704116,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+965611, 1.0, int_stack+1095436,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+47795,int_stack+46499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677174, 1.0, int_stack+705124,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+991693, 1.0, int_stack+1097704,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994717, 1.0, int_stack+1109044,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+12495,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+50360,int_stack+49415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286015, 1.0, int_stack+306740,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+51620,int_stack+50360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287905, 1.0, int_stack+308630,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1005868, 1.0, int_stack+1169029,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+53240,int_stack+51620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290425, 1.0, int_stack+311150,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1066519, 1.0, int_stack+1113580,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070299, 1.0, int_stack+1226737,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2467621,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+55706,int_stack+55265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+690620, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+56294,int_stack+55706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+691061, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1075969, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+57050,int_stack+56294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+691649, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1077292, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1079056, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+58583,int_stack+57995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+696080, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+59367,int_stack+58583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+696668, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1081702, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+60375,int_stack+59367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+697452, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1083466, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1091908, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+62391,int_stack+61635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+703360, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+63399,int_stack+62391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+704116, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1095436, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+64695,int_stack+63399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+705124, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1097704, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1109044, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+38955,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+67260,int_stack+66315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+306740, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+68520,int_stack+67260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+308630, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1169029, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+70140,int_stack+68520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+311150, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1113580, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1226737, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2502901,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+72606,int_stack+72165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+662670, 0.0, zero_stack, 1.0, int_stack+718570,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+73194,int_stack+72606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663111, 0.0, zero_stack, 1.0, int_stack+719011,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+933208, 0.0, zero_stack, 1.0, int_stack+1232407,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+73950,int_stack+73194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663699, 0.0, zero_stack, 1.0, int_stack+719599,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934531, 0.0, zero_stack, 1.0, int_stack+1233730,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+936295, 0.0, zero_stack, 1.0, int_stack+1235494,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+75483,int_stack+74895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668130, 0.0, zero_stack, 1.0, int_stack+724030,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+76267,int_stack+75483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668718, 0.0, zero_stack, 1.0, int_stack+724618,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952675, 0.0, zero_stack, 1.0, int_stack+1238140,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+77275,int_stack+76267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669502, 0.0, zero_stack, 1.0, int_stack+725402,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+954439, 0.0, zero_stack, 1.0, int_stack+1239904,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+956791, 0.0, zero_stack, 1.0, int_stack+1248346,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+79291,int_stack+78535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675410, 0.0, zero_stack, 1.0, int_stack+731310,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+80299,int_stack+79291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676166, 0.0, zero_stack, 1.0, int_stack+732066,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+965611, 0.0, zero_stack, 1.0, int_stack+1251874,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+81595,int_stack+80299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677174, 0.0, zero_stack, 1.0, int_stack+733074,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+991693, 0.0, zero_stack, 1.0, int_stack+1254142,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994717, 0.0, zero_stack, 1.0, int_stack+1265482,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2538181,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+84160,int_stack+83215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286015, 0.0, zero_stack, 1.0, int_stack+327465,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+85420,int_stack+84160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287905, 0.0, zero_stack, 1.0, int_stack+329355,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1005868, 0.0, zero_stack, 1.0, int_stack+1325467,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+87040,int_stack+85420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290425, 0.0, zero_stack, 1.0, int_stack+331875,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1066519, 0.0, zero_stack, 1.0, int_stack+1270018,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070299, 0.0, zero_stack, 1.0, int_stack+1383175,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2564641,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+89506,int_stack+89065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690620, 1.0, int_stack+718570, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+90094,int_stack+89506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691061, 1.0, int_stack+719011, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1075969, 1.0, int_stack+1232407, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+90850,int_stack+90094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691649, 1.0, int_stack+719599, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1077292, 1.0, int_stack+1233730, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1079056, 1.0, int_stack+1235494, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+92383,int_stack+91795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696080, 1.0, int_stack+724030, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+93167,int_stack+92383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696668, 1.0, int_stack+724618, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1081702, 1.0, int_stack+1238140, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+94175,int_stack+93167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697452, 1.0, int_stack+725402, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1083466, 1.0, int_stack+1239904, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1091908, 1.0, int_stack+1248346, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+96191,int_stack+95435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703360, 1.0, int_stack+731310, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+97199,int_stack+96191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704116, 1.0, int_stack+732066, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095436, 1.0, int_stack+1251874, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+98495,int_stack+97199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705124, 1.0, int_stack+733074, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097704, 1.0, int_stack+1254142, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1109044, 1.0, int_stack+1265482, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+65415,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+101060,int_stack+100115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+306740, 1.0, int_stack+327465, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+102320,int_stack+101060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308630, 1.0, int_stack+329355, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1169029, 1.0, int_stack+1325467, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+103940,int_stack+102320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311150, 1.0, int_stack+331875, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1113580, 1.0, int_stack+1270018, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226737, 1.0, int_stack+1383175, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2599921,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+106406,int_stack+105965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+718570, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+106994,int_stack+106406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+719011, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1232407, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+107750,int_stack+106994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+719599, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1233730, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1235494, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+109283,int_stack+108695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+724030, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+110067,int_stack+109283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+724618, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1238140, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+111075,int_stack+110067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+725402, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1239904, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1248346, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+113091,int_stack+112335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+731310, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+114099,int_stack+113091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+732066, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1251874, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+115395,int_stack+114099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+733074, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1254142, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1265482, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2635201,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+117960,int_stack+117015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+327465, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+119220,int_stack+117960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+329355, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1325467, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+120840,int_stack+119220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+331875, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1270018, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1383175, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2661661,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+123306,int_stack+122865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+662670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+746520,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+123894,int_stack+123306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663111, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+746961,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+933208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1388845,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+124650,int_stack+123894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663699, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+747549,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934531, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390168,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+936295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1391932,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+126183,int_stack+125595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751980,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+126967,int_stack+126183, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668718, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+752568,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952675, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1394578,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+127975,int_stack+126967, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669502, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+753352,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+954439, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1396342,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+956791, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1404784,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+129991,int_stack+129235, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+759260,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+130999,int_stack+129991, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676166, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760016,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+965611, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1408312,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+132295,int_stack+130999, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+761024,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+991693, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1410580,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994717, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1421920,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+91875,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+134860,int_stack+133915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348190,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+136120,int_stack+134860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350080,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1005868, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+137740,int_stack+136120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352600,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1066519, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1426456,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070299, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1533565,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2696941,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+140206,int_stack+139765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690620, 0.0, zero_stack, 1.0, int_stack+746520, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+140794,int_stack+140206, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691061, 0.0, zero_stack, 1.0, int_stack+746961, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1075969, 0.0, zero_stack, 1.0, int_stack+1388845, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+141550,int_stack+140794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+691649, 0.0, zero_stack, 1.0, int_stack+747549, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1077292, 0.0, zero_stack, 1.0, int_stack+1390168, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1079056, 0.0, zero_stack, 1.0, int_stack+1391932, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+143083,int_stack+142495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696080, 0.0, zero_stack, 1.0, int_stack+751980, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+143867,int_stack+143083, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696668, 0.0, zero_stack, 1.0, int_stack+752568, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1081702, 0.0, zero_stack, 1.0, int_stack+1394578, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+144875,int_stack+143867, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697452, 0.0, zero_stack, 1.0, int_stack+753352, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1083466, 0.0, zero_stack, 1.0, int_stack+1396342, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1091908, 0.0, zero_stack, 1.0, int_stack+1404784, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+146891,int_stack+146135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703360, 0.0, zero_stack, 1.0, int_stack+759260, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+147899,int_stack+146891, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704116, 0.0, zero_stack, 1.0, int_stack+760016, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095436, 0.0, zero_stack, 1.0, int_stack+1408312, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+149195,int_stack+147899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705124, 0.0, zero_stack, 1.0, int_stack+761024, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097704, 0.0, zero_stack, 1.0, int_stack+1410580, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1109044, 0.0, zero_stack, 1.0, int_stack+1421920, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+118335,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+151760,int_stack+150815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+306740, 0.0, zero_stack, 1.0, int_stack+348190, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+153020,int_stack+151760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308630, 0.0, zero_stack, 1.0, int_stack+350080, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1169029, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+154640,int_stack+153020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311150, 0.0, zero_stack, 1.0, int_stack+352600, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1113580, 0.0, zero_stack, 1.0, int_stack+1426456, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226737, 0.0, zero_stack, 1.0, int_stack+1533565, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2732221,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+157106,int_stack+156665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718570, 1.0, int_stack+746520, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+157694,int_stack+157106, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719011, 1.0, int_stack+746961, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232407, 1.0, int_stack+1388845, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+158450,int_stack+157694, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719599, 1.0, int_stack+747549, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233730, 1.0, int_stack+1390168, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1235494, 1.0, int_stack+1391932, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+159983,int_stack+159395, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+724030, 1.0, int_stack+751980, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+160767,int_stack+159983, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+724618, 1.0, int_stack+752568, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1238140, 1.0, int_stack+1394578, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+161775,int_stack+160767, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725402, 1.0, int_stack+753352, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1239904, 1.0, int_stack+1396342, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1248346, 1.0, int_stack+1404784, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+163791,int_stack+163035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731310, 1.0, int_stack+759260, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+164799,int_stack+163791, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+732066, 1.0, int_stack+760016, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1251874, 1.0, int_stack+1408312, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+166095,int_stack+164799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+733074, 1.0, int_stack+761024, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1254142, 1.0, int_stack+1410580, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1265482, 1.0, int_stack+1421920, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2767501,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+168660,int_stack+167715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327465, 1.0, int_stack+348190, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+169920,int_stack+168660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329355, 1.0, int_stack+350080, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1325467, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+171540,int_stack+169920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331875, 1.0, int_stack+352600, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1270018, 1.0, int_stack+1426456, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1383175, 1.0, int_stack+1533565, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2793961,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+174006,int_stack+173565, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+746520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+174594,int_stack+174006, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+746961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1388845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+175350,int_stack+174594, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+747549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1390168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1391932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+176883,int_stack+176295, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+751980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+177667,int_stack+176883, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+752568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1394578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+178675,int_stack+177667, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+753352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1396342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1404784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+180691,int_stack+179935, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+759260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+181699,int_stack+180691, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+760016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1408312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+182995,int_stack+181699, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+761024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1410580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1421920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+144795,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+185560,int_stack+184615, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+348190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+186820,int_stack+185560, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+350080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+188440,int_stack+186820, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+352600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1426456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1533565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2829241,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+190906,int_stack+190465, 0.0, zero_stack, 1.0, int_stack+662670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774470,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+191494,int_stack+190906, 0.0, zero_stack, 1.0, int_stack+663111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774911,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+933208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1539235,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+192250,int_stack+191494, 0.0, zero_stack, 1.0, int_stack+663699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775499,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 1.0, int_stack+934531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1540558,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 1.0, int_stack+936295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1542322,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+193783,int_stack+193195, 0.0, zero_stack, 1.0, int_stack+668130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779930,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+194567,int_stack+193783, 0.0, zero_stack, 1.0, int_stack+668718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780518,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+952675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1544968,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+195575,int_stack+194567, 0.0, zero_stack, 1.0, int_stack+669502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781302,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 1.0, int_stack+954439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1546732,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 1.0, int_stack+956791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1555174,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+197591,int_stack+196835, 0.0, zero_stack, 1.0, int_stack+675410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+787210,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+198599,int_stack+197591, 0.0, zero_stack, 1.0, int_stack+676166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+787966,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+965611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1558702,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+199895,int_stack+198599, 0.0, zero_stack, 1.0, int_stack+677174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788974,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+991693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1560970,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 1.0, int_stack+994717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1572310,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+171255,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+202460,int_stack+201515, 0.0, zero_stack, 1.0, int_stack+286015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368915,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+203720,int_stack+202460, 0.0, zero_stack, 1.0, int_stack+287905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370805,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+1005868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1632295,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+205340,int_stack+203720, 0.0, zero_stack, 1.0, int_stack+290425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373325,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 1.0, int_stack+1066519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1576846,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 1.0, int_stack+1070299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1690003,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2864521,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+207806,int_stack+207365, 0.0, zero_stack, 1.0, int_stack+690620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774470, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+208394,int_stack+207806, 0.0, zero_stack, 1.0, int_stack+691061, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+774911, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1075969, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1539235, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+209150,int_stack+208394, 0.0, zero_stack, 1.0, int_stack+691649, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775499, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 1.0, int_stack+1077292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1540558, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 1.0, int_stack+1079056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1542322, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+210683,int_stack+210095, 0.0, zero_stack, 1.0, int_stack+696080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779930, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+211467,int_stack+210683, 0.0, zero_stack, 1.0, int_stack+696668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780518, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1081702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1544968, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+212475,int_stack+211467, 0.0, zero_stack, 1.0, int_stack+697452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781302, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 1.0, int_stack+1083466, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1546732, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 1.0, int_stack+1091908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1555174, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+214491,int_stack+213735, 0.0, zero_stack, 1.0, int_stack+703360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+787210, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+215499,int_stack+214491, 0.0, zero_stack, 1.0, int_stack+704116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+787966, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+1095436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1558702, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+216795,int_stack+215499, 0.0, zero_stack, 1.0, int_stack+705124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788974, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1097704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1560970, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 1.0, int_stack+1109044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1572310, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2899801,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+219360,int_stack+218415, 0.0, zero_stack, 1.0, int_stack+306740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368915, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+220620,int_stack+219360, 0.0, zero_stack, 1.0, int_stack+308630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370805, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+1169029, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1632295, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+222240,int_stack+220620, 0.0, zero_stack, 1.0, int_stack+311150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373325, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 1.0, int_stack+1113580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1576846, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 1.0, int_stack+1226737, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1690003, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2926261,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+224706,int_stack+224265, 0.0, zero_stack, 1.0, int_stack+718570, 0.0, zero_stack, 1.0, int_stack+774470, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+225294,int_stack+224706, 0.0, zero_stack, 1.0, int_stack+719011, 0.0, zero_stack, 1.0, int_stack+774911, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1232407, 0.0, zero_stack, 1.0, int_stack+1539235, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+226050,int_stack+225294, 0.0, zero_stack, 1.0, int_stack+719599, 0.0, zero_stack, 1.0, int_stack+775499, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 1.0, int_stack+1233730, 0.0, zero_stack, 1.0, int_stack+1540558, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 1.0, int_stack+1235494, 0.0, zero_stack, 1.0, int_stack+1542322, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+227583,int_stack+226995, 0.0, zero_stack, 1.0, int_stack+724030, 0.0, zero_stack, 1.0, int_stack+779930, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+228367,int_stack+227583, 0.0, zero_stack, 1.0, int_stack+724618, 0.0, zero_stack, 1.0, int_stack+780518, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1238140, 0.0, zero_stack, 1.0, int_stack+1544968, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+229375,int_stack+228367, 0.0, zero_stack, 1.0, int_stack+725402, 0.0, zero_stack, 1.0, int_stack+781302, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 1.0, int_stack+1239904, 0.0, zero_stack, 1.0, int_stack+1546732, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 1.0, int_stack+1248346, 0.0, zero_stack, 1.0, int_stack+1555174, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+231391,int_stack+230635, 0.0, zero_stack, 1.0, int_stack+731310, 0.0, zero_stack, 1.0, int_stack+787210, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+232399,int_stack+231391, 0.0, zero_stack, 1.0, int_stack+732066, 0.0, zero_stack, 1.0, int_stack+787966, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+1251874, 0.0, zero_stack, 1.0, int_stack+1558702, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+233695,int_stack+232399, 0.0, zero_stack, 1.0, int_stack+733074, 0.0, zero_stack, 1.0, int_stack+788974, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1254142, 0.0, zero_stack, 1.0, int_stack+1560970, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 1.0, int_stack+1265482, 0.0, zero_stack, 1.0, int_stack+1572310, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+197715,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+236260,int_stack+235315, 0.0, zero_stack, 1.0, int_stack+327465, 0.0, zero_stack, 1.0, int_stack+368915, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+237520,int_stack+236260, 0.0, zero_stack, 1.0, int_stack+329355, 0.0, zero_stack, 1.0, int_stack+370805, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+1325467, 0.0, zero_stack, 1.0, int_stack+1632295, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+239140,int_stack+237520, 0.0, zero_stack, 1.0, int_stack+331875, 0.0, zero_stack, 1.0, int_stack+373325, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 1.0, int_stack+1270018, 0.0, zero_stack, 1.0, int_stack+1576846, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 1.0, int_stack+1383175, 0.0, zero_stack, 1.0, int_stack+1690003, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2961541,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+241606,int_stack+241165, 0.0, zero_stack, 1.0, int_stack+746520, 1.0, int_stack+774470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+242194,int_stack+241606, 0.0, zero_stack, 1.0, int_stack+746961, 1.0, int_stack+774911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1388845, 1.0, int_stack+1539235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+242950,int_stack+242194, 0.0, zero_stack, 1.0, int_stack+747549, 1.0, int_stack+775499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 1.0, int_stack+1390168, 1.0, int_stack+1540558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 1.0, int_stack+1391932, 1.0, int_stack+1542322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+244483,int_stack+243895, 0.0, zero_stack, 1.0, int_stack+751980, 1.0, int_stack+779930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+245267,int_stack+244483, 0.0, zero_stack, 1.0, int_stack+752568, 1.0, int_stack+780518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1394578, 1.0, int_stack+1544968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+246275,int_stack+245267, 0.0, zero_stack, 1.0, int_stack+753352, 1.0, int_stack+781302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 1.0, int_stack+1396342, 1.0, int_stack+1546732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 1.0, int_stack+1404784, 1.0, int_stack+1555174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+248291,int_stack+247535, 0.0, zero_stack, 1.0, int_stack+759260, 1.0, int_stack+787210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+249299,int_stack+248291, 0.0, zero_stack, 1.0, int_stack+760016, 1.0, int_stack+787966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+1408312, 1.0, int_stack+1558702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+250595,int_stack+249299, 0.0, zero_stack, 1.0, int_stack+761024, 1.0, int_stack+788974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1410580, 1.0, int_stack+1560970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 1.0, int_stack+1421920, 1.0, int_stack+1572310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+224175,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+253160,int_stack+252215, 0.0, zero_stack, 1.0, int_stack+348190, 1.0, int_stack+368915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+254420,int_stack+253160, 0.0, zero_stack, 1.0, int_stack+350080, 1.0, int_stack+370805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+1632295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+256040,int_stack+254420, 0.0, zero_stack, 1.0, int_stack+352600, 1.0, int_stack+373325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 1.0, int_stack+1426456, 1.0, int_stack+1576846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 1.0, int_stack+1533565, 1.0, int_stack+1690003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2996821,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+258506,int_stack+258065, 0.0, zero_stack, 2.0, int_stack+774470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+259094,int_stack+258506, 0.0, zero_stack, 2.0, int_stack+774911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 2.0, int_stack+1539235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+259850,int_stack+259094, 0.0, zero_stack, 2.0, int_stack+775499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 2.0, int_stack+1540558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 2.0, int_stack+1542322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+261383,int_stack+260795, 0.0, zero_stack, 2.0, int_stack+779930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+262167,int_stack+261383, 0.0, zero_stack, 2.0, int_stack+780518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 2.0, int_stack+1544968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+263175,int_stack+262167, 0.0, zero_stack, 2.0, int_stack+781302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 2.0, int_stack+1546732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 0.0, zero_stack, 2.0, int_stack+1555174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+265191,int_stack+264435, 0.0, zero_stack, 2.0, int_stack+787210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+266199,int_stack+265191, 0.0, zero_stack, 2.0, int_stack+787966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+2338471, 0.0, zero_stack, 2.0, int_stack+1558702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+267495,int_stack+266199, 0.0, zero_stack, 2.0, int_stack+788974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1934641,int_stack+2338471,int_stack+1927081, 0.0, zero_stack, 2.0, int_stack+1560970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2362285,int_stack+1934641,int_stack+1930105, 0.0, zero_stack, 2.0, int_stack+1572310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+2362285,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3032101,int_stack+1927081,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+270060,int_stack+269115, 0.0, zero_stack, 2.0, int_stack+368915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2341306,int_stack+271320,int_stack+270060, 0.0, zero_stack, 2.0, int_stack+370805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2345086,int_stack+2341306,int_stack+2338471, 0.0, zero_stack, 2.0, int_stack+1632295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+272940,int_stack+271320, 0.0, zero_stack, 2.0, int_stack+373325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2350756,int_stack+2233441,int_stack+2341306, 0.0, zero_stack, 2.0, int_stack+1576846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1861741,int_stack+2350756,int_stack+2345086, 0.0, zero_stack, 2.0, int_stack+1690003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2338471,int_stack+1861741,int_stack+2362285,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3058561,int_stack+2338471,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+275406,int_stack+274965, 1.0, int_stack+662670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+802420,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+275994,int_stack+275406, 1.0, int_stack+663111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+802861,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 1.0, int_stack+933208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1695673,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+276750,int_stack+275994, 1.0, int_stack+663699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803449,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 1.0, int_stack+934531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696996,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 1.0, int_stack+936295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1698760,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+278283,int_stack+277695, 1.0, int_stack+668130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+807880,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+279067,int_stack+278283, 1.0, int_stack+668718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808468,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 1.0, int_stack+952675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1701406,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+280075,int_stack+279067, 1.0, int_stack+669502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+809252,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2338471,int_stack+1934725,int_stack+1928845, 1.0, int_stack+954439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1703170,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2343175,int_stack+2338471,int_stack+1931197, 1.0, int_stack+956791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1711612,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2349055,int_stack+2343175,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2338471,int_stack+282091,int_stack+281335, 1.0, int_stack+675410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815916,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+952675,int_stack+283099,int_stack+282091, 1.0, int_stack+676166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+817680,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+955699,int_stack+952675,int_stack+2338471, 1.0, int_stack+965611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1715140,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2338471,int_stack+284395,int_stack+283099, 1.0, int_stack+677174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819984,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2338471,int_stack+952675, 1.0, int_stack+991693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1717408,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1933129,int_stack+1927081,int_stack+955699, 1.0, int_stack+994717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1728748,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+250635,int_stack+1933129,int_stack+2343175,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3093841,int_stack+250635,int_stack+2349055,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+289165,int_stack+286960, 1.0, int_stack+286015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390585,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+952675,int_stack+292045,int_stack+289165, 1.0, int_stack+287905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393735,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2338471,int_stack+952675,int_stack+1927081, 1.0, int_stack+1005868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1783873,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+293665,int_stack+292045, 1.0, int_stack+290425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396255,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2344141,int_stack+2233441,int_stack+952675, 1.0, int_stack+1066519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2351701,int_stack+2344141,int_stack+2338471, 1.0, int_stack+1070299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1841581,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+268275,int_stack+2351701,int_stack+1933129,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3120301,int_stack+268275,int_stack+250635,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+250635,int_stack+296131,int_stack+295690, 1.0, int_stack+690620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+802420, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+251958,int_stack+296719,int_stack+296131, 1.0, int_stack+691061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+802861, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+253722,int_stack+251958,int_stack+250635, 1.0, int_stack+1075969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1695673, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+256368,int_stack+297475,int_stack+296719, 1.0, int_stack+691649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803449, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+258636,int_stack+256368,int_stack+251958, 1.0, int_stack+1077292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696996, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+262164,int_stack+258636,int_stack+253722, 1.0, int_stack+1079056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1698760, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+250635,int_stack+299008,int_stack+298420, 1.0, int_stack+696080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+807880, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+252399,int_stack+299792,int_stack+299008, 1.0, int_stack+696668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808468, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+254751,int_stack+252399,int_stack+250635, 1.0, int_stack+1081702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1701406, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+258279,int_stack+300800,int_stack+299792, 1.0, int_stack+697452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+809252, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+266574,int_stack+258279,int_stack+252399, 1.0, int_stack+1083466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1703170, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+271278,int_stack+266574,int_stack+254751, 1.0, int_stack+1091908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1711612, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+277158,int_stack+271278,int_stack+262164,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1091908,int_stack+302816,int_stack+302060, 1.0, int_stack+703360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815916, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+250635,int_stack+303824,int_stack+302816, 1.0, int_stack+704116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+817680, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+253659,int_stack+250635,int_stack+1091908, 1.0, int_stack+1095436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1715140, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1091908,int_stack+305120,int_stack+303824, 1.0, int_stack+705124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819984, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+258195,int_stack+1091908,int_stack+250635, 1.0, int_stack+1097704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1717408, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1091908,int_stack+258195,int_stack+253659, 1.0, int_stack+1109044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1728748, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1091908,int_stack+271278,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+250635,int_stack+1927081,int_stack+277158,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1109044,int_stack+309890,int_stack+307685, 1.0, int_stack+306740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390585, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+277095,int_stack+312770,int_stack+309890, 1.0, int_stack+308630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393735, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+280875,int_stack+277095,int_stack+1109044, 1.0, int_stack+1169029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1783873, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+314390,int_stack+312770, 1.0, int_stack+311150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396255, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+286545,int_stack+2233441,int_stack+277095, 1.0, int_stack+1113580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1109044,int_stack+286545,int_stack+280875, 1.0, int_stack+1226737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1841581, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+1109044,int_stack+1091908,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3155581,int_stack+277095,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+316856,int_stack+316415, 1.0, int_stack+718570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+802420, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+317444,int_stack+316856, 1.0, int_stack+719011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+802861, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 1.0, int_stack+1232407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1695673, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+318200,int_stack+317444, 1.0, int_stack+719599, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803449, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 1.0, int_stack+1233730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696996, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 1.0, int_stack+1235494, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1698760, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+319733,int_stack+319145, 1.0, int_stack+724030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+807880, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+320517,int_stack+319733, 1.0, int_stack+724618, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808468, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 1.0, int_stack+1238140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1701406, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+321525,int_stack+320517, 1.0, int_stack+725402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+809252, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1934725,int_stack+1928845, 1.0, int_stack+1239904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1703170, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1931197, 1.0, int_stack+1248346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1711612, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1248346,int_stack+323541,int_stack+322785, 1.0, int_stack+731310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815916, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+277095,int_stack+324549,int_stack+323541, 1.0, int_stack+732066, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+817680, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1927081,int_stack+277095,int_stack+1248346, 1.0, int_stack+1251874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1715140, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1248346,int_stack+325845,int_stack+324549, 1.0, int_stack+733074, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819984, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1169029,int_stack+1248346,int_stack+277095, 1.0, int_stack+1254142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1717408, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1248346,int_stack+1169029,int_stack+1927081, 1.0, int_stack+1265482, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1728748, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1248346,int_stack+281799,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+300909,int_stack+1927081,int_stack+287679,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1265482,int_stack+330615,int_stack+328410, 1.0, int_stack+327465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390585, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1169029,int_stack+333495,int_stack+330615, 1.0, int_stack+329355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393735, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+277095,int_stack+1169029,int_stack+1265482, 1.0, int_stack+1325467, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1783873, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+335115,int_stack+333495, 1.0, int_stack+331875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396255, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+282765,int_stack+2233441,int_stack+1169029, 1.0, int_stack+1270018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1265482,int_stack+282765,int_stack+277095, 1.0, int_stack+1383175, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+1265482,int_stack+1248346,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3190861,int_stack+277095,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+337581,int_stack+337140, 1.0, int_stack+746520, 0.0, zero_stack, 1.0, int_stack+802420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+338169,int_stack+337581, 1.0, int_stack+746961, 0.0, zero_stack, 1.0, int_stack+802861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 1.0, int_stack+1388845, 0.0, zero_stack, 1.0, int_stack+1695673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+338925,int_stack+338169, 1.0, int_stack+747549, 0.0, zero_stack, 1.0, int_stack+803449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 1.0, int_stack+1390168, 0.0, zero_stack, 1.0, int_stack+1696996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 1.0, int_stack+1391932, 0.0, zero_stack, 1.0, int_stack+1698760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+340458,int_stack+339870, 1.0, int_stack+751980, 0.0, zero_stack, 1.0, int_stack+807880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+341242,int_stack+340458, 1.0, int_stack+752568, 0.0, zero_stack, 1.0, int_stack+808468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 1.0, int_stack+1394578, 0.0, zero_stack, 1.0, int_stack+1701406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+342250,int_stack+341242, 1.0, int_stack+753352, 0.0, zero_stack, 1.0, int_stack+809252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1934725,int_stack+1928845, 1.0, int_stack+1396342, 0.0, zero_stack, 1.0, int_stack+1703170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1931197, 1.0, int_stack+1404784, 0.0, zero_stack, 1.0, int_stack+1711612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1404784,int_stack+344266,int_stack+343510, 1.0, int_stack+759260, 0.0, zero_stack, 1.0, int_stack+815916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+277095,int_stack+345274,int_stack+344266, 1.0, int_stack+760016, 0.0, zero_stack, 1.0, int_stack+817680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1927081,int_stack+277095,int_stack+1404784, 1.0, int_stack+1408312, 0.0, zero_stack, 1.0, int_stack+1715140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1404784,int_stack+346570,int_stack+345274, 1.0, int_stack+761024, 0.0, zero_stack, 1.0, int_stack+819984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1169029,int_stack+1404784,int_stack+277095, 1.0, int_stack+1410580, 0.0, zero_stack, 1.0, int_stack+1717408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1404784,int_stack+1169029,int_stack+1927081, 1.0, int_stack+1421920, 0.0, zero_stack, 1.0, int_stack+1728748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1404784,int_stack+281799,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2338471,int_stack+1927081,int_stack+287679,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1421920,int_stack+351340,int_stack+349135, 1.0, int_stack+348190, 0.0, zero_stack, 1.0, int_stack+390585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1169029,int_stack+354220,int_stack+351340, 1.0, int_stack+350080, 0.0, zero_stack, 1.0, int_stack+393735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2364931,int_stack+1169029,int_stack+1421920, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+1783873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+355840,int_stack+354220, 1.0, int_stack+352600, 0.0, zero_stack, 1.0, int_stack+396255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+2233441,int_stack+1169029, 1.0, int_stack+1426456, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1421920,int_stack+277095,int_stack+2364931, 1.0, int_stack+1533565, 0.0, zero_stack, 1.0, int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+1421920,int_stack+1404784,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3226141,int_stack+277095,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+358306,int_stack+357865, 1.0, int_stack+774470, 1.0, int_stack+802420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+358894,int_stack+358306, 1.0, int_stack+774911, 1.0, int_stack+802861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 1.0, int_stack+1539235, 1.0, int_stack+1695673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+359650,int_stack+358894, 1.0, int_stack+775499, 1.0, int_stack+803449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 1.0, int_stack+1540558, 1.0, int_stack+1696996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 1.0, int_stack+1542322, 1.0, int_stack+1698760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+361183,int_stack+360595, 1.0, int_stack+779930, 1.0, int_stack+807880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+361967,int_stack+361183, 1.0, int_stack+780518, 1.0, int_stack+808468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 1.0, int_stack+1544968, 1.0, int_stack+1701406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+362975,int_stack+361967, 1.0, int_stack+781302, 1.0, int_stack+809252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1934725,int_stack+1928845, 1.0, int_stack+1546732, 1.0, int_stack+1703170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1931197, 1.0, int_stack+1555174, 1.0, int_stack+1711612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1555174,int_stack+364991,int_stack+364235, 1.0, int_stack+787210, 1.0, int_stack+815916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+277095,int_stack+365999,int_stack+364991, 1.0, int_stack+787966, 1.0, int_stack+817680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1927081,int_stack+277095,int_stack+1555174, 1.0, int_stack+1558702, 1.0, int_stack+1715140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1555174,int_stack+367295,int_stack+365999, 1.0, int_stack+788974, 1.0, int_stack+819984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1169029,int_stack+1555174,int_stack+277095, 1.0, int_stack+1560970, 1.0, int_stack+1717408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1555174,int_stack+1169029,int_stack+1927081, 1.0, int_stack+1572310, 1.0, int_stack+1728748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1555174,int_stack+281799,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+327369,int_stack+1927081,int_stack+287679,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+372065,int_stack+369860, 1.0, int_stack+368915, 1.0, int_stack+390585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1572310,int_stack+374945,int_stack+372065, 1.0, int_stack+370805, 1.0, int_stack+393735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2364931,int_stack+1572310,int_stack+0, 1.0, int_stack+1632295, 1.0, int_stack+1783873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+376565,int_stack+374945, 1.0, int_stack+373325, 1.0, int_stack+396255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+2233441,int_stack+1572310, 1.0, int_stack+1576846, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1572310,int_stack+277095,int_stack+2364931, 1.0, int_stack+1690003, 1.0, int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+1572310,int_stack+1555174,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3261421,int_stack+277095,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+379031,int_stack+378590, 2.0, int_stack+802420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+379619,int_stack+379031, 2.0, int_stack+802861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 2.0, int_stack+1695673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+380375,int_stack+379619, 2.0, int_stack+803449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 2.0, int_stack+1696996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 2.0, int_stack+1698760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+381908,int_stack+381320, 2.0, int_stack+807880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+382692,int_stack+381908, 2.0, int_stack+808468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 2.0, int_stack+1701406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+383700,int_stack+382692, 2.0, int_stack+809252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1934725,int_stack+1928845, 2.0, int_stack+1703170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1931197, 2.0, int_stack+1711612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1938610,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1711612,int_stack+385716,int_stack+384960, 2.0, int_stack+815916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+277095,int_stack+386724,int_stack+385716, 2.0, int_stack+817680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1927081,int_stack+277095,int_stack+1711612, 2.0, int_stack+1715140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1711612,int_stack+388020,int_stack+386724, 2.0, int_stack+819984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1632295,int_stack+1711612,int_stack+277095, 2.0, int_stack+1717408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1711612,int_stack+1632295,int_stack+1927081, 2.0, int_stack+1728748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1711612,int_stack+281799,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+353829,int_stack+1927081,int_stack+287679,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+394995,int_stack+391530, 2.0, int_stack+390585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1728748,int_stack+397875,int_stack+394995, 2.0, int_stack+393735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2364931,int_stack+1728748,int_stack+0, 2.0, int_stack+1783873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+399495,int_stack+397875, 2.0, int_stack+396255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+2233441,int_stack+1728748, 2.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+284655,int_stack+277095,int_stack+2364931, 2.0, int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1064377,int_stack+284655,int_stack+1711612,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3296701,int_stack+1064377,int_stack+1927081,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+401961,int_stack+401520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837255,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+402549,int_stack+401961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837696,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+403305,int_stack+402549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838284,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988480,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1875475,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+404838,int_stack+404250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842715,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+405622,int_stack+404838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843303,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+406630,int_stack+405622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844087,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1064377,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878121,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1069081,int_stack+1064377,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+277095,int_stack+1069081,int_stack+1938610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1064377,int_stack+408646,int_stack+407890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849995,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+409654,int_stack+408646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850751,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+1064377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1064377,int_stack+410950,int_stack+409654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851759,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1783873,int_stack+1064377,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001521,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1783873,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+380289,int_stack+1934641,int_stack+1069081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3331981,int_stack+380289,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+413515,int_stack+412570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497070,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+279930,int_stack+414775,int_stack+413515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498960,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+279930,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1984411,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+416395,int_stack+414775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501480,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2233441,int_stack+279930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+277095,int_stack+1927081,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1064377,int_stack+277095,int_stack+1934641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3358441,int_stack+1064377,int_stack+380289, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1016749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+380289,int_stack+418861,int_stack+418420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837255, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+381612,int_stack+419449,int_stack+418861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837696, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+383376,int_stack+381612,int_stack+380289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+386022,int_stack+420205,int_stack+419449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838284, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+388290,int_stack+386022,int_stack+381612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988480, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+391818,int_stack+388290,int_stack+383376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1875475, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+380289,int_stack+421738,int_stack+421150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842715, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+382053,int_stack+422522,int_stack+421738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843303, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+384405,int_stack+382053,int_stack+380289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+387933,int_stack+423530,int_stack+422522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844087, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+396228,int_stack+387933,int_stack+382053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878121, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+400932,int_stack+396228,int_stack+384405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+406812,int_stack+400932,int_stack+391818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1087498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+380289,int_stack+425546,int_stack+424790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849995, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+382557,int_stack+426554,int_stack+425546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850751, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+385581,int_stack+382557,int_stack+380289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+390117,int_stack+427850,int_stack+426554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851759, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1783873,int_stack+390117,int_stack+382557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001521, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+390117,int_stack+1783873,int_stack+385581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+390117,int_stack+400932, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1103164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3393721,int_stack+1927081,int_stack+406812, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1155799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1783873,int_stack+430415,int_stack+429470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497070, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+397677,int_stack+431675,int_stack+430415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498960, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+397677,int_stack+1783873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1984411, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+433295,int_stack+431675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501480, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+401457,int_stack+2233441,int_stack+397677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+409017,int_stack+401457,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1064377,int_stack+409017,int_stack+390117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1175077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+380289,int_stack+1064377,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1182637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+435761,int_stack+435320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837255, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+436349,int_stack+435761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837696, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+437105,int_stack+436349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838284, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988480, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1875475, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+438638,int_stack+438050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842715, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+439422,int_stack+438638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843303, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+440430,int_stack+439422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844087, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1064377,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878121, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1069081,int_stack+1064377,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+415569,int_stack+1069081,int_stack+1938610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1243936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1064377,int_stack+442446,int_stack+441690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849995, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+443454,int_stack+442446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850751, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+1064377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1064377,int_stack+444750,int_stack+443454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851759, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1783873,int_stack+1064377,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001521, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1783873,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+277095,int_stack+1934641,int_stack+1069081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1259602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3420181,int_stack+277095,int_stack+415569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1312237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+415569,int_stack+447315,int_stack+446370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497070, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+418404,int_stack+448575,int_stack+447315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498960, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+418404,int_stack+415569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1984411, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+450195,int_stack+448575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501480, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2233441,int_stack+418404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+415569,int_stack+1927081,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+425019,int_stack+415569,int_stack+1934641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3446641,int_stack+425019,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1339075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+452661,int_stack+452220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+278418,int_stack+453249,int_stack+452661, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+280182,int_stack+278418,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+282828,int_stack+454005,int_stack+453249, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+285096,int_stack+282828,int_stack+278418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+288624,int_stack+285096,int_stack+280182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1875475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+455538,int_stack+454950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+278859,int_stack+456322,int_stack+455538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+281211,int_stack+278859,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+284739,int_stack+457330,int_stack+456322, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+293034,int_stack+284739,int_stack+278859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+415569,int_stack+293034,int_stack+281211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+421449,int_stack+415569,int_stack+288624, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+459346,int_stack+458590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+279363,int_stack+460354,int_stack+459346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+282387,int_stack+279363,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+286923,int_stack+461650,int_stack+460354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1783873,int_stack+286923,int_stack+279363, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+286923,int_stack+1783873,int_stack+282387, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+286923,int_stack+415569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1416040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+434679,int_stack+1927081,int_stack+421449, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1468675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+415569,int_stack+464215,int_stack+463270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+418404,int_stack+465475,int_stack+464215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+418404,int_stack+415569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1984411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+467095,int_stack+465475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+422184,int_stack+2233441,int_stack+418404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+277095,int_stack+422184,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1064377,int_stack+277095,int_stack+286923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1481905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3481921,int_stack+1064377,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1489465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+469561,int_stack+469120, 0.0, zero_stack, 1.0, int_stack+837255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+470149,int_stack+469561, 0.0, zero_stack, 1.0, int_stack+837696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+470905,int_stack+470149, 0.0, zero_stack, 1.0, int_stack+838284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 1.0, int_stack+988480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 1.0, int_stack+1875475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+472438,int_stack+471850, 0.0, zero_stack, 1.0, int_stack+842715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+473222,int_stack+472438, 0.0, zero_stack, 1.0, int_stack+843303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+474230,int_stack+473222, 0.0, zero_stack, 1.0, int_stack+844087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1064377,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 1.0, int_stack+1878121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1069081,int_stack+1064377,int_stack+1931197, 0.0, zero_stack, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+277095,int_stack+1069081,int_stack+1938610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1550764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1064377,int_stack+476246,int_stack+475490, 0.0, zero_stack, 1.0, int_stack+849995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+477254,int_stack+476246, 0.0, zero_stack, 1.0, int_stack+850751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+1064377, 0.0, zero_stack, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1064377,int_stack+478550,int_stack+477254, 0.0, zero_stack, 1.0, int_stack+851759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1783873,int_stack+1064377,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1001521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1783873,int_stack+1930105, 0.0, zero_stack, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+415569,int_stack+1934641,int_stack+1069081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1566430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3517201,int_stack+415569,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1619065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+481115,int_stack+480170, 0.0, zero_stack, 1.0, int_stack+497070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+279930,int_stack+482375,int_stack+481115, 0.0, zero_stack, 1.0, int_stack+498960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+279930,int_stack+277095, 0.0, zero_stack, 1.0, int_stack+1984411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+483995,int_stack+482375, 0.0, zero_stack, 1.0, int_stack+501480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2233441,int_stack+279930, 0.0, zero_stack, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+277095,int_stack+1927081,int_stack+1841581, 0.0, zero_stack, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1064377,int_stack+277095,int_stack+1934641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1638343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3543661,int_stack+1064377,int_stack+415569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1645903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+415569,int_stack+486461,int_stack+486020, 1.0, int_stack+837255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+416892,int_stack+487049,int_stack+486461, 1.0, int_stack+837696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+418656,int_stack+416892,int_stack+415569, 1.0, int_stack+987157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+421302,int_stack+487805,int_stack+487049, 1.0, int_stack+838284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+423570,int_stack+421302,int_stack+416892, 1.0, int_stack+988480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+987157,int_stack+423570,int_stack+418656, 1.0, int_stack+1875475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+991567,int_stack+489338,int_stack+488750, 1.0, int_stack+842715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+993331,int_stack+490122,int_stack+489338, 1.0, int_stack+843303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+995683,int_stack+993331,int_stack+991567, 1.0, int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+415569,int_stack+491130,int_stack+490122, 1.0, int_stack+844087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+418593,int_stack+415569,int_stack+993331, 1.0, int_stack+1878121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+423297,int_stack+418593,int_stack+995683, 1.0, int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1060849,int_stack+423297,int_stack+987157, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1707202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987157,int_stack+493146,int_stack+492390, 1.0, int_stack+849995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+989425,int_stack+494154,int_stack+493146, 1.0, int_stack+850751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+992449,int_stack+989425,int_stack+987157, 1.0, int_stack+999253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+996985,int_stack+495450,int_stack+494154, 1.0, int_stack+851759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1783873,int_stack+996985,int_stack+989425, 1.0, int_stack+1001521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+996985,int_stack+1783873,int_stack+992449, 1.0, int_stack+960319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+996985,int_stack+423297, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+461139,int_stack+1927081,int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1770643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1060849,int_stack+500220,int_stack+498015, 1.0, int_stack+497070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1063684,int_stack+503100,int_stack+500220, 1.0, int_stack+498960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+1063684,int_stack+1060849, 1.0, int_stack+1984411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+504720,int_stack+503100, 1.0, int_stack+501480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1067464,int_stack+2233441,int_stack+1063684, 1.0, int_stack+938941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1075024,int_stack+1067464,int_stack+1841581, 1.0, int_stack+927475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+1075024,int_stack+996985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1789921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3578941,int_stack+277095,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1797481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+507186,int_stack+506745,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+507774,int_stack+507186,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1928404,int_stack+949147,int_stack+1927081,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1931050,int_stack+508530,int_stack+507774,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1933318,int_stack+1931050,int_stack+949147,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1936846,int_stack+1933318,int_stack+1928404,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+510063,int_stack+509475,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+510847,int_stack+510063,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1929433,int_stack+1927081,int_stack+949147,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1932961,int_stack+511855,int_stack+510847,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1932961,int_stack+1927081,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1929433,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1936846, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1851661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+513871,int_stack+513115,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+514879,int_stack+513871,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+277095,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+277095,int_stack+516175,int_stack+514879,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+277095,int_stack+1927081,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1060849,int_stack+1934641,int_stack+281799, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+487599,int_stack+1060849,int_stack+287679, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1971181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1984411,int_stack+518740,int_stack+517795,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+520000,int_stack+518740,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+1927081,int_stack+1984411,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+521620,int_stack+520000,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+2233441,int_stack+1927081,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+284655,int_stack+277095,int_stack+1841581,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1861741,int_stack+284655,int_stack+1934641, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1990459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3614221,int_stack+1861741,int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1998019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1060849,int_stack+524086,int_stack+523645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865205,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+524674,int_stack+524086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865646,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1062172,int_stack+949147,int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004545,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1064818,int_stack+525430,int_stack+524674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866234,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1067086,int_stack+1064818,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+950911,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1070614,int_stack+1067086,int_stack+1062172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2042119,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+526963,int_stack+526375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870665,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1060849,int_stack+527747,int_stack+526963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871253,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1063201,int_stack+1060849,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2044765,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1066729,int_stack+528755,int_stack+527747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872037,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1075024,int_stack+1066729,int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2046529,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1079728,int_stack+1075024,int_stack+1063201, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2054971,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1861741,int_stack+1079728,int_stack+1070614, 0.0, zero_stack, 1.0, int_stack+944737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1060849,int_stack+530771,int_stack+530015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877945,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1063117,int_stack+531779,int_stack+530771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878701,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1066141,int_stack+1063117,int_stack+1060849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2058499,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1070677,int_stack+533075,int_stack+531779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879709,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+1070677,int_stack+1063117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2060767,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1070677,int_stack+1984411,int_stack+1066141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121949,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1070677,int_stack+1079728, 0.0, zero_stack, 1.0, int_stack+968047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3649501,int_stack+1927081,int_stack+1861741, 0.0, zero_stack, 1.0, int_stack+973927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1861741,int_stack+535640,int_stack+534695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619195,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1864576,int_stack+536900,int_stack+535640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621085,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+1864576,int_stack+1861741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2126485,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+538520,int_stack+536900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623605,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1868356,int_stack+2233441,int_stack+1864576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2129320,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1875916,int_stack+1868356,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2188081,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+1875916,int_stack+1070677, 0.0, zero_stack, 1.0, int_stack+1009189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3675961,int_stack+277095,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1016749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+540986,int_stack+540545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865205, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+541574,int_stack+540986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865646, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1928404,int_stack+949147,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004545, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1931050,int_stack+542330,int_stack+541574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866234, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1933318,int_stack+1931050,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+950911, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1936846,int_stack+1933318,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2042119, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+543863,int_stack+543275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870665, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+544647,int_stack+543863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871253, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1929433,int_stack+1927081,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2044765, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932961,int_stack+545655,int_stack+544647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872037, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1932961,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2046529, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1929433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2054971, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1936846, 0.0, zero_stack, 1.0, int_stack+1087498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+547671,int_stack+546915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877945, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+548679,int_stack+547671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878701, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2058499, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+277095,int_stack+549975,int_stack+548679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879709, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+277095,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2060767, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121949, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1861741,int_stack+1934641,int_stack+281799, 0.0, zero_stack, 1.0, int_stack+1103164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1060849,int_stack+1861741,int_stack+287679, 0.0, zero_stack, 1.0, int_stack+1155799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1984411,int_stack+552540,int_stack+551595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619195, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+553800,int_stack+552540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621085, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+1927081,int_stack+1984411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2126485, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+555420,int_stack+553800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623605, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+2233441,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2129320, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+284655,int_stack+277095,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2188081, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+514059,int_stack+284655,int_stack+1934641, 0.0, zero_stack, 1.0, int_stack+1175077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3711241,int_stack+514059,int_stack+1861741, 0.0, zero_stack, 1.0, int_stack+1182637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1861741,int_stack+557886,int_stack+557445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865205, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+558474,int_stack+557886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865646, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1863064,int_stack+949147,int_stack+1861741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004545, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1865710,int_stack+559230,int_stack+558474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866234, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1867978,int_stack+1865710,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+950911, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1871506,int_stack+1867978,int_stack+1863064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2042119, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+560763,int_stack+560175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870665, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1861741,int_stack+561547,int_stack+560763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871253, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1864093,int_stack+1861741,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2044765, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1867621,int_stack+562555,int_stack+561547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872037, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1875916,int_stack+1867621,int_stack+1861741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2046529, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1880620,int_stack+1875916,int_stack+1864093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2054971, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+1880620,int_stack+1871506, 0.0, zero_stack, 1.0, int_stack+1243936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1861741,int_stack+564571,int_stack+563815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877945, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1864009,int_stack+565579,int_stack+564571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878701, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1867033,int_stack+1864009,int_stack+1861741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2058499, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1871569,int_stack+566875,int_stack+565579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879709, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+1871569,int_stack+1864009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2060767, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1871569,int_stack+1984411,int_stack+1867033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121949, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1871569,int_stack+1880620, 0.0, zero_stack, 1.0, int_stack+1259602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+527289,int_stack+1927081,int_stack+514059, 0.0, zero_stack, 1.0, int_stack+1312237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+514059,int_stack+569440,int_stack+568495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619195, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+516894,int_stack+570700,int_stack+569440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621085, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+516894,int_stack+514059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2126485, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+572320,int_stack+570700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623605, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1879129,int_stack+2233441,int_stack+516894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2129320, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+1879129,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+514059,int_stack+1871569, 0.0, zero_stack, 1.0, int_stack+1331515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3746521,int_stack+277095,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1339075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+574786,int_stack+574345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+575374,int_stack+574786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1928404,int_stack+949147,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1931050,int_stack+576130,int_stack+575374, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1933318,int_stack+1931050,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+950911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1936846,int_stack+1933318,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2042119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+577663,int_stack+577075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+578447,int_stack+577663, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1929433,int_stack+1927081,int_stack+949147, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2044765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932961,int_stack+579455,int_stack+578447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1932961,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2046529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1929433, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2054971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1936846, 0.0, zero_stack, 1.0, int_stack+1400374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+581471,int_stack+580715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+582479,int_stack+581471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+878701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2058499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+277095,int_stack+583775,int_stack+582479, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+277095,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2060767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1861741,int_stack+1934641,int_stack+281799, 0.0, zero_stack, 1.0, int_stack+1416040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+553749,int_stack+1861741,int_stack+287679, 0.0, zero_stack, 1.0, int_stack+1468675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1984411,int_stack+586340,int_stack+585395, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+587600,int_stack+586340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+1927081,int_stack+1984411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2126485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+589220,int_stack+587600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+2233441,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2129320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+284655,int_stack+277095,int_stack+1841581, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+284655,int_stack+1934641, 0.0, zero_stack, 1.0, int_stack+1481905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3804481,int_stack+3781801,int_stack+1861741, 0.0, zero_stack, 1.0, int_stack+1489465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1861741,int_stack+591686,int_stack+591245, 0.0, zero_stack, 1.0, int_stack+865205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+592274,int_stack+591686, 0.0, zero_stack, 1.0, int_stack+865646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1863064,int_stack+949147,int_stack+1861741, 0.0, zero_stack, 1.0, int_stack+1004545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1865710,int_stack+593030,int_stack+592274, 0.0, zero_stack, 1.0, int_stack+866234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1867978,int_stack+1865710,int_stack+949147, 0.0, zero_stack, 1.0, int_stack+950911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1871506,int_stack+1867978,int_stack+1863064, 0.0, zero_stack, 1.0, int_stack+2042119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+594563,int_stack+593975, 0.0, zero_stack, 1.0, int_stack+870665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1861741,int_stack+595347,int_stack+594563, 0.0, zero_stack, 1.0, int_stack+871253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1864093,int_stack+1861741,int_stack+949147, 0.0, zero_stack, 1.0, int_stack+2044765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1867621,int_stack+596355,int_stack+595347, 0.0, zero_stack, 1.0, int_stack+872037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1875916,int_stack+1867621,int_stack+1861741, 0.0, zero_stack, 1.0, int_stack+2046529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1880620,int_stack+1875916,int_stack+1864093, 0.0, zero_stack, 1.0, int_stack+2054971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+1880620,int_stack+1871506, 0.0, zero_stack, 1.0, int_stack+1550764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1861741,int_stack+598371,int_stack+597615, 0.0, zero_stack, 1.0, int_stack+877945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1864009,int_stack+599379,int_stack+598371, 0.0, zero_stack, 1.0, int_stack+878701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1867033,int_stack+1864009,int_stack+1861741, 0.0, zero_stack, 1.0, int_stack+2058499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1871569,int_stack+600675,int_stack+599379, 0.0, zero_stack, 1.0, int_stack+879709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+1871569,int_stack+1864009, 0.0, zero_stack, 1.0, int_stack+2060767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1871569,int_stack+1984411,int_stack+1867033, 0.0, zero_stack, 1.0, int_stack+2121949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1871569,int_stack+1880620, 0.0, zero_stack, 1.0, int_stack+1566430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3839761,int_stack+1927081,int_stack+514059, 0.0, zero_stack, 1.0, int_stack+1619065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+514059,int_stack+603240,int_stack+602295, 0.0, zero_stack, 1.0, int_stack+619195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+516894,int_stack+604500,int_stack+603240, 0.0, zero_stack, 1.0, int_stack+621085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+516894,int_stack+514059, 0.0, zero_stack, 1.0, int_stack+2126485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+606120,int_stack+604500, 0.0, zero_stack, 1.0, int_stack+623605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1879129,int_stack+2233441,int_stack+516894, 0.0, zero_stack, 1.0, int_stack+2129320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+1879129,int_stack+1841581, 0.0, zero_stack, 1.0, int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+514059,int_stack+1871569, 0.0, zero_stack, 1.0, int_stack+1638343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3866221,int_stack+3781801,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1645903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+608586,int_stack+608145, 1.0, int_stack+865205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+609174,int_stack+608586, 1.0, int_stack+865646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1928404,int_stack+949147,int_stack+1927081, 1.0, int_stack+1004545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1931050,int_stack+609930,int_stack+609174, 1.0, int_stack+866234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1933318,int_stack+1931050,int_stack+949147, 1.0, int_stack+950911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+949147,int_stack+1933318,int_stack+1928404, 1.0, int_stack+2042119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2042119,int_stack+611463,int_stack+610875, 1.0, int_stack+870665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+953557,int_stack+612247,int_stack+611463, 1.0, int_stack+871253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+955909,int_stack+953557,int_stack+2042119, 1.0, int_stack+2044765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2042119,int_stack+613255,int_stack+612247, 1.0, int_stack+872037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+959437,int_stack+2042119,int_stack+953557, 1.0, int_stack+2046529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2042119,int_stack+959437,int_stack+955909, 1.0, int_stack+2054971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+2042119,int_stack+949147, 0.0, zero_stack, 1.0, int_stack+1707202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+615271,int_stack+614515, 1.0, int_stack+877945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+951415,int_stack+616279,int_stack+615271, 1.0, int_stack+878701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+954439,int_stack+951415,int_stack+949147, 1.0, int_stack+2058499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+958975,int_stack+617575,int_stack+616279, 1.0, int_stack+879709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+958975,int_stack+951415, 1.0, int_stack+2060767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+958975,int_stack+1984411,int_stack+954439, 1.0, int_stack+2121949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+958975,int_stack+2042119, 0.0, zero_stack, 1.0, int_stack+1722868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1861741,int_stack+1927081,int_stack+514059, 0.0, zero_stack, 1.0, int_stack+1770643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+514059,int_stack+622345,int_stack+620140, 1.0, int_stack+619195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+516894,int_stack+625225,int_stack+622345, 1.0, int_stack+621085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1841581,int_stack+516894,int_stack+514059, 1.0, int_stack+2126485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+626845,int_stack+625225, 1.0, int_stack+623605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2042119,int_stack+2233441,int_stack+516894, 1.0, int_stack+2129320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+2042119,int_stack+1841581, 1.0, int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+514059,int_stack+958975, 0.0, zero_stack, 1.0, int_stack+1789921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+580209,int_stack+3781801,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+1797481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+629311,int_stack+628870,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+629899,int_stack+629311,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+630655,int_stack+629899,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+632188,int_stack+631600,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+632972,int_stack+632188,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+633980,int_stack+632972,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1934725,int_stack+1928845,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1931197,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1938610, 0.0, zero_stack, 1.0, int_stack+1851661, 1.0, int_stack+2050561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+635996,int_stack+635240,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+637004,int_stack+635996,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+3781801,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+638300,int_stack+637004,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+3781801,int_stack+1927081,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+949147,int_stack+1934641,int_stack+3786505, 0.0, zero_stack, 1.0, int_stack+6615, 1.0, int_stack+2066227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3901501,int_stack+949147,int_stack+514059, 0.0, zero_stack, 1.0, int_stack+1971181, 1.0, int_stack+2072107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+514059,int_stack+640865,int_stack+639920,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+516894,int_stack+642125,int_stack+640865,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+516894,int_stack+514059,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+643745,int_stack+642125,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2233441,int_stack+516894,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+1927081,int_stack+2188081,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+514059,int_stack+1934641, 0.0, zero_stack, 1.0, int_stack+1990459, 1.0, int_stack+2136421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3927961,int_stack+3781801,int_stack+949147, 0.0, zero_stack, 1.0, int_stack+1998019, 1.0, int_stack+2143981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+646211,int_stack+645770,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+950470,int_stack+646799,int_stack+646211,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+952234,int_stack+950470,int_stack+949147,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+954880,int_stack+647555,int_stack+646799,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+957148,int_stack+954880,int_stack+950470,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+960676,int_stack+957148,int_stack+952234,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+949147,int_stack+649088,int_stack+648500,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+950911,int_stack+649872,int_stack+649088,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+953263,int_stack+950911,int_stack+949147,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+956791,int_stack+650880,int_stack+649872,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+956791,int_stack+950911,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+953263,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+960676, 0.0, zero_stack, 2.0, int_stack+2050561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+652896,int_stack+652140,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+949147,int_stack+653904,int_stack+652896,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+952171,int_stack+949147,int_stack+3781801,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+655200,int_stack+653904,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+3781801,int_stack+949147,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+956707,int_stack+1984411,int_stack+952171,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+956707,int_stack+3786505, 0.0, zero_stack, 2.0, int_stack+2066227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+615489,int_stack+1927081,int_stack+514059, 0.0, zero_stack, 2.0, int_stack+2072107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+514059,int_stack+657765,int_stack+656820,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+964267,int_stack+659025,int_stack+657765,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+964267,int_stack+514059,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+660645,int_stack+659025,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+949147,int_stack+2233441,int_stack+964267,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+949147,int_stack+2188081,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+514059,int_stack+956707, 0.0, zero_stack, 2.0, int_stack+2136421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3963241,int_stack+3781801,int_stack+1927081, 0.0, zero_stack, 2.0, int_stack+2143981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+665841,int_stack+665400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895885,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+666429,int_stack+665841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896326,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2193751,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+667185,int_stack+666429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896914,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195074,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196838,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+672358,int_stack+671770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+904985,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+673142,int_stack+672358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905573,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199484,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+674150,int_stack+673142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+906357,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201248,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209690,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1938610, 1.0, int_stack+944737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+680846,int_stack+680090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912265,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+681854,int_stack+680846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+913021,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+3781801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847251,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+683150,int_stack+681854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914029,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+3781801,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2213218,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2216242,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+277095,int_stack+1934641,int_stack+3786505, 1.0, int_stack+968047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+641949,int_stack+277095,int_stack+514059, 1.0, int_stack+973927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+514059,int_stack+685715,int_stack+684770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+827580,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+516894,int_stack+686975,int_stack+685715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829470,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+516894,int_stack+514059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2226826,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+688595,int_stack+686975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+831990,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2233441,int_stack+516894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2229661,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+1927081,int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856071,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+514059,int_stack+1934641, 1.0, int_stack+1009189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+927475,int_stack+3781801,int_stack+277095, 1.0, int_stack+1016749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+693791,int_stack+693350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895885, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+278418,int_stack+694379,int_stack+693791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896326, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+280182,int_stack+278418,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2193751, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+282828,int_stack+695135,int_stack+694379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896914, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+285096,int_stack+282828,int_stack+278418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195074, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+288624,int_stack+285096,int_stack+280182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196838, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+700308,int_stack+699720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+904985, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+278859,int_stack+701092,int_stack+700308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905573, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+281211,int_stack+278859,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199484, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+284739,int_stack+702100,int_stack+701092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+906357, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+293034,int_stack+284739,int_stack+278859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201248, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3781801,int_stack+293034,int_stack+281211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209690, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3781801,int_stack+288624, 1.0, int_stack+1087498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+708796,int_stack+708040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912265, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+279363,int_stack+709804,int_stack+708796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+913021, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+282387,int_stack+279363,int_stack+277095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847251, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+286923,int_stack+711100,int_stack+709804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914029, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+286923,int_stack+279363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2213218, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+286923,int_stack+1984411,int_stack+282387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2216242, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+286923,int_stack+3781801, 1.0, int_stack+1103164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+668409,int_stack+1927081,int_stack+514059, 1.0, int_stack+1155799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+713665,int_stack+712720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+827580, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1158634,int_stack+714925,int_stack+713665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829470, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+1158634,int_stack+1155799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2226826, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+716545,int_stack+714925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+831990, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1162414,int_stack+2233441,int_stack+1158634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2229661, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+1162414,int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856071, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+514059,int_stack+286923, 1.0, int_stack+1175077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+962755,int_stack+3781801,int_stack+1927081, 1.0, int_stack+1182637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+721741,int_stack+721300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895885, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+722329,int_stack+721741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896326, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2193751, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+723085,int_stack+722329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896914, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195074, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196838, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+728258,int_stack+727670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+904985, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+729042,int_stack+728258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905573, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199484, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+730050,int_stack+729042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+906357, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201248, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1931197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209690, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1938610, 1.0, int_stack+1243936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+736746,int_stack+735990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912265, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+737754,int_stack+736746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+913021, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+3781801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847251, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+739050,int_stack+737754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914029, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+3781801,int_stack+1927081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2213218, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2216242, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1155799,int_stack+1934641,int_stack+3786505, 1.0, int_stack+1259602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1173439,int_stack+1155799,int_stack+514059, 1.0, int_stack+1312237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312237,int_stack+741615,int_stack+740670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+827580, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1315072,int_stack+742875,int_stack+741615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829470, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+1315072,int_stack+1312237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2226826, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+744495,int_stack+742875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+831990, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2233441,int_stack+1315072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2229661, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312237,int_stack+1927081,int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856071, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+1312237,int_stack+1934641, 1.0, int_stack+1331515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+694869,int_stack+3781801,int_stack+1155799, 1.0, int_stack+1339075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+749691,int_stack+749250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1157122,int_stack+750279,int_stack+749691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1158886,int_stack+1157122,int_stack+1155799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2193751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1161532,int_stack+751035,int_stack+750279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1163800,int_stack+1161532,int_stack+1157122, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1167328,int_stack+1163800,int_stack+1158886, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+756208,int_stack+755620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+904985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1157563,int_stack+756992,int_stack+756208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1159915,int_stack+1157563,int_stack+1155799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1163443,int_stack+758000,int_stack+756992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+906357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1163443,int_stack+1157563, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1159915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1167328, 1.0, int_stack+1400374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+764696,int_stack+763940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1155799,int_stack+765704,int_stack+764696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+913021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1158823,int_stack+1155799,int_stack+3781801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+767000,int_stack+765704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+3781801,int_stack+1155799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2213218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1163359,int_stack+1984411,int_stack+1158823, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2216242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1163359,int_stack+3786505, 1.0, int_stack+1416040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1312237,int_stack+1927081,int_stack+514059, 1.0, int_stack+1468675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1468675,int_stack+769565,int_stack+768620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+827580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1471510,int_stack+770825,int_stack+769565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+1471510,int_stack+1468675, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2226826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+772445,int_stack+770825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+831990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1155799,int_stack+2233441,int_stack+1471510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2229661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1468675,int_stack+1155799,int_stack+2188081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+1468675,int_stack+1163359, 1.0, int_stack+1481905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+730149,int_stack+3781801,int_stack+1927081, 1.0, int_stack+1489465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+777641,int_stack+777200, 0.0, zero_stack, 1.0, int_stack+895885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+778229,int_stack+777641, 0.0, zero_stack, 1.0, int_stack+896326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+2193751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+778985,int_stack+778229, 0.0, zero_stack, 1.0, int_stack+896914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404, 0.0, zero_stack, 1.0, int_stack+2195074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168, 0.0, zero_stack, 1.0, int_stack+2196838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+784158,int_stack+783570, 0.0, zero_stack, 1.0, int_stack+904985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+784942,int_stack+784158, 0.0, zero_stack, 1.0, int_stack+905573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+2199484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+785950,int_stack+784942, 0.0, zero_stack, 1.0, int_stack+906357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1934725,int_stack+1928845, 0.0, zero_stack, 1.0, int_stack+2201248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1931197, 0.0, zero_stack, 1.0, int_stack+2209690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1938610, 1.0, int_stack+1550764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+792646,int_stack+791890, 0.0, zero_stack, 1.0, int_stack+912265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+793654,int_stack+792646, 0.0, zero_stack, 1.0, int_stack+913021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+3781801, 0.0, zero_stack, 1.0, int_stack+1847251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+794950,int_stack+793654, 0.0, zero_stack, 1.0, int_stack+914029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+3781801,int_stack+1927081, 0.0, zero_stack, 1.0, int_stack+2213218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105, 0.0, zero_stack, 1.0, int_stack+2216242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1155799,int_stack+1934641,int_stack+3786505, 1.0, int_stack+1566430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1468675,int_stack+1155799,int_stack+514059, 1.0, int_stack+1619065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1619065,int_stack+797515,int_stack+796570, 0.0, zero_stack, 1.0, int_stack+827580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1621900,int_stack+798775,int_stack+797515, 0.0, zero_stack, 1.0, int_stack+829470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2188081,int_stack+1621900,int_stack+1619065, 0.0, zero_stack, 1.0, int_stack+2226826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+800395,int_stack+798775, 0.0, zero_stack, 1.0, int_stack+831990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+2233441,int_stack+1621900, 0.0, zero_stack, 1.0, int_stack+2229661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1619065,int_stack+1927081,int_stack+2188081, 0.0, zero_stack, 1.0, int_stack+1856071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+1619065,int_stack+1934641, 1.0, int_stack+1638343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+765429,int_stack+3781801,int_stack+1155799, 1.0, int_stack+1645903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+805591,int_stack+805150, 1.0, int_stack+895885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1157122,int_stack+806179,int_stack+805591, 1.0, int_stack+896326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1158886,int_stack+1157122,int_stack+1155799, 1.0, int_stack+2193751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1161532,int_stack+806935,int_stack+806179, 1.0, int_stack+896914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1163800,int_stack+1161532,int_stack+1157122, 1.0, int_stack+2195074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1167328,int_stack+1163800,int_stack+1158886, 1.0, int_stack+2196838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+812108,int_stack+811520, 1.0, int_stack+904985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1157563,int_stack+812892,int_stack+812108, 1.0, int_stack+905573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1159915,int_stack+1157563,int_stack+1155799, 1.0, int_stack+2199484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1163443,int_stack+813900,int_stack+812892, 1.0, int_stack+906357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1163443,int_stack+1157563, 1.0, int_stack+2201248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1159915, 1.0, int_stack+2209690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1167328, 1.0, int_stack+1707202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2209690,int_stack+823656,int_stack+822900, 1.0, int_stack+912265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3781801,int_stack+824664,int_stack+823656, 1.0, int_stack+913021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1155799,int_stack+3781801,int_stack+2209690, 1.0, int_stack+1847251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1160335,int_stack+825960,int_stack+824664, 1.0, int_stack+914029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+1160335,int_stack+3781801, 1.0, int_stack+2213218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1160335,int_stack+1984411,int_stack+1155799, 1.0, int_stack+2216242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1927081,int_stack+1160335,int_stack+3786505, 1.0, int_stack+1722868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1619065,int_stack+1927081,int_stack+514059, 1.0, int_stack+1770643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1770643,int_stack+830730,int_stack+828525, 1.0, int_stack+827580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1773478,int_stack+833610,int_stack+830730, 1.0, int_stack+829470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2364931,int_stack+1773478,int_stack+1770643, 1.0, int_stack+2226826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2233441,int_stack+835230,int_stack+833610, 1.0, int_stack+831990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1777258,int_stack+2233441,int_stack+1773478, 1.0, int_stack+2229661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2226826,int_stack+1777258,int_stack+2364931, 1.0, int_stack+1856071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+2226826,int_stack+1160335, 1.0, int_stack+1789921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+800709,int_stack+3781801,int_stack+1927081, 1.0, int_stack+1797481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+840426,int_stack+839985,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1928404,int_stack+841014,int_stack+840426,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1930168,int_stack+1928404,int_stack+1927081,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1932814,int_stack+841770,int_stack+841014,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1935082,int_stack+1932814,int_stack+1928404,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1938610,int_stack+1935082,int_stack+1930168,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1927081,int_stack+846943,int_stack+846355,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1928845,int_stack+847727,int_stack+846943,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1931197,int_stack+1928845,int_stack+1927081,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1934725,int_stack+848735,int_stack+847727,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1934725,int_stack+1928845,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1931197,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1938610, 1.0, int_stack+1851661, 0.0, zero_stack, 1.0, int_stack+2205280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+855431,int_stack+854675,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1927081,int_stack+856439,int_stack+855431,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1930105,int_stack+1927081,int_stack+3781801,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+857735,int_stack+856439,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1984411,int_stack+3781801,int_stack+1927081,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1934641,int_stack+1984411,int_stack+1930105,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1155799,int_stack+1934641,int_stack+3786505, 1.0, int_stack+6615, 0.0, zero_stack, 1.0, int_stack+2220946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1770643,int_stack+1155799,int_stack+514059, 1.0, int_stack+1971181, 0.0, zero_stack, 1.0, int_stack+2273581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1971181,int_stack+860300,int_stack+859355,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1974016,int_stack+861560,int_stack+860300,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2364931,int_stack+1974016,int_stack+1971181,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1977796,int_stack+863180,int_stack+861560,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1927081,int_stack+1977796,int_stack+1974016,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1971181,int_stack+1927081,int_stack+2364931,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+1971181,int_stack+1934641, 1.0, int_stack+1990459, 0.0, zero_stack, 1.0, int_stack+2286811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+998035,int_stack+3781801,int_stack+1155799, 1.0, int_stack+1998019, 0.0, zero_stack, 1.0, int_stack+2294371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+868376,int_stack+867935,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1157122,int_stack+868964,int_stack+868376,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1158886,int_stack+1157122,int_stack+1155799,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1161532,int_stack+869720,int_stack+868964,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1163800,int_stack+1161532,int_stack+1157122,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1167328,int_stack+1163800,int_stack+1158886,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+874893,int_stack+874305,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1157563,int_stack+875677,int_stack+874893,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1159915,int_stack+1157563,int_stack+1155799,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1163443,int_stack+876685,int_stack+875677,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+1163443,int_stack+1157563,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3786505,int_stack+3781801,int_stack+1159915,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+514059,int_stack+3786505,int_stack+1167328, 1.0, int_stack+2050561, 1.0, int_stack+2205280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3781801,int_stack+883381,int_stack+882625,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1155799,int_stack+884389,int_stack+883381,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1158823,int_stack+1155799,int_stack+3781801,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3781801,int_stack+885685,int_stack+884389,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1163359,int_stack+3781801,int_stack+1155799,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3792385,int_stack+1163359,int_stack+1158823,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1155799,int_stack+3792385,int_stack+3786505, 1.0, int_stack+2066227, 1.0, int_stack+2220946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1971181,int_stack+1155799,int_stack+514059, 1.0, int_stack+2072107, 1.0, int_stack+2273581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+514059,int_stack+888250,int_stack+887305,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+516894,int_stack+889510,int_stack+888250,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2364931,int_stack+516894,int_stack+514059,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+520674,int_stack+891130,int_stack+889510,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3781801,int_stack+520674,int_stack+516894,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+3781801,int_stack+2364931,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+277095,int_stack+514059,int_stack+3792385, 1.0, int_stack+2136421, 1.0, int_stack+2286811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2042119,int_stack+277095,int_stack+1155799, 1.0, int_stack+2143981, 1.0, int_stack+2294371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+899056,int_stack+898615,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1157122,int_stack+899644,int_stack+899056,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1158886,int_stack+1157122,int_stack+1155799,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1161532,int_stack+900400,int_stack+899644,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1163800,int_stack+1161532,int_stack+1157122,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1167328,int_stack+1163800,int_stack+1158886,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1155799,int_stack+909213,int_stack+908625,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1157563,int_stack+909997,int_stack+909213,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1159915,int_stack+1157563,int_stack+1155799,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1163443,int_stack+911005,int_stack+909997,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+1163443,int_stack+1157563,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+281799,int_stack+277095,int_stack+1159915,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+287679,int_stack+281799,int_stack+1167328, 2.0, int_stack+2205280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+277095,int_stack+917701,int_stack+916945,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1155799,int_stack+918709,int_stack+917701,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1158823,int_stack+1155799,int_stack+277095,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+277095,int_stack+920005,int_stack+918709,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1163359,int_stack+277095,int_stack+1155799,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+514059,int_stack+1163359,int_stack+1158823,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1155799,int_stack+514059,int_stack+281799, 2.0, int_stack+2220946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2188081,int_stack+1155799,int_stack+287679, 2.0, int_stack+2273581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2273581,int_stack+922570,int_stack+921625,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2276416,int_stack+923830,int_stack+922570,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+521619,int_stack+2276416,int_stack+2273581,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2280196,int_stack+925450,int_stack+923830,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+277095,int_stack+2280196,int_stack+2276416,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2273581,int_stack+277095,int_stack+521619,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3781801,int_stack+2273581,int_stack+514059, 2.0, int_stack+2286811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2121949,int_stack+3781801,int_stack+1155799, 2.0, int_stack+2294371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+835989,int_stack+1120519,int_stack+1034389,210);
     Libderiv->ABCD[11] = int_stack + 835989;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+880089,int_stack+1276957,int_stack+1200277,210);
     Libderiv->ABCD[10] = int_stack + 880089;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1087309,int_stack+1433395,int_stack+1356715,210);
     Libderiv->ABCD[9] = int_stack + 1087309;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1690003,int_stack+1583785,int_stack+1507105,210);
     Libderiv->ABCD[8] = int_stack + 1690003;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1533565,int_stack+1735363,int_stack+1663543,210);
     Libderiv->ABCD[7] = int_stack + 1533565;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1383175,int_stack+1891801,int_stack+1815121,210);
     Libderiv->ABCD[6] = int_stack + 1383175;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1888201,int_stack+2086669,int_stack+2015659, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1944721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 1888201;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2077399,int_stack+2238301,int_stack+2161621, 0.0, zero_stack, 1.0, int_stack+1944721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 2077399;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2214541,int_stack+2370601,int_stack+2312011, 1.0, int_stack+1944721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 2214541;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2258641,int_stack+2432341,int_stack+2405881,210);
     Libderiv->ABCD[155] = int_stack + 2258641;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2364931,int_stack+2467621,int_stack+12495,210);
     Libderiv->ABCD[143] = int_stack + 2364931;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2409031,int_stack+2502901,int_stack+38955,210);
     Libderiv->ABCD[142] = int_stack + 2409031;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2453131,int_stack+2564641,int_stack+2538181,210);
     Libderiv->ABCD[131] = int_stack + 2453131;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2497231,int_stack+2599921,int_stack+65415,210);
     Libderiv->ABCD[130] = int_stack + 2497231;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2541331,int_stack+2661661,int_stack+2635201,210);
     Libderiv->ABCD[129] = int_stack + 2541331;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2585431,int_stack+2696941,int_stack+91875,210);
     Libderiv->ABCD[119] = int_stack + 2585431;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2629531,int_stack+2732221,int_stack+118335,210);
     Libderiv->ABCD[118] = int_stack + 2629531;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2673631,int_stack+2793961,int_stack+2767501,210);
     Libderiv->ABCD[117] = int_stack + 2673631;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2717731,int_stack+2829241,int_stack+144795,210);
     Libderiv->ABCD[116] = int_stack + 2717731;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2761831,int_stack+2864521,int_stack+171255,210);
     Libderiv->ABCD[107] = int_stack + 2761831;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2805931,int_stack+2926261,int_stack+2899801,210);
     Libderiv->ABCD[106] = int_stack + 2805931;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2850031,int_stack+2961541,int_stack+197715,210);
     Libderiv->ABCD[105] = int_stack + 2850031;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2894131,int_stack+2996821,int_stack+224175,210);
     Libderiv->ABCD[104] = int_stack + 2894131;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2938231,int_stack+3058561,int_stack+3032101,210);
     Libderiv->ABCD[103] = int_stack + 2938231;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2982331,int_stack+3120301,int_stack+3093841,210);
     Libderiv->ABCD[95] = int_stack + 2982331;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3026431,int_stack+3155581,int_stack+250635,210);
     Libderiv->ABCD[94] = int_stack + 3026431;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3070531,int_stack+3190861,int_stack+300909,210);
     Libderiv->ABCD[93] = int_stack + 3070531;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3114631,int_stack+3226141,int_stack+2338471,210);
     Libderiv->ABCD[92] = int_stack + 3114631;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3158731,int_stack+3261421,int_stack+327369,210);
     Libderiv->ABCD[91] = int_stack + 3158731;
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3202831,int_stack+3296701,int_stack+353829,210);
     Libderiv->ABCD[90] = int_stack + 3202831;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3246931,int_stack+3358441,int_stack+3331981, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[47] = int_stack + 3246931;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3291031,int_stack+380289,int_stack+3393721, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1200277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[46] = int_stack + 3291031;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3335131,int_stack+3446641,int_stack+3420181, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[45] = int_stack + 3335131;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3379231,int_stack+3481921,int_stack+434679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1507105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[44] = int_stack + 3379231;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3423331,int_stack+3543661,int_stack+3517201, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1663543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[43] = int_stack + 3423331;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3467431,int_stack+3578941,int_stack+461139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1815121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[42] = int_stack + 3467431;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3511531,int_stack+3614221,int_stack+487599, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2015659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[38] = int_stack + 3511531;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3555631,int_stack+3675961,int_stack+3649501, 0.0, zero_stack, 1.0, int_stack+1034389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[35] = int_stack + 3555631;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3599731,int_stack+3711241,int_stack+1060849, 0.0, zero_stack, 1.0, int_stack+1200277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[34] = int_stack + 3599731;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3643831,int_stack+3746521,int_stack+527289, 0.0, zero_stack, 1.0, int_stack+1356715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[33] = int_stack + 3643831;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3687931,int_stack+3804481,int_stack+553749, 0.0, zero_stack, 1.0, int_stack+1507105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[32] = int_stack + 3687931;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3732031,int_stack+3866221,int_stack+3839761, 0.0, zero_stack, 1.0, int_stack+1663543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[31] = int_stack + 3732031;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3776131,int_stack+580209,int_stack+1861741, 0.0, zero_stack, 1.0, int_stack+1815121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[30] = int_stack + 3776131;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3820231,int_stack+3927961,int_stack+3901501, 0.0, zero_stack, 1.0, int_stack+2015659, 1.0, int_stack+2161621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[26] = int_stack + 3820231;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3864331,int_stack+3963241,int_stack+615489, 0.0, zero_stack, 2.0, int_stack+2161621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[25] = int_stack + 3864331;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3908431,int_stack+927475,int_stack+641949, 1.0, int_stack+1034389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[23] = int_stack + 3908431;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3952531,int_stack+962755,int_stack+668409, 1.0, int_stack+1200277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[22] = int_stack + 3952531;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1199899,int_stack+694869,int_stack+1173439, 1.0, int_stack+1356715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[21] = int_stack + 1199899;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1338697,int_stack+730149,int_stack+1312237, 1.0, int_stack+1507105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[20] = int_stack + 1338697;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1243999,int_stack+765429,int_stack+1468675, 1.0, int_stack+1663543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[19] = int_stack + 1243999;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1645525,int_stack+800709,int_stack+1619065, 1.0, int_stack+1815121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[18] = int_stack + 1645525;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1797103,int_stack+998035,int_stack+1770643, 1.0, int_stack+2015659, 0.0, zero_stack, 1.0, int_stack+2312011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[14] = int_stack + 1797103;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1997641,int_stack+2042119,int_stack+1971181, 1.0, int_stack+2161621, 1.0, int_stack+2312011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[13] = int_stack + 1997641;
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1841203,int_stack+2121949,int_stack+2188081, 2.0, int_stack+2312011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[12] = int_stack + 1841203;

}
