/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (dd|hh) integrals */

void d12vrr_order_ddhh(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+9, dvrr_stack+34, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+21, dvrr_stack+40, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68, dvrr_stack+65, dvrr_stack+3, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+74, dvrr_stack+68, dvrr_stack+15, dvrr_stack+65, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+84, dvrr_stack+74, dvrr_stack+21, dvrr_stack+68, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+99, dvrr_stack+84, dvrr_stack+50, NULL, NULL, dvrr_stack+21);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+144, dvrr_stack+84, dvrr_stack+50, dvrr_stack+74, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+165, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+168, dvrr_stack+165, dvrr_stack+65, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+174, dvrr_stack+168, dvrr_stack+68, dvrr_stack+165, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+184, dvrr_stack+174, dvrr_stack+74, dvrr_stack+168, dvrr_stack+68, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+199, dvrr_stack+184, dvrr_stack+84, dvrr_stack+174, dvrr_stack+74, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+165, dvrr_stack+31, dvrr_stack+65, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+220, dvrr_stack+34, dvrr_stack+165, dvrr_stack+6, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+230, dvrr_stack+40, dvrr_stack+220, dvrr_stack+9, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+245, dvrr_stack+50, dvrr_stack+230, dvrr_stack+21, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+266, dvrr_stack+144, dvrr_stack+245, NULL, NULL, dvrr_stack+50);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+329, dvrr_stack+199, dvrr_stack+144, NULL, NULL, dvrr_stack+84);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+392, dvrr_stack+329, dvrr_stack+266, dvrr_stack+199, dvrr_stack+144, dvrr_stack+99);
 tmp = dvrr_stack + 392;
 target_ptr = Libderiv->dvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+518, dvrr_stack+144, dvrr_stack+245, dvrr_stack+84, dvrr_stack+50, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+546, dvrr_stack+199, dvrr_stack+144, dvrr_stack+184, dvrr_stack+84, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+171, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+574, dvrr_stack+65, dvrr_stack+171, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+580, dvrr_stack+165, dvrr_stack+574, dvrr_stack+31, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+590, dvrr_stack+220, dvrr_stack+580, dvrr_stack+34, dvrr_stack+165, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+605, dvrr_stack+230, dvrr_stack+590, dvrr_stack+40, dvrr_stack+220, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+626, dvrr_stack+245, dvrr_stack+605, dvrr_stack+50, dvrr_stack+230, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+654, dvrr_stack+518, dvrr_stack+626, NULL, NULL, dvrr_stack+245);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+738, dvrr_stack+546, dvrr_stack+518, NULL, NULL, dvrr_stack+144);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+822, dvrr_stack+738, dvrr_stack+654, dvrr_stack+546, dvrr_stack+518, dvrr_stack+266);
 tmp = dvrr_stack + 822;
 target_ptr = Libderiv->dvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+990,dvrr_stack+822,dvrr_stack+392,6);


 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1368, dvrr_stack+518, dvrr_stack+626, dvrr_stack+144, dvrr_stack+245, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1404, dvrr_stack+546, dvrr_stack+518, dvrr_stack+199, dvrr_stack+144, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1440, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1443, dvrr_stack+171, dvrr_stack+1440, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1449, dvrr_stack+574, dvrr_stack+1443, dvrr_stack+65, dvrr_stack+171, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1459, dvrr_stack+580, dvrr_stack+1449, dvrr_stack+165, dvrr_stack+574, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1474, dvrr_stack+590, dvrr_stack+1459, dvrr_stack+220, dvrr_stack+580, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1495, dvrr_stack+605, dvrr_stack+1474, dvrr_stack+230, dvrr_stack+590, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1523, dvrr_stack+626, dvrr_stack+1495, dvrr_stack+245, dvrr_stack+605, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1559, dvrr_stack+1368, dvrr_stack+1523, NULL, NULL, dvrr_stack+626);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1667, dvrr_stack+1404, dvrr_stack+1368, NULL, NULL, dvrr_stack+518);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1775, dvrr_stack+1667, dvrr_stack+1559, dvrr_stack+1404, dvrr_stack+1368, dvrr_stack+654);
 tmp = dvrr_stack + 1775;
 target_ptr = Libderiv->dvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+1991,dvrr_stack+1775,dvrr_stack+822,6);


 /* compute (2 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+2495,dvrr_stack+1991,dvrr_stack+990,6);


 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,126,dvrr_stack+3251, dvrr_stack+2495, dvrr_stack+392);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3629, dvrr_stack+1368, dvrr_stack+1523, dvrr_stack+518, dvrr_stack+626, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3674, dvrr_stack+1404, dvrr_stack+1368, dvrr_stack+546, dvrr_stack+518, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3719, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3722, dvrr_stack+1440, dvrr_stack+3719, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3728, dvrr_stack+1443, dvrr_stack+3722, dvrr_stack+171, dvrr_stack+1440, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3738, dvrr_stack+1449, dvrr_stack+3728, dvrr_stack+574, dvrr_stack+1443, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3753, dvrr_stack+1459, dvrr_stack+3738, dvrr_stack+580, dvrr_stack+1449, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3774, dvrr_stack+1474, dvrr_stack+3753, dvrr_stack+590, dvrr_stack+1459, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3802, dvrr_stack+1495, dvrr_stack+3774, dvrr_stack+605, dvrr_stack+1474, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3838, dvrr_stack+1523, dvrr_stack+3802, dvrr_stack+626, dvrr_stack+1495, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3883, dvrr_stack+3629, dvrr_stack+3838, NULL, NULL, dvrr_stack+1523);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4018, dvrr_stack+3674, dvrr_stack+3629, NULL, NULL, dvrr_stack+1368);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4153, dvrr_stack+4018, dvrr_stack+3883, dvrr_stack+3674, dvrr_stack+3629, dvrr_stack+1559);
 tmp = dvrr_stack + 4153;
 target_ptr = Libderiv->dvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+4423,dvrr_stack+4153,dvrr_stack+1775,6);


 /* compute (2 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+5071,dvrr_stack+4423,dvrr_stack+1991,6);


 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,168,dvrr_stack+6079, dvrr_stack+5071, dvrr_stack+822);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6583, dvrr_stack+3629, dvrr_stack+3838, dvrr_stack+1368, dvrr_stack+1523, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6638, dvrr_stack+3674, dvrr_stack+3629, dvrr_stack+1404, dvrr_stack+1368, NULL);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+171, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6693, dvrr_stack+3719, dvrr_stack+171, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6699, dvrr_stack+3722, dvrr_stack+6693, dvrr_stack+1440, dvrr_stack+3719, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6709, dvrr_stack+3728, dvrr_stack+6699, dvrr_stack+1443, dvrr_stack+3722, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6724, dvrr_stack+3738, dvrr_stack+6709, dvrr_stack+1449, dvrr_stack+3728, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+6745, dvrr_stack+3753, dvrr_stack+6724, dvrr_stack+1459, dvrr_stack+3738, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6773, dvrr_stack+3774, dvrr_stack+6745, dvrr_stack+1474, dvrr_stack+3753, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6809, dvrr_stack+3802, dvrr_stack+6773, dvrr_stack+1495, dvrr_stack+3774, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6854, dvrr_stack+3838, dvrr_stack+6809, dvrr_stack+1523, dvrr_stack+3802, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6909, dvrr_stack+6583, dvrr_stack+6854, NULL, NULL, dvrr_stack+3838);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7074, dvrr_stack+6638, dvrr_stack+6583, NULL, NULL, dvrr_stack+3629);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7239, dvrr_stack+7074, dvrr_stack+6909, dvrr_stack+6638, dvrr_stack+6583, dvrr_stack+3883);
 tmp = dvrr_stack + 7239;
 target_ptr = Libderiv->dvrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+7569,dvrr_stack+7239,dvrr_stack+4153,6);


 /* compute (2 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+8379,dvrr_stack+7569,dvrr_stack+4423,6);


 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,216,dvrr_stack+9675, dvrr_stack+8379, dvrr_stack+1775);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10323, dvrr_stack+6583, dvrr_stack+6854, dvrr_stack+3629, dvrr_stack+3838, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10389, dvrr_stack+6638, dvrr_stack+6583, dvrr_stack+3674, dvrr_stack+3629, NULL);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1440, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1443, dvrr_stack+171, dvrr_stack+1440, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+10455, dvrr_stack+6693, dvrr_stack+1443, dvrr_stack+3719, dvrr_stack+171, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10465, dvrr_stack+6699, dvrr_stack+10455, dvrr_stack+3722, dvrr_stack+6693, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+10480, dvrr_stack+6709, dvrr_stack+10465, dvrr_stack+3728, dvrr_stack+6699, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10501, dvrr_stack+6724, dvrr_stack+10480, dvrr_stack+3738, dvrr_stack+6709, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10529, dvrr_stack+6745, dvrr_stack+10501, dvrr_stack+3753, dvrr_stack+6724, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10565, dvrr_stack+6773, dvrr_stack+10529, dvrr_stack+3774, dvrr_stack+6745, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10610, dvrr_stack+6809, dvrr_stack+10565, dvrr_stack+3802, dvrr_stack+6773, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10665, dvrr_stack+6854, dvrr_stack+10610, dvrr_stack+3838, dvrr_stack+6809, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10731, dvrr_stack+10323, dvrr_stack+10665, NULL, NULL, dvrr_stack+6854);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10929, dvrr_stack+10389, dvrr_stack+10323, NULL, NULL, dvrr_stack+6583);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11127, dvrr_stack+10929, dvrr_stack+10731, dvrr_stack+10389, dvrr_stack+10323, dvrr_stack+6909);
 tmp = dvrr_stack + 11127;
 target_ptr = Libderiv->dvrr_classes[2][10];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+11523,dvrr_stack+11127,dvrr_stack+7239,6);


 /* compute (2 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+12513,dvrr_stack+11523,dvrr_stack+7569,6);


 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,270,dvrr_stack+14133, dvrr_stack+12513, dvrr_stack+4153);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+14943, dvrr_stack+10323, dvrr_stack+10665, dvrr_stack+6583, dvrr_stack+6854, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15021, dvrr_stack+10389, dvrr_stack+10323, dvrr_stack+6638, dvrr_stack+6583, NULL);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3719, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3722, dvrr_stack+1440, dvrr_stack+3719, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3728, dvrr_stack+1443, dvrr_stack+3722, dvrr_stack+171, dvrr_stack+1440, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+15099, dvrr_stack+10455, dvrr_stack+3728, dvrr_stack+6693, dvrr_stack+1443, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+15114, dvrr_stack+10465, dvrr_stack+15099, dvrr_stack+6699, dvrr_stack+10455, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+15135, dvrr_stack+10480, dvrr_stack+15114, dvrr_stack+6709, dvrr_stack+10465, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+15163, dvrr_stack+10501, dvrr_stack+15135, dvrr_stack+6724, dvrr_stack+10480, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15199, dvrr_stack+10529, dvrr_stack+15163, dvrr_stack+6745, dvrr_stack+10501, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15244, dvrr_stack+10565, dvrr_stack+15199, dvrr_stack+6773, dvrr_stack+10529, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+15299, dvrr_stack+10610, dvrr_stack+15244, dvrr_stack+6809, dvrr_stack+10565, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15365, dvrr_stack+10665, dvrr_stack+15299, dvrr_stack+6854, dvrr_stack+10610, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15443, dvrr_stack+14943, dvrr_stack+15365, NULL, NULL, dvrr_stack+10665);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15677, dvrr_stack+15021, dvrr_stack+14943, NULL, NULL, dvrr_stack+10323);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15911, dvrr_stack+15677, dvrr_stack+15443, dvrr_stack+15021, dvrr_stack+14943, dvrr_stack+10731);

 /* compute (2 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+16379,dvrr_stack+15911,dvrr_stack+11127,6);


 /* compute (2 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+17567,dvrr_stack+16379,dvrr_stack+11523,6);


 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,330,dvrr_stack+19547, dvrr_stack+17567, dvrr_stack+7239);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+20537, dvrr_stack+14943, dvrr_stack+15365, dvrr_stack+10323, dvrr_stack+10665, NULL);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+20628, dvrr_stack+15021, dvrr_stack+14943, dvrr_stack+10389, dvrr_stack+10323, NULL);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+171, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15021, dvrr_stack+3719, dvrr_stack+171, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+15027, dvrr_stack+3722, dvrr_stack+15021, dvrr_stack+1440, dvrr_stack+3719, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+15037, dvrr_stack+3728, dvrr_stack+15027, dvrr_stack+1443, dvrr_stack+3722, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+15052, dvrr_stack+15099, dvrr_stack+15037, dvrr_stack+10455, dvrr_stack+3728, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+6693, dvrr_stack+15114, dvrr_stack+15052, dvrr_stack+10465, dvrr_stack+15099, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+20719, dvrr_stack+15135, dvrr_stack+6693, dvrr_stack+10480, dvrr_stack+15114, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10455, dvrr_stack+15163, dvrr_stack+20719, dvrr_stack+10501, dvrr_stack+15135, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20755, dvrr_stack+15199, dvrr_stack+10455, dvrr_stack+10529, dvrr_stack+15163, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20810, dvrr_stack+15244, dvrr_stack+20755, dvrr_stack+10565, dvrr_stack+15199, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+20876, dvrr_stack+15299, dvrr_stack+20810, dvrr_stack+10610, dvrr_stack+15244, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+20954, dvrr_stack+15365, dvrr_stack+20876, dvrr_stack+10665, dvrr_stack+15299, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+21045, dvrr_stack+20537, dvrr_stack+20954, NULL, NULL, dvrr_stack+15365);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+21318, dvrr_stack+20628, dvrr_stack+20537, NULL, NULL, dvrr_stack+14943);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+21591, dvrr_stack+21318, dvrr_stack+21045, dvrr_stack+20628, dvrr_stack+20537, dvrr_stack+15443);

 /* compute (2 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+22137,dvrr_stack+21591,dvrr_stack+15911,6);


 /* compute (2 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+23541,dvrr_stack+22137,dvrr_stack+16379,6);


 /* compute (2 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,396,dvrr_stack+25917, dvrr_stack+23541, dvrr_stack+11127);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+20628, dvrr_stack+21, dvrr_stack+40, NULL, NULL, dvrr_stack+9);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+20658, dvrr_stack+50, dvrr_stack+230, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+27105, dvrr_stack+99, dvrr_stack+20658, dvrr_stack+84, dvrr_stack+50, dvrr_stack+20628);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+27195, dvrr_stack+245, dvrr_stack+605, NULL, NULL, dvrr_stack+230);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+27258, dvrr_stack+266, dvrr_stack+27195, dvrr_stack+144, dvrr_stack+245, dvrr_stack+20658);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+27384, dvrr_stack+392, dvrr_stack+27258, dvrr_stack+329, dvrr_stack+266, dvrr_stack+27105);
 tmp = dvrr_stack + 27384;
 target_ptr = Libderiv->dvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+27594, dvrr_stack+626, dvrr_stack+1495, NULL, NULL, dvrr_stack+605);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+27678, dvrr_stack+654, dvrr_stack+27594, dvrr_stack+518, dvrr_stack+626, dvrr_stack+27195);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+27846, dvrr_stack+822, dvrr_stack+27678, dvrr_stack+738, dvrr_stack+654, dvrr_stack+27258);
 tmp = dvrr_stack + 27846;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+28126,dvrr_stack+27846,dvrr_stack+27384,10);


 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28756, dvrr_stack+1523, dvrr_stack+3802, NULL, NULL, dvrr_stack+1495);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28864, dvrr_stack+1559, dvrr_stack+28756, dvrr_stack+1368, dvrr_stack+1523, dvrr_stack+27594);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29080, dvrr_stack+1775, dvrr_stack+28864, dvrr_stack+1667, dvrr_stack+1559, dvrr_stack+27678);
 tmp = dvrr_stack + 29080;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+29440,dvrr_stack+29080,dvrr_stack+27846,10);


 /* compute (3 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+30280,dvrr_stack+29440,dvrr_stack+28126,10);


 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,210,dvrr_stack+31540, dvrr_stack+30280, dvrr_stack+27384);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+32170, dvrr_stack+3838, dvrr_stack+6809, NULL, NULL, dvrr_stack+3802);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+32305, dvrr_stack+3883, dvrr_stack+32170, dvrr_stack+3629, dvrr_stack+3838, dvrr_stack+28756);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+32575, dvrr_stack+4153, dvrr_stack+32305, dvrr_stack+4018, dvrr_stack+3883, dvrr_stack+28864);
 tmp = dvrr_stack + 32575;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+33025,dvrr_stack+32575,dvrr_stack+29080,10);


 /* compute (3 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+34105,dvrr_stack+33025,dvrr_stack+29440,10);


 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,280,dvrr_stack+35785, dvrr_stack+34105, dvrr_stack+27846);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36625, dvrr_stack+6854, dvrr_stack+10610, NULL, NULL, dvrr_stack+6809);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36790, dvrr_stack+6909, dvrr_stack+36625, dvrr_stack+6583, dvrr_stack+6854, dvrr_stack+32170);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+37120, dvrr_stack+7239, dvrr_stack+36790, dvrr_stack+7074, dvrr_stack+6909, dvrr_stack+32305);
 tmp = dvrr_stack + 37120;
 target_ptr = Libderiv->dvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+37670,dvrr_stack+37120,dvrr_stack+32575,10);


 /* compute (3 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+39020,dvrr_stack+37670,dvrr_stack+33025,10);


 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,360,dvrr_stack+41180, dvrr_stack+39020, dvrr_stack+29080);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42260, dvrr_stack+10665, dvrr_stack+15299, NULL, NULL, dvrr_stack+10610);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42458, dvrr_stack+10731, dvrr_stack+42260, dvrr_stack+10323, dvrr_stack+10665, dvrr_stack+36625);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42854, dvrr_stack+11127, dvrr_stack+42458, dvrr_stack+10929, dvrr_stack+10731, dvrr_stack+36790);
 tmp = dvrr_stack + 42854;
 target_ptr = Libderiv->dvrr_classes[3][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+43514,dvrr_stack+42854,dvrr_stack+37120,10);


 /* compute (3 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+45164,dvrr_stack+43514,dvrr_stack+37670,10);


 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,450,dvrr_stack+47864, dvrr_stack+45164, dvrr_stack+32575);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49214, dvrr_stack+15365, dvrr_stack+20876, NULL, NULL, dvrr_stack+15299);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49448, dvrr_stack+15443, dvrr_stack+49214, dvrr_stack+14943, dvrr_stack+15365, dvrr_stack+42260);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49916, dvrr_stack+15911, dvrr_stack+49448, dvrr_stack+15677, dvrr_stack+15443, dvrr_stack+42458);

 /* compute (3 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+50696,dvrr_stack+49916,dvrr_stack+42854,10);


 /* compute (3 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+52676,dvrr_stack+50696,dvrr_stack+43514,10);


 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,550,dvrr_stack+55976, dvrr_stack+52676, dvrr_stack+37120);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6721, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+14943, dvrr_stack+171, dvrr_stack+6721, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+14949, dvrr_stack+15021, dvrr_stack+14943, dvrr_stack+3719, dvrr_stack+171, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+14959, dvrr_stack+15027, dvrr_stack+14949, dvrr_stack+3722, dvrr_stack+15021, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+144, dvrr_stack+15037, dvrr_stack+14959, dvrr_stack+3728, dvrr_stack+15027, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+518, dvrr_stack+15052, dvrr_stack+144, dvrr_stack+15099, dvrr_stack+15037, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1368, dvrr_stack+6693, dvrr_stack+518, dvrr_stack+15114, dvrr_stack+15052, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3629, dvrr_stack+20719, dvrr_stack+1368, dvrr_stack+15135, dvrr_stack+6693, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6583, dvrr_stack+10455, dvrr_stack+3629, dvrr_stack+15163, dvrr_stack+20719, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+10323, dvrr_stack+20755, dvrr_stack+6583, dvrr_stack+15199, dvrr_stack+10455, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15073, dvrr_stack+20810, dvrr_stack+10323, dvrr_stack+15244, dvrr_stack+20755, NULL);

 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+57626, dvrr_stack+20876, dvrr_stack+15073, dvrr_stack+15299, dvrr_stack+20810, NULL);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+57717, dvrr_stack+20954, dvrr_stack+57626, NULL, NULL, dvrr_stack+20876);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+57990, dvrr_stack+21045, dvrr_stack+57717, dvrr_stack+20537, dvrr_stack+20954, dvrr_stack+49214);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+58536, dvrr_stack+21591, dvrr_stack+57990, dvrr_stack+21318, dvrr_stack+21045, dvrr_stack+49448);

 /* compute (3 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+59446,dvrr_stack+58536,dvrr_stack+49916,10);


 /* compute (3 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+61786,dvrr_stack+59446,dvrr_stack+50696,10);


 /* compute (3 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,660,dvrr_stack+65746, dvrr_stack+61786, dvrr_stack+42854);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+21318, dvrr_stack+9, dvrr_stack+34, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+21336, dvrr_stack+40, dvrr_stack+220, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+21366, dvrr_stack+20628, dvrr_stack+21336, dvrr_stack+21, dvrr_stack+40, dvrr_stack+21318);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+21426, dvrr_stack+230, dvrr_stack+590, NULL, NULL, dvrr_stack+220);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+21471, dvrr_stack+20658, dvrr_stack+21426, dvrr_stack+50, dvrr_stack+230, dvrr_stack+21336);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+67726, dvrr_stack+27105, dvrr_stack+21471, dvrr_stack+99, dvrr_stack+20658, dvrr_stack+21366);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+20537, dvrr_stack+605, dvrr_stack+1474, NULL, NULL, dvrr_stack+590);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+67876, dvrr_stack+27195, dvrr_stack+20537, dvrr_stack+245, dvrr_stack+605, dvrr_stack+21426);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+68002, dvrr_stack+27258, dvrr_stack+67876, dvrr_stack+266, dvrr_stack+27195, dvrr_stack+21471);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+68212, dvrr_stack+27384, dvrr_stack+68002, dvrr_stack+392, dvrr_stack+27258, dvrr_stack+67726);
 tmp = dvrr_stack + 68212;
 target_ptr = Libderiv->dvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+245, dvrr_stack+1495, dvrr_stack+3774, NULL, NULL, dvrr_stack+1474);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+68527, dvrr_stack+27594, dvrr_stack+245, dvrr_stack+626, dvrr_stack+1495, dvrr_stack+20537);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+68695, dvrr_stack+27678, dvrr_stack+68527, dvrr_stack+654, dvrr_stack+27594, dvrr_stack+67876);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+68975, dvrr_stack+27846, dvrr_stack+68695, dvrr_stack+822, dvrr_stack+27678, dvrr_stack+68002);
 tmp = dvrr_stack + 68975;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+69395,dvrr_stack+68975,dvrr_stack+68212,15);


 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+626, dvrr_stack+3802, dvrr_stack+6773, NULL, NULL, dvrr_stack+3774);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+70340, dvrr_stack+28756, dvrr_stack+626, dvrr_stack+1523, dvrr_stack+3802, dvrr_stack+245);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+70556, dvrr_stack+28864, dvrr_stack+70340, dvrr_stack+1559, dvrr_stack+28756, dvrr_stack+68527);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+70916, dvrr_stack+29080, dvrr_stack+70556, dvrr_stack+1775, dvrr_stack+28864, dvrr_stack+68695);
 tmp = dvrr_stack + 70916;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+71456,dvrr_stack+70916,dvrr_stack+68975,15);


 /* compute (4 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+72716,dvrr_stack+71456,dvrr_stack+69395,15);


 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,315,dvrr_stack+74606, dvrr_stack+72716, dvrr_stack+68212);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1523, dvrr_stack+6809, dvrr_stack+10565, NULL, NULL, dvrr_stack+6773);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+75551, dvrr_stack+32170, dvrr_stack+1523, dvrr_stack+3838, dvrr_stack+6809, dvrr_stack+626);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+75821, dvrr_stack+32305, dvrr_stack+75551, dvrr_stack+3883, dvrr_stack+32170, dvrr_stack+70340);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+76271, dvrr_stack+32575, dvrr_stack+75821, dvrr_stack+4153, dvrr_stack+32305, dvrr_stack+70556);
 tmp = dvrr_stack + 76271;
 target_ptr = Libderiv->dvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+76946,dvrr_stack+76271,dvrr_stack+70916,15);


 /* compute (4 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+78566,dvrr_stack+76946,dvrr_stack+71456,15);


 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,420,dvrr_stack+81086, dvrr_stack+78566, dvrr_stack+68975);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3838, dvrr_stack+10610, dvrr_stack+15244, NULL, NULL, dvrr_stack+10565);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+82346, dvrr_stack+36625, dvrr_stack+3838, dvrr_stack+6854, dvrr_stack+10610, dvrr_stack+1523);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+82676, dvrr_stack+36790, dvrr_stack+82346, dvrr_stack+6909, dvrr_stack+36625, dvrr_stack+75551);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+83226, dvrr_stack+37120, dvrr_stack+82676, dvrr_stack+7239, dvrr_stack+36790, dvrr_stack+75821);
 tmp = dvrr_stack + 83226;
 target_ptr = Libderiv->dvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+84051,dvrr_stack+83226,dvrr_stack+76271,15);


 /* compute (4 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+86076,dvrr_stack+84051,dvrr_stack+76946,15);


 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,540,dvrr_stack+89316, dvrr_stack+86076, dvrr_stack+70916);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6854, dvrr_stack+15299, dvrr_stack+20810, NULL, NULL, dvrr_stack+15244);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+90936, dvrr_stack+42260, dvrr_stack+6854, dvrr_stack+10665, dvrr_stack+15299, dvrr_stack+3838);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+91332, dvrr_stack+42458, dvrr_stack+90936, dvrr_stack+10731, dvrr_stack+42260, dvrr_stack+82346);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+91992, dvrr_stack+42854, dvrr_stack+91332, dvrr_stack+11127, dvrr_stack+42458, dvrr_stack+82676);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+92982,dvrr_stack+91992,dvrr_stack+83226,15);


 /* compute (4 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+95457,dvrr_stack+92982,dvrr_stack+84051,15);


 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,675,dvrr_stack+99507, dvrr_stack+95457, dvrr_stack+76271);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+10665, dvrr_stack+20876, dvrr_stack+15073, NULL, NULL, dvrr_stack+20810);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+101532, dvrr_stack+49214, dvrr_stack+10665, dvrr_stack+15365, dvrr_stack+20876, dvrr_stack+6854);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+102000, dvrr_stack+49448, dvrr_stack+101532, dvrr_stack+15443, dvrr_stack+49214, dvrr_stack+90936);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+102780, dvrr_stack+49916, dvrr_stack+102000, dvrr_stack+15911, dvrr_stack+49448, dvrr_stack+91332);

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+103950,dvrr_stack+102780,dvrr_stack+91992,15);


 /* compute (4 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+106920,dvrr_stack+103950,dvrr_stack+92982,15);


 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,825,dvrr_stack+111870, dvrr_stack+106920, dvrr_stack+83226);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+15365, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15368, dvrr_stack+6721, dvrr_stack+15365, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+15374, dvrr_stack+14943, dvrr_stack+15368, dvrr_stack+171, dvrr_stack+6721, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4003, dvrr_stack+14949, dvrr_stack+15374, dvrr_stack+15021, dvrr_stack+14943, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+15365, dvrr_stack+14959, dvrr_stack+4003, dvrr_stack+15027, dvrr_stack+14949, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+20600, dvrr_stack+144, dvrr_stack+15365, dvrr_stack+15037, dvrr_stack+14959, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+15365, dvrr_stack+518, dvrr_stack+20600, dvrr_stack+15052, dvrr_stack+144, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15401, dvrr_stack+1368, dvrr_stack+15365, dvrr_stack+6693, dvrr_stack+518, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15446, dvrr_stack+3629, dvrr_stack+15401, dvrr_stack+20719, dvrr_stack+1368, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+15365, dvrr_stack+6583, dvrr_stack+15446, dvrr_stack+10455, dvrr_stack+3629, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+15431, dvrr_stack+10323, dvrr_stack+15365, dvrr_stack+20755, dvrr_stack+6583, NULL);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+15509, dvrr_stack+15073, dvrr_stack+15431, dvrr_stack+20810, dvrr_stack+10323, NULL);

 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+114345, dvrr_stack+57626, dvrr_stack+15509, NULL, NULL, dvrr_stack+15073);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+114618, dvrr_stack+57717, dvrr_stack+114345, dvrr_stack+20954, dvrr_stack+57626, dvrr_stack+10665);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+115164, dvrr_stack+57990, dvrr_stack+114618, dvrr_stack+21045, dvrr_stack+57717, dvrr_stack+101532);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+116074, dvrr_stack+58536, dvrr_stack+115164, dvrr_stack+21591, dvrr_stack+57990, dvrr_stack+102000);

 /* compute (4 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+117439,dvrr_stack+116074,dvrr_stack+102780,15);


 /* compute (4 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+120949,dvrr_stack+117439,dvrr_stack+103950,15);


 /* compute (4 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,990,dvrr_stack+126889, dvrr_stack+120949, dvrr_stack+91992);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,126,dvrr_stack+57626, dvrr_stack+2495, dvrr_stack+392);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,168,dvrr_stack+58004, dvrr_stack+5071, dvrr_stack+822);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,216,dvrr_stack+114345, dvrr_stack+8379, dvrr_stack+1775);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,270,dvrr_stack+114993, dvrr_stack+12513, dvrr_stack+4153);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,330,dvrr_stack+129859, dvrr_stack+17567, dvrr_stack+7239);

 /* compute (2 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,396,dvrr_stack+130849, dvrr_stack+23541, dvrr_stack+11127);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,210,dvrr_stack+132037, dvrr_stack+30280, dvrr_stack+27384);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,280,dvrr_stack+132667, dvrr_stack+34105, dvrr_stack+27846);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,360,dvrr_stack+133507, dvrr_stack+39020, dvrr_stack+29080);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,450,dvrr_stack+134587, dvrr_stack+45164, dvrr_stack+32575);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,550,dvrr_stack+135937, dvrr_stack+52676, dvrr_stack+37120);

 /* compute (3 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,660,dvrr_stack+137587, dvrr_stack+61786, dvrr_stack+42854);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,315,dvrr_stack+139567, dvrr_stack+72716, dvrr_stack+68212);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,420,dvrr_stack+140512, dvrr_stack+78566, dvrr_stack+68975);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,540,dvrr_stack+141772, dvrr_stack+86076, dvrr_stack+70916);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,675,dvrr_stack+143392, dvrr_stack+95457, dvrr_stack+76271);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,825,dvrr_stack+145417, dvrr_stack+106920, dvrr_stack+83226);

 /* compute (4 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,990,dvrr_stack+147892, dvrr_stack+120949, dvrr_stack+91992);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,126,dvrr_stack+150862, dvrr_stack+2495, dvrr_stack+392);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,168,dvrr_stack+2495, dvrr_stack+5071, dvrr_stack+822);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,216,dvrr_stack+5071, dvrr_stack+8379, dvrr_stack+1775);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,270,dvrr_stack+8379, dvrr_stack+12513, dvrr_stack+4153);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,330,dvrr_stack+12513, dvrr_stack+17567, dvrr_stack+7239);

 /* compute (2 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,396,dvrr_stack+17567, dvrr_stack+23541, dvrr_stack+11127);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,210,dvrr_stack+13503, dvrr_stack+30280, dvrr_stack+27384);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,280,dvrr_stack+30280, dvrr_stack+34105, dvrr_stack+27846);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,360,dvrr_stack+34105, dvrr_stack+39020, dvrr_stack+29080);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,450,dvrr_stack+39020, dvrr_stack+45164, dvrr_stack+32575);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,550,dvrr_stack+45164, dvrr_stack+52676, dvrr_stack+37120);

 /* compute (3 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,660,dvrr_stack+52676, dvrr_stack+61786, dvrr_stack+42854);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,315,dvrr_stack+61786, dvrr_stack+72716, dvrr_stack+68212);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,420,dvrr_stack+72716, dvrr_stack+78566, dvrr_stack+68975);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,540,dvrr_stack+78566, dvrr_stack+86076, dvrr_stack+70916);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,675,dvrr_stack+86076, dvrr_stack+95457, dvrr_stack+76271);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,825,dvrr_stack+95457, dvrr_stack+106920, dvrr_stack+83226);

 /* compute (4 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,990,dvrr_stack+106920, dvrr_stack+120949, dvrr_stack+91992);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+10899, dvrr_stack+74, dvrr_stack+21, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+3629, dvrr_stack+184, dvrr_stack+84, NULL, NULL, dvrr_stack+74);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+120949, dvrr_stack+3629, dvrr_stack+99, dvrr_stack+184, dvrr_stack+84, dvrr_stack+10899);

 /* compute (2 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+121039,dvrr_stack+392,dvrr_stack+120949,6);


 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,90,dvrr_stack+121309, dvrr_stack+121039, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+15509, dvrr_stack+1991, NULL);
 tmp = dvrr_stack + 15509;
 target_ptr = Libderiv->deriv_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+121399, dvrr_stack+990, NULL);
 tmp = dvrr_stack + 121399;
 target_ptr = Libderiv->deriv_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+121525, dvrr_stack+4423, NULL);
 tmp = dvrr_stack + 121525;
 target_ptr = Libderiv->deriv_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+121741, dvrr_stack+7569, NULL);
 tmp = dvrr_stack + 121741;
 target_ptr = Libderiv->deriv_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+122011, dvrr_stack+11523, NULL);
 tmp = dvrr_stack + 122011;
 target_ptr = Libderiv->deriv_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,396,dvrr_stack+122341, dvrr_stack+16379, NULL);
 tmp = dvrr_stack + 122341;
 target_ptr = Libderiv->deriv_classes[2][10][11];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,468,dvrr_stack+122737, dvrr_stack+22137, NULL);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+123205, dvrr_stack+15, dvrr_stack+9, NULL, NULL, dvrr_stack+0);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+123223, dvrr_stack+10899, dvrr_stack+20628, dvrr_stack+74, dvrr_stack+21, dvrr_stack+123205);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+123283, dvrr_stack+120949, dvrr_stack+27105, dvrr_stack+3629, dvrr_stack+99, dvrr_stack+123223);

 /* compute (3 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+123433,dvrr_stack+27384,dvrr_stack+123283,10);


 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+123883, dvrr_stack+123433, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+124033, dvrr_stack+29440, NULL);
 tmp = dvrr_stack + 124033;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+124313, dvrr_stack+28126, NULL);
 tmp = dvrr_stack + 124313;
 target_ptr = Libderiv->deriv_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+5719, dvrr_stack+33025, NULL);
 tmp = dvrr_stack + 5719;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+124523, dvrr_stack+37670, NULL);
 tmp = dvrr_stack + 124523;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+124973, dvrr_stack+43514, NULL);
 tmp = dvrr_stack + 124973;
 target_ptr = Libderiv->deriv_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,660,dvrr_stack+125523, dvrr_stack+50696, NULL);
 tmp = dvrr_stack + 125523;
 target_ptr = Libderiv->deriv_classes[3][10][11];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,780,dvrr_stack+109890, dvrr_stack+59446, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1658, dvrr_stack+0, dvrr_stack+6, NULL, NULL, Data->F+4);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+1368, dvrr_stack+123205, dvrr_stack+21318, dvrr_stack+15, dvrr_stack+9, dvrr_stack+1658);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+126183, dvrr_stack+123223, dvrr_stack+21366, dvrr_stack+10899, dvrr_stack+20628, dvrr_stack+1368);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+126283, dvrr_stack+123283, dvrr_stack+67726, dvrr_stack+120949, dvrr_stack+27105, dvrr_stack+126183);

 /* compute (4 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+110670,dvrr_stack+68212,dvrr_stack+126283,15);


 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,225,dvrr_stack+126508, dvrr_stack+110670, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+31120, dvrr_stack+71456, NULL);
 tmp = dvrr_stack + 31120;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+111345, dvrr_stack+69395, NULL);
 tmp = dvrr_stack + 111345;
 target_ptr = Libderiv->deriv_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+97932, dvrr_stack+76946, NULL);
 tmp = dvrr_stack + 97932;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+98472, dvrr_stack+84051, NULL);
 tmp = dvrr_stack + 98472;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+88101, dvrr_stack+92982, NULL);
 tmp = dvrr_stack + 88101;
 target_ptr = Libderiv->deriv_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+62731, dvrr_stack+103950, NULL);
 tmp = dvrr_stack + 62731;
 target_ptr = Libderiv->deriv_classes[4][10][11];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1170,dvrr_stack+63721, dvrr_stack+117439, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,90,dvrr_stack+126733, dvrr_stack+121039, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+111660, dvrr_stack+1991, NULL);
 tmp = dvrr_stack + 111660;
 target_ptr = Libderiv->deriv_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+99147, dvrr_stack+990, NULL);
 tmp = dvrr_stack + 99147;
 target_ptr = Libderiv->deriv_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+99273, dvrr_stack+4423, NULL);
 tmp = dvrr_stack + 99273;
 target_ptr = Libderiv->deriv_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+88926, dvrr_stack+7569, NULL);
 tmp = dvrr_stack + 88926;
 target_ptr = Libderiv->deriv_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+80186, dvrr_stack+11523, NULL);
 tmp = dvrr_stack + 80186;
 target_ptr = Libderiv->deriv_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+80516, dvrr_stack+16379, NULL);
 tmp = dvrr_stack + 80516;
 target_ptr = Libderiv->deriv_classes[2][10][10];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,468,dvrr_stack+73976, dvrr_stack+22137, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+80912, dvrr_stack+123433, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+64891, dvrr_stack+29440, NULL);
 tmp = dvrr_stack + 64891;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+65171, dvrr_stack+28126, NULL);
 tmp = dvrr_stack + 65171;
 target_ptr = Libderiv->deriv_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+65381, dvrr_stack+33025, NULL);
 tmp = dvrr_stack + 65381;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+54656, dvrr_stack+37670, NULL);
 tmp = dvrr_stack + 54656;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+55106, dvrr_stack+43514, NULL);
 tmp = dvrr_stack + 55106;
 target_ptr = Libderiv->deriv_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+46814, dvrr_stack+50696, NULL);
 tmp = dvrr_stack + 46814;
 target_ptr = Libderiv->deriv_classes[3][10][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,780,dvrr_stack+40370, dvrr_stack+59446, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+55656, dvrr_stack+110670, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+35185, dvrr_stack+71456, NULL);
 tmp = dvrr_stack + 35185;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+47474, dvrr_stack+69395, NULL);
 tmp = dvrr_stack + 47474;
 target_ptr = Libderiv->deriv_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+23541, dvrr_stack+76946, NULL);
 tmp = dvrr_stack + 23541;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+24081, dvrr_stack+84051, NULL);
 tmp = dvrr_stack + 24081;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+24756, dvrr_stack+92982, NULL);
 tmp = dvrr_stack + 24756;
 target_ptr = Libderiv->deriv_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+151240, dvrr_stack+103950, NULL);
 tmp = dvrr_stack + 151240;
 target_ptr = Libderiv->deriv_classes[4][10][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1170,dvrr_stack+152230, dvrr_stack+117439, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+89196, dvrr_stack+121039, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+121039, dvrr_stack+1991, NULL);
 tmp = dvrr_stack + 121039;
 target_ptr = Libderiv->deriv_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+1991, dvrr_stack+990, NULL);
 tmp = dvrr_stack + 1991;
 target_ptr = Libderiv->deriv_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+990, dvrr_stack+4423, NULL);
 tmp = dvrr_stack + 990;
 target_ptr = Libderiv->deriv_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+4423, dvrr_stack+7569, NULL);
 tmp = dvrr_stack + 4423;
 target_ptr = Libderiv->deriv_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+7569, dvrr_stack+11523, NULL);
 tmp = dvrr_stack + 7569;
 target_ptr = Libderiv->deriv_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+11523, dvrr_stack+16379, NULL);
 tmp = dvrr_stack + 11523;
 target_ptr = Libderiv->deriv_classes[2][10][9];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,468,dvrr_stack+16379, dvrr_stack+22137, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+22137, dvrr_stack+123433, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+123433, dvrr_stack+29440, NULL);
 tmp = dvrr_stack + 123433;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+29440, dvrr_stack+28126, NULL);
 tmp = dvrr_stack + 29440;
 target_ptr = Libderiv->deriv_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+28126, dvrr_stack+33025, NULL);
 tmp = dvrr_stack + 28126;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+33025, dvrr_stack+37670, NULL);
 tmp = dvrr_stack + 33025;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+37670, dvrr_stack+43514, NULL);
 tmp = dvrr_stack + 37670;
 target_ptr = Libderiv->deriv_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+43514, dvrr_stack+50696, NULL);
 tmp = dvrr_stack + 43514;
 target_ptr = Libderiv->deriv_classes[3][10][9];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,780,dvrr_stack+50696, dvrr_stack+59446, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+59446, dvrr_stack+110670, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+110670, dvrr_stack+71456, NULL);
 tmp = dvrr_stack + 110670;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+71456, dvrr_stack+69395, NULL);
 tmp = dvrr_stack + 71456;
 target_ptr = Libderiv->deriv_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+69395, dvrr_stack+76946, NULL);
 tmp = dvrr_stack + 69395;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+76946, dvrr_stack+84051, NULL);
 tmp = dvrr_stack + 76946;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+84051, dvrr_stack+92982, NULL);
 tmp = dvrr_stack + 84051;
 target_ptr = Libderiv->deriv_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+44174, dvrr_stack+103950, NULL);
 tmp = dvrr_stack + 44174;
 target_ptr = Libderiv->deriv_classes[4][10][9];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1170,dvrr_stack+103950, dvrr_stack+117439, NULL);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+99489, dvrr_stack+68, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+89286, dvrr_stack+174, dvrr_stack+74, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+117439, dvrr_stack+89286, dvrr_stack+10899, dvrr_stack+174, dvrr_stack+74, dvrr_stack+99489);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+74, dvrr_stack+392, dvrr_stack+117439);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+117499, dvrr_stack+1775, dvrr_stack+392);
 tmp = dvrr_stack + 117499;
 target_ptr = Libderiv->deriv_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+117667, dvrr_stack+822, dvrr_stack+120949);
 tmp = dvrr_stack + 117667;
 target_ptr = Libderiv->deriv_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+117793, dvrr_stack+4153, dvrr_stack+822);
 tmp = dvrr_stack + 117793;
 target_ptr = Libderiv->deriv_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+28486, dvrr_stack+7239, dvrr_stack+1775);
 tmp = dvrr_stack + 28486;
 target_ptr = Libderiv->deriv_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+118009, dvrr_stack+11127, dvrr_stack+4153);
 tmp = dvrr_stack + 118009;
 target_ptr = Libderiv->deriv_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+118339, dvrr_stack+15911, dvrr_stack+7239);
 tmp = dvrr_stack + 118339;
 target_ptr = Libderiv->deriv_classes[2][10][8];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,6,1,dvrr_stack+118735, dvrr_stack+21591, dvrr_stack+11127);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1440, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+3);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+119203, dvrr_stack+99489, dvrr_stack+123205, dvrr_stack+68, dvrr_stack+15, dvrr_stack+1440);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+119239, dvrr_stack+117439, dvrr_stack+123223, dvrr_stack+89286, dvrr_stack+10899, dvrr_stack+119203);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+119339, dvrr_stack+27384, dvrr_stack+119239);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+119489, dvrr_stack+29080, dvrr_stack+27384);
 tmp = dvrr_stack + 119489;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+119769, dvrr_stack+27846, dvrr_stack+123283);
 tmp = dvrr_stack + 119769;
 target_ptr = Libderiv->deriv_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+119979, dvrr_stack+32575, dvrr_stack+27846);
 tmp = dvrr_stack + 119979;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+120339, dvrr_stack+37120, dvrr_stack+29080);
 tmp = dvrr_stack + 120339;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+105120, dvrr_stack+42854, dvrr_stack+32575);
 tmp = dvrr_stack + 105120;
 target_ptr = Libderiv->deriv_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+105670, dvrr_stack+49916, dvrr_stack+37120);
 tmp = dvrr_stack + 105670;
 target_ptr = Libderiv->deriv_classes[3][10][8];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,10,1,dvrr_stack+92982, dvrr_stack+58536, dvrr_stack+42854);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+10899, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+10902, dvrr_stack+1440, dvrr_stack+1658, dvrr_stack+3, dvrr_stack+0, dvrr_stack+10899);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+120789, dvrr_stack+119203, dvrr_stack+1368, dvrr_stack+99489, dvrr_stack+123205, dvrr_stack+10902);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+106330, dvrr_stack+119239, dvrr_stack+126183, dvrr_stack+117439, dvrr_stack+123223, dvrr_stack+120789);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+106480, dvrr_stack+68212, dvrr_stack+106330);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+93762, dvrr_stack+70916, dvrr_stack+68212);
 tmp = dvrr_stack + 93762;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+94182, dvrr_stack+68975, dvrr_stack+126283);
 tmp = dvrr_stack + 94182;
 target_ptr = Libderiv->deriv_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+94497, dvrr_stack+76271, dvrr_stack+68975);
 tmp = dvrr_stack + 94497;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+84876, dvrr_stack+83226, dvrr_stack+70916);
 tmp = dvrr_stack + 84876;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+77621, dvrr_stack+91992, dvrr_stack+76271);
 tmp = dvrr_stack + 77621;
 target_ptr = Libderiv->deriv_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+59671, dvrr_stack+102780, dvrr_stack+83226);
 tmp = dvrr_stack + 59671;
 target_ptr = Libderiv->deriv_classes[4][10][8];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,15,1,dvrr_stack+51476, dvrr_stack+116074, dvrr_stack+91992);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+120789, dvrr_stack+392, dvrr_stack+117439);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+106705, dvrr_stack+1775, dvrr_stack+392);
 tmp = dvrr_stack + 106705;
 target_ptr = Libderiv->deriv_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+95037, dvrr_stack+822, dvrr_stack+120949);
 tmp = dvrr_stack + 95037;
 target_ptr = Libderiv->deriv_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+95163, dvrr_stack+4153, dvrr_stack+822);
 tmp = dvrr_stack + 95163;
 target_ptr = Libderiv->deriv_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+85551, dvrr_stack+7239, dvrr_stack+1775);
 tmp = dvrr_stack + 85551;
 target_ptr = Libderiv->deriv_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+69935, dvrr_stack+11127, dvrr_stack+4153);
 tmp = dvrr_stack + 69935;
 target_ptr = Libderiv->deriv_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+71771, dvrr_stack+15911, dvrr_stack+7239);
 tmp = dvrr_stack + 71771;
 target_ptr = Libderiv->deriv_classes[2][10][7];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,6,1,dvrr_stack+72167, dvrr_stack+21591, dvrr_stack+11127);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+85821, dvrr_stack+27384, dvrr_stack+119239);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+60661, dvrr_stack+29080, dvrr_stack+27384);
 tmp = dvrr_stack + 60661;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+111090, dvrr_stack+27846, dvrr_stack+123283);
 tmp = dvrr_stack + 111090;
 target_ptr = Libderiv->deriv_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+60941, dvrr_stack+32575, dvrr_stack+27846);
 tmp = dvrr_stack + 60941;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+61301, dvrr_stack+37120, dvrr_stack+29080);
 tmp = dvrr_stack + 61301;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+38220, dvrr_stack+42854, dvrr_stack+32575);
 tmp = dvrr_stack + 38220;
 target_ptr = Libderiv->deriv_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+22287, dvrr_stack+49916, dvrr_stack+37120);
 tmp = dvrr_stack + 22287;
 target_ptr = Libderiv->deriv_classes[3][10][7];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,10,1,dvrr_stack+18755, dvrr_stack+58536, dvrr_stack+42854);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+38770, dvrr_stack+68212, dvrr_stack+106330);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+33475, dvrr_stack+70916, dvrr_stack+68212);
 tmp = dvrr_stack + 33475;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+29650, dvrr_stack+68975, dvrr_stack+126283);
 tmp = dvrr_stack + 29650;
 target_ptr = Libderiv->deriv_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+22947, dvrr_stack+76271, dvrr_stack+68975);
 tmp = dvrr_stack + 22947;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+16847, dvrr_stack+83226, dvrr_stack+70916);
 tmp = dvrr_stack + 16847;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+153400, dvrr_stack+91992, dvrr_stack+76271);
 tmp = dvrr_stack + 153400;
 target_ptr = Libderiv->deriv_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+154225, dvrr_stack+102780, dvrr_stack+83226);
 tmp = dvrr_stack + 154225;
 target_ptr = Libderiv->deriv_classes[4][10][7];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,15,1,dvrr_stack+155215, dvrr_stack+116074, dvrr_stack+91992);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+85971, dvrr_stack+392, dvrr_stack+117439);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+33895, dvrr_stack+1775, dvrr_stack+392);
 tmp = dvrr_stack + 33895;
 target_ptr = Libderiv->deriv_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+29965, dvrr_stack+822, dvrr_stack+120949);
 tmp = dvrr_stack + 29965;
 target_ptr = Libderiv->deriv_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+11919, dvrr_stack+4153, dvrr_stack+822);
 tmp = dvrr_stack + 11919;
 target_ptr = Libderiv->deriv_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+12135, dvrr_stack+7239, dvrr_stack+1775);
 tmp = dvrr_stack + 12135;
 target_ptr = Libderiv->deriv_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+7899, dvrr_stack+11127, dvrr_stack+4153);
 tmp = dvrr_stack + 7899;
 target_ptr = Libderiv->deriv_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+9189, dvrr_stack+15911, dvrr_stack+7239);
 tmp = dvrr_stack + 9189;
 target_ptr = Libderiv->deriv_classes[2][10][6];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,6,1,dvrr_stack+15911, dvrr_stack+21591, dvrr_stack+11127);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+8229, dvrr_stack+27384, dvrr_stack+119239);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+4693, dvrr_stack+29080, dvrr_stack+27384);
 tmp = dvrr_stack + 4693;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+2117, dvrr_stack+27846, dvrr_stack+123283);
 tmp = dvrr_stack + 2117;
 target_ptr = Libderiv->deriv_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+20954, dvrr_stack+32575, dvrr_stack+27846);
 tmp = dvrr_stack + 20954;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+21561, dvrr_stack+37120, dvrr_stack+29080);
 tmp = dvrr_stack + 21561;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+156385, dvrr_stack+42854, dvrr_stack+32575);
 tmp = dvrr_stack + 156385;
 target_ptr = Libderiv->deriv_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+156935, dvrr_stack+49916, dvrr_stack+37120);
 tmp = dvrr_stack + 156935;
 target_ptr = Libderiv->deriv_classes[3][10][6];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,10,1,dvrr_stack+157595, dvrr_stack+58536, dvrr_stack+42854);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+25581, dvrr_stack+68212, dvrr_stack+106330);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+58508, dvrr_stack+70916, dvrr_stack+68212);
 tmp = dvrr_stack + 58508;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+58928, dvrr_stack+68975, dvrr_stack+126283);
 tmp = dvrr_stack + 58928;
 target_ptr = Libderiv->deriv_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+158375, dvrr_stack+76271, dvrr_stack+68975);
 tmp = dvrr_stack + 158375;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+158915, dvrr_stack+83226, dvrr_stack+70916);
 tmp = dvrr_stack + 158915;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+159590, dvrr_stack+91992, dvrr_stack+76271);
 tmp = dvrr_stack + 159590;
 target_ptr = Libderiv->deriv_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+160415, dvrr_stack+102780, dvrr_stack+83226);
 tmp = dvrr_stack + 160415;
 target_ptr = Libderiv->deriv_classes[4][10][6];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,15,1,dvrr_stack+161405, dvrr_stack+116074, dvrr_stack+91992);

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+30091,dvrr_stack+738,dvrr_stack+329,3);


 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+106330, dvrr_stack+30091, NULL);

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+2999,dvrr_stack+1667,dvrr_stack+738,3);


 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+106393, dvrr_stack+2999, NULL);

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+115803,dvrr_stack+4018,dvrr_stack+1667,3);


 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+12405, dvrr_stack+115803, NULL);

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+116127,dvrr_stack+7074,dvrr_stack+4018,3);


 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+120879, dvrr_stack+116127, NULL);

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+116532,dvrr_stack+10929,dvrr_stack+7074,3);


 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+123713, dvrr_stack+116532, NULL);

 /* compute (1 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+162575,dvrr_stack+15677,dvrr_stack+10929,3);


 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,198,dvrr_stack+59243, dvrr_stack+162575, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1440, dvrr_stack+6, dvrr_stack+31, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+99489, dvrr_stack+34, dvrr_stack+165, NULL, NULL, dvrr_stack+31);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+119203, dvrr_stack+21318, dvrr_stack+99489, dvrr_stack+9, dvrr_stack+34, dvrr_stack+1440);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+10899, dvrr_stack+220, dvrr_stack+580, NULL, NULL, dvrr_stack+165);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+119239, dvrr_stack+21336, dvrr_stack+10899, dvrr_stack+40, dvrr_stack+220, dvrr_stack+99489);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+78446, dvrr_stack+21366, dvrr_stack+119239, dvrr_stack+20628, dvrr_stack+21336, dvrr_stack+119203);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+111300, dvrr_stack+590, dvrr_stack+1459, NULL, NULL, dvrr_stack+580);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+9585, dvrr_stack+21426, dvrr_stack+111300, dvrr_stack+230, dvrr_stack+590, dvrr_stack+10899);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1206, dvrr_stack+21471, dvrr_stack+9585, dvrr_stack+20658, dvrr_stack+21426, dvrr_stack+119239);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+117027, dvrr_stack+67726, dvrr_stack+1206, dvrr_stack+27105, dvrr_stack+21471, dvrr_stack+78446);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+27105, dvrr_stack+1474, dvrr_stack+3753, NULL, NULL, dvrr_stack+1459);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+22011, dvrr_stack+20537, dvrr_stack+27105, dvrr_stack+605, dvrr_stack+1474, dvrr_stack+111300);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+117252, dvrr_stack+67876, dvrr_stack+22011, dvrr_stack+27195, dvrr_stack+20537, dvrr_stack+9585);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+163169, dvrr_stack+68002, dvrr_stack+117252, dvrr_stack+27258, dvrr_stack+67876, dvrr_stack+1206);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+163484, dvrr_stack+68212, dvrr_stack+163169, dvrr_stack+27384, dvrr_stack+68002, dvrr_stack+117027);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+27168, dvrr_stack+3774, dvrr_stack+6745, NULL, NULL, dvrr_stack+3753);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2327, dvrr_stack+245, dvrr_stack+27168, dvrr_stack+1495, dvrr_stack+3774, dvrr_stack+27105);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+163925, dvrr_stack+68527, dvrr_stack+2327, dvrr_stack+27594, dvrr_stack+245, dvrr_stack+22011);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+164205, dvrr_stack+68695, dvrr_stack+163925, dvrr_stack+27678, dvrr_stack+68527, dvrr_stack+117252);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+164625, dvrr_stack+68975, dvrr_stack+164205, dvrr_stack+27846, dvrr_stack+68695, dvrr_stack+163169);

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+165213,dvrr_stack+164625,dvrr_stack+163484,21);


 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+166536, dvrr_stack+165213, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27594, dvrr_stack+6773, dvrr_stack+10529, NULL, NULL, dvrr_stack+6745);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+166977, dvrr_stack+626, dvrr_stack+27594, dvrr_stack+3802, dvrr_stack+6773, dvrr_stack+27168);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+167193, dvrr_stack+70340, dvrr_stack+166977, dvrr_stack+28756, dvrr_stack+626, dvrr_stack+2327);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+167553, dvrr_stack+70556, dvrr_stack+167193, dvrr_stack+28864, dvrr_stack+70340, dvrr_stack+163925);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+168093, dvrr_stack+70916, dvrr_stack+167553, dvrr_stack+29080, dvrr_stack+70556, dvrr_stack+164205);

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+168849,dvrr_stack+168093,dvrr_stack+164625,21);


 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+170613, dvrr_stack+168849, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+28756, dvrr_stack+10565, dvrr_stack+15199, NULL, NULL, dvrr_stack+10529);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+171201, dvrr_stack+1523, dvrr_stack+28756, dvrr_stack+6809, dvrr_stack+10565, dvrr_stack+27594);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+171471, dvrr_stack+75551, dvrr_stack+171201, dvrr_stack+32170, dvrr_stack+1523, dvrr_stack+166977);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+171921, dvrr_stack+75821, dvrr_stack+171471, dvrr_stack+32305, dvrr_stack+75551, dvrr_stack+167193);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+172596, dvrr_stack+76271, dvrr_stack+171921, dvrr_stack+32575, dvrr_stack+75821, dvrr_stack+167553);

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+173541,dvrr_stack+172596,dvrr_stack+168093,21);


 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+175809, dvrr_stack+173541, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32170, dvrr_stack+15244, dvrr_stack+20755, NULL, NULL, dvrr_stack+15199);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+176565, dvrr_stack+3838, dvrr_stack+32170, dvrr_stack+10610, dvrr_stack+15244, dvrr_stack+28756);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+176895, dvrr_stack+82346, dvrr_stack+176565, dvrr_stack+36625, dvrr_stack+3838, dvrr_stack+171201);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+177445, dvrr_stack+82676, dvrr_stack+176895, dvrr_stack+36790, dvrr_stack+82346, dvrr_stack+171471);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+178270, dvrr_stack+83226, dvrr_stack+177445, dvrr_stack+37120, dvrr_stack+82676, dvrr_stack+171921);

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+179425,dvrr_stack+178270,dvrr_stack+172596,21);


 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+182260, dvrr_stack+179425, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+36625, dvrr_stack+20810, dvrr_stack+10323, NULL, NULL, dvrr_stack+20755);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+183205, dvrr_stack+6854, dvrr_stack+36625, dvrr_stack+15299, dvrr_stack+20810, dvrr_stack+32170);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+183601, dvrr_stack+90936, dvrr_stack+183205, dvrr_stack+42260, dvrr_stack+6854, dvrr_stack+176565);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+184261, dvrr_stack+91332, dvrr_stack+183601, dvrr_stack+42458, dvrr_stack+90936, dvrr_stack+176895);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+185251, dvrr_stack+91992, dvrr_stack+184261, dvrr_stack+42854, dvrr_stack+91332, dvrr_stack+177445);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+186637,dvrr_stack+185251,dvrr_stack+178270,21);


 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+190102, dvrr_stack+186637, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42260, dvrr_stack+15073, dvrr_stack+15431, NULL, NULL, dvrr_stack+10323);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+191257, dvrr_stack+10665, dvrr_stack+42260, dvrr_stack+20876, dvrr_stack+15073, dvrr_stack+36625);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+191725, dvrr_stack+101532, dvrr_stack+191257, dvrr_stack+49214, dvrr_stack+10665, dvrr_stack+183205);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+192505, dvrr_stack+102000, dvrr_stack+191725, dvrr_stack+49448, dvrr_stack+101532, dvrr_stack+183601);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+193675, dvrr_stack+102780, dvrr_stack+192505, dvrr_stack+49916, dvrr_stack+102000, dvrr_stack+184261);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+195313,dvrr_stack+193675,dvrr_stack+185251,21);


 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+101532, dvrr_stack+195313, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+102918, dvrr_stack+30091, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+102981, dvrr_stack+2999, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+103065, dvrr_stack+115803, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+103173, dvrr_stack+116127, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+103308, dvrr_stack+116532, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+103473, dvrr_stack+162575, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+49214, dvrr_stack+165213, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+49655, dvrr_stack+168849, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+191257, dvrr_stack+173541, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+192013, dvrr_stack+179425, NULL);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+199471, dvrr_stack+186637, NULL);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+200626, dvrr_stack+195313, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+103671, dvrr_stack+30091, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+30091, dvrr_stack+2999, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+2999, dvrr_stack+115803, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+115803, dvrr_stack+116127, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+115938, dvrr_stack+116532, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+116103, dvrr_stack+162575, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+162575, dvrr_stack+165213, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+165213, dvrr_stack+168849, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+168849, dvrr_stack+173541, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+173541, dvrr_stack+179425, NULL);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+179425, dvrr_stack+186637, NULL);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+186637, dvrr_stack+195313, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+195313, dvrr_stack+738, dvrr_stack+3629);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+195376, dvrr_stack+1667, dvrr_stack+329);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+195460, dvrr_stack+4018, dvrr_stack+738);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+195568, dvrr_stack+7074, dvrr_stack+1667);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+195703, dvrr_stack+10929, dvrr_stack+4018);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+195868, dvrr_stack+15677, dvrr_stack+7074);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+106477, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+196066, dvrr_stack+1658, dvrr_stack+1440, dvrr_stack+0, dvrr_stack+6, dvrr_stack+106477);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+196084, dvrr_stack+1368, dvrr_stack+119203, dvrr_stack+123205, dvrr_stack+21318, dvrr_stack+196066);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+196144, dvrr_stack+126183, dvrr_stack+78446, dvrr_stack+123223, dvrr_stack+21366, dvrr_stack+196084);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+196294, dvrr_stack+126283, dvrr_stack+117027, dvrr_stack+123283, dvrr_stack+67726, dvrr_stack+196144);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+196609, dvrr_stack+164625, dvrr_stack+196294);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+197050, dvrr_stack+168093, dvrr_stack+163484);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+197638, dvrr_stack+172596, dvrr_stack+164625);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+198394, dvrr_stack+178270, dvrr_stack+168093);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+188023, dvrr_stack+185251, dvrr_stack+172596);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+180580, dvrr_stack+193675, dvrr_stack+178270);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+126183, dvrr_stack+738, dvrr_stack+3629);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+126246, dvrr_stack+1667, dvrr_stack+329);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+126330, dvrr_stack+4018, dvrr_stack+738);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+196066, dvrr_stack+7074, dvrr_stack+1667);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+123205, dvrr_stack+10929, dvrr_stack+4018);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+189178, dvrr_stack+15677, dvrr_stack+7074);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+189376, dvrr_stack+164625, dvrr_stack+196294);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+174486, dvrr_stack+168093, dvrr_stack+163484);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+169605, dvrr_stack+172596, dvrr_stack+164625);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+202012, dvrr_stack+178270, dvrr_stack+168093);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+202957, dvrr_stack+185251, dvrr_stack+172596);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+204112, dvrr_stack+193675, dvrr_stack+178270);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+123370, dvrr_stack+738, dvrr_stack+3629);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+196201, dvrr_stack+1667, dvrr_stack+329);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+199339, dvrr_stack+4018, dvrr_stack+738);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+189817, dvrr_stack+7074, dvrr_stack+1667);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+181966, dvrr_stack+10929, dvrr_stack+4018);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+175074, dvrr_stack+15677, dvrr_stack+7074);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+175272, dvrr_stack+164625, dvrr_stack+196294);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+165801, dvrr_stack+168093, dvrr_stack+163484);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+205498, dvrr_stack+172596, dvrr_stack+164625);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+206254, dvrr_stack+178270, dvrr_stack+168093);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+207199, dvrr_stack+185251, dvrr_stack+172596);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+208354, dvrr_stack+193675, dvrr_stack+178270);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+15677, dvrr_stack+392, dvrr_stack+199);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+196285, dvrr_stack+68212, dvrr_stack+392);
 tmp = dvrr_stack + 196285;
 target_ptr = Libderiv->deriv_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+15740, dvrr_stack+822, dvrr_stack+546);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+116301, dvrr_stack+68975, dvrr_stack+822);
 tmp = dvrr_stack + 116301;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+196495, dvrr_stack+1775, dvrr_stack+1404);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+116581, dvrr_stack+70916, dvrr_stack+1775);
 tmp = dvrr_stack + 116581;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+189952, dvrr_stack+4153, dvrr_stack+3674);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+50243, dvrr_stack+76271, dvrr_stack+4153);
 tmp = dvrr_stack + 50243;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+170361, dvrr_stack+7239, dvrr_stack+6638);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+192958, dvrr_stack+83226, dvrr_stack+7239);
 tmp = dvrr_stack + 192958;
 target_ptr = Libderiv->deriv_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+103734, dvrr_stack+11127, dvrr_stack+10389);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+193508, dvrr_stack+91992, dvrr_stack+11127);
 tmp = dvrr_stack + 193508;
 target_ptr = Libderiv->deriv_classes[3][10][2];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+182131, dvrr_stack+27384, dvrr_stack+329);
 tmp = dvrr_stack + 182131;
 target_ptr = Libderiv->deriv_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+194168, dvrr_stack+163484, dvrr_stack+27384);
 tmp = dvrr_stack + 194168;
 target_ptr = Libderiv->deriv_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+194483, dvrr_stack+27846, dvrr_stack+738);
 tmp = dvrr_stack + 194483;
 target_ptr = Libderiv->deriv_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+194651, dvrr_stack+164625, dvrr_stack+27846);
 tmp = dvrr_stack + 194651;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+195071, dvrr_stack+29080, dvrr_stack+1667);
 tmp = dvrr_stack + 195071;
 target_ptr = Libderiv->deriv_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+42260, dvrr_stack+168093, dvrr_stack+29080);
 tmp = dvrr_stack + 42260;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+36823, dvrr_stack+32575, dvrr_stack+4018);
 tmp = dvrr_stack + 36823;
 target_ptr = Libderiv->deriv_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+209740, dvrr_stack+172596, dvrr_stack+32575);
 tmp = dvrr_stack + 209740;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+210415, dvrr_stack+37120, dvrr_stack+7074);
 tmp = dvrr_stack + 210415;
 target_ptr = Libderiv->deriv_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+210745, dvrr_stack+178270, dvrr_stack+37120);
 tmp = dvrr_stack + 210745;
 target_ptr = Libderiv->deriv_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+211570, dvrr_stack+42854, dvrr_stack+10929);
 tmp = dvrr_stack + 211570;
 target_ptr = Libderiv->deriv_classes[2][10][2];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+211966, dvrr_stack+185251, dvrr_stack+42854);
 tmp = dvrr_stack + 211966;
 target_ptr = Libderiv->deriv_classes[4][10][2];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+106477, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+1658, dvrr_stack+31, dvrr_stack+65, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+103932, dvrr_stack+1440, dvrr_stack+1658, dvrr_stack+6, dvrr_stack+31, dvrr_stack+106477);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+15824, dvrr_stack+165, dvrr_stack+574, NULL, NULL, dvrr_stack+65);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+3802, dvrr_stack+99489, dvrr_stack+15824, dvrr_stack+34, dvrr_stack+165, dvrr_stack+1658);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+15842, dvrr_stack+119203, dvrr_stack+3802, dvrr_stack+21318, dvrr_stack+99489, dvrr_stack+103932);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+89286, dvrr_stack+580, dvrr_stack+1449, NULL, NULL, dvrr_stack+574);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+126438, dvrr_stack+10899, dvrr_stack+89286, dvrr_stack+220, dvrr_stack+580, dvrr_stack+15824);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+166389, dvrr_stack+119239, dvrr_stack+126438, dvrr_stack+21336, dvrr_stack+10899, dvrr_stack+3802);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+163016, dvrr_stack+78446, dvrr_stack+166389, dvrr_stack+21366, dvrr_stack+119239, dvrr_stack+15842);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+3629, dvrr_stack+1459, dvrr_stack+3738, NULL, NULL, dvrr_stack+1449);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+78446, dvrr_stack+111300, dvrr_stack+3629, dvrr_stack+590, dvrr_stack+1459, dvrr_stack+89286);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+10610, dvrr_stack+9585, dvrr_stack+78446, dvrr_stack+21426, dvrr_stack+111300, dvrr_stack+126438);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+32335, dvrr_stack+1206, dvrr_stack+10610, dvrr_stack+21471, dvrr_stack+9585, dvrr_stack+166389);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+212956, dvrr_stack+117027, dvrr_stack+32335, dvrr_stack+67726, dvrr_stack+1206, dvrr_stack+163016);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+163016, dvrr_stack+3753, dvrr_stack+6724, NULL, NULL, dvrr_stack+3738);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1206, dvrr_stack+27105, dvrr_stack+163016, dvrr_stack+1474, dvrr_stack+3753, dvrr_stack+3629);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+116941, dvrr_stack+22011, dvrr_stack+1206, dvrr_stack+20537, dvrr_stack+27105, dvrr_stack+78446);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+213271, dvrr_stack+117252, dvrr_stack+116941, dvrr_stack+67876, dvrr_stack+22011, dvrr_stack+10610);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+213586, dvrr_stack+163169, dvrr_stack+213271, dvrr_stack+68002, dvrr_stack+117252, dvrr_stack+32335);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+214027, dvrr_stack+163484, dvrr_stack+213586, dvrr_stack+68212, dvrr_stack+163169, dvrr_stack+212956);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+67726, dvrr_stack+214027, dvrr_stack+68212);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+212956, dvrr_stack+6745, dvrr_stack+10501, NULL, NULL, dvrr_stack+6724);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+213040, dvrr_stack+27168, dvrr_stack+212956, dvrr_stack+3774, dvrr_stack+6745, dvrr_stack+163016);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+163016, dvrr_stack+2327, dvrr_stack+213040, dvrr_stack+245, dvrr_stack+27168, dvrr_stack+1206);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+214615, dvrr_stack+163925, dvrr_stack+163016, dvrr_stack+68527, dvrr_stack+2327, dvrr_stack+116941);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+215035, dvrr_stack+164205, dvrr_stack+214615, dvrr_stack+68695, dvrr_stack+163925, dvrr_stack+213271);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+215623, dvrr_stack+164625, dvrr_stack+215035, dvrr_stack+68975, dvrr_stack+164205, dvrr_stack+213586);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+163925, dvrr_stack+215623, dvrr_stack+68975);

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+164513, dvrr_stack+10529, dvrr_stack+15163, NULL, NULL, dvrr_stack+10501);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+116941, dvrr_stack+27594, dvrr_stack+164513, dvrr_stack+6773, dvrr_stack+10529, dvrr_stack+212956);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+68527, dvrr_stack+166977, dvrr_stack+116941, dvrr_stack+626, dvrr_stack+27594, dvrr_stack+213040);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+212956, dvrr_stack+167193, dvrr_stack+68527, dvrr_stack+70340, dvrr_stack+166977, dvrr_stack+163016);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+216407, dvrr_stack+167553, dvrr_stack+212956, dvrr_stack+70556, dvrr_stack+167193, dvrr_stack+214615);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+217163, dvrr_stack+168093, dvrr_stack+216407, dvrr_stack+70916, dvrr_stack+167553, dvrr_stack+215035);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+214615, dvrr_stack+217163, dvrr_stack+70916);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+215371, dvrr_stack+15199, dvrr_stack+10455, NULL, NULL, dvrr_stack+15163);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+163016, dvrr_stack+28756, dvrr_stack+215371, dvrr_stack+10565, dvrr_stack+15199, dvrr_stack+164513);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+166977, dvrr_stack+171201, dvrr_stack+163016, dvrr_stack+1523, dvrr_stack+28756, dvrr_stack+116941);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+218171, dvrr_stack+171471, dvrr_stack+166977, dvrr_stack+75551, dvrr_stack+171201, dvrr_stack+68527);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+218846, dvrr_stack+171921, dvrr_stack+218171, dvrr_stack+75821, dvrr_stack+171471, dvrr_stack+212956);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+219791, dvrr_stack+172596, dvrr_stack+218846, dvrr_stack+76271, dvrr_stack+171921, dvrr_stack+216407);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+212956, dvrr_stack+219791, dvrr_stack+76271);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+216407, dvrr_stack+20755, dvrr_stack+6583, NULL, NULL, dvrr_stack+10455);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10455, dvrr_stack+32170, dvrr_stack+216407, dvrr_stack+15244, dvrr_stack+20755, dvrr_stack+215371);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+216572, dvrr_stack+176565, dvrr_stack+10455, dvrr_stack+3838, dvrr_stack+32170, dvrr_stack+163016);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+171201, dvrr_stack+176895, dvrr_stack+216572, dvrr_stack+82346, dvrr_stack+176565, dvrr_stack+166977);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+221051, dvrr_stack+177445, dvrr_stack+171201, dvrr_stack+82676, dvrr_stack+176895, dvrr_stack+218171);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+222206, dvrr_stack+178270, dvrr_stack+221051, dvrr_stack+83226, dvrr_stack+177445, dvrr_stack+218846);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+218171, dvrr_stack+222206, dvrr_stack+83226);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1206, dvrr_stack+10323, dvrr_stack+15365, NULL, NULL, dvrr_stack+6583);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+219326, dvrr_stack+36625, dvrr_stack+1206, dvrr_stack+20810, dvrr_stack+10323, dvrr_stack+216407);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+166977, dvrr_stack+183205, dvrr_stack+219326, dvrr_stack+6854, dvrr_stack+36625, dvrr_stack+10455);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+176565, dvrr_stack+183601, dvrr_stack+166977, dvrr_stack+90936, dvrr_stack+183205, dvrr_stack+216572);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+223746, dvrr_stack+184261, dvrr_stack+176565, dvrr_stack+91332, dvrr_stack+183601, dvrr_stack+171201);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+225132, dvrr_stack+185251, dvrr_stack+223746, dvrr_stack+91992, dvrr_stack+184261, dvrr_stack+221051);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+223746, dvrr_stack+225132, dvrr_stack+91992);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+221051, dvrr_stack+392, dvrr_stack+199);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+221114, dvrr_stack+68212, dvrr_stack+392);
 tmp = dvrr_stack + 221114;
 target_ptr = Libderiv->deriv_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+221324, dvrr_stack+822, dvrr_stack+546);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+221408, dvrr_stack+68975, dvrr_stack+822);
 tmp = dvrr_stack + 221408;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+221688, dvrr_stack+1775, dvrr_stack+1404);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+221796, dvrr_stack+70916, dvrr_stack+1775);
 tmp = dvrr_stack + 221796;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+171201, dvrr_stack+4153, dvrr_stack+3674);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+171336, dvrr_stack+76271, dvrr_stack+4153);
 tmp = dvrr_stack + 171336;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+171786, dvrr_stack+7239, dvrr_stack+6638);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+171951, dvrr_stack+83226, dvrr_stack+7239);
 tmp = dvrr_stack + 171951;
 target_ptr = Libderiv->deriv_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+36625, dvrr_stack+11127, dvrr_stack+10389);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+176565, dvrr_stack+91992, dvrr_stack+11127);
 tmp = dvrr_stack + 176565;
 target_ptr = Libderiv->deriv_classes[3][10][1];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+213901, dvrr_stack+27384, dvrr_stack+329);
 tmp = dvrr_stack + 213901;
 target_ptr = Libderiv->deriv_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+177225, dvrr_stack+163484, dvrr_stack+27384);
 tmp = dvrr_stack + 177225;
 target_ptr = Libderiv->deriv_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+2327, dvrr_stack+27846, dvrr_stack+738);
 tmp = dvrr_stack + 2327;
 target_ptr = Libderiv->deriv_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+177540, dvrr_stack+164625, dvrr_stack+27846);
 tmp = dvrr_stack + 177540;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+177960, dvrr_stack+29080, dvrr_stack+1667);
 tmp = dvrr_stack + 177960;
 target_ptr = Libderiv->deriv_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+183205, dvrr_stack+168093, dvrr_stack+29080);
 tmp = dvrr_stack + 183205;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+183745, dvrr_stack+32575, dvrr_stack+4018);
 tmp = dvrr_stack + 183745;
 target_ptr = Libderiv->deriv_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+184015, dvrr_stack+172596, dvrr_stack+32575);
 tmp = dvrr_stack + 184015;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+184690, dvrr_stack+37120, dvrr_stack+7074);
 tmp = dvrr_stack + 184690;
 target_ptr = Libderiv->deriv_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+90936, dvrr_stack+178270, dvrr_stack+37120);
 tmp = dvrr_stack + 90936;
 target_ptr = Libderiv->deriv_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+166977, dvrr_stack+42854, dvrr_stack+10929);
 tmp = dvrr_stack + 166977;
 target_ptr = Libderiv->deriv_classes[2][10][1];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+226980, dvrr_stack+185251, dvrr_stack+42854);
 tmp = dvrr_stack + 226980;
 target_ptr = Libderiv->deriv_classes[4][10][1];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+167373, dvrr_stack+214027, dvrr_stack+68212);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+216407, dvrr_stack+215623, dvrr_stack+68975);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+82346, dvrr_stack+217163, dvrr_stack+70916);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+227970, dvrr_stack+219791, dvrr_stack+76271);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+228915, dvrr_stack+222206, dvrr_stack+83226);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+230070, dvrr_stack+225132, dvrr_stack+91992);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+172501, dvrr_stack+392, dvrr_stack+199);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+185020, dvrr_stack+68212, dvrr_stack+392);
 tmp = dvrr_stack + 185020;
 target_ptr = Libderiv->deriv_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+392, dvrr_stack+822, dvrr_stack+546);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+10455, dvrr_stack+68975, dvrr_stack+822);
 tmp = dvrr_stack + 10455;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+822, dvrr_stack+1775, dvrr_stack+1404);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+219326, dvrr_stack+70916, dvrr_stack+1775);
 tmp = dvrr_stack + 219326;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+1775, dvrr_stack+4153, dvrr_stack+3674);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+1206, dvrr_stack+76271, dvrr_stack+4153);
 tmp = dvrr_stack + 1206;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+164, dvrr_stack+7239, dvrr_stack+6638);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+75551, dvrr_stack+83226, dvrr_stack+7239);
 tmp = dvrr_stack + 75551;
 target_ptr = Libderiv->deriv_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+7239, dvrr_stack+11127, dvrr_stack+10389);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+231456, dvrr_stack+91992, dvrr_stack+11127);
 tmp = dvrr_stack + 231456;
 target_ptr = Libderiv->deriv_classes[3][10][0];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+22011, dvrr_stack+27384, dvrr_stack+329);
 tmp = dvrr_stack + 22011;
 target_ptr = Libderiv->deriv_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+11127, dvrr_stack+163484, dvrr_stack+27384);
 tmp = dvrr_stack + 11127;
 target_ptr = Libderiv->deriv_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+216995, dvrr_stack+27846, dvrr_stack+738);
 tmp = dvrr_stack + 216995;
 target_ptr = Libderiv->deriv_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+6583, dvrr_stack+164625, dvrr_stack+27846);
 tmp = dvrr_stack + 6583;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+4153, dvrr_stack+29080, dvrr_stack+1667);
 tmp = dvrr_stack + 4153;
 target_ptr = Libderiv->deriv_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+163016, dvrr_stack+168093, dvrr_stack+29080);
 tmp = dvrr_stack + 163016;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+476, dvrr_stack+32575, dvrr_stack+4018);
 tmp = dvrr_stack + 476;
 target_ptr = Libderiv->deriv_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+167814, dvrr_stack+172596, dvrr_stack+32575);
 tmp = dvrr_stack + 167814;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+172564, dvrr_stack+37120, dvrr_stack+7074);
 tmp = dvrr_stack + 172564;
 target_ptr = Libderiv->deriv_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+32170, dvrr_stack+178270, dvrr_stack+37120);
 tmp = dvrr_stack + 32170;
 target_ptr = Libderiv->deriv_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+172894, dvrr_stack+42854, dvrr_stack+10929);
 tmp = dvrr_stack + 172894;
 target_ptr = Libderiv->deriv_classes[2][10][0];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+178176, dvrr_stack+185251, dvrr_stack+42854);
 tmp = dvrr_stack + 178176;
 target_ptr = Libderiv->deriv_classes[4][10][0];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+185230, dvrr_stack+214027, dvrr_stack+68212);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+214027, dvrr_stack+215623, dvrr_stack+68975);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+185671, dvrr_stack+217163, dvrr_stack+70916);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+217163, dvrr_stack+219791, dvrr_stack+76271);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+219686, dvrr_stack+222206, dvrr_stack+83226);

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+222156, dvrr_stack+225132, dvrr_stack+91992);

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,126,dvrr_stack+225132, dvrr_stack+3251, NULL);
 tmp = dvrr_stack + 225132;
 target_ptr = Libderiv->deriv2_classes[2][5][143];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,168,dvrr_stack+225258, dvrr_stack+6079, NULL);
 tmp = dvrr_stack + 225258;
 target_ptr = Libderiv->deriv2_classes[2][6][143];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,216,dvrr_stack+225426, dvrr_stack+9675, NULL);
 tmp = dvrr_stack + 225426;
 target_ptr = Libderiv->deriv2_classes[2][7][143];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,270,dvrr_stack+225642, dvrr_stack+14133, NULL);
 tmp = dvrr_stack + 225642;
 target_ptr = Libderiv->deriv2_classes[2][8][143];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,330,dvrr_stack+225912, dvrr_stack+19547, NULL);
 tmp = dvrr_stack + 225912;
 target_ptr = Libderiv->deriv2_classes[2][9][143];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,396,dvrr_stack+226242, dvrr_stack+25917, NULL);
 tmp = dvrr_stack + 226242;
 target_ptr = Libderiv->deriv2_classes[2][10][143];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,210,dvrr_stack+186427, dvrr_stack+31540, NULL);
 tmp = dvrr_stack + 186427;
 target_ptr = Libderiv->deriv2_classes[3][5][143];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,280,dvrr_stack+226638, dvrr_stack+35785, NULL);
 tmp = dvrr_stack + 226638;
 target_ptr = Libderiv->deriv2_classes[3][6][143];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,360,dvrr_stack+168489, dvrr_stack+41180, NULL);
 tmp = dvrr_stack + 168489;
 target_ptr = Libderiv->deriv2_classes[3][7][143];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,450,dvrr_stack+91761, dvrr_stack+47864, NULL);
 tmp = dvrr_stack + 91761;
 target_ptr = Libderiv->deriv2_classes[3][8][143];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,550,dvrr_stack+92211, dvrr_stack+55976, NULL);
 tmp = dvrr_stack + 92211;
 target_ptr = Libderiv->deriv2_classes[3][9][143];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,660,dvrr_stack+83102, dvrr_stack+65746, NULL);
 tmp = dvrr_stack + 83102;
 target_ptr = Libderiv->deriv2_classes[3][10][143];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,315,dvrr_stack+10735, dvrr_stack+74606, NULL);
 tmp = dvrr_stack + 10735;
 target_ptr = Libderiv->deriv2_classes[4][5][143];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,420,dvrr_stack+215371, dvrr_stack+81086, NULL);
 tmp = dvrr_stack + 215371;
 target_ptr = Libderiv->deriv2_classes[4][6][143];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,540,dvrr_stack+215791, dvrr_stack+89316, NULL);
 tmp = dvrr_stack + 215791;
 target_ptr = Libderiv->deriv2_classes[4][7][143];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,675,dvrr_stack+76101, dvrr_stack+99507, NULL);
 tmp = dvrr_stack + 76101;
 target_ptr = Libderiv->deriv2_classes[4][8][143];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,825,dvrr_stack+27105, dvrr_stack+111870, NULL);
 tmp = dvrr_stack + 27105;
 target_ptr = Libderiv->deriv2_classes[4][9][143];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,990,dvrr_stack+68167, dvrr_stack+126889, NULL);
 tmp = dvrr_stack + 68167;
 target_ptr = Libderiv->deriv2_classes[4][10][143];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,126,dvrr_stack+7437, dvrr_stack+3251, NULL);
 tmp = dvrr_stack + 7437;
 target_ptr = Libderiv->deriv2_classes[2][5][131];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,168,dvrr_stack+223542, dvrr_stack+6079, NULL);
 tmp = dvrr_stack + 223542;
 target_ptr = Libderiv->deriv2_classes[2][6][131];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,216,dvrr_stack+173290, dvrr_stack+9675, NULL);
 tmp = dvrr_stack + 173290;
 target_ptr = Libderiv->deriv2_classes[2][7][131];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,270,dvrr_stack+83762, dvrr_stack+14133, NULL);
 tmp = dvrr_stack + 83762;
 target_ptr = Libderiv->deriv2_classes[2][8][131];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,330,dvrr_stack+163556, dvrr_stack+19547, NULL);
 tmp = dvrr_stack + 163556;
 target_ptr = Libderiv->deriv2_classes[2][9][131];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,396,dvrr_stack+116941, dvrr_stack+25917, NULL);
 tmp = dvrr_stack + 116941;
 target_ptr = Libderiv->deriv2_classes[2][10][131];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,210,dvrr_stack+220841, dvrr_stack+31540, NULL);
 tmp = dvrr_stack + 220841;
 target_ptr = Libderiv->deriv2_classes[3][5][131];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,280,dvrr_stack+28756, dvrr_stack+35785, NULL);
 tmp = dvrr_stack + 28756;
 target_ptr = Libderiv->deriv2_classes[3][6][131];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,360,dvrr_stack+29036, dvrr_stack+41180, NULL);
 tmp = dvrr_stack + 29036;
 target_ptr = Libderiv->deriv2_classes[3][7][131];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,450,dvrr_stack+164513, dvrr_stack+47864, NULL);
 tmp = dvrr_stack + 164513;
 target_ptr = Libderiv->deriv2_classes[3][8][131];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,550,dvrr_stack+42800, dvrr_stack+55976, NULL);
 tmp = dvrr_stack + 42800;
 target_ptr = Libderiv->deriv2_classes[3][9][131];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,660,dvrr_stack+70265, dvrr_stack+65746, NULL);
 tmp = dvrr_stack + 70265;
 target_ptr = Libderiv->deriv2_classes[3][10][131];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,315,dvrr_stack+20537, dvrr_stack+74606, NULL);
 tmp = dvrr_stack + 20537;
 target_ptr = Libderiv->deriv2_classes[4][5][131];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,420,dvrr_stack+3629, dvrr_stack+81086, NULL);
 tmp = dvrr_stack + 3629;
 target_ptr = Libderiv->deriv2_classes[4][6][131];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,540,dvrr_stack+37093, dvrr_stack+89316, NULL);
 tmp = dvrr_stack + 37093;
 target_ptr = Libderiv->deriv2_classes[4][7][131];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,675,dvrr_stack+232116, dvrr_stack+99507, NULL);
 tmp = dvrr_stack + 232116;
 target_ptr = Libderiv->deriv2_classes[4][8][131];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,825,dvrr_stack+232791, dvrr_stack+111870, NULL);
 tmp = dvrr_stack + 232791;
 target_ptr = Libderiv->deriv2_classes[4][9][131];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,990,dvrr_stack+233616, dvrr_stack+126889, NULL);
 tmp = dvrr_stack + 233616;
 target_ptr = Libderiv->deriv2_classes[4][10][131];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+179166, dvrr_stack+57626, NULL);
 tmp = dvrr_stack + 179166;
 target_ptr = Libderiv->deriv2_classes[2][5][130];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+92761, dvrr_stack+58004, NULL);
 tmp = dvrr_stack + 92761;
 target_ptr = Libderiv->deriv2_classes[2][6][130];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+7003, dvrr_stack+114345, NULL);
 tmp = dvrr_stack + 7003;
 target_ptr = Libderiv->deriv2_classes[2][7][130];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+70925, dvrr_stack+114993, NULL);
 tmp = dvrr_stack + 70925;
 target_ptr = Libderiv->deriv2_classes[2][8][130];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+14943, dvrr_stack+129859, NULL);
 tmp = dvrr_stack + 14943;
 target_ptr = Libderiv->deriv2_classes[2][9][130];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+234606, dvrr_stack+130849, NULL);
 tmp = dvrr_stack + 234606;
 target_ptr = Libderiv->deriv2_classes[2][10][130];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+164963, dvrr_stack+132037, NULL);
 tmp = dvrr_stack + 164963;
 target_ptr = Libderiv->deriv2_classes[3][5][130];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+235002, dvrr_stack+132667, NULL);
 tmp = dvrr_stack + 235002;
 target_ptr = Libderiv->deriv2_classes[3][6][130];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+235282, dvrr_stack+133507, NULL);
 tmp = dvrr_stack + 235282;
 target_ptr = Libderiv->deriv2_classes[3][7][130];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+235642, dvrr_stack+134587, NULL);
 tmp = dvrr_stack + 235642;
 target_ptr = Libderiv->deriv2_classes[3][8][130];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+236092, dvrr_stack+135937, NULL);
 tmp = dvrr_stack + 236092;
 target_ptr = Libderiv->deriv2_classes[3][9][130];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+236642, dvrr_stack+137587, NULL);
 tmp = dvrr_stack + 236642;
 target_ptr = Libderiv->deriv2_classes[3][10][130];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+237302, dvrr_stack+139567, NULL);
 tmp = dvrr_stack + 237302;
 target_ptr = Libderiv->deriv2_classes[4][5][130];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+237617, dvrr_stack+140512, NULL);
 tmp = dvrr_stack + 237617;
 target_ptr = Libderiv->deriv2_classes[4][6][130];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+238037, dvrr_stack+141772, NULL);
 tmp = dvrr_stack + 238037;
 target_ptr = Libderiv->deriv2_classes[4][7][130];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+238577, dvrr_stack+143392, NULL);
 tmp = dvrr_stack + 238577;
 target_ptr = Libderiv->deriv2_classes[4][8][130];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+239252, dvrr_stack+145417, NULL);
 tmp = dvrr_stack + 239252;
 target_ptr = Libderiv->deriv2_classes[4][9][130];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+240077, dvrr_stack+147892, NULL);
 tmp = dvrr_stack + 240077;
 target_ptr = Libderiv->deriv2_classes[4][10][130];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,126,dvrr_stack+179292, dvrr_stack+3251, NULL);
 tmp = dvrr_stack + 179292;
 target_ptr = Libderiv->deriv2_classes[2][5][119];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,168,dvrr_stack+76776, dvrr_stack+6079, NULL);
 tmp = dvrr_stack + 76776;
 target_ptr = Libderiv->deriv2_classes[2][6][119];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,216,dvrr_stack+6079, dvrr_stack+9675, NULL);
 tmp = dvrr_stack + 6079;
 target_ptr = Libderiv->deriv2_classes[2][7][119];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,270,dvrr_stack+6295, dvrr_stack+14133, NULL);
 tmp = dvrr_stack + 6295;
 target_ptr = Libderiv->deriv2_classes[2][8][119];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,330,dvrr_stack+14133, dvrr_stack+19547, NULL);
 tmp = dvrr_stack + 14133;
 target_ptr = Libderiv->deriv2_classes[2][9][119];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,396,dvrr_stack+14463, dvrr_stack+25917, NULL);
 tmp = dvrr_stack + 14463;
 target_ptr = Libderiv->deriv2_classes[2][10][119];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,210,dvrr_stack+69157, dvrr_stack+31540, NULL);
 tmp = dvrr_stack + 69157;
 target_ptr = Libderiv->deriv2_classes[3][5][119];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,280,dvrr_stack+31540, dvrr_stack+35785, NULL);
 tmp = dvrr_stack + 31540;
 target_ptr = Libderiv->deriv2_classes[3][6][119];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,360,dvrr_stack+9585, dvrr_stack+41180, NULL);
 tmp = dvrr_stack + 9585;
 target_ptr = Libderiv->deriv2_classes[3][7][119];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,450,dvrr_stack+9945, dvrr_stack+47864, NULL);
 tmp = dvrr_stack + 9945;
 target_ptr = Libderiv->deriv2_classes[3][8][119];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,550,dvrr_stack+47789, dvrr_stack+55976, NULL);
 tmp = dvrr_stack + 47789;
 target_ptr = Libderiv->deriv2_classes[3][9][119];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,660,dvrr_stack+55881, dvrr_stack+65746, NULL);
 tmp = dvrr_stack + 55881;
 target_ptr = Libderiv->deriv2_classes[3][10][119];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,315,dvrr_stack+31820, dvrr_stack+74606, NULL);
 tmp = dvrr_stack + 31820;
 target_ptr = Libderiv->deriv2_classes[4][5][119];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,420,dvrr_stack+3107, dvrr_stack+81086, NULL);
 tmp = dvrr_stack + 3107;
 target_ptr = Libderiv->deriv2_classes[4][6][119];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,540,dvrr_stack+81062, dvrr_stack+89316, NULL);
 tmp = dvrr_stack + 81062;
 target_ptr = Libderiv->deriv2_classes[4][7][119];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,675,dvrr_stack+89286, dvrr_stack+99507, NULL);
 tmp = dvrr_stack + 89286;
 target_ptr = Libderiv->deriv2_classes[4][8][119];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,825,dvrr_stack+89961, dvrr_stack+111870, NULL);
 tmp = dvrr_stack + 89961;
 target_ptr = Libderiv->deriv2_classes[4][9][119];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,990,dvrr_stack+99489, dvrr_stack+126889, NULL);
 tmp = dvrr_stack + 99489;
 target_ptr = Libderiv->deriv2_classes[4][10][119];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+117337, dvrr_stack+57626, NULL);
 tmp = dvrr_stack + 117337;
 target_ptr = Libderiv->deriv2_classes[2][5][118];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+27930, dvrr_stack+58004, NULL);
 tmp = dvrr_stack + 27930;
 target_ptr = Libderiv->deriv2_classes[2][6][118];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+100479, dvrr_stack+114345, NULL);
 tmp = dvrr_stack + 100479;
 target_ptr = Libderiv->deriv2_classes[2][7][118];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+100695, dvrr_stack+114993, NULL);
 tmp = dvrr_stack + 100695;
 target_ptr = Libderiv->deriv2_classes[2][8][118];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+100965, dvrr_stack+129859, NULL);
 tmp = dvrr_stack + 100965;
 target_ptr = Libderiv->deriv2_classes[2][9][118];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+126823, dvrr_stack+130849, NULL);
 tmp = dvrr_stack + 126823;
 target_ptr = Libderiv->deriv2_classes[2][10][118];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+101295, dvrr_stack+132037, NULL);
 tmp = dvrr_stack + 101295;
 target_ptr = Libderiv->deriv2_classes[3][5][118];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+127219, dvrr_stack+132667, NULL);
 tmp = dvrr_stack + 127219;
 target_ptr = Libderiv->deriv2_classes[3][6][118];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+127499, dvrr_stack+133507, NULL);
 tmp = dvrr_stack + 127499;
 target_ptr = Libderiv->deriv2_classes[3][7][118];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+127859, dvrr_stack+134587, NULL);
 tmp = dvrr_stack + 127859;
 target_ptr = Libderiv->deriv2_classes[3][8][118];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+128309, dvrr_stack+135937, NULL);
 tmp = dvrr_stack + 128309;
 target_ptr = Libderiv->deriv2_classes[3][9][118];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+128859, dvrr_stack+137587, NULL);
 tmp = dvrr_stack + 128859;
 target_ptr = Libderiv->deriv2_classes[3][10][118];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+129519, dvrr_stack+139567, NULL);
 tmp = dvrr_stack + 129519;
 target_ptr = Libderiv->deriv2_classes[4][5][118];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+129834, dvrr_stack+140512, NULL);
 tmp = dvrr_stack + 129834;
 target_ptr = Libderiv->deriv2_classes[4][6][118];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+130254, dvrr_stack+141772, NULL);
 tmp = dvrr_stack + 130254;
 target_ptr = Libderiv->deriv2_classes[4][7][118];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+130794, dvrr_stack+143392, NULL);
 tmp = dvrr_stack + 130794;
 target_ptr = Libderiv->deriv2_classes[4][8][118];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+131469, dvrr_stack+145417, NULL);
 tmp = dvrr_stack + 131469;
 target_ptr = Libderiv->deriv2_classes[4][9][118];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+132294, dvrr_stack+147892, NULL);
 tmp = dvrr_stack + 132294;
 target_ptr = Libderiv->deriv2_classes[4][10][118];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+166389, dvrr_stack+150862, NULL);
 tmp = dvrr_stack + 166389;
 target_ptr = Libderiv->deriv2_classes[2][5][117];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+71195, dvrr_stack+2495, NULL);
 tmp = dvrr_stack + 71195;
 target_ptr = Libderiv->deriv2_classes[2][6][117];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+2495, dvrr_stack+5071, NULL);
 tmp = dvrr_stack + 2495;
 target_ptr = Libderiv->deriv2_classes[2][7][117];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+2711, dvrr_stack+8379, NULL);
 tmp = dvrr_stack + 2711;
 target_ptr = Libderiv->deriv2_classes[2][8][117];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+8379, dvrr_stack+12513, NULL);
 tmp = dvrr_stack + 8379;
 target_ptr = Libderiv->deriv2_classes[2][9][117];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+12513, dvrr_stack+17567, NULL);
 tmp = dvrr_stack + 12513;
 target_ptr = Libderiv->deriv2_classes[2][10][117];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+12909, dvrr_stack+13503, NULL);
 tmp = dvrr_stack + 12909;
 target_ptr = Libderiv->deriv2_classes[3][5][117];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+13119, dvrr_stack+30280, NULL);
 tmp = dvrr_stack + 13119;
 target_ptr = Libderiv->deriv2_classes[3][6][117];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+13399, dvrr_stack+34105, NULL);
 tmp = dvrr_stack + 13399;
 target_ptr = Libderiv->deriv2_classes[3][7][117];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+8709, dvrr_stack+39020, NULL);
 tmp = dvrr_stack + 8709;
 target_ptr = Libderiv->deriv2_classes[3][8][117];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+30175, dvrr_stack+45164, NULL);
 tmp = dvrr_stack + 30175;
 target_ptr = Libderiv->deriv2_classes[3][9][117];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+45164, dvrr_stack+52676, NULL);
 tmp = dvrr_stack + 45164;
 target_ptr = Libderiv->deriv2_classes[3][10][117];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+45824, dvrr_stack+61786, NULL);
 tmp = dvrr_stack + 45824;
 target_ptr = Libderiv->deriv2_classes[4][5][117];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+46139, dvrr_stack+72716, NULL);
 tmp = dvrr_stack + 46139;
 target_ptr = Libderiv->deriv2_classes[4][6][117];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+72635, dvrr_stack+78566, NULL);
 tmp = dvrr_stack + 72635;
 target_ptr = Libderiv->deriv2_classes[4][7][117];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+78446, dvrr_stack+86076, NULL);
 tmp = dvrr_stack + 78446;
 target_ptr = Libderiv->deriv2_classes[4][8][117];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+79121, dvrr_stack+95457, NULL);
 tmp = dvrr_stack + 79121;
 target_ptr = Libderiv->deriv2_classes[4][9][117];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+95379, dvrr_stack+106920, NULL);
 tmp = dvrr_stack + 95379;
 target_ptr = Libderiv->deriv2_classes[4][10][117];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+46559, dvrr_stack+15509, dvrr_stack+121309);
 tmp = dvrr_stack + 46559;
 target_ptr = Libderiv->deriv2_classes[2][5][107];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+13759, dvrr_stack+121525, dvrr_stack+121399);
 tmp = dvrr_stack + 13759;
 target_ptr = Libderiv->deriv2_classes[2][6][107];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+79946, dvrr_stack+121741, dvrr_stack+15509);
 tmp = dvrr_stack + 79946;
 target_ptr = Libderiv->deriv2_classes[2][7][107];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+30725, dvrr_stack+122011, dvrr_stack+121525);
 tmp = dvrr_stack + 30725;
 target_ptr = Libderiv->deriv2_classes[2][8][107];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+106873, dvrr_stack+122341, dvrr_stack+121741);
 tmp = dvrr_stack + 106873;
 target_ptr = Libderiv->deriv2_classes[2][9][107];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+107203, dvrr_stack+122737, dvrr_stack+122011);
 tmp = dvrr_stack + 107203;
 target_ptr = Libderiv->deriv2_classes[2][10][107];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+107599, dvrr_stack+124033, dvrr_stack+123883);
 tmp = dvrr_stack + 107599;
 target_ptr = Libderiv->deriv2_classes[3][5][107];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+107809, dvrr_stack+5719, dvrr_stack+124313);
 tmp = dvrr_stack + 107809;
 target_ptr = Libderiv->deriv2_classes[3][6][107];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+108089, dvrr_stack+124523, dvrr_stack+124033);
 tmp = dvrr_stack + 108089;
 target_ptr = Libderiv->deriv2_classes[3][7][107];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+108449, dvrr_stack+124973, dvrr_stack+5719);
 tmp = dvrr_stack + 108449;
 target_ptr = Libderiv->deriv2_classes[3][8][107];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+108899, dvrr_stack+125523, dvrr_stack+124523);
 tmp = dvrr_stack + 108899;
 target_ptr = Libderiv->deriv2_classes[3][9][107];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+96369, dvrr_stack+109890, dvrr_stack+124973);
 tmp = dvrr_stack + 96369;
 target_ptr = Libderiv->deriv2_classes[3][10][107];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+109449, dvrr_stack+31120, dvrr_stack+126508);
 tmp = dvrr_stack + 109449;
 target_ptr = Libderiv->deriv2_classes[4][5][107];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+97029, dvrr_stack+97932, dvrr_stack+111345);
 tmp = dvrr_stack + 97029;
 target_ptr = Libderiv->deriv2_classes[4][6][107];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+86061, dvrr_stack+98472, dvrr_stack+31120);
 tmp = dvrr_stack + 86061;
 target_ptr = Libderiv->deriv2_classes[4][7][107];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+86601, dvrr_stack+88101, dvrr_stack+97932);
 tmp = dvrr_stack + 86601;
 target_ptr = Libderiv->deriv2_classes[4][8][107];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+87276, dvrr_stack+62731, dvrr_stack+98472);
 tmp = dvrr_stack + 87276;
 target_ptr = Libderiv->deriv2_classes[4][9][107];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+52646, dvrr_stack+63721, dvrr_stack+88101);
 tmp = dvrr_stack + 52646;
 target_ptr = Libderiv->deriv2_classes[4][10][107];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+109764, dvrr_stack+111660, dvrr_stack+126733);
 tmp = dvrr_stack + 109764;
 target_ptr = Libderiv->deriv2_classes[2][5][106];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+13927, dvrr_stack+99273, dvrr_stack+99147);
 tmp = dvrr_stack + 13927;
 target_ptr = Libderiv->deriv2_classes[2][6][106];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+97449, dvrr_stack+88926, dvrr_stack+111660);
 tmp = dvrr_stack + 97449;
 target_ptr = Libderiv->deriv2_classes[2][7][106];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+73175, dvrr_stack+80186, dvrr_stack+99273);
 tmp = dvrr_stack + 73175;
 target_ptr = Libderiv->deriv2_classes[2][8][106];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+73445, dvrr_stack+80516, dvrr_stack+88926);
 tmp = dvrr_stack + 73445;
 target_ptr = Libderiv->deriv2_classes[2][9][106];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+61751, dvrr_stack+73976, dvrr_stack+80186);
 tmp = dvrr_stack + 61751;
 target_ptr = Libderiv->deriv2_classes[2][10][106];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+97665, dvrr_stack+64891, dvrr_stack+80912);
 tmp = dvrr_stack + 97665;
 target_ptr = Libderiv->deriv2_classes[3][5][106];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+62147, dvrr_stack+65381, dvrr_stack+65171);
 tmp = dvrr_stack + 62147;
 target_ptr = Libderiv->deriv2_classes[3][6][106];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+53636, dvrr_stack+54656, dvrr_stack+64891);
 tmp = dvrr_stack + 53636;
 target_ptr = Libderiv->deriv2_classes[3][7][106];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+53996, dvrr_stack+55106, dvrr_stack+65381);
 tmp = dvrr_stack + 53996;
 target_ptr = Libderiv->deriv2_classes[3][8][106];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+38995, dvrr_stack+46814, dvrr_stack+54656);
 tmp = dvrr_stack + 38995;
 target_ptr = Libderiv->deriv2_classes[3][9][106];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+39545, dvrr_stack+40370, dvrr_stack+55106);
 tmp = dvrr_stack + 39545;
 target_ptr = Libderiv->deriv2_classes[3][10][106];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+34063, dvrr_stack+35185, dvrr_stack+55656);
 tmp = dvrr_stack + 34063;
 target_ptr = Libderiv->deriv2_classes[4][5][106];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+34378, dvrr_stack+23541, dvrr_stack+47474);
 tmp = dvrr_stack + 34378;
 target_ptr = Libderiv->deriv2_classes[4][6][106];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+17522, dvrr_stack+24081, dvrr_stack+35185);
 tmp = dvrr_stack + 17522;
 target_ptr = Libderiv->deriv2_classes[4][7][106];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+18062, dvrr_stack+24756, dvrr_stack+23541);
 tmp = dvrr_stack + 18062;
 target_ptr = Libderiv->deriv2_classes[4][8][106];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+133284, dvrr_stack+151240, dvrr_stack+24081);
 tmp = dvrr_stack + 133284;
 target_ptr = Libderiv->deriv2_classes[4][9][106];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+134109, dvrr_stack+152230, dvrr_stack+24756);
 tmp = dvrr_stack + 134109;
 target_ptr = Libderiv->deriv2_classes[4][10][106];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+46685, dvrr_stack+121039, dvrr_stack+89196);
 tmp = dvrr_stack + 46685;
 target_ptr = Libderiv->deriv2_classes[2][5][105];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+73775, dvrr_stack+990, dvrr_stack+1991);
 tmp = dvrr_stack + 73775;
 target_ptr = Libderiv->deriv2_classes[2][6][105];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+62427, dvrr_stack+4423, dvrr_stack+121039);
 tmp = dvrr_stack + 62427;
 target_ptr = Libderiv->deriv2_classes[2][7][105];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+34798, dvrr_stack+7569, dvrr_stack+990);
 tmp = dvrr_stack + 34798;
 target_ptr = Libderiv->deriv2_classes[2][8][105];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+4973, dvrr_stack+11523, dvrr_stack+4423);
 tmp = dvrr_stack + 4973;
 target_ptr = Libderiv->deriv2_classes[2][9][105];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+5303, dvrr_stack+16379, dvrr_stack+7569);
 tmp = dvrr_stack + 5303;
 target_ptr = Libderiv->deriv2_classes[2][10][105];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+54446, dvrr_stack+123433, dvrr_stack+22137);
 tmp = dvrr_stack + 54446;
 target_ptr = Libderiv->deriv2_classes[3][5][105];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+135099, dvrr_stack+28126, dvrr_stack+29440);
 tmp = dvrr_stack + 135099;
 target_ptr = Libderiv->deriv2_classes[3][6][105];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+135379, dvrr_stack+33025, dvrr_stack+123433);
 tmp = dvrr_stack + 135379;
 target_ptr = Libderiv->deriv2_classes[3][7][105];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+135739, dvrr_stack+37670, dvrr_stack+28126);
 tmp = dvrr_stack + 135739;
 target_ptr = Libderiv->deriv2_classes[3][8][105];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+136189, dvrr_stack+43514, dvrr_stack+33025);
 tmp = dvrr_stack + 136189;
 target_ptr = Libderiv->deriv2_classes[3][9][105];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+136739, dvrr_stack+50696, dvrr_stack+37670);
 tmp = dvrr_stack + 136739;
 target_ptr = Libderiv->deriv2_classes[3][10][105];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+137399, dvrr_stack+110670, dvrr_stack+59446);
 tmp = dvrr_stack + 137399;
 target_ptr = Libderiv->deriv2_classes[4][5][105];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+137714, dvrr_stack+69395, dvrr_stack+71456);
 tmp = dvrr_stack + 137714;
 target_ptr = Libderiv->deriv2_classes[4][6][105];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+138134, dvrr_stack+76946, dvrr_stack+110670);
 tmp = dvrr_stack + 138134;
 target_ptr = Libderiv->deriv2_classes[4][7][105];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+138674, dvrr_stack+84051, dvrr_stack+69395);
 tmp = dvrr_stack + 138674;
 target_ptr = Libderiv->deriv2_classes[4][8][105];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+139349, dvrr_stack+44174, dvrr_stack+76946);
 tmp = dvrr_stack + 139349;
 target_ptr = Libderiv->deriv2_classes[4][9][105];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+140174, dvrr_stack+103950, dvrr_stack+84051);
 tmp = dvrr_stack + 140174;
 target_ptr = Libderiv->deriv2_classes[4][10][105];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+90786, dvrr_stack+117499, dvrr_stack+74);
 tmp = dvrr_stack + 90786;
 target_ptr = Libderiv->deriv2_classes[2][5][104];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+141164, dvrr_stack+117793, dvrr_stack+117667);
 tmp = dvrr_stack + 141164;
 target_ptr = Libderiv->deriv2_classes[2][6][104];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+141332, dvrr_stack+28486, dvrr_stack+117499);
 tmp = dvrr_stack + 141332;
 target_ptr = Libderiv->deriv2_classes[2][7][104];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+141548, dvrr_stack+118009, dvrr_stack+117793);
 tmp = dvrr_stack + 141548;
 target_ptr = Libderiv->deriv2_classes[2][8][104];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+141818, dvrr_stack+118339, dvrr_stack+28486);
 tmp = dvrr_stack + 141818;
 target_ptr = Libderiv->deriv2_classes[2][9][104];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+142148, dvrr_stack+118735, dvrr_stack+118009);
 tmp = dvrr_stack + 142148;
 target_ptr = Libderiv->deriv2_classes[2][10][104];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+142544, dvrr_stack+119489, dvrr_stack+119339);
 tmp = dvrr_stack + 142544;
 target_ptr = Libderiv->deriv2_classes[3][5][104];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+142754, dvrr_stack+119979, dvrr_stack+119769);
 tmp = dvrr_stack + 142754;
 target_ptr = Libderiv->deriv2_classes[3][6][104];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+143034, dvrr_stack+120339, dvrr_stack+119489);
 tmp = dvrr_stack + 143034;
 target_ptr = Libderiv->deriv2_classes[3][7][104];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+143394, dvrr_stack+105120, dvrr_stack+119979);
 tmp = dvrr_stack + 143394;
 target_ptr = Libderiv->deriv2_classes[3][8][104];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+143844, dvrr_stack+105670, dvrr_stack+120339);
 tmp = dvrr_stack + 143844;
 target_ptr = Libderiv->deriv2_classes[3][9][104];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+144394, dvrr_stack+92982, dvrr_stack+105120);
 tmp = dvrr_stack + 144394;
 target_ptr = Libderiv->deriv2_classes[3][10][104];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+145054, dvrr_stack+93762, dvrr_stack+106480);
 tmp = dvrr_stack + 145054;
 target_ptr = Libderiv->deriv2_classes[4][5][104];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+145369, dvrr_stack+94497, dvrr_stack+94182);
 tmp = dvrr_stack + 145369;
 target_ptr = Libderiv->deriv2_classes[4][6][104];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+145789, dvrr_stack+84876, dvrr_stack+93762);
 tmp = dvrr_stack + 145789;
 target_ptr = Libderiv->deriv2_classes[4][7][104];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+146329, dvrr_stack+77621, dvrr_stack+94497);
 tmp = dvrr_stack + 146329;
 target_ptr = Libderiv->deriv2_classes[4][8][104];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+147004, dvrr_stack+59671, dvrr_stack+84876);
 tmp = dvrr_stack + 147004;
 target_ptr = Libderiv->deriv2_classes[4][9][104];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+147829, dvrr_stack+51476, dvrr_stack+77621);
 tmp = dvrr_stack + 147829;
 target_ptr = Libderiv->deriv2_classes[4][10][104];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+119203, dvrr_stack+15509, dvrr_stack+121309);
 tmp = dvrr_stack + 119203;
 target_ptr = Libderiv->deriv2_classes[2][5][95];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+148819, dvrr_stack+121525, dvrr_stack+121399);
 tmp = dvrr_stack + 148819;
 target_ptr = Libderiv->deriv2_classes[2][6][95];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+148987, dvrr_stack+121741, dvrr_stack+15509);
 tmp = dvrr_stack + 148987;
 target_ptr = Libderiv->deriv2_classes[2][7][95];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+149203, dvrr_stack+122011, dvrr_stack+121525);
 tmp = dvrr_stack + 149203;
 target_ptr = Libderiv->deriv2_classes[2][8][95];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+149473, dvrr_stack+122341, dvrr_stack+121741);
 tmp = dvrr_stack + 149473;
 target_ptr = Libderiv->deriv2_classes[2][9][95];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+149803, dvrr_stack+122737, dvrr_stack+122011);
 tmp = dvrr_stack + 149803;
 target_ptr = Libderiv->deriv2_classes[2][10][95];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+150199, dvrr_stack+124033, dvrr_stack+123883);
 tmp = dvrr_stack + 150199;
 target_ptr = Libderiv->deriv2_classes[3][5][95];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+150409, dvrr_stack+5719, dvrr_stack+124313);
 tmp = dvrr_stack + 150409;
 target_ptr = Libderiv->deriv2_classes[3][6][95];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+150689, dvrr_stack+124523, dvrr_stack+124033);
 tmp = dvrr_stack + 150689;
 target_ptr = Libderiv->deriv2_classes[3][7][95];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+111828, dvrr_stack+124973, dvrr_stack+5719);
 tmp = dvrr_stack + 111828;
 target_ptr = Libderiv->deriv2_classes[3][8][95];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+112278, dvrr_stack+125523, dvrr_stack+124523);
 tmp = dvrr_stack + 112278;
 target_ptr = Libderiv->deriv2_classes[3][9][95];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+112828, dvrr_stack+109890, dvrr_stack+124973);
 tmp = dvrr_stack + 112828;
 target_ptr = Libderiv->deriv2_classes[3][10][95];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+113488, dvrr_stack+31120, dvrr_stack+126508);
 tmp = dvrr_stack + 113488;
 target_ptr = Libderiv->deriv2_classes[4][5][95];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+113803, dvrr_stack+97932, dvrr_stack+111345);
 tmp = dvrr_stack + 113803;
 target_ptr = Libderiv->deriv2_classes[4][6][95];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+114223, dvrr_stack+98472, dvrr_stack+31120);
 tmp = dvrr_stack + 114223;
 target_ptr = Libderiv->deriv2_classes[4][7][95];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+114763, dvrr_stack+88101, dvrr_stack+97932);
 tmp = dvrr_stack + 114763;
 target_ptr = Libderiv->deriv2_classes[4][8][95];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+74444, dvrr_stack+62731, dvrr_stack+98472);
 tmp = dvrr_stack + 74444;
 target_ptr = Libderiv->deriv2_classes[4][9][95];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+65741, dvrr_stack+63721, dvrr_stack+88101);
 tmp = dvrr_stack + 65741;
 target_ptr = Libderiv->deriv2_classes[4][10][95];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+43350, dvrr_stack+111660, dvrr_stack+126733);
 tmp = dvrr_stack + 43350;
 target_ptr = Libderiv->deriv2_classes[2][5][94];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+151049, dvrr_stack+99273, dvrr_stack+99147);
 tmp = dvrr_stack + 151049;
 target_ptr = Libderiv->deriv2_classes[2][6][94];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+115438, dvrr_stack+88926, dvrr_stack+111660);
 tmp = dvrr_stack + 115438;
 target_ptr = Libderiv->deriv2_classes[2][7][94];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+81602, dvrr_stack+80186, dvrr_stack+99273);
 tmp = dvrr_stack + 81602;
 target_ptr = Libderiv->deriv2_classes[2][8][94];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+81872, dvrr_stack+80516, dvrr_stack+88926);
 tmp = dvrr_stack + 81872;
 target_ptr = Libderiv->deriv2_classes[2][9][94];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+66731, dvrr_stack+73976, dvrr_stack+80186);
 tmp = dvrr_stack + 66731;
 target_ptr = Libderiv->deriv2_classes[2][10][94];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+75269, dvrr_stack+64891, dvrr_stack+80912);
 tmp = dvrr_stack + 75269;
 target_ptr = Libderiv->deriv2_classes[3][5][94];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+67127, dvrr_stack+65381, dvrr_stack+65171);
 tmp = dvrr_stack + 67127;
 target_ptr = Libderiv->deriv2_classes[3][6][94];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+56541, dvrr_stack+54656, dvrr_stack+64891);
 tmp = dvrr_stack + 56541;
 target_ptr = Libderiv->deriv2_classes[3][7][94];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+56901, dvrr_stack+55106, dvrr_stack+65381);
 tmp = dvrr_stack + 56901;
 target_ptr = Libderiv->deriv2_classes[3][8][94];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+57351, dvrr_stack+46814, dvrr_stack+54656);
 tmp = dvrr_stack + 57351;
 target_ptr = Libderiv->deriv2_classes[3][9][94];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+48339, dvrr_stack+40370, dvrr_stack+55106);
 tmp = dvrr_stack + 48339;
 target_ptr = Libderiv->deriv2_classes[3][10][94];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+67407, dvrr_stack+35185, dvrr_stack+55656);
 tmp = dvrr_stack + 67407;
 target_ptr = Libderiv->deriv2_classes[4][5][94];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+57901, dvrr_stack+23541, dvrr_stack+47474);
 tmp = dvrr_stack + 57901;
 target_ptr = Libderiv->deriv2_classes[4][6][94];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+41150, dvrr_stack+24081, dvrr_stack+35185);
 tmp = dvrr_stack + 41150;
 target_ptr = Libderiv->deriv2_classes[4][7][94];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+35605, dvrr_stack+24756, dvrr_stack+23541);
 tmp = dvrr_stack + 35605;
 target_ptr = Libderiv->deriv2_classes[4][8][94];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+25806, dvrr_stack+151240, dvrr_stack+24081);
 tmp = dvrr_stack + 25806;
 target_ptr = Libderiv->deriv2_classes[4][9][94];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+19535, dvrr_stack+152230, dvrr_stack+24756);
 tmp = dvrr_stack + 19535;
 target_ptr = Libderiv->deriv2_classes[4][10][94];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+40205, dvrr_stack+121039, dvrr_stack+89196);
 tmp = dvrr_stack + 40205;
 target_ptr = Libderiv->deriv2_classes[2][5][93];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+58321, dvrr_stack+990, dvrr_stack+1991);
 tmp = dvrr_stack + 58321;
 target_ptr = Libderiv->deriv2_classes[2][6][93];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+41690, dvrr_stack+4423, dvrr_stack+121039);
 tmp = dvrr_stack + 41690;
 target_ptr = Libderiv->deriv2_classes[2][7][93];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+41906, dvrr_stack+7569, dvrr_stack+990);
 tmp = dvrr_stack + 41906;
 target_ptr = Libderiv->deriv2_classes[2][8][93];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+36280, dvrr_stack+11523, dvrr_stack+4423);
 tmp = dvrr_stack + 36280;
 target_ptr = Libderiv->deriv2_classes[2][9][93];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+26631, dvrr_stack+16379, dvrr_stack+7569);
 tmp = dvrr_stack + 26631;
 target_ptr = Libderiv->deriv2_classes[2][10][93];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+48999, dvrr_stack+123433, dvrr_stack+22137);
 tmp = dvrr_stack + 48999;
 target_ptr = Libderiv->deriv2_classes[3][5][93];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+241067, dvrr_stack+28126, dvrr_stack+29440);
 tmp = dvrr_stack + 241067;
 target_ptr = Libderiv->deriv2_classes[3][6][93];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+241347, dvrr_stack+33025, dvrr_stack+123433);
 tmp = dvrr_stack + 241347;
 target_ptr = Libderiv->deriv2_classes[3][7][93];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+241707, dvrr_stack+37670, dvrr_stack+28126);
 tmp = dvrr_stack + 241707;
 target_ptr = Libderiv->deriv2_classes[3][8][93];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+242157, dvrr_stack+43514, dvrr_stack+33025);
 tmp = dvrr_stack + 242157;
 target_ptr = Libderiv->deriv2_classes[3][9][93];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+242707, dvrr_stack+50696, dvrr_stack+37670);
 tmp = dvrr_stack + 242707;
 target_ptr = Libderiv->deriv2_classes[3][10][93];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+243367, dvrr_stack+110670, dvrr_stack+59446);
 tmp = dvrr_stack + 243367;
 target_ptr = Libderiv->deriv2_classes[4][5][93];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+243682, dvrr_stack+69395, dvrr_stack+71456);
 tmp = dvrr_stack + 243682;
 target_ptr = Libderiv->deriv2_classes[4][6][93];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+244102, dvrr_stack+76946, dvrr_stack+110670);
 tmp = dvrr_stack + 244102;
 target_ptr = Libderiv->deriv2_classes[4][7][93];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+244642, dvrr_stack+84051, dvrr_stack+69395);
 tmp = dvrr_stack + 244642;
 target_ptr = Libderiv->deriv2_classes[4][8][93];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+245317, dvrr_stack+44174, dvrr_stack+76946);
 tmp = dvrr_stack + 245317;
 target_ptr = Libderiv->deriv2_classes[4][9][93];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+246142, dvrr_stack+103950, dvrr_stack+84051);
 tmp = dvrr_stack + 246142;
 target_ptr = Libderiv->deriv2_classes[4][10][93];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+115654, dvrr_stack+117499, dvrr_stack+74);
 tmp = dvrr_stack + 115654;
 target_ptr = Libderiv->deriv2_classes[2][5][92];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+21314, dvrr_stack+117793, dvrr_stack+117667);
 tmp = dvrr_stack + 21314;
 target_ptr = Libderiv->deriv2_classes[2][6][92];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+15273, dvrr_stack+28486, dvrr_stack+117499);
 tmp = dvrr_stack + 15273;
 target_ptr = Libderiv->deriv2_classes[2][7][92];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+247132, dvrr_stack+118009, dvrr_stack+117793);
 tmp = dvrr_stack + 247132;
 target_ptr = Libderiv->deriv2_classes[2][8][92];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+247402, dvrr_stack+118339, dvrr_stack+28486);
 tmp = dvrr_stack + 247402;
 target_ptr = Libderiv->deriv2_classes[2][9][92];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+247732, dvrr_stack+118735, dvrr_stack+118009);
 tmp = dvrr_stack + 247732;
 target_ptr = Libderiv->deriv2_classes[2][10][92];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+248128, dvrr_stack+119489, dvrr_stack+119339);
 tmp = dvrr_stack + 248128;
 target_ptr = Libderiv->deriv2_classes[3][5][92];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+248338, dvrr_stack+119979, dvrr_stack+119769);
 tmp = dvrr_stack + 248338;
 target_ptr = Libderiv->deriv2_classes[3][6][92];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+248618, dvrr_stack+120339, dvrr_stack+119489);
 tmp = dvrr_stack + 248618;
 target_ptr = Libderiv->deriv2_classes[3][7][92];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+248978, dvrr_stack+105120, dvrr_stack+119979);
 tmp = dvrr_stack + 248978;
 target_ptr = Libderiv->deriv2_classes[3][8][92];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+249428, dvrr_stack+105670, dvrr_stack+120339);
 tmp = dvrr_stack + 249428;
 target_ptr = Libderiv->deriv2_classes[3][9][92];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+249978, dvrr_stack+92982, dvrr_stack+105120);
 tmp = dvrr_stack + 249978;
 target_ptr = Libderiv->deriv2_classes[3][10][92];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+250638, dvrr_stack+93762, dvrr_stack+106480);
 tmp = dvrr_stack + 250638;
 target_ptr = Libderiv->deriv2_classes[4][5][92];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+250953, dvrr_stack+94497, dvrr_stack+94182);
 tmp = dvrr_stack + 250953;
 target_ptr = Libderiv->deriv2_classes[4][6][92];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+251373, dvrr_stack+84876, dvrr_stack+93762);
 tmp = dvrr_stack + 251373;
 target_ptr = Libderiv->deriv2_classes[4][7][92];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+251913, dvrr_stack+77621, dvrr_stack+94497);
 tmp = dvrr_stack + 251913;
 target_ptr = Libderiv->deriv2_classes[4][8][92];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+252588, dvrr_stack+59671, dvrr_stack+84876);
 tmp = dvrr_stack + 252588;
 target_ptr = Libderiv->deriv2_classes[4][9][92];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+253413, dvrr_stack+51476, dvrr_stack+77621);
 tmp = dvrr_stack + 253413;
 target_ptr = Libderiv->deriv2_classes[4][10][92];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+82202, dvrr_stack+106705, dvrr_stack+120789);
 tmp = dvrr_stack + 82202;
 target_ptr = Libderiv->deriv2_classes[2][5][91];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+254403, dvrr_stack+95163, dvrr_stack+95037);
 tmp = dvrr_stack + 254403;
 target_ptr = Libderiv->deriv2_classes[2][6][91];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+254571, dvrr_stack+85551, dvrr_stack+106705);
 tmp = dvrr_stack + 254571;
 target_ptr = Libderiv->deriv2_classes[2][7][91];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+254787, dvrr_stack+69935, dvrr_stack+95163);
 tmp = dvrr_stack + 254787;
 target_ptr = Libderiv->deriv2_classes[2][8][91];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+255057, dvrr_stack+71771, dvrr_stack+85551);
 tmp = dvrr_stack + 255057;
 target_ptr = Libderiv->deriv2_classes[2][9][91];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+255387, dvrr_stack+72167, dvrr_stack+69935);
 tmp = dvrr_stack + 255387;
 target_ptr = Libderiv->deriv2_classes[2][10][91];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+255783, dvrr_stack+60661, dvrr_stack+85821);
 tmp = dvrr_stack + 255783;
 target_ptr = Libderiv->deriv2_classes[3][5][91];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+255993, dvrr_stack+60941, dvrr_stack+111090);
 tmp = dvrr_stack + 255993;
 target_ptr = Libderiv->deriv2_classes[3][6][91];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+256273, dvrr_stack+61301, dvrr_stack+60661);
 tmp = dvrr_stack + 256273;
 target_ptr = Libderiv->deriv2_classes[3][7][91];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+256633, dvrr_stack+38220, dvrr_stack+60941);
 tmp = dvrr_stack + 256633;
 target_ptr = Libderiv->deriv2_classes[3][8][91];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+257083, dvrr_stack+22287, dvrr_stack+61301);
 tmp = dvrr_stack + 257083;
 target_ptr = Libderiv->deriv2_classes[3][9][91];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+257633, dvrr_stack+18755, dvrr_stack+38220);
 tmp = dvrr_stack + 257633;
 target_ptr = Libderiv->deriv2_classes[3][10][91];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+258293, dvrr_stack+33475, dvrr_stack+38770);
 tmp = dvrr_stack + 258293;
 target_ptr = Libderiv->deriv2_classes[4][5][91];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+258608, dvrr_stack+22947, dvrr_stack+29650);
 tmp = dvrr_stack + 258608;
 target_ptr = Libderiv->deriv2_classes[4][6][91];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+259028, dvrr_stack+16847, dvrr_stack+33475);
 tmp = dvrr_stack + 259028;
 target_ptr = Libderiv->deriv2_classes[4][7][91];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+259568, dvrr_stack+153400, dvrr_stack+22947);
 tmp = dvrr_stack + 259568;
 target_ptr = Libderiv->deriv2_classes[4][8][91];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+260243, dvrr_stack+154225, dvrr_stack+16847);
 tmp = dvrr_stack + 260243;
 target_ptr = Libderiv->deriv2_classes[4][9][91];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+261068, dvrr_stack+155215, dvrr_stack+153400);
 tmp = dvrr_stack + 261068;
 target_ptr = Libderiv->deriv2_classes[4][10][91];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+262058, dvrr_stack+15509, dvrr_stack+121309);
 tmp = dvrr_stack + 262058;
 target_ptr = Libderiv->deriv2_classes[2][5][83];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+121207, dvrr_stack+121525, dvrr_stack+121399);
 tmp = dvrr_stack + 121207;
 target_ptr = Libderiv->deriv2_classes[2][6][83];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+262184, dvrr_stack+121741, dvrr_stack+15509);
 tmp = dvrr_stack + 262184;
 target_ptr = Libderiv->deriv2_classes[2][7][83];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+262400, dvrr_stack+122011, dvrr_stack+121525);
 tmp = dvrr_stack + 262400;
 target_ptr = Libderiv->deriv2_classes[2][8][83];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+262670, dvrr_stack+122341, dvrr_stack+121741);
 tmp = dvrr_stack + 262670;
 target_ptr = Libderiv->deriv2_classes[2][9][83];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+263000, dvrr_stack+122737, dvrr_stack+122011);
 tmp = dvrr_stack + 263000;
 target_ptr = Libderiv->deriv2_classes[2][10][83];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+122737, dvrr_stack+124033, dvrr_stack+123883);
 tmp = dvrr_stack + 122737;
 target_ptr = Libderiv->deriv2_classes[3][5][83];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+263396, dvrr_stack+5719, dvrr_stack+124313);
 tmp = dvrr_stack + 263396;
 target_ptr = Libderiv->deriv2_classes[3][6][83];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+263676, dvrr_stack+124523, dvrr_stack+124033);
 tmp = dvrr_stack + 263676;
 target_ptr = Libderiv->deriv2_classes[3][7][83];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+264036, dvrr_stack+124973, dvrr_stack+5719);
 tmp = dvrr_stack + 264036;
 target_ptr = Libderiv->deriv2_classes[3][8][83];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+264486, dvrr_stack+125523, dvrr_stack+124523);
 tmp = dvrr_stack + 264486;
 target_ptr = Libderiv->deriv2_classes[3][9][83];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+265036, dvrr_stack+109890, dvrr_stack+124973);
 tmp = dvrr_stack + 265036;
 target_ptr = Libderiv->deriv2_classes[3][10][83];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+109890, dvrr_stack+31120, dvrr_stack+126508);
 tmp = dvrr_stack + 109890;
 target_ptr = Libderiv->deriv2_classes[4][5][83];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+110205, dvrr_stack+97932, dvrr_stack+111345);
 tmp = dvrr_stack + 110205;
 target_ptr = Libderiv->deriv2_classes[4][6][83];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+265696, dvrr_stack+98472, dvrr_stack+31120);
 tmp = dvrr_stack + 265696;
 target_ptr = Libderiv->deriv2_classes[4][7][83];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+266236, dvrr_stack+88101, dvrr_stack+97932);
 tmp = dvrr_stack + 266236;
 target_ptr = Libderiv->deriv2_classes[4][8][83];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+266911, dvrr_stack+62731, dvrr_stack+98472);
 tmp = dvrr_stack + 266911;
 target_ptr = Libderiv->deriv2_classes[4][9][83];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+267736, dvrr_stack+63721, dvrr_stack+88101);
 tmp = dvrr_stack + 267736;
 target_ptr = Libderiv->deriv2_classes[4][10][83];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+63721, dvrr_stack+111660, dvrr_stack+126733);
 tmp = dvrr_stack + 63721;
 target_ptr = Libderiv->deriv2_classes[2][5][82];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+63847, dvrr_stack+99273, dvrr_stack+99147);
 tmp = dvrr_stack + 63847;
 target_ptr = Libderiv->deriv2_classes[2][6][82];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+64015, dvrr_stack+88926, dvrr_stack+111660);
 tmp = dvrr_stack + 64015;
 target_ptr = Libderiv->deriv2_classes[2][7][82];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+64231, dvrr_stack+80186, dvrr_stack+99273);
 tmp = dvrr_stack + 64231;
 target_ptr = Libderiv->deriv2_classes[2][8][82];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+64501, dvrr_stack+80516, dvrr_stack+88926);
 tmp = dvrr_stack + 64501;
 target_ptr = Libderiv->deriv2_classes[2][9][82];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+268726, dvrr_stack+73976, dvrr_stack+80186);
 tmp = dvrr_stack + 268726;
 target_ptr = Libderiv->deriv2_classes[2][10][82];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+122947, dvrr_stack+64891, dvrr_stack+80912);
 tmp = dvrr_stack + 122947;
 target_ptr = Libderiv->deriv2_classes[3][5][82];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+126438, dvrr_stack+65381, dvrr_stack+65171);
 tmp = dvrr_stack + 126438;
 target_ptr = Libderiv->deriv2_classes[3][6][82];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+73943, dvrr_stack+54656, dvrr_stack+64891);
 tmp = dvrr_stack + 73943;
 target_ptr = Libderiv->deriv2_classes[3][7][82];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+269122, dvrr_stack+55106, dvrr_stack+65381);
 tmp = dvrr_stack + 269122;
 target_ptr = Libderiv->deriv2_classes[3][8][82];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+269572, dvrr_stack+46814, dvrr_stack+54656);
 tmp = dvrr_stack + 269572;
 target_ptr = Libderiv->deriv2_classes[3][9][82];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+270122, dvrr_stack+40370, dvrr_stack+55106);
 tmp = dvrr_stack + 270122;
 target_ptr = Libderiv->deriv2_classes[3][10][82];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+40331, dvrr_stack+35185, dvrr_stack+55656);
 tmp = dvrr_stack + 40331;
 target_ptr = Libderiv->deriv2_classes[4][5][82];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+40646, dvrr_stack+23541, dvrr_stack+47474);
 tmp = dvrr_stack + 40646;
 target_ptr = Libderiv->deriv2_classes[4][6][82];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+270782, dvrr_stack+24081, dvrr_stack+35185);
 tmp = dvrr_stack + 270782;
 target_ptr = Libderiv->deriv2_classes[4][7][82];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+271322, dvrr_stack+24756, dvrr_stack+23541);
 tmp = dvrr_stack + 271322;
 target_ptr = Libderiv->deriv2_classes[4][8][82];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+271997, dvrr_stack+151240, dvrr_stack+24081);
 tmp = dvrr_stack + 271997;
 target_ptr = Libderiv->deriv2_classes[4][9][82];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+272822, dvrr_stack+152230, dvrr_stack+24756);
 tmp = dvrr_stack + 272822;
 target_ptr = Libderiv->deriv2_classes[4][10][82];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+152230, dvrr_stack+121039, dvrr_stack+89196);
 tmp = dvrr_stack + 152230;
 target_ptr = Libderiv->deriv2_classes[2][5][81];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+152356, dvrr_stack+990, dvrr_stack+1991);
 tmp = dvrr_stack + 152356;
 target_ptr = Libderiv->deriv2_classes[2][6][81];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+152524, dvrr_stack+4423, dvrr_stack+121039);
 tmp = dvrr_stack + 152524;
 target_ptr = Libderiv->deriv2_classes[2][7][81];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+152740, dvrr_stack+7569, dvrr_stack+990);
 tmp = dvrr_stack + 152740;
 target_ptr = Libderiv->deriv2_classes[2][8][81];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+153010, dvrr_stack+11523, dvrr_stack+4423);
 tmp = dvrr_stack + 153010;
 target_ptr = Libderiv->deriv2_classes[2][9][81];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+273812, dvrr_stack+16379, dvrr_stack+7569);
 tmp = dvrr_stack + 273812;
 target_ptr = Libderiv->deriv2_classes[2][10][81];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+16379, dvrr_stack+123433, dvrr_stack+22137);
 tmp = dvrr_stack + 16379;
 target_ptr = Libderiv->deriv2_classes[3][5][81];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+274208, dvrr_stack+28126, dvrr_stack+29440);
 tmp = dvrr_stack + 274208;
 target_ptr = Libderiv->deriv2_classes[3][6][81];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+274488, dvrr_stack+33025, dvrr_stack+123433);
 tmp = dvrr_stack + 274488;
 target_ptr = Libderiv->deriv2_classes[3][7][81];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+274848, dvrr_stack+37670, dvrr_stack+28126);
 tmp = dvrr_stack + 274848;
 target_ptr = Libderiv->deriv2_classes[3][8][81];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+275298, dvrr_stack+43514, dvrr_stack+33025);
 tmp = dvrr_stack + 275298;
 target_ptr = Libderiv->deriv2_classes[3][9][81];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+275848, dvrr_stack+50696, dvrr_stack+37670);
 tmp = dvrr_stack + 275848;
 target_ptr = Libderiv->deriv2_classes[3][10][81];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+50693, dvrr_stack+110670, dvrr_stack+59446);
 tmp = dvrr_stack + 50693;
 target_ptr = Libderiv->deriv2_classes[4][5][81];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+51008, dvrr_stack+69395, dvrr_stack+71456);
 tmp = dvrr_stack + 51008;
 target_ptr = Libderiv->deriv2_classes[4][6][81];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+276508, dvrr_stack+76946, dvrr_stack+110670);
 tmp = dvrr_stack + 276508;
 target_ptr = Libderiv->deriv2_classes[4][7][81];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+277048, dvrr_stack+84051, dvrr_stack+69395);
 tmp = dvrr_stack + 277048;
 target_ptr = Libderiv->deriv2_classes[4][8][81];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+277723, dvrr_stack+44174, dvrr_stack+76946);
 tmp = dvrr_stack + 277723;
 target_ptr = Libderiv->deriv2_classes[4][9][81];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+278548, dvrr_stack+103950, dvrr_stack+84051);
 tmp = dvrr_stack + 278548;
 target_ptr = Libderiv->deriv2_classes[4][10][81];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+22137, dvrr_stack+117499, dvrr_stack+74);
 tmp = dvrr_stack + 22137;
 target_ptr = Libderiv->deriv2_classes[2][5][80];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+16589, dvrr_stack+117793, dvrr_stack+117667);
 tmp = dvrr_stack + 16589;
 target_ptr = Libderiv->deriv2_classes[2][6][80];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+55656, dvrr_stack+28486, dvrr_stack+117499);
 tmp = dvrr_stack + 55656;
 target_ptr = Libderiv->deriv2_classes[2][7][80];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+103932, dvrr_stack+118009, dvrr_stack+117793);
 tmp = dvrr_stack + 103932;
 target_ptr = Libderiv->deriv2_classes[2][8][80];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+104202, dvrr_stack+118339, dvrr_stack+28486);
 tmp = dvrr_stack + 104202;
 target_ptr = Libderiv->deriv2_classes[2][9][80];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+104532, dvrr_stack+118735, dvrr_stack+118009);
 tmp = dvrr_stack + 104532;
 target_ptr = Libderiv->deriv2_classes[2][10][80];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+118735, dvrr_stack+119489, dvrr_stack+119339);
 tmp = dvrr_stack + 118735;
 target_ptr = Libderiv->deriv2_classes[3][5][80];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+279538, dvrr_stack+119979, dvrr_stack+119769);
 tmp = dvrr_stack + 279538;
 target_ptr = Libderiv->deriv2_classes[3][6][80];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+279818, dvrr_stack+120339, dvrr_stack+119489);
 tmp = dvrr_stack + 279818;
 target_ptr = Libderiv->deriv2_classes[3][7][80];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+280178, dvrr_stack+105120, dvrr_stack+119979);
 tmp = dvrr_stack + 280178;
 target_ptr = Libderiv->deriv2_classes[3][8][80];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+280628, dvrr_stack+105670, dvrr_stack+120339);
 tmp = dvrr_stack + 280628;
 target_ptr = Libderiv->deriv2_classes[3][9][80];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+281178, dvrr_stack+92982, dvrr_stack+105120);
 tmp = dvrr_stack + 281178;
 target_ptr = Libderiv->deriv2_classes[3][10][80];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+92929, dvrr_stack+93762, dvrr_stack+106480);
 tmp = dvrr_stack + 92929;
 target_ptr = Libderiv->deriv2_classes[4][5][80];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+93244, dvrr_stack+94497, dvrr_stack+94182);
 tmp = dvrr_stack + 93244;
 target_ptr = Libderiv->deriv2_classes[4][6][80];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+281838, dvrr_stack+84876, dvrr_stack+93762);
 tmp = dvrr_stack + 281838;
 target_ptr = Libderiv->deriv2_classes[4][7][80];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+282378, dvrr_stack+77621, dvrr_stack+94497);
 tmp = dvrr_stack + 282378;
 target_ptr = Libderiv->deriv2_classes[4][8][80];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+283053, dvrr_stack+59671, dvrr_stack+84876);
 tmp = dvrr_stack + 283053;
 target_ptr = Libderiv->deriv2_classes[4][9][80];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+283878, dvrr_stack+51476, dvrr_stack+77621);
 tmp = dvrr_stack + 283878;
 target_ptr = Libderiv->deriv2_classes[4][10][80];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+118945, dvrr_stack+106705, dvrr_stack+120789);
 tmp = dvrr_stack + 118945;
 target_ptr = Libderiv->deriv2_classes[2][5][79];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+104928, dvrr_stack+95163, dvrr_stack+95037);
 tmp = dvrr_stack + 104928;
 target_ptr = Libderiv->deriv2_classes[2][6][79];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+106477, dvrr_stack+85551, dvrr_stack+106705);
 tmp = dvrr_stack + 106477;
 target_ptr = Libderiv->deriv2_classes[2][7][79];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+51428, dvrr_stack+69935, dvrr_stack+95163);
 tmp = dvrr_stack + 51428;
 target_ptr = Libderiv->deriv2_classes[2][8][79];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+51698, dvrr_stack+71771, dvrr_stack+85551);
 tmp = dvrr_stack + 51698;
 target_ptr = Libderiv->deriv2_classes[2][9][79];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+52028, dvrr_stack+72167, dvrr_stack+69935);
 tmp = dvrr_stack + 52028;
 target_ptr = Libderiv->deriv2_classes[2][10][79];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+72167, dvrr_stack+60661, dvrr_stack+85821);
 tmp = dvrr_stack + 72167;
 target_ptr = Libderiv->deriv2_classes[3][5][79];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+284868, dvrr_stack+60941, dvrr_stack+111090);
 tmp = dvrr_stack + 284868;
 target_ptr = Libderiv->deriv2_classes[3][6][79];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+285148, dvrr_stack+61301, dvrr_stack+60661);
 tmp = dvrr_stack + 285148;
 target_ptr = Libderiv->deriv2_classes[3][7][79];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+285508, dvrr_stack+38220, dvrr_stack+60941);
 tmp = dvrr_stack + 285508;
 target_ptr = Libderiv->deriv2_classes[3][8][79];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+285958, dvrr_stack+22287, dvrr_stack+61301);
 tmp = dvrr_stack + 285958;
 target_ptr = Libderiv->deriv2_classes[3][9][79];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+286508, dvrr_stack+18755, dvrr_stack+38220);
 tmp = dvrr_stack + 286508;
 target_ptr = Libderiv->deriv2_classes[3][10][79];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+18737, dvrr_stack+33475, dvrr_stack+38770);
 tmp = dvrr_stack + 18737;
 target_ptr = Libderiv->deriv2_classes[4][5][79];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+19052, dvrr_stack+22947, dvrr_stack+29650);
 tmp = dvrr_stack + 19052;
 target_ptr = Libderiv->deriv2_classes[4][6][79];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+287168, dvrr_stack+16847, dvrr_stack+33475);
 tmp = dvrr_stack + 287168;
 target_ptr = Libderiv->deriv2_classes[4][7][79];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+287708, dvrr_stack+153400, dvrr_stack+22947);
 tmp = dvrr_stack + 287708;
 target_ptr = Libderiv->deriv2_classes[4][8][79];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+288383, dvrr_stack+154225, dvrr_stack+16847);
 tmp = dvrr_stack + 288383;
 target_ptr = Libderiv->deriv2_classes[4][9][79];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+289208, dvrr_stack+155215, dvrr_stack+153400);
 tmp = dvrr_stack + 289208;
 target_ptr = Libderiv->deriv2_classes[4][10][79];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+155215, dvrr_stack+33895, dvrr_stack+85971);
 tmp = dvrr_stack + 155215;
 target_ptr = Libderiv->deriv2_classes[2][5][78];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+155341, dvrr_stack+11919, dvrr_stack+29965);
 tmp = dvrr_stack + 155341;
 target_ptr = Libderiv->deriv2_classes[2][6][78];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+155509, dvrr_stack+12135, dvrr_stack+33895);
 tmp = dvrr_stack + 155509;
 target_ptr = Libderiv->deriv2_classes[2][7][78];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+155725, dvrr_stack+7899, dvrr_stack+11919);
 tmp = dvrr_stack + 155725;
 target_ptr = Libderiv->deriv2_classes[2][8][78];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+155995, dvrr_stack+9189, dvrr_stack+12135);
 tmp = dvrr_stack + 155995;
 target_ptr = Libderiv->deriv2_classes[2][9][78];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+290198, dvrr_stack+15911, dvrr_stack+7899);
 tmp = dvrr_stack + 290198;
 target_ptr = Libderiv->deriv2_classes[2][10][78];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+38770, dvrr_stack+4693, dvrr_stack+8229);
 tmp = dvrr_stack + 38770;
 target_ptr = Libderiv->deriv2_classes[3][5][78];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+15824, dvrr_stack+20954, dvrr_stack+2117);
 tmp = dvrr_stack + 15824;
 target_ptr = Libderiv->deriv2_classes[3][6][78];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+290594, dvrr_stack+21561, dvrr_stack+4693);
 tmp = dvrr_stack + 290594;
 target_ptr = Libderiv->deriv2_classes[3][7][78];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+290954, dvrr_stack+156385, dvrr_stack+20954);
 tmp = dvrr_stack + 290954;
 target_ptr = Libderiv->deriv2_classes[3][8][78];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+291404, dvrr_stack+156935, dvrr_stack+21561);
 tmp = dvrr_stack + 291404;
 target_ptr = Libderiv->deriv2_classes[3][9][78];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+291954, dvrr_stack+157595, dvrr_stack+156385);
 tmp = dvrr_stack + 291954;
 target_ptr = Libderiv->deriv2_classes[3][10][78];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+157595, dvrr_stack+58508, dvrr_stack+25581);
 tmp = dvrr_stack + 157595;
 target_ptr = Libderiv->deriv2_classes[4][5][78];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+157910, dvrr_stack+158375, dvrr_stack+58928);
 tmp = dvrr_stack + 157910;
 target_ptr = Libderiv->deriv2_classes[4][6][78];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+292614, dvrr_stack+158915, dvrr_stack+58508);
 tmp = dvrr_stack + 292614;
 target_ptr = Libderiv->deriv2_classes[4][7][78];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+293154, dvrr_stack+159590, dvrr_stack+158375);
 tmp = dvrr_stack + 293154;
 target_ptr = Libderiv->deriv2_classes[4][8][78];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+293829, dvrr_stack+160415, dvrr_stack+158915);
 tmp = dvrr_stack + 293829;
 target_ptr = Libderiv->deriv2_classes[4][9][78];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+294654, dvrr_stack+161405, dvrr_stack+159590);
 tmp = dvrr_stack + 294654;
 target_ptr = Libderiv->deriv2_classes[4][10][78];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,21,dvrr_stack+161405, dvrr_stack+124313, dvrr_stack+106330);
 tmp = dvrr_stack + 161405;
 target_ptr = Libderiv->deriv2_classes[2][5][35];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,28,dvrr_stack+161531, dvrr_stack+124033, dvrr_stack+106393);
 tmp = dvrr_stack + 161531;
 target_ptr = Libderiv->deriv2_classes[2][6][35];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,36,dvrr_stack+161699, dvrr_stack+5719, dvrr_stack+12405);
 tmp = dvrr_stack + 161699;
 target_ptr = Libderiv->deriv2_classes[2][7][35];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,45,dvrr_stack+161915, dvrr_stack+124523, dvrr_stack+120879);
 tmp = dvrr_stack + 161915;
 target_ptr = Libderiv->deriv2_classes[2][8][35];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,55,dvrr_stack+162185, dvrr_stack+124973, dvrr_stack+123713);
 tmp = dvrr_stack + 162185;
 target_ptr = Libderiv->deriv2_classes[2][9][35];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,66,dvrr_stack+295644, dvrr_stack+125523, dvrr_stack+59243);
 tmp = dvrr_stack + 295644;
 target_ptr = Libderiv->deriv2_classes[2][10][35];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,21,dvrr_stack+25581, dvrr_stack+111345, dvrr_stack+121399);
 tmp = dvrr_stack + 25581;
 target_ptr = Libderiv->deriv2_classes[3][5][35];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,28,dvrr_stack+296040, dvrr_stack+31120, dvrr_stack+15509);
 tmp = dvrr_stack + 296040;
 target_ptr = Libderiv->deriv2_classes[3][6][35];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,36,dvrr_stack+296320, dvrr_stack+97932, dvrr_stack+121525);
 tmp = dvrr_stack + 296320;
 target_ptr = Libderiv->deriv2_classes[3][7][35];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,45,dvrr_stack+296680, dvrr_stack+98472, dvrr_stack+121741);
 tmp = dvrr_stack + 296680;
 target_ptr = Libderiv->deriv2_classes[3][8][35];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,55,dvrr_stack+297130, dvrr_stack+88101, dvrr_stack+122011);
 tmp = dvrr_stack + 297130;
 target_ptr = Libderiv->deriv2_classes[3][9][35];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,66,dvrr_stack+297680, dvrr_stack+62731, dvrr_stack+122341);
 tmp = dvrr_stack + 297680;
 target_ptr = Libderiv->deriv2_classes[3][10][35];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,21,dvrr_stack+298340, dvrr_stack+166536, dvrr_stack+124313);
 tmp = dvrr_stack + 298340;
 target_ptr = Libderiv->deriv2_classes[4][5][35];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,28,dvrr_stack+298655, dvrr_stack+170613, dvrr_stack+124033);
 tmp = dvrr_stack + 298655;
 target_ptr = Libderiv->deriv2_classes[4][6][35];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,36,dvrr_stack+299075, dvrr_stack+175809, dvrr_stack+5719);
 tmp = dvrr_stack + 299075;
 target_ptr = Libderiv->deriv2_classes[4][7][35];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,45,dvrr_stack+299615, dvrr_stack+182260, dvrr_stack+124523);
 tmp = dvrr_stack + 299615;
 target_ptr = Libderiv->deriv2_classes[4][8][35];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,55,dvrr_stack+300290, dvrr_stack+190102, dvrr_stack+124973);
 tmp = dvrr_stack + 300290;
 target_ptr = Libderiv->deriv2_classes[4][9][35];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,66,dvrr_stack+301115, dvrr_stack+101532, dvrr_stack+125523);
 tmp = dvrr_stack + 301115;
 target_ptr = Libderiv->deriv2_classes[4][10][35];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+8229, dvrr_stack+65171, dvrr_stack+102918);
 tmp = dvrr_stack + 8229;
 target_ptr = Libderiv->deriv2_classes[2][5][34];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+85821, dvrr_stack+64891, dvrr_stack+102981);
 tmp = dvrr_stack + 85821;
 target_ptr = Libderiv->deriv2_classes[2][6][34];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+72377, dvrr_stack+65381, dvrr_stack+103065);
 tmp = dvrr_stack + 72377;
 target_ptr = Libderiv->deriv2_classes[2][7][34];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+16104, dvrr_stack+54656, dvrr_stack+103173);
 tmp = dvrr_stack + 16104;
 target_ptr = Libderiv->deriv2_classes[2][8][34];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+302105, dvrr_stack+55106, dvrr_stack+103308);
 tmp = dvrr_stack + 302105;
 target_ptr = Libderiv->deriv2_classes[2][9][34];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+302435, dvrr_stack+46814, dvrr_stack+103473);
 tmp = dvrr_stack + 302435;
 target_ptr = Libderiv->deriv2_classes[2][10][34];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+52424, dvrr_stack+47474, dvrr_stack+99147);
 tmp = dvrr_stack + 52424;
 target_ptr = Libderiv->deriv2_classes[3][5][34];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+302831, dvrr_stack+35185, dvrr_stack+111660);
 tmp = dvrr_stack + 302831;
 target_ptr = Libderiv->deriv2_classes[3][6][34];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+303111, dvrr_stack+23541, dvrr_stack+99273);
 tmp = dvrr_stack + 303111;
 target_ptr = Libderiv->deriv2_classes[3][7][34];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+303471, dvrr_stack+24081, dvrr_stack+88926);
 tmp = dvrr_stack + 303471;
 target_ptr = Libderiv->deriv2_classes[3][8][34];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+303921, dvrr_stack+24756, dvrr_stack+80186);
 tmp = dvrr_stack + 303921;
 target_ptr = Libderiv->deriv2_classes[3][9][34];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+304471, dvrr_stack+151240, dvrr_stack+80516);
 tmp = dvrr_stack + 304471;
 target_ptr = Libderiv->deriv2_classes[3][10][34];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+305131, dvrr_stack+49214, dvrr_stack+65171);
 tmp = dvrr_stack + 305131;
 target_ptr = Libderiv->deriv2_classes[4][5][34];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+305446, dvrr_stack+49655, dvrr_stack+64891);
 tmp = dvrr_stack + 305446;
 target_ptr = Libderiv->deriv2_classes[4][6][34];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+305866, dvrr_stack+191257, dvrr_stack+65381);
 tmp = dvrr_stack + 305866;
 target_ptr = Libderiv->deriv2_classes[4][7][34];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+306406, dvrr_stack+192013, dvrr_stack+54656);
 tmp = dvrr_stack + 306406;
 target_ptr = Libderiv->deriv2_classes[4][8][34];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+307081, dvrr_stack+199471, dvrr_stack+55106);
 tmp = dvrr_stack + 307081;
 target_ptr = Libderiv->deriv2_classes[4][9][34];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+307906, dvrr_stack+200626, dvrr_stack+46814);
 tmp = dvrr_stack + 307906;
 target_ptr = Libderiv->deriv2_classes[4][10][34];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+119071, dvrr_stack+29440, dvrr_stack+103671);
 tmp = dvrr_stack + 119071;
 target_ptr = Libderiv->deriv2_classes[2][5][33];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+59441, dvrr_stack+123433, dvrr_stack+30091);
 tmp = dvrr_stack + 59441;
 target_ptr = Libderiv->deriv2_classes[2][6][33];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+308896, dvrr_stack+28126, dvrr_stack+2999);
 tmp = dvrr_stack + 308896;
 target_ptr = Libderiv->deriv2_classes[2][7][33];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+309112, dvrr_stack+33025, dvrr_stack+115803);
 tmp = dvrr_stack + 309112;
 target_ptr = Libderiv->deriv2_classes[2][8][33];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+309382, dvrr_stack+37670, dvrr_stack+115938);
 tmp = dvrr_stack + 309382;
 target_ptr = Libderiv->deriv2_classes[2][9][33];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+309712, dvrr_stack+43514, dvrr_stack+116103);
 tmp = dvrr_stack + 309712;
 target_ptr = Libderiv->deriv2_classes[2][10][33];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+310108, dvrr_stack+71456, dvrr_stack+1991);
 tmp = dvrr_stack + 310108;
 target_ptr = Libderiv->deriv2_classes[3][5][33];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+310318, dvrr_stack+110670, dvrr_stack+121039);
 tmp = dvrr_stack + 310318;
 target_ptr = Libderiv->deriv2_classes[3][6][33];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+310598, dvrr_stack+69395, dvrr_stack+990);
 tmp = dvrr_stack + 310598;
 target_ptr = Libderiv->deriv2_classes[3][7][33];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+310958, dvrr_stack+76946, dvrr_stack+4423);
 tmp = dvrr_stack + 310958;
 target_ptr = Libderiv->deriv2_classes[3][8][33];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+311408, dvrr_stack+84051, dvrr_stack+7569);
 tmp = dvrr_stack + 311408;
 target_ptr = Libderiv->deriv2_classes[3][9][33];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+311958, dvrr_stack+44174, dvrr_stack+11523);
 tmp = dvrr_stack + 311958;
 target_ptr = Libderiv->deriv2_classes[3][10][33];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+312618, dvrr_stack+162575, dvrr_stack+29440);
 tmp = dvrr_stack + 312618;
 target_ptr = Libderiv->deriv2_classes[4][5][33];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+312933, dvrr_stack+165213, dvrr_stack+123433);
 tmp = dvrr_stack + 312933;
 target_ptr = Libderiv->deriv2_classes[4][6][33];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+313353, dvrr_stack+168849, dvrr_stack+28126);
 tmp = dvrr_stack + 313353;
 target_ptr = Libderiv->deriv2_classes[4][7][33];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+313893, dvrr_stack+173541, dvrr_stack+33025);
 tmp = dvrr_stack + 313893;
 target_ptr = Libderiv->deriv2_classes[4][8][33];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+314568, dvrr_stack+179425, dvrr_stack+37670);
 tmp = dvrr_stack + 314568;
 target_ptr = Libderiv->deriv2_classes[4][9][33];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+315393, dvrr_stack+186637, dvrr_stack+43514);
 tmp = dvrr_stack + 315393;
 target_ptr = Libderiv->deriv2_classes[4][10][33];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+80912, dvrr_stack+119769, dvrr_stack+195313);
 tmp = dvrr_stack + 80912;
 target_ptr = Libderiv->deriv2_classes[2][5][32];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+316383, dvrr_stack+119489, dvrr_stack+195376);
 tmp = dvrr_stack + 316383;
 target_ptr = Libderiv->deriv2_classes[2][6][32];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+316551, dvrr_stack+119979, dvrr_stack+195460);
 tmp = dvrr_stack + 316551;
 target_ptr = Libderiv->deriv2_classes[2][7][32];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+316767, dvrr_stack+120339, dvrr_stack+195568);
 tmp = dvrr_stack + 316767;
 target_ptr = Libderiv->deriv2_classes[2][8][32];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+317037, dvrr_stack+105120, dvrr_stack+195703);
 tmp = dvrr_stack + 317037;
 target_ptr = Libderiv->deriv2_classes[2][9][32];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+317367, dvrr_stack+105670, dvrr_stack+195868);
 tmp = dvrr_stack + 317367;
 target_ptr = Libderiv->deriv2_classes[2][10][32];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+317763, dvrr_stack+94182, dvrr_stack+117667);
 tmp = dvrr_stack + 317763;
 target_ptr = Libderiv->deriv2_classes[3][5][32];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+317973, dvrr_stack+93762, dvrr_stack+117499);
 tmp = dvrr_stack + 317973;
 target_ptr = Libderiv->deriv2_classes[3][6][32];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+318253, dvrr_stack+94497, dvrr_stack+117793);
 tmp = dvrr_stack + 318253;
 target_ptr = Libderiv->deriv2_classes[3][7][32];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+318613, dvrr_stack+84876, dvrr_stack+28486);
 tmp = dvrr_stack + 318613;
 target_ptr = Libderiv->deriv2_classes[3][8][32];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+319063, dvrr_stack+77621, dvrr_stack+118009);
 tmp = dvrr_stack + 319063;
 target_ptr = Libderiv->deriv2_classes[3][9][32];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+319613, dvrr_stack+59671, dvrr_stack+118339);
 tmp = dvrr_stack + 319613;
 target_ptr = Libderiv->deriv2_classes[3][10][32];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+320273, dvrr_stack+196609, dvrr_stack+119769);
 tmp = dvrr_stack + 320273;
 target_ptr = Libderiv->deriv2_classes[4][5][32];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+320588, dvrr_stack+197050, dvrr_stack+119489);
 tmp = dvrr_stack + 320588;
 target_ptr = Libderiv->deriv2_classes[4][6][32];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+321008, dvrr_stack+197638, dvrr_stack+119979);
 tmp = dvrr_stack + 321008;
 target_ptr = Libderiv->deriv2_classes[4][7][32];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+321548, dvrr_stack+198394, dvrr_stack+120339);
 tmp = dvrr_stack + 321548;
 target_ptr = Libderiv->deriv2_classes[4][8][32];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+322223, dvrr_stack+188023, dvrr_stack+105120);
 tmp = dvrr_stack + 322223;
 target_ptr = Libderiv->deriv2_classes[4][9][32];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+323048, dvrr_stack+180580, dvrr_stack+105670);
 tmp = dvrr_stack + 323048;
 target_ptr = Libderiv->deriv2_classes[4][10][32];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+119329, dvrr_stack+111090, dvrr_stack+126183);
 tmp = dvrr_stack + 119329;
 target_ptr = Libderiv->deriv2_classes[2][5][31];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+324038, dvrr_stack+60661, dvrr_stack+126246);
 tmp = dvrr_stack + 324038;
 target_ptr = Libderiv->deriv2_classes[2][6][31];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+324206, dvrr_stack+60941, dvrr_stack+126330);
 tmp = dvrr_stack + 324206;
 target_ptr = Libderiv->deriv2_classes[2][7][31];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+324422, dvrr_stack+61301, dvrr_stack+196066);
 tmp = dvrr_stack + 324422;
 target_ptr = Libderiv->deriv2_classes[2][8][31];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+324692, dvrr_stack+38220, dvrr_stack+123205);
 tmp = dvrr_stack + 324692;
 target_ptr = Libderiv->deriv2_classes[2][9][31];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+325022, dvrr_stack+22287, dvrr_stack+189178);
 tmp = dvrr_stack + 325022;
 target_ptr = Libderiv->deriv2_classes[2][10][31];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+325418, dvrr_stack+29650, dvrr_stack+95037);
 tmp = dvrr_stack + 325418;
 target_ptr = Libderiv->deriv2_classes[3][5][31];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+325628, dvrr_stack+33475, dvrr_stack+106705);
 tmp = dvrr_stack + 325628;
 target_ptr = Libderiv->deriv2_classes[3][6][31];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+325908, dvrr_stack+22947, dvrr_stack+95163);
 tmp = dvrr_stack + 325908;
 target_ptr = Libderiv->deriv2_classes[3][7][31];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+326268, dvrr_stack+16847, dvrr_stack+85551);
 tmp = dvrr_stack + 326268;
 target_ptr = Libderiv->deriv2_classes[3][8][31];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+326718, dvrr_stack+153400, dvrr_stack+69935);
 tmp = dvrr_stack + 326718;
 target_ptr = Libderiv->deriv2_classes[3][9][31];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+327268, dvrr_stack+154225, dvrr_stack+71771);
 tmp = dvrr_stack + 327268;
 target_ptr = Libderiv->deriv2_classes[3][10][31];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+327928, dvrr_stack+189376, dvrr_stack+111090);
 tmp = dvrr_stack + 327928;
 target_ptr = Libderiv->deriv2_classes[4][5][31];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+328243, dvrr_stack+174486, dvrr_stack+60661);
 tmp = dvrr_stack + 328243;
 target_ptr = Libderiv->deriv2_classes[4][6][31];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+328663, dvrr_stack+169605, dvrr_stack+60941);
 tmp = dvrr_stack + 328663;
 target_ptr = Libderiv->deriv2_classes[4][7][31];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+329203, dvrr_stack+202012, dvrr_stack+61301);
 tmp = dvrr_stack + 329203;
 target_ptr = Libderiv->deriv2_classes[4][8][31];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+329878, dvrr_stack+202957, dvrr_stack+38220);
 tmp = dvrr_stack + 329878;
 target_ptr = Libderiv->deriv2_classes[4][9][31];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+330703, dvrr_stack+204112, dvrr_stack+22287);
 tmp = dvrr_stack + 330703;
 target_ptr = Libderiv->deriv2_classes[4][10][31];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+0, dvrr_stack+2117, dvrr_stack+123370);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[2][5][30];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+331693, dvrr_stack+4693, dvrr_stack+196201);
 tmp = dvrr_stack + 331693;
 target_ptr = Libderiv->deriv2_classes[2][6][30];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+331861, dvrr_stack+20954, dvrr_stack+199339);
 tmp = dvrr_stack + 331861;
 target_ptr = Libderiv->deriv2_classes[2][7][30];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+332077, dvrr_stack+21561, dvrr_stack+189817);
 tmp = dvrr_stack + 332077;
 target_ptr = Libderiv->deriv2_classes[2][8][30];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+332347, dvrr_stack+156385, dvrr_stack+181966);
 tmp = dvrr_stack + 332347;
 target_ptr = Libderiv->deriv2_classes[2][9][30];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+332677, dvrr_stack+156935, dvrr_stack+175074);
 tmp = dvrr_stack + 332677;
 target_ptr = Libderiv->deriv2_classes[2][10][30];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+333073, dvrr_stack+58928, dvrr_stack+29965);
 tmp = dvrr_stack + 333073;
 target_ptr = Libderiv->deriv2_classes[3][5][30];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+333283, dvrr_stack+58508, dvrr_stack+33895);
 tmp = dvrr_stack + 333283;
 target_ptr = Libderiv->deriv2_classes[3][6][30];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+333563, dvrr_stack+158375, dvrr_stack+11919);
 tmp = dvrr_stack + 333563;
 target_ptr = Libderiv->deriv2_classes[3][7][30];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+333923, dvrr_stack+158915, dvrr_stack+12135);
 tmp = dvrr_stack + 333923;
 target_ptr = Libderiv->deriv2_classes[3][8][30];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+334373, dvrr_stack+159590, dvrr_stack+7899);
 tmp = dvrr_stack + 334373;
 target_ptr = Libderiv->deriv2_classes[3][9][30];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+334923, dvrr_stack+160415, dvrr_stack+9189);
 tmp = dvrr_stack + 334923;
 target_ptr = Libderiv->deriv2_classes[3][10][30];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+335583, dvrr_stack+175272, dvrr_stack+2117);
 tmp = dvrr_stack + 335583;
 target_ptr = Libderiv->deriv2_classes[4][5][30];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+335898, dvrr_stack+165801, dvrr_stack+4693);
 tmp = dvrr_stack + 335898;
 target_ptr = Libderiv->deriv2_classes[4][6][30];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+336318, dvrr_stack+205498, dvrr_stack+20954);
 tmp = dvrr_stack + 336318;
 target_ptr = Libderiv->deriv2_classes[4][7][30];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+336858, dvrr_stack+206254, dvrr_stack+21561);
 tmp = dvrr_stack + 336858;
 target_ptr = Libderiv->deriv2_classes[4][8][30];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+337533, dvrr_stack+207199, dvrr_stack+156385);
 tmp = dvrr_stack + 337533;
 target_ptr = Libderiv->deriv2_classes[4][9][30];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+338358, dvrr_stack+208354, dvrr_stack+156935);
 tmp = dvrr_stack + 338358;
 target_ptr = Libderiv->deriv2_classes[4][10][30];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+74303, dvrr_stack+196285, dvrr_stack+15677);
 tmp = dvrr_stack + 74303;
 target_ptr = Libderiv->deriv2_classes[2][5][26];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+339348, dvrr_stack+116301, dvrr_stack+15740);
 tmp = dvrr_stack + 339348;
 target_ptr = Libderiv->deriv2_classes[2][6][26];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+339516, dvrr_stack+116581, dvrr_stack+196495);
 tmp = dvrr_stack + 339516;
 target_ptr = Libderiv->deriv2_classes[2][7][26];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+339732, dvrr_stack+50243, dvrr_stack+189952);
 tmp = dvrr_stack + 339732;
 target_ptr = Libderiv->deriv2_classes[2][8][26];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+340002, dvrr_stack+192958, dvrr_stack+170361);
 tmp = dvrr_stack + 340002;
 target_ptr = Libderiv->deriv2_classes[2][9][26];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+340332, dvrr_stack+193508, dvrr_stack+103734);
 tmp = dvrr_stack + 340332;
 target_ptr = Libderiv->deriv2_classes[2][10][26];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+340728, dvrr_stack+194168, dvrr_stack+182131);
 tmp = dvrr_stack + 340728;
 target_ptr = Libderiv->deriv2_classes[3][5][26];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+340938, dvrr_stack+194651, dvrr_stack+194483);
 tmp = dvrr_stack + 340938;
 target_ptr = Libderiv->deriv2_classes[3][6][26];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+341218, dvrr_stack+42260, dvrr_stack+195071);
 tmp = dvrr_stack + 341218;
 target_ptr = Libderiv->deriv2_classes[3][7][26];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+341578, dvrr_stack+209740, dvrr_stack+36823);
 tmp = dvrr_stack + 341578;
 target_ptr = Libderiv->deriv2_classes[3][8][26];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+342028, dvrr_stack+210745, dvrr_stack+210415);
 tmp = dvrr_stack + 342028;
 target_ptr = Libderiv->deriv2_classes[3][9][26];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+342578, dvrr_stack+211966, dvrr_stack+211570);
 tmp = dvrr_stack + 342578;
 target_ptr = Libderiv->deriv2_classes[3][10][26];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+343238, dvrr_stack+67726, dvrr_stack+196285);
 tmp = dvrr_stack + 343238;
 target_ptr = Libderiv->deriv2_classes[4][5][26];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+343553, dvrr_stack+163925, dvrr_stack+116301);
 tmp = dvrr_stack + 343553;
 target_ptr = Libderiv->deriv2_classes[4][6][26];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+343973, dvrr_stack+214615, dvrr_stack+116581);
 tmp = dvrr_stack + 343973;
 target_ptr = Libderiv->deriv2_classes[4][7][26];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+344513, dvrr_stack+212956, dvrr_stack+50243);
 tmp = dvrr_stack + 344513;
 target_ptr = Libderiv->deriv2_classes[4][8][26];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+345188, dvrr_stack+218171, dvrr_stack+192958);
 tmp = dvrr_stack + 345188;
 target_ptr = Libderiv->deriv2_classes[4][9][26];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,66,dvrr_stack+346013, dvrr_stack+223746, dvrr_stack+193508);
 tmp = dvrr_stack + 346013;
 target_ptr = Libderiv->deriv2_classes[4][10][26];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,21,dvrr_stack+123878, dvrr_stack+124313, dvrr_stack+106330);
 tmp = dvrr_stack + 123878;
 target_ptr = Libderiv->deriv2_classes[2][5][23];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,28,dvrr_stack+347003, dvrr_stack+124033, dvrr_stack+106393);
 tmp = dvrr_stack + 347003;
 target_ptr = Libderiv->deriv2_classes[2][6][23];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,36,dvrr_stack+347171, dvrr_stack+5719, dvrr_stack+12405);
 tmp = dvrr_stack + 347171;
 target_ptr = Libderiv->deriv2_classes[2][7][23];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,45,dvrr_stack+347387, dvrr_stack+124523, dvrr_stack+120879);
 tmp = dvrr_stack + 347387;
 target_ptr = Libderiv->deriv2_classes[2][8][23];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,55,dvrr_stack+347657, dvrr_stack+124973, dvrr_stack+123713);
 tmp = dvrr_stack + 347657;
 target_ptr = Libderiv->deriv2_classes[2][9][23];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,66,dvrr_stack+347987, dvrr_stack+125523, dvrr_stack+59243);
 tmp = dvrr_stack + 347987;
 target_ptr = Libderiv->deriv2_classes[2][10][23];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,21,dvrr_stack+348383, dvrr_stack+111345, dvrr_stack+121399);
 tmp = dvrr_stack + 348383;
 target_ptr = Libderiv->deriv2_classes[3][5][23];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,28,dvrr_stack+348593, dvrr_stack+31120, dvrr_stack+15509);
 tmp = dvrr_stack + 348593;
 target_ptr = Libderiv->deriv2_classes[3][6][23];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,36,dvrr_stack+348873, dvrr_stack+97932, dvrr_stack+121525);
 tmp = dvrr_stack + 348873;
 target_ptr = Libderiv->deriv2_classes[3][7][23];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,45,dvrr_stack+349233, dvrr_stack+98472, dvrr_stack+121741);
 tmp = dvrr_stack + 349233;
 target_ptr = Libderiv->deriv2_classes[3][8][23];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,55,dvrr_stack+349683, dvrr_stack+88101, dvrr_stack+122011);
 tmp = dvrr_stack + 349683;
 target_ptr = Libderiv->deriv2_classes[3][9][23];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,66,dvrr_stack+350233, dvrr_stack+62731, dvrr_stack+122341);
 tmp = dvrr_stack + 350233;
 target_ptr = Libderiv->deriv2_classes[3][10][23];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,21,dvrr_stack+350893, dvrr_stack+166536, dvrr_stack+124313);
 tmp = dvrr_stack + 350893;
 target_ptr = Libderiv->deriv2_classes[4][5][23];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,28,dvrr_stack+351208, dvrr_stack+170613, dvrr_stack+124033);
 tmp = dvrr_stack + 351208;
 target_ptr = Libderiv->deriv2_classes[4][6][23];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,36,dvrr_stack+351628, dvrr_stack+175809, dvrr_stack+5719);
 tmp = dvrr_stack + 351628;
 target_ptr = Libderiv->deriv2_classes[4][7][23];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,45,dvrr_stack+352168, dvrr_stack+182260, dvrr_stack+124523);
 tmp = dvrr_stack + 352168;
 target_ptr = Libderiv->deriv2_classes[4][8][23];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,55,dvrr_stack+352843, dvrr_stack+190102, dvrr_stack+124973);
 tmp = dvrr_stack + 352843;
 target_ptr = Libderiv->deriv2_classes[4][9][23];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,66,dvrr_stack+353668, dvrr_stack+101532, dvrr_stack+125523);
 tmp = dvrr_stack + 353668;
 target_ptr = Libderiv->deriv2_classes[4][10][23];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+354658, dvrr_stack+65171, dvrr_stack+102918);
 tmp = dvrr_stack + 354658;
 target_ptr = Libderiv->deriv2_classes[2][5][22];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+354784, dvrr_stack+64891, dvrr_stack+102981);
 tmp = dvrr_stack + 354784;
 target_ptr = Libderiv->deriv2_classes[2][6][22];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+354952, dvrr_stack+65381, dvrr_stack+103065);
 tmp = dvrr_stack + 354952;
 target_ptr = Libderiv->deriv2_classes[2][7][22];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+355168, dvrr_stack+54656, dvrr_stack+103173);
 tmp = dvrr_stack + 355168;
 target_ptr = Libderiv->deriv2_classes[2][8][22];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+355438, dvrr_stack+55106, dvrr_stack+103308);
 tmp = dvrr_stack + 355438;
 target_ptr = Libderiv->deriv2_classes[2][9][22];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+355768, dvrr_stack+46814, dvrr_stack+103473);
 tmp = dvrr_stack + 355768;
 target_ptr = Libderiv->deriv2_classes[2][10][22];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+356164, dvrr_stack+47474, dvrr_stack+99147);
 tmp = dvrr_stack + 356164;
 target_ptr = Libderiv->deriv2_classes[3][5][22];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+356374, dvrr_stack+35185, dvrr_stack+111660);
 tmp = dvrr_stack + 356374;
 target_ptr = Libderiv->deriv2_classes[3][6][22];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+356654, dvrr_stack+23541, dvrr_stack+99273);
 tmp = dvrr_stack + 356654;
 target_ptr = Libderiv->deriv2_classes[3][7][22];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+357014, dvrr_stack+24081, dvrr_stack+88926);
 tmp = dvrr_stack + 357014;
 target_ptr = Libderiv->deriv2_classes[3][8][22];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+357464, dvrr_stack+24756, dvrr_stack+80186);
 tmp = dvrr_stack + 357464;
 target_ptr = Libderiv->deriv2_classes[3][9][22];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+358014, dvrr_stack+151240, dvrr_stack+80516);
 tmp = dvrr_stack + 358014;
 target_ptr = Libderiv->deriv2_classes[3][10][22];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+358674, dvrr_stack+49214, dvrr_stack+65171);
 tmp = dvrr_stack + 358674;
 target_ptr = Libderiv->deriv2_classes[4][5][22];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+358989, dvrr_stack+49655, dvrr_stack+64891);
 tmp = dvrr_stack + 358989;
 target_ptr = Libderiv->deriv2_classes[4][6][22];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+359409, dvrr_stack+191257, dvrr_stack+65381);
 tmp = dvrr_stack + 359409;
 target_ptr = Libderiv->deriv2_classes[4][7][22];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+359949, dvrr_stack+192013, dvrr_stack+54656);
 tmp = dvrr_stack + 359949;
 target_ptr = Libderiv->deriv2_classes[4][8][22];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+360624, dvrr_stack+199471, dvrr_stack+55106);
 tmp = dvrr_stack + 360624;
 target_ptr = Libderiv->deriv2_classes[4][9][22];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+361449, dvrr_stack+200626, dvrr_stack+46814);
 tmp = dvrr_stack + 361449;
 target_ptr = Libderiv->deriv2_classes[4][10][22];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+362439, dvrr_stack+29440, dvrr_stack+103671);
 tmp = dvrr_stack + 362439;
 target_ptr = Libderiv->deriv2_classes[2][5][21];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+362565, dvrr_stack+123433, dvrr_stack+30091);
 tmp = dvrr_stack + 362565;
 target_ptr = Libderiv->deriv2_classes[2][6][21];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+362733, dvrr_stack+28126, dvrr_stack+2999);
 tmp = dvrr_stack + 362733;
 target_ptr = Libderiv->deriv2_classes[2][7][21];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+362949, dvrr_stack+33025, dvrr_stack+115803);
 tmp = dvrr_stack + 362949;
 target_ptr = Libderiv->deriv2_classes[2][8][21];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+363219, dvrr_stack+37670, dvrr_stack+115938);
 tmp = dvrr_stack + 363219;
 target_ptr = Libderiv->deriv2_classes[2][9][21];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+363549, dvrr_stack+43514, dvrr_stack+116103);
 tmp = dvrr_stack + 363549;
 target_ptr = Libderiv->deriv2_classes[2][10][21];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+363945, dvrr_stack+71456, dvrr_stack+1991);
 tmp = dvrr_stack + 363945;
 target_ptr = Libderiv->deriv2_classes[3][5][21];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+364155, dvrr_stack+110670, dvrr_stack+121039);
 tmp = dvrr_stack + 364155;
 target_ptr = Libderiv->deriv2_classes[3][6][21];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+364435, dvrr_stack+69395, dvrr_stack+990);
 tmp = dvrr_stack + 364435;
 target_ptr = Libderiv->deriv2_classes[3][7][21];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+364795, dvrr_stack+76946, dvrr_stack+4423);
 tmp = dvrr_stack + 364795;
 target_ptr = Libderiv->deriv2_classes[3][8][21];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+365245, dvrr_stack+84051, dvrr_stack+7569);
 tmp = dvrr_stack + 365245;
 target_ptr = Libderiv->deriv2_classes[3][9][21];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+365795, dvrr_stack+44174, dvrr_stack+11523);
 tmp = dvrr_stack + 365795;
 target_ptr = Libderiv->deriv2_classes[3][10][21];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+366455, dvrr_stack+162575, dvrr_stack+29440);
 tmp = dvrr_stack + 366455;
 target_ptr = Libderiv->deriv2_classes[4][5][21];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+366770, dvrr_stack+165213, dvrr_stack+123433);
 tmp = dvrr_stack + 366770;
 target_ptr = Libderiv->deriv2_classes[4][6][21];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+367190, dvrr_stack+168849, dvrr_stack+28126);
 tmp = dvrr_stack + 367190;
 target_ptr = Libderiv->deriv2_classes[4][7][21];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+367730, dvrr_stack+173541, dvrr_stack+33025);
 tmp = dvrr_stack + 367730;
 target_ptr = Libderiv->deriv2_classes[4][8][21];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+368405, dvrr_stack+179425, dvrr_stack+37670);
 tmp = dvrr_stack + 368405;
 target_ptr = Libderiv->deriv2_classes[4][9][21];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+369230, dvrr_stack+186637, dvrr_stack+43514);
 tmp = dvrr_stack + 369230;
 target_ptr = Libderiv->deriv2_classes[4][10][21];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+370220, dvrr_stack+119769, dvrr_stack+195313);
 tmp = dvrr_stack + 370220;
 target_ptr = Libderiv->deriv2_classes[2][5][20];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+370346, dvrr_stack+119489, dvrr_stack+195376);
 tmp = dvrr_stack + 370346;
 target_ptr = Libderiv->deriv2_classes[2][6][20];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+370514, dvrr_stack+119979, dvrr_stack+195460);
 tmp = dvrr_stack + 370514;
 target_ptr = Libderiv->deriv2_classes[2][7][20];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+370730, dvrr_stack+120339, dvrr_stack+195568);
 tmp = dvrr_stack + 370730;
 target_ptr = Libderiv->deriv2_classes[2][8][20];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+371000, dvrr_stack+105120, dvrr_stack+195703);
 tmp = dvrr_stack + 371000;
 target_ptr = Libderiv->deriv2_classes[2][9][20];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+371330, dvrr_stack+105670, dvrr_stack+195868);
 tmp = dvrr_stack + 371330;
 target_ptr = Libderiv->deriv2_classes[2][10][20];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+371726, dvrr_stack+94182, dvrr_stack+117667);
 tmp = dvrr_stack + 371726;
 target_ptr = Libderiv->deriv2_classes[3][5][20];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+371936, dvrr_stack+93762, dvrr_stack+117499);
 tmp = dvrr_stack + 371936;
 target_ptr = Libderiv->deriv2_classes[3][6][20];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+372216, dvrr_stack+94497, dvrr_stack+117793);
 tmp = dvrr_stack + 372216;
 target_ptr = Libderiv->deriv2_classes[3][7][20];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+372576, dvrr_stack+84876, dvrr_stack+28486);
 tmp = dvrr_stack + 372576;
 target_ptr = Libderiv->deriv2_classes[3][8][20];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+373026, dvrr_stack+77621, dvrr_stack+118009);
 tmp = dvrr_stack + 373026;
 target_ptr = Libderiv->deriv2_classes[3][9][20];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+373576, dvrr_stack+59671, dvrr_stack+118339);
 tmp = dvrr_stack + 373576;
 target_ptr = Libderiv->deriv2_classes[3][10][20];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+374236, dvrr_stack+196609, dvrr_stack+119769);
 tmp = dvrr_stack + 374236;
 target_ptr = Libderiv->deriv2_classes[4][5][20];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+374551, dvrr_stack+197050, dvrr_stack+119489);
 tmp = dvrr_stack + 374551;
 target_ptr = Libderiv->deriv2_classes[4][6][20];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+374971, dvrr_stack+197638, dvrr_stack+119979);
 tmp = dvrr_stack + 374971;
 target_ptr = Libderiv->deriv2_classes[4][7][20];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+375511, dvrr_stack+198394, dvrr_stack+120339);
 tmp = dvrr_stack + 375511;
 target_ptr = Libderiv->deriv2_classes[4][8][20];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+376186, dvrr_stack+188023, dvrr_stack+105120);
 tmp = dvrr_stack + 376186;
 target_ptr = Libderiv->deriv2_classes[4][9][20];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+377011, dvrr_stack+180580, dvrr_stack+105670);
 tmp = dvrr_stack + 377011;
 target_ptr = Libderiv->deriv2_classes[4][10][20];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+378001, dvrr_stack+111090, dvrr_stack+126183);
 tmp = dvrr_stack + 378001;
 target_ptr = Libderiv->deriv2_classes[2][5][19];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+378127, dvrr_stack+60661, dvrr_stack+126246);
 tmp = dvrr_stack + 378127;
 target_ptr = Libderiv->deriv2_classes[2][6][19];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+378295, dvrr_stack+60941, dvrr_stack+126330);
 tmp = dvrr_stack + 378295;
 target_ptr = Libderiv->deriv2_classes[2][7][19];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+378511, dvrr_stack+61301, dvrr_stack+196066);
 tmp = dvrr_stack + 378511;
 target_ptr = Libderiv->deriv2_classes[2][8][19];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+378781, dvrr_stack+38220, dvrr_stack+123205);
 tmp = dvrr_stack + 378781;
 target_ptr = Libderiv->deriv2_classes[2][9][19];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+379111, dvrr_stack+22287, dvrr_stack+189178);
 tmp = dvrr_stack + 379111;
 target_ptr = Libderiv->deriv2_classes[2][10][19];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+379507, dvrr_stack+29650, dvrr_stack+95037);
 tmp = dvrr_stack + 379507;
 target_ptr = Libderiv->deriv2_classes[3][5][19];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+379717, dvrr_stack+33475, dvrr_stack+106705);
 tmp = dvrr_stack + 379717;
 target_ptr = Libderiv->deriv2_classes[3][6][19];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+379997, dvrr_stack+22947, dvrr_stack+95163);
 tmp = dvrr_stack + 379997;
 target_ptr = Libderiv->deriv2_classes[3][7][19];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+380357, dvrr_stack+16847, dvrr_stack+85551);
 tmp = dvrr_stack + 380357;
 target_ptr = Libderiv->deriv2_classes[3][8][19];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+380807, dvrr_stack+153400, dvrr_stack+69935);
 tmp = dvrr_stack + 380807;
 target_ptr = Libderiv->deriv2_classes[3][9][19];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+381357, dvrr_stack+154225, dvrr_stack+71771);
 tmp = dvrr_stack + 381357;
 target_ptr = Libderiv->deriv2_classes[3][10][19];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+382017, dvrr_stack+189376, dvrr_stack+111090);
 tmp = dvrr_stack + 382017;
 target_ptr = Libderiv->deriv2_classes[4][5][19];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+382332, dvrr_stack+174486, dvrr_stack+60661);
 tmp = dvrr_stack + 382332;
 target_ptr = Libderiv->deriv2_classes[4][6][19];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+382752, dvrr_stack+169605, dvrr_stack+60941);
 tmp = dvrr_stack + 382752;
 target_ptr = Libderiv->deriv2_classes[4][7][19];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+383292, dvrr_stack+202012, dvrr_stack+61301);
 tmp = dvrr_stack + 383292;
 target_ptr = Libderiv->deriv2_classes[4][8][19];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+383967, dvrr_stack+202957, dvrr_stack+38220);
 tmp = dvrr_stack + 383967;
 target_ptr = Libderiv->deriv2_classes[4][9][19];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+384792, dvrr_stack+204112, dvrr_stack+22287);
 tmp = dvrr_stack + 384792;
 target_ptr = Libderiv->deriv2_classes[4][10][19];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+385782, dvrr_stack+2117, dvrr_stack+123370);
 tmp = dvrr_stack + 385782;
 target_ptr = Libderiv->deriv2_classes[2][5][18];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+385908, dvrr_stack+4693, dvrr_stack+196201);
 tmp = dvrr_stack + 385908;
 target_ptr = Libderiv->deriv2_classes[2][6][18];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+386076, dvrr_stack+20954, dvrr_stack+199339);
 tmp = dvrr_stack + 386076;
 target_ptr = Libderiv->deriv2_classes[2][7][18];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+386292, dvrr_stack+21561, dvrr_stack+189817);
 tmp = dvrr_stack + 386292;
 target_ptr = Libderiv->deriv2_classes[2][8][18];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+386562, dvrr_stack+156385, dvrr_stack+181966);
 tmp = dvrr_stack + 386562;
 target_ptr = Libderiv->deriv2_classes[2][9][18];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+386892, dvrr_stack+156935, dvrr_stack+175074);
 tmp = dvrr_stack + 386892;
 target_ptr = Libderiv->deriv2_classes[2][10][18];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+387288, dvrr_stack+58928, dvrr_stack+29965);
 tmp = dvrr_stack + 387288;
 target_ptr = Libderiv->deriv2_classes[3][5][18];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+387498, dvrr_stack+58508, dvrr_stack+33895);
 tmp = dvrr_stack + 387498;
 target_ptr = Libderiv->deriv2_classes[3][6][18];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+387778, dvrr_stack+158375, dvrr_stack+11919);
 tmp = dvrr_stack + 387778;
 target_ptr = Libderiv->deriv2_classes[3][7][18];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+388138, dvrr_stack+158915, dvrr_stack+12135);
 tmp = dvrr_stack + 388138;
 target_ptr = Libderiv->deriv2_classes[3][8][18];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+388588, dvrr_stack+159590, dvrr_stack+7899);
 tmp = dvrr_stack + 388588;
 target_ptr = Libderiv->deriv2_classes[3][9][18];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+389138, dvrr_stack+160415, dvrr_stack+9189);
 tmp = dvrr_stack + 389138;
 target_ptr = Libderiv->deriv2_classes[3][10][18];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+389798, dvrr_stack+175272, dvrr_stack+2117);
 tmp = dvrr_stack + 389798;
 target_ptr = Libderiv->deriv2_classes[4][5][18];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+390113, dvrr_stack+165801, dvrr_stack+4693);
 tmp = dvrr_stack + 390113;
 target_ptr = Libderiv->deriv2_classes[4][6][18];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+390533, dvrr_stack+205498, dvrr_stack+20954);
 tmp = dvrr_stack + 390533;
 target_ptr = Libderiv->deriv2_classes[4][7][18];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+391073, dvrr_stack+206254, dvrr_stack+21561);
 tmp = dvrr_stack + 391073;
 target_ptr = Libderiv->deriv2_classes[4][8][18];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+391748, dvrr_stack+207199, dvrr_stack+156385);
 tmp = dvrr_stack + 391748;
 target_ptr = Libderiv->deriv2_classes[4][9][18];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+392573, dvrr_stack+208354, dvrr_stack+156935);
 tmp = dvrr_stack + 392573;
 target_ptr = Libderiv->deriv2_classes[4][10][18];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+393563, dvrr_stack+196285, dvrr_stack+15677);
 tmp = dvrr_stack + 393563;
 target_ptr = Libderiv->deriv2_classes[2][5][14];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+393689, dvrr_stack+116301, dvrr_stack+15740);
 tmp = dvrr_stack + 393689;
 target_ptr = Libderiv->deriv2_classes[2][6][14];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+393857, dvrr_stack+116581, dvrr_stack+196495);
 tmp = dvrr_stack + 393857;
 target_ptr = Libderiv->deriv2_classes[2][7][14];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+394073, dvrr_stack+50243, dvrr_stack+189952);
 tmp = dvrr_stack + 394073;
 target_ptr = Libderiv->deriv2_classes[2][8][14];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+394343, dvrr_stack+192958, dvrr_stack+170361);
 tmp = dvrr_stack + 394343;
 target_ptr = Libderiv->deriv2_classes[2][9][14];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+394673, dvrr_stack+193508, dvrr_stack+103734);
 tmp = dvrr_stack + 394673;
 target_ptr = Libderiv->deriv2_classes[2][10][14];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+395069, dvrr_stack+194168, dvrr_stack+182131);
 tmp = dvrr_stack + 395069;
 target_ptr = Libderiv->deriv2_classes[3][5][14];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+395279, dvrr_stack+194651, dvrr_stack+194483);
 tmp = dvrr_stack + 395279;
 target_ptr = Libderiv->deriv2_classes[3][6][14];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+395559, dvrr_stack+42260, dvrr_stack+195071);
 tmp = dvrr_stack + 395559;
 target_ptr = Libderiv->deriv2_classes[3][7][14];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+395919, dvrr_stack+209740, dvrr_stack+36823);
 tmp = dvrr_stack + 395919;
 target_ptr = Libderiv->deriv2_classes[3][8][14];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+396369, dvrr_stack+210745, dvrr_stack+210415);
 tmp = dvrr_stack + 396369;
 target_ptr = Libderiv->deriv2_classes[3][9][14];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+396919, dvrr_stack+211966, dvrr_stack+211570);
 tmp = dvrr_stack + 396919;
 target_ptr = Libderiv->deriv2_classes[3][10][14];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+397579, dvrr_stack+67726, dvrr_stack+196285);
 tmp = dvrr_stack + 397579;
 target_ptr = Libderiv->deriv2_classes[4][5][14];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+397894, dvrr_stack+163925, dvrr_stack+116301);
 tmp = dvrr_stack + 397894;
 target_ptr = Libderiv->deriv2_classes[4][6][14];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+398314, dvrr_stack+214615, dvrr_stack+116581);
 tmp = dvrr_stack + 398314;
 target_ptr = Libderiv->deriv2_classes[4][7][14];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+398854, dvrr_stack+212956, dvrr_stack+50243);
 tmp = dvrr_stack + 398854;
 target_ptr = Libderiv->deriv2_classes[4][8][14];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+399529, dvrr_stack+218171, dvrr_stack+192958);
 tmp = dvrr_stack + 399529;
 target_ptr = Libderiv->deriv2_classes[4][9][14];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+400354, dvrr_stack+223746, dvrr_stack+193508);
 tmp = dvrr_stack + 400354;
 target_ptr = Libderiv->deriv2_classes[4][10][14];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+401344, dvrr_stack+221114, dvrr_stack+221051);
 tmp = dvrr_stack + 401344;
 target_ptr = Libderiv->deriv2_classes[2][5][13];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+401470, dvrr_stack+221408, dvrr_stack+221324);
 tmp = dvrr_stack + 401470;
 target_ptr = Libderiv->deriv2_classes[2][6][13];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+401638, dvrr_stack+221796, dvrr_stack+221688);
 tmp = dvrr_stack + 401638;
 target_ptr = Libderiv->deriv2_classes[2][7][13];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+401854, dvrr_stack+171336, dvrr_stack+171201);
 tmp = dvrr_stack + 401854;
 target_ptr = Libderiv->deriv2_classes[2][8][13];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+402124, dvrr_stack+171951, dvrr_stack+171786);
 tmp = dvrr_stack + 402124;
 target_ptr = Libderiv->deriv2_classes[2][9][13];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+402454, dvrr_stack+176565, dvrr_stack+36625);
 tmp = dvrr_stack + 402454;
 target_ptr = Libderiv->deriv2_classes[2][10][13];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+402850, dvrr_stack+177225, dvrr_stack+213901);
 tmp = dvrr_stack + 402850;
 target_ptr = Libderiv->deriv2_classes[3][5][13];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+403060, dvrr_stack+177540, dvrr_stack+2327);
 tmp = dvrr_stack + 403060;
 target_ptr = Libderiv->deriv2_classes[3][6][13];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+403340, dvrr_stack+183205, dvrr_stack+177960);
 tmp = dvrr_stack + 403340;
 target_ptr = Libderiv->deriv2_classes[3][7][13];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+403700, dvrr_stack+184015, dvrr_stack+183745);
 tmp = dvrr_stack + 403700;
 target_ptr = Libderiv->deriv2_classes[3][8][13];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+404150, dvrr_stack+90936, dvrr_stack+184690);
 tmp = dvrr_stack + 404150;
 target_ptr = Libderiv->deriv2_classes[3][9][13];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+404700, dvrr_stack+226980, dvrr_stack+166977);
 tmp = dvrr_stack + 404700;
 target_ptr = Libderiv->deriv2_classes[3][10][13];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+405360, dvrr_stack+167373, dvrr_stack+221114);
 tmp = dvrr_stack + 405360;
 target_ptr = Libderiv->deriv2_classes[4][5][13];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+405675, dvrr_stack+216407, dvrr_stack+221408);
 tmp = dvrr_stack + 405675;
 target_ptr = Libderiv->deriv2_classes[4][6][13];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+406095, dvrr_stack+82346, dvrr_stack+221796);
 tmp = dvrr_stack + 406095;
 target_ptr = Libderiv->deriv2_classes[4][7][13];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+406635, dvrr_stack+227970, dvrr_stack+171336);
 tmp = dvrr_stack + 406635;
 target_ptr = Libderiv->deriv2_classes[4][8][13];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+407310, dvrr_stack+228915, dvrr_stack+171951);
 tmp = dvrr_stack + 407310;
 target_ptr = Libderiv->deriv2_classes[4][9][13];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,66,dvrr_stack+408135, dvrr_stack+230070, dvrr_stack+176565);
 tmp = dvrr_stack + 408135;
 target_ptr = Libderiv->deriv2_classes[4][10][13];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,21,dvrr_stack+409125, dvrr_stack+124313, dvrr_stack+106330);
 tmp = dvrr_stack + 409125;
 target_ptr = Libderiv->deriv2_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,28,dvrr_stack+409251, dvrr_stack+124033, dvrr_stack+106393);
 tmp = dvrr_stack + 409251;
 target_ptr = Libderiv->deriv2_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,36,dvrr_stack+409419, dvrr_stack+5719, dvrr_stack+12405);
 tmp = dvrr_stack + 409419;
 target_ptr = Libderiv->deriv2_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,45,dvrr_stack+409635, dvrr_stack+124523, dvrr_stack+120879);
 tmp = dvrr_stack + 409635;
 target_ptr = Libderiv->deriv2_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,55,dvrr_stack+409905, dvrr_stack+124973, dvrr_stack+123713);
 tmp = dvrr_stack + 409905;
 target_ptr = Libderiv->deriv2_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,66,dvrr_stack+410235, dvrr_stack+125523, dvrr_stack+59243);
 tmp = dvrr_stack + 410235;
 target_ptr = Libderiv->deriv2_classes[2][10][11];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,21,dvrr_stack+120789, dvrr_stack+111345, dvrr_stack+121399);
 tmp = dvrr_stack + 120789;
 target_ptr = Libderiv->deriv2_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,28,dvrr_stack+111300, dvrr_stack+31120, dvrr_stack+15509);
 tmp = dvrr_stack + 111300;
 target_ptr = Libderiv->deriv2_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,36,dvrr_stack+30995, dvrr_stack+97932, dvrr_stack+121525);
 tmp = dvrr_stack + 30995;
 target_ptr = Libderiv->deriv2_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,45,dvrr_stack+97875, dvrr_stack+98472, dvrr_stack+121741);
 tmp = dvrr_stack + 97875;
 target_ptr = Libderiv->deriv2_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,55,dvrr_stack+98325, dvrr_stack+88101, dvrr_stack+122011);
 tmp = dvrr_stack + 98325;
 target_ptr = Libderiv->deriv2_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,66,dvrr_stack+88101, dvrr_stack+62731, dvrr_stack+122341);
 tmp = dvrr_stack + 88101;
 target_ptr = Libderiv->deriv2_classes[3][10][11];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,21,dvrr_stack+62643, dvrr_stack+166536, dvrr_stack+124313);
 tmp = dvrr_stack + 62643;
 target_ptr = Libderiv->deriv2_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,28,dvrr_stack+166515, dvrr_stack+170613, dvrr_stack+124033);
 tmp = dvrr_stack + 166515;
 target_ptr = Libderiv->deriv2_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,36,dvrr_stack+170526, dvrr_stack+175809, dvrr_stack+5719);
 tmp = dvrr_stack + 170526;
 target_ptr = Libderiv->deriv2_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,45,dvrr_stack+175713, dvrr_stack+182260, dvrr_stack+124523);
 tmp = dvrr_stack + 175713;
 target_ptr = Libderiv->deriv2_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,55,dvrr_stack+182257, dvrr_stack+190102, dvrr_stack+124973);
 tmp = dvrr_stack + 182257;
 target_ptr = Libderiv->deriv2_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,66,dvrr_stack+190087, dvrr_stack+101532, dvrr_stack+125523);
 tmp = dvrr_stack + 190087;
 target_ptr = Libderiv->deriv2_classes[4][10][11];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+88761, dvrr_stack+65171, dvrr_stack+102918);
 tmp = dvrr_stack + 88761;
 target_ptr = Libderiv->deriv2_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+59243, dvrr_stack+64891, dvrr_stack+102981);
 tmp = dvrr_stack + 59243;
 target_ptr = Libderiv->deriv2_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+101505, dvrr_stack+65381, dvrr_stack+103065);
 tmp = dvrr_stack + 101505;
 target_ptr = Libderiv->deriv2_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+101721, dvrr_stack+54656, dvrr_stack+103173);
 tmp = dvrr_stack + 101721;
 target_ptr = Libderiv->deriv2_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+101991, dvrr_stack+55106, dvrr_stack+103308);
 tmp = dvrr_stack + 101991;
 target_ptr = Libderiv->deriv2_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+102321, dvrr_stack+46814, dvrr_stack+103473);
 tmp = dvrr_stack + 102321;
 target_ptr = Libderiv->deriv2_classes[2][10][10];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+102717, dvrr_stack+47474, dvrr_stack+99147);
 tmp = dvrr_stack + 102717;
 target_ptr = Libderiv->deriv2_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+47474, dvrr_stack+35185, dvrr_stack+111660);
 tmp = dvrr_stack + 47474;
 target_ptr = Libderiv->deriv2_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+102927, dvrr_stack+23541, dvrr_stack+99273);
 tmp = dvrr_stack + 102927;
 target_ptr = Libderiv->deriv2_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+98875, dvrr_stack+24081, dvrr_stack+88926);
 tmp = dvrr_stack + 98875;
 target_ptr = Libderiv->deriv2_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+62958, dvrr_stack+24756, dvrr_stack+80186);
 tmp = dvrr_stack + 62958;
 target_ptr = Libderiv->deriv2_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+124004, dvrr_stack+151240, dvrr_stack+80516);
 tmp = dvrr_stack + 124004;
 target_ptr = Libderiv->deriv2_classes[3][10][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+88887, dvrr_stack+49214, dvrr_stack+65171);
 tmp = dvrr_stack + 88887;
 target_ptr = Libderiv->deriv2_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+80162, dvrr_stack+49655, dvrr_stack+64891);
 tmp = dvrr_stack + 80162;
 target_ptr = Libderiv->deriv2_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+64831, dvrr_stack+191257, dvrr_stack+65381);
 tmp = dvrr_stack + 64831;
 target_ptr = Libderiv->deriv2_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+191077, dvrr_stack+192013, dvrr_stack+54656);
 tmp = dvrr_stack + 191077;
 target_ptr = Libderiv->deriv2_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+191752, dvrr_stack+199471, dvrr_stack+55106);
 tmp = dvrr_stack + 191752;
 target_ptr = Libderiv->deriv2_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+54656, dvrr_stack+200626, dvrr_stack+46814);
 tmp = dvrr_stack + 54656;
 target_ptr = Libderiv->deriv2_classes[4][10][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+123713, dvrr_stack+29440, dvrr_stack+103671);
 tmp = dvrr_stack + 123713;
 target_ptr = Libderiv->deriv2_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+65371, dvrr_stack+123433, dvrr_stack+30091);
 tmp = dvrr_stack + 65371;
 target_ptr = Libderiv->deriv2_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+46811, dvrr_stack+28126, dvrr_stack+2999);
 tmp = dvrr_stack + 46811;
 target_ptr = Libderiv->deriv2_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+47027, dvrr_stack+33025, dvrr_stack+115803);
 tmp = dvrr_stack + 47027;
 target_ptr = Libderiv->deriv2_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+80582, dvrr_stack+37670, dvrr_stack+115938);
 tmp = dvrr_stack + 80582;
 target_ptr = Libderiv->deriv2_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+103287, dvrr_stack+43514, dvrr_stack+116103);
 tmp = dvrr_stack + 103287;
 target_ptr = Libderiv->deriv2_classes[2][10][9];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+111580, dvrr_stack+71456, dvrr_stack+1991);
 tmp = dvrr_stack + 111580;
 target_ptr = Libderiv->deriv2_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+199447, dvrr_stack+110670, dvrr_stack+121039);
 tmp = dvrr_stack + 199447;
 target_ptr = Libderiv->deriv2_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+110625, dvrr_stack+69395, dvrr_stack+990);
 tmp = dvrr_stack + 110625;
 target_ptr = Libderiv->deriv2_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+69367, dvrr_stack+76946, dvrr_stack+4423);
 tmp = dvrr_stack + 69367;
 target_ptr = Libderiv->deriv2_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+76944, dvrr_stack+84051, dvrr_stack+7569);
 tmp = dvrr_stack + 76944;
 target_ptr = Libderiv->deriv2_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+84032, dvrr_stack+44174, dvrr_stack+11523);
 tmp = dvrr_stack + 84032;
 target_ptr = Libderiv->deriv2_classes[3][10][9];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+44174, dvrr_stack+162575, dvrr_stack+29440);
 tmp = dvrr_stack + 44174;
 target_ptr = Libderiv->deriv2_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+44489, dvrr_stack+165213, dvrr_stack+123433);
 tmp = dvrr_stack + 44489;
 target_ptr = Libderiv->deriv2_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+165173, dvrr_stack+168849, dvrr_stack+28126);
 tmp = dvrr_stack + 165173;
 target_ptr = Libderiv->deriv2_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+168849, dvrr_stack+173541, dvrr_stack+33025);
 tmp = dvrr_stack + 168849;
 target_ptr = Libderiv->deriv2_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+173506, dvrr_stack+179425, dvrr_stack+37670);
 tmp = dvrr_stack + 173506;
 target_ptr = Libderiv->deriv2_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+179418, dvrr_stack+186637, dvrr_stack+43514);
 tmp = dvrr_stack + 179418;
 target_ptr = Libderiv->deriv2_classes[4][10][9];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+2981, dvrr_stack+119769, dvrr_stack+195313);
 tmp = dvrr_stack + 2981;
 target_ptr = Libderiv->deriv2_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+186637, dvrr_stack+119489, dvrr_stack+195376);
 tmp = dvrr_stack + 186637;
 target_ptr = Libderiv->deriv2_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+186805, dvrr_stack+119979, dvrr_stack+195460);
 tmp = dvrr_stack + 186805;
 target_ptr = Libderiv->deriv2_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+187021, dvrr_stack+120339, dvrr_stack+195568);
 tmp = dvrr_stack + 187021;
 target_ptr = Libderiv->deriv2_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+187291, dvrr_stack+105120, dvrr_stack+195703);
 tmp = dvrr_stack + 187291;
 target_ptr = Libderiv->deriv2_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+187621, dvrr_stack+105670, dvrr_stack+195868);
 tmp = dvrr_stack + 187621;
 target_ptr = Libderiv->deriv2_classes[2][10][8];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+123433, dvrr_stack+94182, dvrr_stack+117667);
 tmp = dvrr_stack + 123433;
 target_ptr = Libderiv->deriv2_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+94182, dvrr_stack+93762, dvrr_stack+117499);
 tmp = dvrr_stack + 94182;
 target_ptr = Libderiv->deriv2_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+162515, dvrr_stack+94497, dvrr_stack+117793);
 tmp = dvrr_stack + 162515;
 target_ptr = Libderiv->deriv2_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+94462, dvrr_stack+84876, dvrr_stack+28486);
 tmp = dvrr_stack + 94462;
 target_ptr = Libderiv->deriv2_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+84692, dvrr_stack+77621, dvrr_stack+118009);
 tmp = dvrr_stack + 84692;
 target_ptr = Libderiv->deriv2_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+77494, dvrr_stack+59671, dvrr_stack+118339);
 tmp = dvrr_stack + 77494;
 target_ptr = Libderiv->deriv2_classes[3][10][8];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+11442, dvrr_stack+196609, dvrr_stack+119769);
 tmp = dvrr_stack + 11442;
 target_ptr = Libderiv->deriv2_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+93664, dvrr_stack+197050, dvrr_stack+119489);
 tmp = dvrr_stack + 93664;
 target_ptr = Libderiv->deriv2_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+117463, dvrr_stack+197638, dvrr_stack+119979);
 tmp = dvrr_stack + 117463;
 target_ptr = Libderiv->deriv2_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+118003, dvrr_stack+198394, dvrr_stack+120339);
 tmp = dvrr_stack + 118003;
 target_ptr = Libderiv->deriv2_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+119455, dvrr_stack+188023, dvrr_stack+105120);
 tmp = dvrr_stack + 119455;
 target_ptr = Libderiv->deriv2_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+188017, dvrr_stack+180580, dvrr_stack+105670);
 tmp = dvrr_stack + 188017;
 target_ptr = Libderiv->deriv2_classes[4][10][8];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+189007, dvrr_stack+111090, dvrr_stack+126183);
 tmp = dvrr_stack + 189007;
 target_ptr = Libderiv->deriv2_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+44909, dvrr_stack+60661, dvrr_stack+126246);
 tmp = dvrr_stack + 44909;
 target_ptr = Libderiv->deriv2_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+7563, dvrr_stack+60941, dvrr_stack+126330);
 tmp = dvrr_stack + 7563;
 target_ptr = Libderiv->deriv2_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+4369, dvrr_stack+61301, dvrr_stack+196066);
 tmp = dvrr_stack + 4369;
 target_ptr = Libderiv->deriv2_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+180408, dvrr_stack+38220, dvrr_stack+123205);
 tmp = dvrr_stack + 180408;
 target_ptr = Libderiv->deriv2_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+180738, dvrr_stack+22287, dvrr_stack+189178);
 tmp = dvrr_stack + 180738;
 target_ptr = Libderiv->deriv2_classes[2][10][7];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+189133, dvrr_stack+29650, dvrr_stack+95037);
 tmp = dvrr_stack + 189133;
 target_ptr = Libderiv->deriv2_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+181134, dvrr_stack+33475, dvrr_stack+106705);
 tmp = dvrr_stack + 181134;
 target_ptr = Libderiv->deriv2_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+181414, dvrr_stack+22947, dvrr_stack+95163);
 tmp = dvrr_stack + 181414;
 target_ptr = Libderiv->deriv2_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+22947, dvrr_stack+16847, dvrr_stack+85551);
 tmp = dvrr_stack + 22947;
 target_ptr = Libderiv->deriv2_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+23397, dvrr_stack+153400, dvrr_stack+69935);
 tmp = dvrr_stack + 23397;
 target_ptr = Libderiv->deriv2_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+23947, dvrr_stack+154225, dvrr_stack+71771);
 tmp = dvrr_stack + 23947;
 target_ptr = Libderiv->deriv2_classes[3][10][7];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+24607, dvrr_stack+189376, dvrr_stack+111090);
 tmp = dvrr_stack + 24607;
 target_ptr = Libderiv->deriv2_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+24922, dvrr_stack+174486, dvrr_stack+60661);
 tmp = dvrr_stack + 24922;
 target_ptr = Libderiv->deriv2_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+16757, dvrr_stack+169605, dvrr_stack+60941);
 tmp = dvrr_stack + 16757;
 target_ptr = Libderiv->deriv2_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+169524, dvrr_stack+202012, dvrr_stack+61301);
 tmp = dvrr_stack + 169524;
 target_ptr = Libderiv->deriv2_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+153340, dvrr_stack+202957, dvrr_stack+38220);
 tmp = dvrr_stack + 153340;
 target_ptr = Libderiv->deriv2_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+154165, dvrr_stack+204112, dvrr_stack+22287);
 tmp = dvrr_stack + 154165;
 target_ptr = Libderiv->deriv2_classes[4][10][7];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+25342, dvrr_stack+2117, dvrr_stack+123370);
 tmp = dvrr_stack + 25342;
 target_ptr = Libderiv->deriv2_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+94912, dvrr_stack+4693, dvrr_stack+196201);
 tmp = dvrr_stack + 94912;
 target_ptr = Libderiv->deriv2_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+95080, dvrr_stack+20954, dvrr_stack+199339);
 tmp = dvrr_stack + 95080;
 target_ptr = Libderiv->deriv2_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+189343, dvrr_stack+21561, dvrr_stack+189817);
 tmp = dvrr_stack + 189343;
 target_ptr = Libderiv->deriv2_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+189613, dvrr_stack+156385, dvrr_stack+181966);
 tmp = dvrr_stack + 189613;
 target_ptr = Libderiv->deriv2_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+22263, dvrr_stack+156935, dvrr_stack+175074);
 tmp = dvrr_stack + 22263;
 target_ptr = Libderiv->deriv2_classes[2][10][6];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+22659, dvrr_stack+58928, dvrr_stack+29965);
 tmp = dvrr_stack + 22659;
 target_ptr = Libderiv->deriv2_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+58928, dvrr_stack+58508, dvrr_stack+33895);
 tmp = dvrr_stack + 58928;
 target_ptr = Libderiv->deriv2_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+174331, dvrr_stack+158375, dvrr_stack+11919);
 tmp = dvrr_stack + 174331;
 target_ptr = Libderiv->deriv2_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+158330, dvrr_stack+158915, dvrr_stack+12135);
 tmp = dvrr_stack + 158330;
 target_ptr = Libderiv->deriv2_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+158780, dvrr_stack+159590, dvrr_stack+7899);
 tmp = dvrr_stack + 158780;
 target_ptr = Libderiv->deriv2_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+159330, dvrr_stack+160415, dvrr_stack+9189);
 tmp = dvrr_stack + 159330;
 target_ptr = Libderiv->deriv2_classes[3][10][6];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+110985, dvrr_stack+175272, dvrr_stack+2117);
 tmp = dvrr_stack + 110985;
 target_ptr = Libderiv->deriv2_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+159990, dvrr_stack+165801, dvrr_stack+4693);
 tmp = dvrr_stack + 159990;
 target_ptr = Libderiv->deriv2_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+160410, dvrr_stack+205498, dvrr_stack+20954);
 tmp = dvrr_stack + 160410;
 target_ptr = Libderiv->deriv2_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+11757, dvrr_stack+206254, dvrr_stack+21561);
 tmp = dvrr_stack + 11757;
 target_ptr = Libderiv->deriv2_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+174691, dvrr_stack+207199, dvrr_stack+156385);
 tmp = dvrr_stack + 174691;
 target_ptr = Libderiv->deriv2_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+32995, dvrr_stack+208354, dvrr_stack+156935);
 tmp = dvrr_stack + 32995;
 target_ptr = Libderiv->deriv2_classes[4][10][6];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+170199, dvrr_stack+196285, dvrr_stack+15677);
 tmp = dvrr_stack + 170199;
 target_ptr = Libderiv->deriv2_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+160950, dvrr_stack+116301, dvrr_stack+15740);
 tmp = dvrr_stack + 160950;
 target_ptr = Libderiv->deriv2_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+161118, dvrr_stack+116581, dvrr_stack+196495);
 tmp = dvrr_stack + 161118;
 target_ptr = Libderiv->deriv2_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+196495, dvrr_stack+50243, dvrr_stack+189952);
 tmp = dvrr_stack + 196495;
 target_ptr = Libderiv->deriv2_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+196765, dvrr_stack+192958, dvrr_stack+170361);
 tmp = dvrr_stack + 196765;
 target_ptr = Libderiv->deriv2_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+197095, dvrr_stack+193508, dvrr_stack+103734);
 tmp = dvrr_stack + 197095;
 target_ptr = Libderiv->deriv2_classes[2][10][2];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+197491, dvrr_stack+194168, dvrr_stack+182131);
 tmp = dvrr_stack + 197491;
 target_ptr = Libderiv->deriv2_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+194168, dvrr_stack+194651, dvrr_stack+194483);
 tmp = dvrr_stack + 194168;
 target_ptr = Libderiv->deriv2_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+194448, dvrr_stack+42260, dvrr_stack+195071);
 tmp = dvrr_stack + 194448;
 target_ptr = Libderiv->deriv2_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+7779, dvrr_stack+209740, dvrr_stack+36823);
 tmp = dvrr_stack + 7779;
 target_ptr = Libderiv->deriv2_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+194808, dvrr_stack+210745, dvrr_stack+210415);
 tmp = dvrr_stack + 194808;
 target_ptr = Libderiv->deriv2_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+195358, dvrr_stack+211966, dvrr_stack+211570);
 tmp = dvrr_stack + 195358;
 target_ptr = Libderiv->deriv2_classes[3][10][2];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+197701, dvrr_stack+67726, dvrr_stack+196285);
 tmp = dvrr_stack + 197701;
 target_ptr = Libderiv->deriv2_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+196018, dvrr_stack+163925, dvrr_stack+116301);
 tmp = dvrr_stack + 196018;
 target_ptr = Libderiv->deriv2_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+198016, dvrr_stack+214615, dvrr_stack+116581);
 tmp = dvrr_stack + 198016;
 target_ptr = Libderiv->deriv2_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+214615, dvrr_stack+212956, dvrr_stack+50243);
 tmp = dvrr_stack + 214615;
 target_ptr = Libderiv->deriv2_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+198556, dvrr_stack+218171, dvrr_stack+192958);
 tmp = dvrr_stack + 198556;
 target_ptr = Libderiv->deriv2_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+156325, dvrr_stack+223746, dvrr_stack+193508);
 tmp = dvrr_stack + 156325;
 target_ptr = Libderiv->deriv2_classes[4][10][2];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+36823, dvrr_stack+221114, dvrr_stack+221051);
 tmp = dvrr_stack + 36823;
 target_ptr = Libderiv->deriv2_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+170325, dvrr_stack+221408, dvrr_stack+221324);
 tmp = dvrr_stack + 170325;
 target_ptr = Libderiv->deriv2_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+157315, dvrr_stack+221796, dvrr_stack+221688);
 tmp = dvrr_stack + 157315;
 target_ptr = Libderiv->deriv2_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+123157, dvrr_stack+171336, dvrr_stack+171201);
 tmp = dvrr_stack + 123157;
 target_ptr = Libderiv->deriv2_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+9159, dvrr_stack+171951, dvrr_stack+171786);
 tmp = dvrr_stack + 9159;
 target_ptr = Libderiv->deriv2_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+218108, dvrr_stack+176565, dvrr_stack+36625);
 tmp = dvrr_stack + 218108;
 target_ptr = Libderiv->deriv2_classes[2][10][1];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+17297, dvrr_stack+177225, dvrr_stack+213901);
 tmp = dvrr_stack + 17297;
 target_ptr = Libderiv->deriv2_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+177225, dvrr_stack+177540, dvrr_stack+2327);
 tmp = dvrr_stack + 177225;
 target_ptr = Libderiv->deriv2_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+177505, dvrr_stack+183205, dvrr_stack+177960);
 tmp = dvrr_stack + 177505;
 target_ptr = Libderiv->deriv2_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+218504, dvrr_stack+184015, dvrr_stack+183745);
 tmp = dvrr_stack + 218504;
 target_ptr = Libderiv->deriv2_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+1910, dvrr_stack+90936, dvrr_stack+184690);
 tmp = dvrr_stack + 1910;
 target_ptr = Libderiv->deriv2_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+223710, dvrr_stack+226980, dvrr_stack+166977);
 tmp = dvrr_stack + 223710;
 target_ptr = Libderiv->deriv2_classes[3][10][1];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+226918, dvrr_stack+167373, dvrr_stack+221114);
 tmp = dvrr_stack + 226918;
 target_ptr = Libderiv->deriv2_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+227233, dvrr_stack+216407, dvrr_stack+221408);
 tmp = dvrr_stack + 227233;
 target_ptr = Libderiv->deriv2_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+221051, dvrr_stack+82346, dvrr_stack+221796);
 tmp = dvrr_stack + 221051;
 target_ptr = Libderiv->deriv2_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+224370, dvrr_stack+227970, dvrr_stack+171336);
 tmp = dvrr_stack + 224370;
 target_ptr = Libderiv->deriv2_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+227653, dvrr_stack+228915, dvrr_stack+171951);
 tmp = dvrr_stack + 227653;
 target_ptr = Libderiv->deriv2_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+228478, dvrr_stack+230070, dvrr_stack+176565);
 tmp = dvrr_stack + 228478;
 target_ptr = Libderiv->deriv2_classes[4][10][1];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+177865, dvrr_stack+185020, dvrr_stack+172501);
 tmp = dvrr_stack + 177865;
 target_ptr = Libderiv->deriv2_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+177991, dvrr_stack+10455, dvrr_stack+392);
 tmp = dvrr_stack + 177991;
 target_ptr = Libderiv->deriv2_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+221591, dvrr_stack+219326, dvrr_stack+822);
 tmp = dvrr_stack + 221591;
 target_ptr = Libderiv->deriv2_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+221807, dvrr_stack+1206, dvrr_stack+1775);
 tmp = dvrr_stack + 221807;
 target_ptr = Libderiv->deriv2_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+229468, dvrr_stack+75551, dvrr_stack+164);
 tmp = dvrr_stack + 229468;
 target_ptr = Libderiv->deriv2_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+229798, dvrr_stack+231456, dvrr_stack+7239);
 tmp = dvrr_stack + 229798;
 target_ptr = Libderiv->deriv2_classes[2][10][0];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+230194, dvrr_stack+11127, dvrr_stack+22011);
 tmp = dvrr_stack + 230194;
 target_ptr = Libderiv->deriv2_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+230404, dvrr_stack+6583, dvrr_stack+216995);
 tmp = dvrr_stack + 230404;
 target_ptr = Libderiv->deriv2_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+6565, dvrr_stack+163016, dvrr_stack+4153);
 tmp = dvrr_stack + 6565;
 target_ptr = Libderiv->deriv2_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+162875, dvrr_stack+167814, dvrr_stack+476);
 tmp = dvrr_stack + 162875;
 target_ptr = Libderiv->deriv2_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+230684, dvrr_stack+32170, dvrr_stack+172564);
 tmp = dvrr_stack + 230684;
 target_ptr = Libderiv->deriv2_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+32135, dvrr_stack+178176, dvrr_stack+172894);
 tmp = dvrr_stack + 32135;
 target_ptr = Libderiv->deriv2_classes[3][10][0];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+178159, dvrr_stack+185230, dvrr_stack+185020);
 tmp = dvrr_stack + 178159;
 target_ptr = Libderiv->deriv2_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+178474, dvrr_stack+214027, dvrr_stack+10455);
 tmp = dvrr_stack + 178474;
 target_ptr = Libderiv->deriv2_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+85242, dvrr_stack+185671, dvrr_stack+219326);
 tmp = dvrr_stack + 85242;
 target_ptr = Libderiv->deriv2_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+218954, dvrr_stack+217163, dvrr_stack+1206);
 tmp = dvrr_stack + 218954;
 target_ptr = Libderiv->deriv2_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+216331, dvrr_stack+219686, dvrr_stack+75551);
 tmp = dvrr_stack + 216331;
 target_ptr = Libderiv->deriv2_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,66,dvrr_stack+219629, dvrr_stack+222156, dvrr_stack+231456);
 tmp = dvrr_stack + 219629;
 target_ptr = Libderiv->deriv2_classes[4][10][0];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];


}

