/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ggii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gg|ii) integrals */

void d1hrr_order_ggii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[4][12][11] = int_stack + 4620;
 Libderiv->deriv_classes[5][6][11] = int_stack + 5985;
 Libderiv->deriv_classes[5][7][11] = int_stack + 6573;
 Libderiv->deriv_classes[5][8][11] = int_stack + 7329;
 Libderiv->deriv_classes[5][9][11] = int_stack + 8274;
 Libderiv->deriv_classes[5][10][11] = int_stack + 9429;
 Libderiv->deriv_classes[5][11][11] = int_stack + 10815;
 Libderiv->deriv_classes[5][12][11] = int_stack + 12453;
 Libderiv->deriv_classes[6][6][11] = int_stack + 14364;
 Libderiv->deriv_classes[6][7][11] = int_stack + 15148;
 Libderiv->deriv_classes[6][8][11] = int_stack + 16156;
 Libderiv->deriv_classes[6][9][11] = int_stack + 17416;
 Libderiv->deriv_classes[6][10][11] = int_stack + 18956;
 Libderiv->deriv_classes[6][11][11] = int_stack + 20804;
 Libderiv->deriv_classes[6][12][11] = int_stack + 22988;
 Libderiv->deriv_classes[7][6][11] = int_stack + 25536;
 Libderiv->deriv_classes[7][7][11] = int_stack + 26544;
 Libderiv->deriv_classes[7][8][11] = int_stack + 27840;
 Libderiv->deriv_classes[7][9][11] = int_stack + 29460;
 Libderiv->deriv_classes[7][10][11] = int_stack + 31440;
 Libderiv->deriv_classes[7][11][11] = int_stack + 33816;
 Libderiv->deriv_classes[7][12][11] = int_stack + 36624;
 Libderiv->deriv_classes[8][6][11] = int_stack + 39900;
 Libderiv->deriv_classes[8][7][11] = int_stack + 41160;
 Libderiv->deriv_classes[8][8][11] = int_stack + 42780;
 Libderiv->deriv_classes[8][9][11] = int_stack + 44805;
 Libderiv->deriv_classes[8][10][11] = int_stack + 47280;
 Libderiv->deriv_classes[8][11][11] = int_stack + 50250;
 Libderiv->deriv_classes[8][12][11] = int_stack + 53760;
 Libderiv->deriv_classes[4][6][10] = int_stack + 57855;
 Libderiv->deriv_classes[4][7][10] = int_stack + 58275;
 Libderiv->deriv_classes[4][8][10] = int_stack + 58815;
 Libderiv->deriv_classes[4][9][10] = int_stack + 59490;
 Libderiv->deriv_classes[4][10][10] = int_stack + 60315;
 Libderiv->deriv_classes[4][11][10] = int_stack + 61305;
 Libderiv->deriv_classes[4][12][10] = int_stack + 62475;
 Libderiv->deriv_classes[5][6][10] = int_stack + 63840;
 Libderiv->deriv_classes[5][7][10] = int_stack + 64428;
 Libderiv->deriv_classes[5][8][10] = int_stack + 65184;
 Libderiv->deriv_classes[5][9][10] = int_stack + 66129;
 Libderiv->deriv_classes[5][10][10] = int_stack + 67284;
 Libderiv->deriv_classes[5][11][10] = int_stack + 68670;
 Libderiv->deriv_classes[5][12][10] = int_stack + 70308;
 Libderiv->deriv_classes[6][6][10] = int_stack + 72219;
 Libderiv->deriv_classes[6][7][10] = int_stack + 73003;
 Libderiv->deriv_classes[6][8][10] = int_stack + 74011;
 Libderiv->deriv_classes[6][9][10] = int_stack + 75271;
 Libderiv->deriv_classes[6][10][10] = int_stack + 76811;
 Libderiv->deriv_classes[6][11][10] = int_stack + 78659;
 Libderiv->deriv_classes[6][12][10] = int_stack + 80843;
 Libderiv->deriv_classes[7][6][10] = int_stack + 83391;
 Libderiv->deriv_classes[7][7][10] = int_stack + 84399;
 Libderiv->deriv_classes[7][8][10] = int_stack + 85695;
 Libderiv->deriv_classes[7][9][10] = int_stack + 87315;
 Libderiv->deriv_classes[7][10][10] = int_stack + 89295;
 Libderiv->deriv_classes[7][11][10] = int_stack + 91671;
 Libderiv->deriv_classes[7][12][10] = int_stack + 94479;
 Libderiv->deriv_classes[8][6][10] = int_stack + 97755;
 Libderiv->deriv_classes[8][7][10] = int_stack + 99015;
 Libderiv->deriv_classes[8][8][10] = int_stack + 100635;
 Libderiv->deriv_classes[8][9][10] = int_stack + 102660;
 Libderiv->deriv_classes[8][10][10] = int_stack + 105135;
 Libderiv->deriv_classes[8][11][10] = int_stack + 108105;
 Libderiv->deriv_classes[8][12][10] = int_stack + 111615;
 Libderiv->deriv_classes[4][6][9] = int_stack + 115710;
 Libderiv->deriv_classes[4][7][9] = int_stack + 116130;
 Libderiv->deriv_classes[4][8][9] = int_stack + 116670;
 Libderiv->deriv_classes[4][9][9] = int_stack + 117345;
 Libderiv->deriv_classes[4][10][9] = int_stack + 118170;
 Libderiv->deriv_classes[4][11][9] = int_stack + 119160;
 Libderiv->deriv_classes[4][12][9] = int_stack + 120330;
 Libderiv->deriv_classes[5][6][9] = int_stack + 121695;
 Libderiv->deriv_classes[5][7][9] = int_stack + 122283;
 Libderiv->deriv_classes[5][8][9] = int_stack + 123039;
 Libderiv->deriv_classes[5][9][9] = int_stack + 123984;
 Libderiv->deriv_classes[5][10][9] = int_stack + 125139;
 Libderiv->deriv_classes[5][11][9] = int_stack + 126525;
 Libderiv->deriv_classes[5][12][9] = int_stack + 128163;
 Libderiv->deriv_classes[6][6][9] = int_stack + 130074;
 Libderiv->deriv_classes[6][7][9] = int_stack + 130858;
 Libderiv->deriv_classes[6][8][9] = int_stack + 131866;
 Libderiv->deriv_classes[6][9][9] = int_stack + 133126;
 Libderiv->deriv_classes[6][10][9] = int_stack + 134666;
 Libderiv->deriv_classes[6][11][9] = int_stack + 136514;
 Libderiv->deriv_classes[6][12][9] = int_stack + 138698;
 Libderiv->deriv_classes[7][6][9] = int_stack + 141246;
 Libderiv->deriv_classes[7][7][9] = int_stack + 142254;
 Libderiv->deriv_classes[7][8][9] = int_stack + 143550;
 Libderiv->deriv_classes[7][9][9] = int_stack + 145170;
 Libderiv->deriv_classes[7][10][9] = int_stack + 147150;
 Libderiv->deriv_classes[7][11][9] = int_stack + 149526;
 Libderiv->deriv_classes[7][12][9] = int_stack + 152334;
 Libderiv->deriv_classes[8][6][9] = int_stack + 155610;
 Libderiv->deriv_classes[8][7][9] = int_stack + 156870;
 Libderiv->deriv_classes[8][8][9] = int_stack + 158490;
 Libderiv->deriv_classes[8][9][9] = int_stack + 160515;
 Libderiv->deriv_classes[8][10][9] = int_stack + 162990;
 Libderiv->deriv_classes[8][11][9] = int_stack + 165960;
 Libderiv->deriv_classes[8][12][9] = int_stack + 169470;
 Libderiv->deriv_classes[4][6][8] = int_stack + 173565;
 Libderiv->deriv_classes[4][7][8] = int_stack + 173985;
 Libderiv->deriv_classes[4][8][8] = int_stack + 174525;
 Libderiv->deriv_classes[4][9][8] = int_stack + 175200;
 Libderiv->deriv_classes[4][10][8] = int_stack + 176025;
 Libderiv->deriv_classes[4][11][8] = int_stack + 177015;
 Libderiv->deriv_classes[4][12][8] = int_stack + 178185;
 Libderiv->deriv_classes[5][6][8] = int_stack + 179550;
 Libderiv->deriv_classes[5][7][8] = int_stack + 180138;
 Libderiv->deriv_classes[5][8][8] = int_stack + 180894;
 Libderiv->deriv_classes[5][9][8] = int_stack + 181839;
 Libderiv->deriv_classes[5][10][8] = int_stack + 182994;
 Libderiv->deriv_classes[5][11][8] = int_stack + 184380;
 Libderiv->deriv_classes[5][12][8] = int_stack + 186018;
 Libderiv->deriv_classes[6][6][8] = int_stack + 187929;
 Libderiv->deriv_classes[6][7][8] = int_stack + 188713;
 Libderiv->deriv_classes[6][8][8] = int_stack + 189721;
 Libderiv->deriv_classes[6][9][8] = int_stack + 190981;
 Libderiv->deriv_classes[6][10][8] = int_stack + 192521;
 Libderiv->deriv_classes[6][11][8] = int_stack + 194369;
 Libderiv->deriv_classes[6][12][8] = int_stack + 196553;
 Libderiv->deriv_classes[7][6][8] = int_stack + 199101;
 Libderiv->deriv_classes[7][7][8] = int_stack + 200109;
 Libderiv->deriv_classes[7][8][8] = int_stack + 201405;
 Libderiv->deriv_classes[7][9][8] = int_stack + 203025;
 Libderiv->deriv_classes[7][10][8] = int_stack + 205005;
 Libderiv->deriv_classes[7][11][8] = int_stack + 207381;
 Libderiv->deriv_classes[7][12][8] = int_stack + 210189;
 Libderiv->deriv_classes[8][6][8] = int_stack + 213465;
 Libderiv->deriv_classes[8][7][8] = int_stack + 214725;
 Libderiv->deriv_classes[8][8][8] = int_stack + 216345;
 Libderiv->deriv_classes[8][9][8] = int_stack + 218370;
 Libderiv->deriv_classes[8][10][8] = int_stack + 220845;
 Libderiv->deriv_classes[8][11][8] = int_stack + 223815;
 Libderiv->deriv_classes[8][12][8] = int_stack + 227325;
 Libderiv->deriv_classes[4][6][7] = int_stack + 231420;
 Libderiv->deriv_classes[4][7][7] = int_stack + 231840;
 Libderiv->deriv_classes[4][8][7] = int_stack + 232380;
 Libderiv->deriv_classes[4][9][7] = int_stack + 233055;
 Libderiv->deriv_classes[4][10][7] = int_stack + 233880;
 Libderiv->deriv_classes[4][11][7] = int_stack + 234870;
 Libderiv->deriv_classes[4][12][7] = int_stack + 236040;
 Libderiv->deriv_classes[5][6][7] = int_stack + 237405;
 Libderiv->deriv_classes[5][7][7] = int_stack + 237993;
 Libderiv->deriv_classes[5][8][7] = int_stack + 238749;
 Libderiv->deriv_classes[5][9][7] = int_stack + 239694;
 Libderiv->deriv_classes[5][10][7] = int_stack + 240849;
 Libderiv->deriv_classes[5][11][7] = int_stack + 242235;
 Libderiv->deriv_classes[5][12][7] = int_stack + 243873;
 Libderiv->deriv_classes[6][6][7] = int_stack + 245784;
 Libderiv->deriv_classes[6][7][7] = int_stack + 246568;
 Libderiv->deriv_classes[6][8][7] = int_stack + 247576;
 Libderiv->deriv_classes[6][9][7] = int_stack + 248836;
 Libderiv->deriv_classes[6][10][7] = int_stack + 250376;
 Libderiv->deriv_classes[6][11][7] = int_stack + 252224;
 Libderiv->deriv_classes[6][12][7] = int_stack + 254408;
 Libderiv->deriv_classes[7][6][7] = int_stack + 256956;
 Libderiv->deriv_classes[7][7][7] = int_stack + 257964;
 Libderiv->deriv_classes[7][8][7] = int_stack + 259260;
 Libderiv->deriv_classes[7][9][7] = int_stack + 260880;
 Libderiv->deriv_classes[7][10][7] = int_stack + 262860;
 Libderiv->deriv_classes[7][11][7] = int_stack + 265236;
 Libderiv->deriv_classes[7][12][7] = int_stack + 268044;
 Libderiv->deriv_classes[8][6][7] = int_stack + 271320;
 Libderiv->deriv_classes[8][7][7] = int_stack + 272580;
 Libderiv->deriv_classes[8][8][7] = int_stack + 274200;
 Libderiv->deriv_classes[8][9][7] = int_stack + 276225;
 Libderiv->deriv_classes[8][10][7] = int_stack + 278700;
 Libderiv->deriv_classes[8][11][7] = int_stack + 281670;
 Libderiv->deriv_classes[8][12][7] = int_stack + 285180;
 Libderiv->deriv_classes[4][6][6] = int_stack + 289275;
 Libderiv->deriv_classes[4][7][6] = int_stack + 289695;
 Libderiv->deriv_classes[4][8][6] = int_stack + 290235;
 Libderiv->deriv_classes[4][9][6] = int_stack + 290910;
 Libderiv->deriv_classes[4][10][6] = int_stack + 291735;
 Libderiv->deriv_classes[4][11][6] = int_stack + 292725;
 Libderiv->deriv_classes[4][12][6] = int_stack + 293895;
 Libderiv->deriv_classes[5][6][6] = int_stack + 295260;
 Libderiv->deriv_classes[5][7][6] = int_stack + 295848;
 Libderiv->deriv_classes[5][8][6] = int_stack + 296604;
 Libderiv->deriv_classes[5][9][6] = int_stack + 297549;
 Libderiv->deriv_classes[5][10][6] = int_stack + 298704;
 Libderiv->deriv_classes[5][11][6] = int_stack + 300090;
 Libderiv->deriv_classes[5][12][6] = int_stack + 301728;
 Libderiv->deriv_classes[6][6][6] = int_stack + 303639;
 Libderiv->deriv_classes[6][7][6] = int_stack + 304423;
 Libderiv->deriv_classes[6][8][6] = int_stack + 305431;
 Libderiv->deriv_classes[6][9][6] = int_stack + 306691;
 Libderiv->deriv_classes[6][10][6] = int_stack + 308231;
 Libderiv->deriv_classes[6][11][6] = int_stack + 310079;
 Libderiv->deriv_classes[6][12][6] = int_stack + 312263;
 Libderiv->deriv_classes[7][6][6] = int_stack + 314811;
 Libderiv->deriv_classes[7][7][6] = int_stack + 315819;
 Libderiv->deriv_classes[7][8][6] = int_stack + 317115;
 Libderiv->deriv_classes[7][9][6] = int_stack + 318735;
 Libderiv->deriv_classes[7][10][6] = int_stack + 320715;
 Libderiv->deriv_classes[7][11][6] = int_stack + 323091;
 Libderiv->deriv_classes[7][12][6] = int_stack + 325899;
 Libderiv->dvrr_classes[8][6] = int_stack + 329175;
 Libderiv->deriv_classes[8][6][6] = int_stack + 330435;
 Libderiv->dvrr_classes[8][7] = int_stack + 331695;
 Libderiv->deriv_classes[8][7][6] = int_stack + 333315;
 Libderiv->dvrr_classes[8][8] = int_stack + 334935;
 Libderiv->deriv_classes[8][8][6] = int_stack + 336960;
 Libderiv->dvrr_classes[8][9] = int_stack + 338985;
 Libderiv->deriv_classes[8][9][6] = int_stack + 341460;
 Libderiv->dvrr_classes[8][10] = int_stack + 343935;
 Libderiv->deriv_classes[8][10][6] = int_stack + 346905;
 Libderiv->dvrr_classes[8][11] = int_stack + 349875;
 Libderiv->deriv_classes[8][11][6] = int_stack + 353385;
 Libderiv->deriv_classes[8][12][6] = int_stack + 356895;
 Libderiv->deriv_classes[4][6][2] = int_stack + 360990;
 Libderiv->deriv_classes[4][7][2] = int_stack + 361410;
 Libderiv->deriv_classes[4][8][2] = int_stack + 361950;
 Libderiv->deriv_classes[4][9][2] = int_stack + 362625;
 Libderiv->deriv_classes[4][10][2] = int_stack + 363450;
 Libderiv->deriv_classes[4][11][2] = int_stack + 364440;
 Libderiv->deriv_classes[4][12][2] = int_stack + 365610;
 Libderiv->deriv_classes[5][6][2] = int_stack + 366975;
 Libderiv->deriv_classes[5][7][2] = int_stack + 367563;
 Libderiv->deriv_classes[5][8][2] = int_stack + 368319;
 Libderiv->deriv_classes[5][9][2] = int_stack + 369264;
 Libderiv->deriv_classes[5][10][2] = int_stack + 370419;
 Libderiv->deriv_classes[5][11][2] = int_stack + 371805;
 Libderiv->deriv_classes[5][12][2] = int_stack + 373443;
 Libderiv->deriv_classes[6][6][2] = int_stack + 375354;
 Libderiv->deriv_classes[6][7][2] = int_stack + 376138;
 Libderiv->deriv_classes[6][8][2] = int_stack + 377146;
 Libderiv->deriv_classes[6][9][2] = int_stack + 378406;
 Libderiv->deriv_classes[6][10][2] = int_stack + 379946;
 Libderiv->deriv_classes[6][11][2] = int_stack + 381794;
 Libderiv->deriv_classes[6][12][2] = int_stack + 383978;
 Libderiv->deriv_classes[7][6][2] = int_stack + 386526;
 Libderiv->deriv_classes[7][7][2] = int_stack + 387534;
 Libderiv->deriv_classes[7][8][2] = int_stack + 388830;
 Libderiv->deriv_classes[7][9][2] = int_stack + 390450;
 Libderiv->deriv_classes[7][10][2] = int_stack + 392430;
 Libderiv->deriv_classes[7][11][2] = int_stack + 394806;
 Libderiv->deriv_classes[7][12][2] = int_stack + 397614;
 Libderiv->deriv_classes[8][6][2] = int_stack + 400890;
 Libderiv->deriv_classes[8][7][2] = int_stack + 402150;
 Libderiv->deriv_classes[8][8][2] = int_stack + 403770;
 Libderiv->deriv_classes[8][9][2] = int_stack + 405795;
 Libderiv->deriv_classes[8][10][2] = int_stack + 408270;
 Libderiv->deriv_classes[8][11][2] = int_stack + 411240;
 Libderiv->deriv_classes[8][12][2] = int_stack + 414750;
 Libderiv->deriv_classes[4][6][1] = int_stack + 418845;
 Libderiv->deriv_classes[4][7][1] = int_stack + 419265;
 Libderiv->deriv_classes[4][8][1] = int_stack + 419805;
 Libderiv->deriv_classes[4][9][1] = int_stack + 420480;
 Libderiv->deriv_classes[4][10][1] = int_stack + 421305;
 Libderiv->deriv_classes[4][11][1] = int_stack + 422295;
 Libderiv->deriv_classes[4][12][1] = int_stack + 423465;
 Libderiv->deriv_classes[5][6][1] = int_stack + 424830;
 Libderiv->deriv_classes[5][7][1] = int_stack + 425418;
 Libderiv->deriv_classes[5][8][1] = int_stack + 426174;
 Libderiv->deriv_classes[5][9][1] = int_stack + 427119;
 Libderiv->deriv_classes[5][10][1] = int_stack + 428274;
 Libderiv->deriv_classes[5][11][1] = int_stack + 429660;
 Libderiv->deriv_classes[5][12][1] = int_stack + 431298;
 Libderiv->deriv_classes[6][6][1] = int_stack + 433209;
 Libderiv->deriv_classes[6][7][1] = int_stack + 433993;
 Libderiv->deriv_classes[6][8][1] = int_stack + 435001;
 Libderiv->deriv_classes[6][9][1] = int_stack + 436261;
 Libderiv->deriv_classes[6][10][1] = int_stack + 437801;
 Libderiv->deriv_classes[6][11][1] = int_stack + 439649;
 Libderiv->deriv_classes[6][12][1] = int_stack + 441833;
 Libderiv->deriv_classes[7][6][1] = int_stack + 444381;
 Libderiv->deriv_classes[7][7][1] = int_stack + 445389;
 Libderiv->deriv_classes[7][8][1] = int_stack + 446685;
 Libderiv->deriv_classes[7][9][1] = int_stack + 448305;
 Libderiv->deriv_classes[7][10][1] = int_stack + 450285;
 Libderiv->deriv_classes[7][11][1] = int_stack + 452661;
 Libderiv->deriv_classes[7][12][1] = int_stack + 455469;
 Libderiv->deriv_classes[8][6][1] = int_stack + 458745;
 Libderiv->deriv_classes[8][7][1] = int_stack + 460005;
 Libderiv->deriv_classes[8][8][1] = int_stack + 461625;
 Libderiv->deriv_classes[8][9][1] = int_stack + 463650;
 Libderiv->deriv_classes[8][10][1] = int_stack + 466125;
 Libderiv->deriv_classes[8][11][1] = int_stack + 469095;
 Libderiv->deriv_classes[8][12][1] = int_stack + 472605;
 Libderiv->dvrr_classes[4][6] = int_stack + 476700;
 Libderiv->dvrr_classes[4][7] = int_stack + 477120;
 Libderiv->dvrr_classes[4][8] = int_stack + 477660;
 Libderiv->dvrr_classes[4][9] = int_stack + 478335;
 Libderiv->dvrr_classes[4][10] = int_stack + 479160;
 Libderiv->dvrr_classes[4][11] = int_stack + 480150;
 Libderiv->dvrr_classes[4][12] = int_stack + 481320;
 Libderiv->deriv_classes[4][6][0] = int_stack + 482685;
 Libderiv->deriv_classes[4][7][0] = int_stack + 483105;
 Libderiv->deriv_classes[4][8][0] = int_stack + 483645;
 Libderiv->deriv_classes[4][9][0] = int_stack + 484320;
 Libderiv->deriv_classes[4][10][0] = int_stack + 485145;
 Libderiv->deriv_classes[4][11][0] = int_stack + 486135;
 Libderiv->deriv_classes[4][12][0] = int_stack + 487305;
 Libderiv->dvrr_classes[5][6] = int_stack + 488670;
 Libderiv->dvrr_classes[5][7] = int_stack + 489258;
 Libderiv->dvrr_classes[5][8] = int_stack + 490014;
 Libderiv->dvrr_classes[5][9] = int_stack + 490959;
 Libderiv->dvrr_classes[5][10] = int_stack + 492114;
 Libderiv->dvrr_classes[5][11] = int_stack + 493500;
 Libderiv->dvrr_classes[5][12] = int_stack + 495138;
 Libderiv->deriv_classes[5][6][0] = int_stack + 497049;
 Libderiv->deriv_classes[5][7][0] = int_stack + 497637;
 Libderiv->deriv_classes[5][8][0] = int_stack + 498393;
 Libderiv->deriv_classes[5][9][0] = int_stack + 499338;
 Libderiv->deriv_classes[5][10][0] = int_stack + 500493;
 Libderiv->deriv_classes[5][11][0] = int_stack + 501879;
 Libderiv->deriv_classes[5][12][0] = int_stack + 503517;
 Libderiv->dvrr_classes[6][6] = int_stack + 505428;
 Libderiv->dvrr_classes[6][7] = int_stack + 506212;
 Libderiv->dvrr_classes[6][8] = int_stack + 507220;
 Libderiv->dvrr_classes[6][9] = int_stack + 508480;
 Libderiv->dvrr_classes[6][10] = int_stack + 510020;
 Libderiv->dvrr_classes[6][11] = int_stack + 511868;
 Libderiv->dvrr_classes[6][12] = int_stack + 514052;
 Libderiv->deriv_classes[6][6][0] = int_stack + 516600;
 Libderiv->deriv_classes[6][7][0] = int_stack + 517384;
 Libderiv->deriv_classes[6][8][0] = int_stack + 518392;
 Libderiv->deriv_classes[6][9][0] = int_stack + 519652;
 Libderiv->deriv_classes[6][10][0] = int_stack + 521192;
 Libderiv->deriv_classes[6][11][0] = int_stack + 523040;
 Libderiv->deriv_classes[6][12][0] = int_stack + 525224;
 Libderiv->dvrr_classes[7][6] = int_stack + 527772;
 Libderiv->dvrr_classes[7][7] = int_stack + 528780;
 Libderiv->dvrr_classes[7][8] = int_stack + 530076;
 Libderiv->dvrr_classes[7][9] = int_stack + 531696;
 Libderiv->dvrr_classes[7][10] = int_stack + 533676;
 Libderiv->dvrr_classes[7][11] = int_stack + 536052;
 Libderiv->dvrr_classes[7][12] = int_stack + 538860;
 Libderiv->deriv_classes[7][6][0] = int_stack + 542136;
 Libderiv->deriv_classes[7][7][0] = int_stack + 543144;
 Libderiv->deriv_classes[7][8][0] = int_stack + 544440;
 Libderiv->deriv_classes[7][9][0] = int_stack + 546060;
 Libderiv->deriv_classes[7][10][0] = int_stack + 548040;
 Libderiv->deriv_classes[7][11][0] = int_stack + 550416;
 Libderiv->deriv_classes[7][12][0] = int_stack + 553224;
 Libderiv->deriv_classes[8][6][0] = int_stack + 556500;
 Libderiv->deriv_classes[8][7][0] = int_stack + 557760;
 Libderiv->deriv_classes[8][8][0] = int_stack + 559380;
 Libderiv->deriv_classes[8][9][0] = int_stack + 561405;
 Libderiv->deriv_classes[8][10][0] = int_stack + 563880;
 Libderiv->deriv_classes[8][11][0] = int_stack + 566850;
 Libderiv->deriv_classes[8][12][0] = int_stack + 570360;
 memset(int_stack,0,4595640);

 Libderiv->dvrr_stack = int_stack + 3794095;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ggii(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+574455,int_stack+477120,int_stack+476700,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+575715,int_stack+477660,int_stack+477120,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+577335,int_stack+575715,int_stack+574455,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+579855,int_stack+478335,int_stack+477660,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+581880,int_stack+579855,int_stack+575715,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+585120,int_stack+581880,int_stack+577335,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+589320,int_stack+479160,int_stack+478335,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+591795,int_stack+589320,int_stack+579855,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+595845,int_stack+591795,int_stack+581880,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+601245,int_stack+595845,int_stack+585120,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+607545,int_stack+480150,int_stack+479160,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+610515,int_stack+607545,int_stack+589320,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+615465,int_stack+610515,int_stack+591795,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+622215,int_stack+615465,int_stack+595845,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+630315,int_stack+622215,int_stack+601245,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+639135,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476700,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+640395,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477120,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+642015,int_stack+640395,int_stack+639135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574455,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+644535,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477660,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+646560,int_stack+644535,int_stack+640395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575715,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+649800,int_stack+646560,int_stack+642015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577335,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+639135,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478335,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+654000,int_stack+639135,int_stack+644535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+579855,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+658050,int_stack+654000,int_stack+646560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581880,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+641610,int_stack+658050,int_stack+649800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585120,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+647910,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479160,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+663450,int_stack+647910,int_stack+639135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589320,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+668400,int_stack+663450,int_stack+654000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591795,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+675150,int_stack+668400,int_stack+658050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595845,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+650880,int_stack+675150,int_stack+641610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601245,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+639135,int_stack+4620,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480150,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+639135,int_stack+647910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607545,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+639135,int_stack+0,int_stack+663450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610515,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+683250,int_stack+639135,int_stack+668400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615465,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+639135,int_stack+683250,int_stack+675150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622215,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+659700,int_stack+639135,int_stack+650880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630315,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+639135,int_stack+489258,int_stack+488670,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+640899,int_stack+490014,int_stack+489258,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+643167,int_stack+640899,int_stack+639135,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+646695,int_stack+490959,int_stack+490014,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+649530,int_stack+646695,int_stack+640899,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+649530,int_stack+643167,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+654066,int_stack+492114,int_stack+490959,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+671460,int_stack+654066,int_stack+646695,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+677130,int_stack+671460,int_stack+649530,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+684690,int_stack+677130,int_stack+0,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+693510,int_stack+493500,int_stack+492114,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+697668,int_stack+693510,int_stack+654066,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+704598,int_stack+697668,int_stack+671460,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+714048,int_stack+704598,int_stack+677130,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+725388,int_stack+714048,int_stack+684690,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+657531,int_stack+6573,int_stack+5985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488670,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+737736,int_stack+7329,int_stack+6573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489258,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+740004,int_stack+737736,int_stack+657531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639135,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+743532,int_stack+8274,int_stack+7329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490014,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+746367,int_stack+743532,int_stack+737736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640899,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+750903,int_stack+746367,int_stack+740004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643167,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+737736,int_stack+9429,int_stack+8274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490959,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+756783,int_stack+737736,int_stack+743532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646695,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+762453,int_stack+756783,int_stack+746367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649530,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+741201,int_stack+762453,int_stack+750903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+750021,int_stack+10815,int_stack+9429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492114,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+770013,int_stack+750021,int_stack+737736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654066,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+776943,int_stack+770013,int_stack+756783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+671460,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+786393,int_stack+776943,int_stack+762453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677130,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+754179,int_stack+786393,int_stack+741201, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684690,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+737736,int_stack+12453,int_stack+10815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493500,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+5880,int_stack+737736,int_stack+750021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693510,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+737736,int_stack+5880,int_stack+770013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697668,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+797733,int_stack+737736,int_stack+776943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704598,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+737736,int_stack+797733,int_stack+786393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714048,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+766527,int_stack+737736,int_stack+754179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725388,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+782991,int_stack+766527,int_stack+659700,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+737736,int_stack+506212,int_stack+505428,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+740088,int_stack+507220,int_stack+506212,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+743112,int_stack+740088,int_stack+737736,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+747816,int_stack+508480,int_stack+507220,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+751596,int_stack+747816,int_stack+740088,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+757644,int_stack+751596,int_stack+743112,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5880,int_stack+510020,int_stack+508480,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+657531,int_stack+5880,int_stack+747816,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+818271,int_stack+657531,int_stack+751596,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+828351,int_stack+818271,int_stack+757644,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+665091,int_stack+511868,int_stack+510020,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+840111,int_stack+665091,int_stack+5880,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+849351,int_stack+840111,int_stack+657531,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+861951,int_stack+849351,int_stack+818271,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+877071,int_stack+861951,int_stack+828351,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10500,int_stack+15148,int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505428,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+893535,int_stack+16156,int_stack+15148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506212,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+896559,int_stack+893535,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737736,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10500,int_stack+17416,int_stack+16156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507220,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+901263,int_stack+10500,int_stack+893535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+740088,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+907311,int_stack+901263,int_stack+896559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743112,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+893535,int_stack+18956,int_stack+17416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508480,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+915151,int_stack+893535,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+747816,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+922711,int_stack+915151,int_stack+901263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751596,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+932791,int_stack+922711,int_stack+907311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757644,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+10500,int_stack+20804,int_stack+18956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510020,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+898155,int_stack+10500,int_stack+893535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+944551,int_stack+898155,int_stack+915151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657531,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+907395,int_stack+944551,int_stack+922711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818271,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+957151,int_stack+907395,int_stack+932791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828351,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+922515,int_stack+22988,int_stack+20804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511868,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+929067,int_stack+922515,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665091,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+973615,int_stack+929067,int_stack+898155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840111,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+922515,int_stack+973615,int_stack+944551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849351,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+973615,int_stack+922515,int_stack+907395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+861951,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+893535,int_stack+973615,int_stack+957151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877071,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+915487,int_stack+893535,int_stack+766527,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+964879,int_stack+915487,int_stack+782991,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+10500,int_stack+528780,int_stack+527772,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13524,int_stack+530076,int_stack+528780,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+17412,int_stack+13524,int_stack+10500,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+765484,int_stack+531696,int_stack+530076,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+770344,int_stack+765484,int_stack+13524,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+778120,int_stack+770344,int_stack+17412,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+788200,int_stack+533676,int_stack+531696,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+794140,int_stack+788200,int_stack+765484,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+803860,int_stack+794140,int_stack+770344,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1035439,int_stack+803860,int_stack+778120,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1050559,int_stack+536052,int_stack+533676,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1057687,int_stack+1050559,int_stack+788200,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1069567,int_stack+1057687,int_stack+794140,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1085767,int_stack+1069567,int_stack+803860,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1105207,int_stack+1085767,int_stack+1035439,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1126375,int_stack+26544,int_stack+25536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527772,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1129399,int_stack+27840,int_stack+26544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528780,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1133287,int_stack+1129399,int_stack+1126375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1139335,int_stack+29460,int_stack+27840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530076,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1144195,int_stack+1139335,int_stack+1129399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1151971,int_stack+1144195,int_stack+1133287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1126375,int_stack+31440,int_stack+29460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+531696,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1162051,int_stack+1126375,int_stack+1139335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765484,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1171771,int_stack+1162051,int_stack+1144195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770344,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1132315,int_stack+1171771,int_stack+1151971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778120,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1147435,int_stack+33816,int_stack+31440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533676,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1184731,int_stack+1147435,int_stack+1126375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788200,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1196611,int_stack+1184731,int_stack+1162051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+794140,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1212811,int_stack+1196611,int_stack+1171771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803860,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1154563,int_stack+1212811,int_stack+1132315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035439,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1126375,int_stack+36624,int_stack+33816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536052,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+23460,int_stack+1126375,int_stack+1147435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050559,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1126375,int_stack+23460,int_stack+1184731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1057687,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1232251,int_stack+1126375,int_stack+1196611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1069567,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1126375,int_stack+1232251,int_stack+1212811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1085767,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1175731,int_stack+1126375,int_stack+1154563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1105207,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1203955,int_stack+1175731,int_stack+893535,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1269811,int_stack+1203955,int_stack+915487,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1368595,int_stack+1269811,int_stack+964879,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+893535,int_stack+331695,int_stack+329175,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+897315,int_stack+334935,int_stack+331695,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+902175,int_stack+897315,int_stack+893535,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+909735,int_stack+338985,int_stack+334935,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+915810,int_stack+909735,int_stack+897315,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+925530,int_stack+915810,int_stack+902175,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+938130,int_stack+343935,int_stack+338985,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+945555,int_stack+938130,int_stack+909735,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+957705,int_stack+945555,int_stack+915810,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+973905,int_stack+957705,int_stack+925530,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+992805,int_stack+349875,int_stack+343935,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1001715,int_stack+992805,int_stack+938130,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1126375,int_stack+1001715,int_stack+945555,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1146625,int_stack+1126375,int_stack+957705,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1486195,int_stack+1146625,int_stack+973905,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1016565,int_stack+41160,int_stack+39900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329175,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1020345,int_stack+42780,int_stack+41160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331695,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1025205,int_stack+1020345,int_stack+1016565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893535,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+23460,int_stack+44805,int_stack+42780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334935,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+29535,int_stack+23460,int_stack+1020345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+897315,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1512655,int_stack+29535,int_stack+1025205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902175,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1016565,int_stack+47280,int_stack+44805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338985,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1525255,int_stack+1016565,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+909735,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1537405,int_stack+1525255,int_stack+29535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+915810,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+23460,int_stack+1537405,int_stack+1512655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925530,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1512655,int_stack+50250,int_stack+47280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343935,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1553605,int_stack+1512655,int_stack+1016565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938130,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1568455,int_stack+1553605,int_stack+1525255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945555,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1588705,int_stack+1568455,int_stack+1537405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957705,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1521565,int_stack+1588705,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973905,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+53760,int_stack+50250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349875,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+33990,int_stack+23460,int_stack+1512655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992805,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1613005,int_stack+33990,int_stack+1553605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001715,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+23460,int_stack+1613005,int_stack+1568455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126375,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1548025,int_stack+23460,int_stack+1588705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146625,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1582045,int_stack+1548025,int_stack+1521565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1486195,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1617325,int_stack+1582045,int_stack+1175731,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1701997,int_stack+1617325,int_stack+1203955,784);
 /*--- compute (hf|ii) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1512655,int_stack+1701997,int_stack+1269811,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+58275,int_stack+57855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476700, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24720,int_stack+58815,int_stack+58275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477120, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26340,int_stack+24720,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574455, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28860,int_stack+59490,int_stack+58815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477660, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30885,int_stack+28860,int_stack+24720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575715, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34125,int_stack+30885,int_stack+26340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577335, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+60315,int_stack+59490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478335, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38325,int_stack+23460,int_stack+28860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+579855, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+42375,int_stack+38325,int_stack+30885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581880, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+25935,int_stack+42375,int_stack+34125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585120, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+32235,int_stack+61305,int_stack+60315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479160, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+47775,int_stack+32235,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589320, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+52725,int_stack+47775,int_stack+38325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591795, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1677295,int_stack+52725,int_stack+42375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595845, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+35205,int_stack+1677295,int_stack+25935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601245, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+62475,int_stack+61305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480150, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1685395,int_stack+23460,int_stack+32235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607545, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+1685395,int_stack+47775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610515, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1685395,int_stack+23460,int_stack+52725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615465, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+1685395,int_stack+1677295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622215, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1677295,int_stack+23460,int_stack+35205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630315, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+64428,int_stack+63840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488670, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+25224,int_stack+65184,int_stack+64428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489258, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27492,int_stack+25224,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639135, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31020,int_stack+66129,int_stack+65184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490014, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+33855,int_stack+31020,int_stack+25224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640899, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+38391,int_stack+33855,int_stack+27492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643167, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+67284,int_stack+66129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490959, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+44271,int_stack+23460,int_stack+31020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646695, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+49941,int_stack+44271,int_stack+33855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649530, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+26925,int_stack+49941,int_stack+38391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+35745,int_stack+68670,int_stack+67284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492114, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+57501,int_stack+35745,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654066, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1689055,int_stack+57501,int_stack+44271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+671460, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1698505,int_stack+1689055,int_stack+49941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677130, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+39903,int_stack+1698505,int_stack+26925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684690, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+70308,int_stack+68670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493500, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1709845,int_stack+23460,int_stack+35745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693510, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+1709845,int_stack+57501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697668, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1709845,int_stack+23460,int_stack+1689055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704598, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+1709845,int_stack+1698505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714048, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1689055,int_stack+23460,int_stack+39903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725388, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+23460,int_stack+1689055,int_stack+1677295,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1677295,int_stack+73003,int_stack+72219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505428, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1679647,int_stack+74011,int_stack+73003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506212, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1682671,int_stack+1679647,int_stack+1677295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737736, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+58740,int_stack+75271,int_stack+74011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507220, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+62520,int_stack+58740,int_stack+1679647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+740088, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1705519,int_stack+62520,int_stack+1682671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743112, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1677295,int_stack+76811,int_stack+75271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508480, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+68568,int_stack+1677295,int_stack+58740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+747816, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1713359,int_stack+68568,int_stack+62520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751596, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1723439,int_stack+1713359,int_stack+1705519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757644, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1705519,int_stack+78659,int_stack+76811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510020, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+58740,int_stack+1705519,int_stack+1677295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1735199,int_stack+58740,int_stack+68568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657531, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1747799,int_stack+1735199,int_stack+1713359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818271, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1762919,int_stack+1747799,int_stack+1723439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828351, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1677295,int_stack+80843,int_stack+78659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511868, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1711063,int_stack+1677295,int_stack+1705519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665091, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+67980,int_stack+1711063,int_stack+58740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840111, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1705519,int_stack+67980,int_stack+1735199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849351, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+58740,int_stack+1705519,int_stack+1747799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+861951, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1705519,int_stack+58740,int_stack+1762919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877071, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1727471,int_stack+1705519,int_stack+1689055,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1170925,int_stack+1727471,int_stack+23460,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+84399,int_stack+83391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527772, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26484,int_stack+85695,int_stack+84399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528780, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30372,int_stack+26484,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36420,int_stack+87315,int_stack+85695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530076, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41280,int_stack+36420,int_stack+26484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+49056,int_stack+41280,int_stack+30372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+89295,int_stack+87315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+531696, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+59136,int_stack+23460,int_stack+36420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765484, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+68856,int_stack+59136,int_stack+41280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770344, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+29400,int_stack+68856,int_stack+49056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778120, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+44520,int_stack+91671,int_stack+89295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533676, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1776863,int_stack+44520,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788200, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1788743,int_stack+1776863,int_stack+59136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+794140, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1804943,int_stack+1788743,int_stack+68856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803860, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+51648,int_stack+1804943,int_stack+29400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035439, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+94479,int_stack+91671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536052, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+72816,int_stack+23460,int_stack+44520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050559, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+72816,int_stack+1776863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1057687, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+72816,int_stack+23460,int_stack+1788743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1069567, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+72816,int_stack+1804943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1085767, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1677295,int_stack+23460,int_stack+51648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1105207, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+23460,int_stack+1677295,int_stack+1705519,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1241485,int_stack+23460,int_stack+1727471,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1705519,int_stack+1241485,int_stack+1170925,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1170925,int_stack+99015,int_stack+97755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329175, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1174705,int_stack+100635,int_stack+99015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331695, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1179565,int_stack+1174705,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893535, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1187125,int_stack+102660,int_stack+100635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334935, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1193200,int_stack+1187125,int_stack+1174705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+897315, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1202920,int_stack+1193200,int_stack+1179565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902175, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1170925,int_stack+105135,int_stack+102660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338985, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1215520,int_stack+1170925,int_stack+1187125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+909735, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1016565,int_stack+1215520,int_stack+1193200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+915810, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1178350,int_stack+1016565,int_stack+1202920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925530, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1197250,int_stack+108105,int_stack+105135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343935, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+89316,int_stack+1197250,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938130, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1340269,int_stack+89316,int_stack+1215520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945555, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1206160,int_stack+1340269,int_stack+1016565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957705, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1823119,int_stack+1206160,int_stack+1178350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973905, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1016565,int_stack+111615,int_stack+108105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349875, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1170925,int_stack+1016565,int_stack+1197250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992805, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1849579,int_stack+1170925,int_stack+89316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001715, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1170925,int_stack+1849579,int_stack+1340269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126375, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1849579,int_stack+1170925,int_stack+1206160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146625, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1170925,int_stack+1849579,int_stack+1823119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1486195, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1823119,int_stack+1170925,int_stack+1677295,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1907791,int_stack+1823119,int_stack+23460,784);
 /*--- compute (hf|ii) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2039503,int_stack+1907791,int_stack+1241485,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+116130,int_stack+115710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476700, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24720,int_stack+116670,int_stack+116130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477120, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26340,int_stack+24720,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574455, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28860,int_stack+117345,int_stack+116670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477660, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30885,int_stack+28860,int_stack+24720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575715, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34125,int_stack+30885,int_stack+26340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577335, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+118170,int_stack+117345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478335, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38325,int_stack+23460,int_stack+28860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+579855, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+42375,int_stack+38325,int_stack+30885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581880, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+25935,int_stack+42375,int_stack+34125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585120, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+32235,int_stack+119160,int_stack+118170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479160, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+47775,int_stack+32235,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589320, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+52725,int_stack+47775,int_stack+38325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591795, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+59475,int_stack+52725,int_stack+42375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595845, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+35205,int_stack+59475,int_stack+25935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601245, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+120330,int_stack+119160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480150, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+67575,int_stack+23460,int_stack+32235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607545, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+67575,int_stack+47775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610515, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+67575,int_stack+23460,int_stack+52725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615465, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+67575,int_stack+59475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622215, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+44025,int_stack+23460,int_stack+35205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630315, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+122283,int_stack+121695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488670, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+25224,int_stack+123039,int_stack+122283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489258, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27492,int_stack+25224,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639135, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31020,int_stack+123984,int_stack+123039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490014, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+33855,int_stack+31020,int_stack+25224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640899, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+55785,int_stack+33855,int_stack+27492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643167, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+125139,int_stack+123984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490959, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+61665,int_stack+23460,int_stack+31020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646695, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+67335,int_stack+61665,int_stack+33855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649530, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+26925,int_stack+67335,int_stack+55785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+55785,int_stack+126525,int_stack+125139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492114, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+35745,int_stack+55785,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654066, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+74895,int_stack+35745,int_stack+61665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+671460, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+84345,int_stack+74895,int_stack+67335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677130, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+59943,int_stack+84345,int_stack+26925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684690, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+128163,int_stack+126525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493500, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+95685,int_stack+23460,int_stack+55785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693510, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+95685,int_stack+35745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697668, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+95685,int_stack+23460,int_stack+74895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704598, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+95685,int_stack+84345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714048, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+72291,int_stack+23460,int_stack+59943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725388, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+88755,int_stack+72291,int_stack+44025,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+130858,int_stack+130074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505428, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+25812,int_stack+131866,int_stack+130858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506212, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28836,int_stack+25812,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737736, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+33540,int_stack+133126,int_stack+131866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507220, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+37320,int_stack+33540,int_stack+25812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+740088, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43368,int_stack+37320,int_stack+28836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743112, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+134666,int_stack+133126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508480, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51208,int_stack+23460,int_stack+33540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+747816, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+58768,int_stack+51208,int_stack+37320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751596, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+28080,int_stack+58768,int_stack+43368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757644, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+39840,int_stack+136514,int_stack+134666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510020, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+124035,int_stack+39840,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1823119,int_stack+124035,int_stack+51208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657531, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1835719,int_stack+1823119,int_stack+58768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818271, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+45384,int_stack+1835719,int_stack+28080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828351, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+138698,int_stack+136514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511868, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1850839,int_stack+23460,int_stack+39840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665091, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+1850839,int_stack+124035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840111, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1850839,int_stack+23460,int_stack+1823119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849351, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+1850839,int_stack+1835719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+861951, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1823119,int_stack+23460,int_stack+45384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877071, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1845071,int_stack+1823119,int_stack+72291,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1894463,int_stack+1845071,int_stack+88755,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+142254,int_stack+141246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527772, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26484,int_stack+143550,int_stack+142254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528780, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30372,int_stack+26484,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36420,int_stack+145170,int_stack+143550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530076, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41280,int_stack+36420,int_stack+26484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+49056,int_stack+41280,int_stack+30372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+147150,int_stack+145170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+531696, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+59136,int_stack+23460,int_stack+36420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765484, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+68856,int_stack+59136,int_stack+41280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770344, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+29400,int_stack+68856,int_stack+49056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778120, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+44520,int_stack+149526,int_stack+147150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533676, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+81816,int_stack+44520,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788200, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+93696,int_stack+81816,int_stack+59136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+794140, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+109896,int_stack+93696,int_stack+68856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803860, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+51648,int_stack+109896,int_stack+29400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035439, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+152334,int_stack+149526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536052, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+129336,int_stack+23460,int_stack+44520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050559, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+129336,int_stack+81816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1057687, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+129336,int_stack+23460,int_stack+93696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1069567, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+129336,int_stack+109896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1085767, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1677295,int_stack+23460,int_stack+51648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1105207, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+23460,int_stack+1677295,int_stack+1823119,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1170925,int_stack+23460,int_stack+1845071,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+2204143,int_stack+1170925,int_stack+1894463,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1823119,int_stack+156870,int_stack+155610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329175, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1826899,int_stack+158490,int_stack+156870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331695, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1831759,int_stack+1826899,int_stack+1823119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893535, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1839319,int_stack+160515,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334935, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1845394,int_stack+1839319,int_stack+1826899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+897315, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1855114,int_stack+1845394,int_stack+1831759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902175, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1823119,int_stack+162990,int_stack+160515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338985, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1867714,int_stack+1823119,int_stack+1839319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+909735, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1879864,int_stack+1867714,int_stack+1845394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+915810, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1830544,int_stack+1879864,int_stack+1855114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925530, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1849444,int_stack+165960,int_stack+162990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343935, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1896064,int_stack+1849444,int_stack+1823119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938130, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1910914,int_stack+1896064,int_stack+1867714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945555, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1931164,int_stack+1910914,int_stack+1879864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957705, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1858354,int_stack+1931164,int_stack+1830544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973905, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1823119,int_stack+169470,int_stack+165960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349875, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1955464,int_stack+1823119,int_stack+1849444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992805, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1823119,int_stack+1955464,int_stack+1896064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001715, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1955464,int_stack+1823119,int_stack+1910914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126375, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1823119,int_stack+1955464,int_stack+1931164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146625, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1884814,int_stack+1823119,int_stack+1858354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1486195, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1920094,int_stack+1884814,int_stack+1677295,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2321743,int_stack+1920094,int_stack+23460,784);
 /*--- compute (hf|ii) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1823119,int_stack+2321743,int_stack+1170925,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1170925,int_stack+173985,int_stack+173565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1172185,int_stack+174525,int_stack+173985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1173805,int_stack+1172185,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1176325,int_stack+175200,int_stack+174525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1178350,int_stack+1176325,int_stack+1172185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1181590,int_stack+1178350,int_stack+1173805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1170925,int_stack+176025,int_stack+175200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1185790,int_stack+1170925,int_stack+1176325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+579855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1189840,int_stack+1185790,int_stack+1178350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1173400,int_stack+1189840,int_stack+1181590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1179700,int_stack+177015,int_stack+176025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1195240,int_stack+1179700,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1200190,int_stack+1195240,int_stack+1185790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1206940,int_stack+1200190,int_stack+1189840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1182670,int_stack+1206940,int_stack+1173400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+601245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1170925,int_stack+178185,int_stack+177015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1215040,int_stack+1170925,int_stack+1179700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1170925,int_stack+1215040,int_stack+1195240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1215040,int_stack+1170925,int_stack+1200190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1170925,int_stack+1215040,int_stack+1206940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1191490,int_stack+1170925,int_stack+1182670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1170925,int_stack+180138,int_stack+179550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1172689,int_stack+180894,int_stack+180138, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1174957,int_stack+1172689,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1178485,int_stack+181839,int_stack+180894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1181320,int_stack+1178485,int_stack+1172689, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1203250,int_stack+1181320,int_stack+1174957, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1170925,int_stack+182994,int_stack+181839, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1209130,int_stack+1170925,int_stack+1178485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1214800,int_stack+1209130,int_stack+1181320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1174390,int_stack+1214800,int_stack+1203250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1203250,int_stack+184380,int_stack+182994, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1183210,int_stack+1203250,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1222360,int_stack+1183210,int_stack+1209130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+671460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1231810,int_stack+1222360,int_stack+1214800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1207408,int_stack+1231810,int_stack+1174390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1170925,int_stack+186018,int_stack+184380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1243150,int_stack+1170925,int_stack+1203250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1170925,int_stack+1243150,int_stack+1183210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+697668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1243150,int_stack+1170925,int_stack+1222360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1170925,int_stack+1243150,int_stack+1231810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1219756,int_stack+1170925,int_stack+1207408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1236220,int_stack+1219756,int_stack+1191490,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1170925,int_stack+188713,int_stack+187929, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+505428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1173277,int_stack+189721,int_stack+188713, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1176301,int_stack+1173277,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1181005,int_stack+190981,int_stack+189721, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1184785,int_stack+1181005,int_stack+1173277, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+740088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1190833,int_stack+1184785,int_stack+1176301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1170925,int_stack+192521,int_stack+190981, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1198673,int_stack+1170925,int_stack+1181005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+747816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1206233,int_stack+1198673,int_stack+1184785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1175545,int_stack+1206233,int_stack+1190833, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1187305,int_stack+194369,int_stack+192521, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1271500,int_stack+1187305,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1280740,int_stack+1271500,int_stack+1198673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1293340,int_stack+1280740,int_stack+1206233, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1192849,int_stack+1293340,int_stack+1175545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1170925,int_stack+196553,int_stack+194369, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1308460,int_stack+1170925,int_stack+1187305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1170925,int_stack+1308460,int_stack+1271500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1308460,int_stack+1170925,int_stack+1280740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+849351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1170925,int_stack+1308460,int_stack+1293340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+861951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1271500,int_stack+1170925,int_stack+1192849, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1293452,int_stack+1271500,int_stack+1219756,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2321743,int_stack+1293452,int_stack+1236220,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1170925,int_stack+200109,int_stack+199101, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1173949,int_stack+201405,int_stack+200109, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1177837,int_stack+1173949,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1183885,int_stack+203025,int_stack+201405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1188745,int_stack+1183885,int_stack+1173949, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1196521,int_stack+1188745,int_stack+1177837, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1170925,int_stack+205005,int_stack+203025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+531696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1206601,int_stack+1170925,int_stack+1183885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+765484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1216321,int_stack+1206601,int_stack+1188745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1176865,int_stack+1216321,int_stack+1196521, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1191985,int_stack+207381,int_stack+205005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1229281,int_stack+1191985,int_stack+1170925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1241161,int_stack+1229281,int_stack+1206601, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+794140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1342844,int_stack+1241161,int_stack+1216321, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1199113,int_stack+1342844,int_stack+1176865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1170925,int_stack+210189,int_stack+207381, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2392303,int_stack+1170925,int_stack+1191985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1170925,int_stack+2392303,int_stack+1229281, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1057687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2392303,int_stack+1170925,int_stack+1241161, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1069567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1170925,int_stack+2392303,int_stack+1342844, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1085767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1677295,int_stack+1170925,int_stack+1199113, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1105207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1170925,int_stack+1677295,int_stack+1271500,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+23460,int_stack+1170925,int_stack+1293452,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1236781,int_stack+23460,int_stack+2321743,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2321743,int_stack+214725,int_stack+213465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2325523,int_stack+216345,int_stack+214725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2330383,int_stack+2325523,int_stack+2321743, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+893535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2337943,int_stack+218370,int_stack+216345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2344018,int_stack+2337943,int_stack+2325523, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+897315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2353738,int_stack+2344018,int_stack+2330383, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2321743,int_stack+220845,int_stack+218370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2366338,int_stack+2321743,int_stack+2337943, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+909735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2378488,int_stack+2366338,int_stack+2344018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+915810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2329168,int_stack+2378488,int_stack+2353738, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2348068,int_stack+223815,int_stack+220845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2394688,int_stack+2348068,int_stack+2321743, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+938130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2409538,int_stack+2394688,int_stack+2366338, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+122244,int_stack+2409538,int_stack+2378488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2356978,int_stack+122244,int_stack+2329168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2321743,int_stack+227325,int_stack+223815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2429788,int_stack+2321743,int_stack+2348068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2321743,int_stack+2429788,int_stack+2394688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+146544,int_stack+2321743,int_stack+2409538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2321743,int_stack+146544,int_stack+122244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+122244,int_stack+2321743,int_stack+2356978, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1486195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2321743,int_stack+122244,int_stack+1677295,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2406415,int_stack+2321743,int_stack+1170925,784);
 /*--- compute (hf|ii) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2538127,int_stack+2406415,int_stack+23460,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+231840,int_stack+231420, 0.0, zero_stack, 1.0, int_stack+476700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24720,int_stack+232380,int_stack+231840, 0.0, zero_stack, 1.0, int_stack+477120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26340,int_stack+24720,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+574455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28860,int_stack+233055,int_stack+232380, 0.0, zero_stack, 1.0, int_stack+477660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30885,int_stack+28860,int_stack+24720, 0.0, zero_stack, 1.0, int_stack+575715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34125,int_stack+30885,int_stack+26340, 0.0, zero_stack, 1.0, int_stack+577335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+233880,int_stack+233055, 0.0, zero_stack, 1.0, int_stack+478335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38325,int_stack+23460,int_stack+28860, 0.0, zero_stack, 1.0, int_stack+579855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+42375,int_stack+38325,int_stack+30885, 0.0, zero_stack, 1.0, int_stack+581880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+25935,int_stack+42375,int_stack+34125, 0.0, zero_stack, 1.0, int_stack+585120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+32235,int_stack+234870,int_stack+233880, 0.0, zero_stack, 1.0, int_stack+479160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+47775,int_stack+32235,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+589320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+52725,int_stack+47775,int_stack+38325, 0.0, zero_stack, 1.0, int_stack+591795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+59475,int_stack+52725,int_stack+42375, 0.0, zero_stack, 1.0, int_stack+595845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+35205,int_stack+59475,int_stack+25935, 0.0, zero_stack, 1.0, int_stack+601245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+236040,int_stack+234870, 0.0, zero_stack, 1.0, int_stack+480150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+67575,int_stack+23460,int_stack+32235, 0.0, zero_stack, 1.0, int_stack+607545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+67575,int_stack+47775, 0.0, zero_stack, 1.0, int_stack+610515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+67575,int_stack+23460,int_stack+52725, 0.0, zero_stack, 1.0, int_stack+615465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+67575,int_stack+59475, 0.0, zero_stack, 1.0, int_stack+622215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+44025,int_stack+23460,int_stack+35205, 0.0, zero_stack, 1.0, int_stack+630315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+237993,int_stack+237405, 0.0, zero_stack, 1.0, int_stack+488670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+25224,int_stack+238749,int_stack+237993, 0.0, zero_stack, 1.0, int_stack+489258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27492,int_stack+25224,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+639135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31020,int_stack+239694,int_stack+238749, 0.0, zero_stack, 1.0, int_stack+490014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+33855,int_stack+31020,int_stack+25224, 0.0, zero_stack, 1.0, int_stack+640899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+55785,int_stack+33855,int_stack+27492, 0.0, zero_stack, 1.0, int_stack+643167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+240849,int_stack+239694, 0.0, zero_stack, 1.0, int_stack+490959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+61665,int_stack+23460,int_stack+31020, 0.0, zero_stack, 1.0, int_stack+646695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+67335,int_stack+61665,int_stack+33855, 0.0, zero_stack, 1.0, int_stack+649530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+26925,int_stack+67335,int_stack+55785, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+55785,int_stack+242235,int_stack+240849, 0.0, zero_stack, 1.0, int_stack+492114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+35745,int_stack+55785,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+654066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+74895,int_stack+35745,int_stack+61665, 0.0, zero_stack, 1.0, int_stack+671460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+84345,int_stack+74895,int_stack+67335, 0.0, zero_stack, 1.0, int_stack+677130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+59943,int_stack+84345,int_stack+26925, 0.0, zero_stack, 1.0, int_stack+684690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+243873,int_stack+242235, 0.0, zero_stack, 1.0, int_stack+493500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+95685,int_stack+23460,int_stack+55785, 0.0, zero_stack, 1.0, int_stack+693510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+95685,int_stack+35745, 0.0, zero_stack, 1.0, int_stack+697668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+95685,int_stack+23460,int_stack+74895, 0.0, zero_stack, 1.0, int_stack+704598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+95685,int_stack+84345, 0.0, zero_stack, 1.0, int_stack+714048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+72291,int_stack+23460,int_stack+59943, 0.0, zero_stack, 1.0, int_stack+725388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+88755,int_stack+72291,int_stack+44025,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+246568,int_stack+245784, 0.0, zero_stack, 1.0, int_stack+505428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+25812,int_stack+247576,int_stack+246568, 0.0, zero_stack, 1.0, int_stack+506212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28836,int_stack+25812,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+737736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+33540,int_stack+248836,int_stack+247576, 0.0, zero_stack, 1.0, int_stack+507220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+37320,int_stack+33540,int_stack+25812, 0.0, zero_stack, 1.0, int_stack+740088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43368,int_stack+37320,int_stack+28836, 0.0, zero_stack, 1.0, int_stack+743112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+250376,int_stack+248836, 0.0, zero_stack, 1.0, int_stack+508480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51208,int_stack+23460,int_stack+33540, 0.0, zero_stack, 1.0, int_stack+747816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+58768,int_stack+51208,int_stack+37320, 0.0, zero_stack, 1.0, int_stack+751596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+28080,int_stack+58768,int_stack+43368, 0.0, zero_stack, 1.0, int_stack+757644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+39840,int_stack+252224,int_stack+250376, 0.0, zero_stack, 1.0, int_stack+510020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+124035,int_stack+39840,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+133275,int_stack+124035,int_stack+51208, 0.0, zero_stack, 1.0, int_stack+657531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+145875,int_stack+133275,int_stack+58768, 0.0, zero_stack, 1.0, int_stack+818271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+45384,int_stack+145875,int_stack+28080, 0.0, zero_stack, 1.0, int_stack+828351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+254408,int_stack+252224, 0.0, zero_stack, 1.0, int_stack+511868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+160995,int_stack+23460,int_stack+39840, 0.0, zero_stack, 1.0, int_stack+665091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+160995,int_stack+124035, 0.0, zero_stack, 1.0, int_stack+840111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+160995,int_stack+23460,int_stack+133275, 0.0, zero_stack, 1.0, int_stack+849351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+160995,int_stack+145875, 0.0, zero_stack, 1.0, int_stack+861951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+124035,int_stack+23460,int_stack+45384, 0.0, zero_stack, 1.0, int_stack+877071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+145987,int_stack+124035,int_stack+72291,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2321743,int_stack+145987,int_stack+88755,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+257964,int_stack+256956, 0.0, zero_stack, 1.0, int_stack+527772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26484,int_stack+259260,int_stack+257964, 0.0, zero_stack, 1.0, int_stack+528780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30372,int_stack+26484,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36420,int_stack+260880,int_stack+259260, 0.0, zero_stack, 1.0, int_stack+530076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41280,int_stack+36420,int_stack+26484, 0.0, zero_stack, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+49056,int_stack+41280,int_stack+30372, 0.0, zero_stack, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23460,int_stack+262860,int_stack+260880, 0.0, zero_stack, 1.0, int_stack+531696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+59136,int_stack+23460,int_stack+36420, 0.0, zero_stack, 1.0, int_stack+765484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+68856,int_stack+59136,int_stack+41280, 0.0, zero_stack, 1.0, int_stack+770344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+29400,int_stack+68856,int_stack+49056, 0.0, zero_stack, 1.0, int_stack+778120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+44520,int_stack+265236,int_stack+262860, 0.0, zero_stack, 1.0, int_stack+533676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+81816,int_stack+44520,int_stack+23460, 0.0, zero_stack, 1.0, int_stack+788200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+93696,int_stack+81816,int_stack+59136, 0.0, zero_stack, 1.0, int_stack+794140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+195379,int_stack+93696,int_stack+68856, 0.0, zero_stack, 1.0, int_stack+803860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+51648,int_stack+195379,int_stack+29400, 0.0, zero_stack, 1.0, int_stack+1035439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+268044,int_stack+265236, 0.0, zero_stack, 1.0, int_stack+536052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+214819,int_stack+23460,int_stack+44520, 0.0, zero_stack, 1.0, int_stack+1050559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+23460,int_stack+214819,int_stack+81816, 0.0, zero_stack, 1.0, int_stack+1057687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+214819,int_stack+23460,int_stack+93696, 0.0, zero_stack, 1.0, int_stack+1069567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+23460,int_stack+214819,int_stack+195379, 0.0, zero_stack, 1.0, int_stack+1085767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1677295,int_stack+23460,int_stack+51648, 0.0, zero_stack, 1.0, int_stack+1105207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1170925,int_stack+1677295,int_stack+124035,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+23460,int_stack+1170925,int_stack+145987,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+122244,int_stack+23460,int_stack+2321743,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2321743,int_stack+272580,int_stack+271320, 0.0, zero_stack, 1.0, int_stack+329175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2325523,int_stack+274200,int_stack+272580, 0.0, zero_stack, 1.0, int_stack+331695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2330383,int_stack+2325523,int_stack+2321743, 0.0, zero_stack, 1.0, int_stack+893535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2337943,int_stack+276225,int_stack+274200, 0.0, zero_stack, 1.0, int_stack+334935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2344018,int_stack+2337943,int_stack+2325523, 0.0, zero_stack, 1.0, int_stack+897315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2353738,int_stack+2344018,int_stack+2330383, 0.0, zero_stack, 1.0, int_stack+902175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2321743,int_stack+278700,int_stack+276225, 0.0, zero_stack, 1.0, int_stack+338985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2366338,int_stack+2321743,int_stack+2337943, 0.0, zero_stack, 1.0, int_stack+909735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2378488,int_stack+2366338,int_stack+2344018, 0.0, zero_stack, 1.0, int_stack+915810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2329168,int_stack+2378488,int_stack+2353738, 0.0, zero_stack, 1.0, int_stack+925530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2348068,int_stack+281670,int_stack+278700, 0.0, zero_stack, 1.0, int_stack+343935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2394688,int_stack+2348068,int_stack+2321743, 0.0, zero_stack, 1.0, int_stack+938130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2409538,int_stack+2394688,int_stack+2366338, 0.0, zero_stack, 1.0, int_stack+945555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2429788,int_stack+2409538,int_stack+2378488, 0.0, zero_stack, 1.0, int_stack+957705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2356978,int_stack+2429788,int_stack+2329168, 0.0, zero_stack, 1.0, int_stack+973905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2321743,int_stack+285180,int_stack+281670, 0.0, zero_stack, 1.0, int_stack+349875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2454088,int_stack+2321743,int_stack+2348068, 0.0, zero_stack, 1.0, int_stack+992805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2321743,int_stack+2454088,int_stack+2394688, 0.0, zero_stack, 1.0, int_stack+1001715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2454088,int_stack+2321743,int_stack+2409538, 0.0, zero_stack, 1.0, int_stack+1126375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2321743,int_stack+2454088,int_stack+2429788, 0.0, zero_stack, 1.0, int_stack+1146625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2383438,int_stack+2321743,int_stack+2356978, 0.0, zero_stack, 1.0, int_stack+1486195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2418718,int_stack+2383438,int_stack+1677295,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2702767,int_stack+2418718,int_stack+1170925,784);
 /*--- compute (hf|ii) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2321743,int_stack+2702767,int_stack+23460,784);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+289695,int_stack+289275, 1.0, int_stack+476700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24720,int_stack+290235,int_stack+289695, 1.0, int_stack+477120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26340,int_stack+24720,int_stack+23460, 1.0, int_stack+574455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28860,int_stack+290910,int_stack+290235, 1.0, int_stack+477660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30885,int_stack+28860,int_stack+24720, 1.0, int_stack+575715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34125,int_stack+30885,int_stack+26340, 1.0, int_stack+577335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+574455,int_stack+291735,int_stack+290910, 1.0, int_stack+478335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+23460,int_stack+574455,int_stack+28860, 1.0, int_stack+579855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+38325,int_stack+23460,int_stack+30885, 1.0, int_stack+581880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+576930,int_stack+38325,int_stack+34125, 1.0, int_stack+585120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+583230,int_stack+292725,int_stack+291735, 1.0, int_stack+479160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+27510,int_stack+583230,int_stack+574455, 1.0, int_stack+589320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+43725,int_stack+27510,int_stack+23460, 1.0, int_stack+591795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+586200,int_stack+43725,int_stack+38325, 1.0, int_stack+595845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+32460,int_stack+586200,int_stack+576930, 1.0, int_stack+601245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+293895,int_stack+292725, 1.0, int_stack+480150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+574455,int_stack+23460,int_stack+583230, 1.0, int_stack+607545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+594300,int_stack+574455,int_stack+27510, 1.0, int_stack+610515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+574455,int_stack+594300,int_stack+43725, 1.0, int_stack+615465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+594300,int_stack+574455,int_stack+586200, 1.0, int_stack+622215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+574455,int_stack+594300,int_stack+32460, 1.0, int_stack+630315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+586215,int_stack+295848,int_stack+295260, 1.0, int_stack+488670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+587979,int_stack+296604,int_stack+295848, 1.0, int_stack+489258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+590247,int_stack+587979,int_stack+586215, 1.0, int_stack+639135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+593775,int_stack+297549,int_stack+296604, 1.0, int_stack+490014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+596610,int_stack+593775,int_stack+587979, 1.0, int_stack+640899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+601146,int_stack+596610,int_stack+590247, 1.0, int_stack+643167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+639135,int_stack+298704,int_stack+297549, 1.0, int_stack+490959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+586215,int_stack+639135,int_stack+593775, 1.0, int_stack+646695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+23460,int_stack+586215,int_stack+596610, 1.0, int_stack+649530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+642600,int_stack+23460,int_stack+601146, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+300090,int_stack+298704, 1.0, int_stack+492114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+591885,int_stack+0,int_stack+639135, 1.0, int_stack+654066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+31020,int_stack+591885,int_stack+586215, 1.0, int_stack+671460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+40470,int_stack+31020,int_stack+23460, 1.0, int_stack+677130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+51810,int_stack+40470,int_stack+642600, 1.0, int_stack+684690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+23460,int_stack+301728,int_stack+300090, 1.0, int_stack+493500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+639135,int_stack+23460,int_stack+0, 1.0, int_stack+693510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+64158,int_stack+639135,int_stack+591885, 1.0, int_stack+697668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+639135,int_stack+64158,int_stack+31020, 1.0, int_stack+704598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+64158,int_stack+639135,int_stack+40470, 1.0, int_stack+714048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+639135,int_stack+64158,int_stack+51810, 1.0, int_stack+725388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+23460,int_stack+639135,int_stack+574455,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+574455,int_stack+304423,int_stack+303639, 1.0, int_stack+505428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+576807,int_stack+305431,int_stack+304423, 1.0, int_stack+506212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+579831,int_stack+576807,int_stack+574455, 1.0, int_stack+737736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+584535,int_stack+306691,int_stack+305431, 1.0, int_stack+507220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+588315,int_stack+584535,int_stack+576807, 1.0, int_stack+740088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+594363,int_stack+588315,int_stack+579831, 1.0, int_stack+743112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+737736,int_stack+308231,int_stack+306691, 1.0, int_stack+508480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+574455,int_stack+737736,int_stack+584535, 1.0, int_stack+747816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+58740,int_stack+574455,int_stack+588315, 1.0, int_stack+751596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+742356,int_stack+58740,int_stack+594363, 1.0, int_stack+757644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+754116,int_stack+310079,int_stack+308231, 1.0, int_stack+510020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+582015,int_stack+754116,int_stack+737736, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+591255,int_stack+582015,int_stack+574455, 1.0, int_stack+657531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+68820,int_stack+591255,int_stack+58740, 1.0, int_stack+818271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+83940,int_stack+68820,int_stack+742356, 1.0, int_stack+828351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+58740,int_stack+312263,int_stack+310079, 1.0, int_stack+511868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+737736,int_stack+58740,int_stack+754116, 1.0, int_stack+665091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+748824,int_stack+737736,int_stack+582015, 1.0, int_stack+840111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+100404,int_stack+748824,int_stack+591255, 1.0, int_stack+849351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+737736,int_stack+100404,int_stack+68820, 1.0, int_stack+861951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+58740,int_stack+737736,int_stack+83940, 1.0, int_stack+877071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2702767,int_stack+58740,int_stack+639135,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2752159,int_stack+2702767,int_stack+23460,784);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23460,int_stack+315819,int_stack+314811, 1.0, int_stack+527772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26484,int_stack+317115,int_stack+315819, 1.0, int_stack+528780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30372,int_stack+26484,int_stack+23460, 1.0, int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+36420,int_stack+318735,int_stack+317115, 1.0, int_stack+530076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41280,int_stack+36420,int_stack+26484, 1.0, int_stack+13524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+639135,int_stack+41280,int_stack+30372, 1.0, int_stack+17412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+49056,int_stack+320715,int_stack+318735, 1.0, int_stack+531696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+649215,int_stack+49056,int_stack+36420, 1.0, int_stack+765484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+737736,int_stack+649215,int_stack+41280, 1.0, int_stack+770344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+750696,int_stack+737736,int_stack+639135, 1.0, int_stack+778120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+639135,int_stack+323091,int_stack+320715, 1.0, int_stack+533676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+765816,int_stack+639135,int_stack+49056, 1.0, int_stack+788200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+777696,int_stack+765816,int_stack+649215, 1.0, int_stack+794140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+80692,int_stack+777696,int_stack+737736, 1.0, int_stack+803860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+793896,int_stack+80692,int_stack+750696, 1.0, int_stack+1035439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+737736,int_stack+325899,int_stack+323091, 1.0, int_stack+536052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+746160,int_stack+737736,int_stack+639135, 1.0, int_stack+1050559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+639135,int_stack+746160,int_stack+765816, 1.0, int_stack+1057687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+737736,int_stack+639135,int_stack+777696, 1.0, int_stack+1069567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+762036,int_stack+737736,int_stack+80692, 1.0, int_stack+1085767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1677295,int_stack+762036,int_stack+793896, 1.0, int_stack+1105207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1170925,int_stack+1677295,int_stack+58740,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+737736,int_stack+1170925,int_stack+2702767,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+0,int_stack+737736,int_stack+2752159,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2702767,int_stack+333315,int_stack+330435, 1.0, int_stack+329175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2706547,int_stack+336960,int_stack+333315, 1.0, int_stack+331695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2711407,int_stack+2706547,int_stack+2702767, 1.0, int_stack+893535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2718967,int_stack+341460,int_stack+336960, 1.0, int_stack+334935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2725042,int_stack+2718967,int_stack+2706547, 1.0, int_stack+897315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2734762,int_stack+2725042,int_stack+2711407, 1.0, int_stack+902175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+893535,int_stack+346905,int_stack+341460, 1.0, int_stack+338985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2702767,int_stack+893535,int_stack+2718967, 1.0, int_stack+909735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2747362,int_stack+2702767,int_stack+2725042, 1.0, int_stack+915810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+900960,int_stack+2747362,int_stack+2734762, 1.0, int_stack+925530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+919860,int_stack+353385,int_stack+346905, 1.0, int_stack+343935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2714917,int_stack+919860,int_stack+893535, 1.0, int_stack+938130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2763562,int_stack+2714917,int_stack+2702767, 1.0, int_stack+945555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+928770,int_stack+2763562,int_stack+2747362, 1.0, int_stack+957705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2729767,int_stack+928770,int_stack+900960, 1.0, int_stack+973905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2702767,int_stack+356895,int_stack+353385, 1.0, int_stack+349875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+893535,int_stack+2702767,int_stack+919860, 1.0, int_stack+992805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+953070,int_stack+893535,int_stack+2714917, 1.0, int_stack+1001715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+893535,int_stack+953070,int_stack+2763562, 1.0, int_stack+1126375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+953070,int_stack+893535,int_stack+928770, 1.0, int_stack+1146625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+893535,int_stack+953070,int_stack+2729767, 1.0, int_stack+1486195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+928815,int_stack+893535,int_stack+1677295,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2702767,int_stack+928815,int_stack+1170925,784);
 /*--- compute (hf|ii) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2834479,int_stack+2702767,int_stack+737736,784);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+737736,int_stack+481320,int_stack+480150,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+741246,int_stack+737736,int_stack+607545,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+747186,int_stack+741246,int_stack+610515,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+755436,int_stack+747186,int_stack+615465,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+737736,int_stack+755436,int_stack+622215,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+749076,int_stack+737736,int_stack+630315,15);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+737736,int_stack+495138,int_stack+493500,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+760836,int_stack+737736,int_stack+693510,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+769152,int_stack+760836,int_stack+697668,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+780702,int_stack+769152,int_stack+704598,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+760836,int_stack+780702,int_stack+714048,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+776712,int_stack+760836,int_stack+725388,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+793176,int_stack+776712,int_stack+749076,784);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+760836,int_stack+514052,int_stack+511868,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+828456,int_stack+760836,int_stack+665091,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+760836,int_stack+828456,int_stack+840111,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+828456,int_stack+760836,int_stack+849351,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2702767,int_stack+828456,int_stack+861951,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+828456,int_stack+2702767,int_stack+877071,28);
 /*--- compute (hp|ii) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2702767,int_stack+828456,int_stack+776712,784);
 /*--- compute (gd|ii) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2752159,int_stack+2702767,int_stack+793176,784);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2822719,int_stack+538860,int_stack+536052,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+850408,int_stack+2822719,int_stack+1050559,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+864664,int_stack+850408,int_stack+1057687,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+884464,int_stack+864664,int_stack+1069567,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+850408,int_stack+884464,int_stack+1085767,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1677295,int_stack+850408,int_stack+1105207,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+850408,int_stack+1677295,int_stack+828456,784);
 /*--- compute (hd|ii) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+916264,int_stack+850408,int_stack+2702767,784);
 /*--- compute (gf|ii) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1015048,int_stack+916264,int_stack+2752159,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1132648,int_stack+361410,int_stack+360990,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1133908,int_stack+361950,int_stack+361410,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1135528,int_stack+1133908,int_stack+1132648,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1138048,int_stack+362625,int_stack+361950,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1140073,int_stack+1138048,int_stack+1133908,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1143313,int_stack+1140073,int_stack+1135528,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1132648,int_stack+363450,int_stack+362625,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1147513,int_stack+1132648,int_stack+1138048,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1151563,int_stack+1147513,int_stack+1140073,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1135123,int_stack+1151563,int_stack+1143313,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1141423,int_stack+364440,int_stack+363450,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1156963,int_stack+1141423,int_stack+1132648,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1161913,int_stack+1156963,int_stack+1147513,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1168663,int_stack+1161913,int_stack+1151563,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1144393,int_stack+1168663,int_stack+1135123,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1132648,int_stack+365610,int_stack+364440,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1176763,int_stack+1132648,int_stack+1141423,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1132648,int_stack+1176763,int_stack+1156963,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1176763,int_stack+1132648,int_stack+1161913,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1132648,int_stack+1176763,int_stack+1168663,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2822719,int_stack+1132648,int_stack+1144393,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1132648,int_stack+367563,int_stack+366975,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1134412,int_stack+368319,int_stack+367563,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1136680,int_stack+1134412,int_stack+1132648,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1140208,int_stack+369264,int_stack+368319,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1143043,int_stack+1140208,int_stack+1134412,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1147579,int_stack+1143043,int_stack+1136680,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1132648,int_stack+370419,int_stack+369264,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1153459,int_stack+1132648,int_stack+1140208,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1159129,int_stack+1153459,int_stack+1143043,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1136113,int_stack+1159129,int_stack+1147579,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1144933,int_stack+371805,int_stack+370419,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1166689,int_stack+1144933,int_stack+1132648,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1173619,int_stack+1166689,int_stack+1153459,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1183069,int_stack+1173619,int_stack+1159129,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1149091,int_stack+1183069,int_stack+1136113,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1132648,int_stack+373443,int_stack+371805,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1194409,int_stack+1132648,int_stack+1144933,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1132648,int_stack+1194409,int_stack+1166689,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1194409,int_stack+1132648,int_stack+1173619,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+760836,int_stack+1194409,int_stack+1183069,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1161439,int_stack+760836,int_stack+1149091,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1177903,int_stack+1161439,int_stack+2822719, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+749076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2822719,int_stack+376138,int_stack+375354,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2825071,int_stack+377146,int_stack+376138,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2828095,int_stack+2825071,int_stack+2822719,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+760836,int_stack+378406,int_stack+377146,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+764616,int_stack+760836,int_stack+2825071,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1132648,int_stack+764616,int_stack+2828095,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2822719,int_stack+379946,int_stack+378406,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1140488,int_stack+2822719,int_stack+760836,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1148048,int_stack+1140488,int_stack+764616,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+760836,int_stack+1148048,int_stack+1132648,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1132648,int_stack+381794,int_stack+379946,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1213183,int_stack+1132648,int_stack+2822719,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1222423,int_stack+1213183,int_stack+1140488,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1486195,int_stack+1222423,int_stack+1148048,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1138192,int_stack+1486195,int_stack+760836,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+760836,int_stack+383978,int_stack+381794,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+2822719,int_stack+760836,int_stack+1132648,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+760836,int_stack+2822719,int_stack+1213183,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+574455,int_stack+760836,int_stack+1222423,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1213183,int_stack+574455,int_stack+1486195,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1486195,int_stack+1213183,int_stack+1138192,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+574455,int_stack+1486195,int_stack+1161439, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+623847,int_stack+574455,int_stack+1177903, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+793176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1508147,int_stack+387534,int_stack+386526,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+694407,int_stack+388830,int_stack+387534,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+698295,int_stack+694407,int_stack+1508147,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+704343,int_stack+390450,int_stack+388830,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+709203,int_stack+704343,int_stack+694407,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+716979,int_stack+709203,int_stack+698295,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+694407,int_stack+392430,int_stack+390450,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+727059,int_stack+694407,int_stack+704343,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+760836,int_stack+727059,int_stack+709203,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+700347,int_stack+760836,int_stack+716979,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+715467,int_stack+394806,int_stack+392430,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+736779,int_stack+715467,int_stack+694407,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1132648,int_stack+736779,int_stack+727059,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1148848,int_stack+1132648,int_stack+760836,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1168288,int_stack+1148848,int_stack+700347,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+760836,int_stack+397614,int_stack+394806,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+694407,int_stack+760836,int_stack+715467,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+708663,int_stack+694407,int_stack+736779,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1189456,int_stack+708663,int_stack+1132648,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+694407,int_stack+1189456,int_stack+1148848,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1189456,int_stack+694407,int_stack+1168288,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+239844,int_stack+1189456,int_stack+1486195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hd|ii) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2999119,int_stack+239844,int_stack+574455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2702767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gf|ii) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+3097903,int_stack+2999119,int_stack+623847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2752159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+574455,int_stack+402150,int_stack+400890,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+578235,int_stack+403770,int_stack+402150,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+583095,int_stack+578235,int_stack+574455,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+590655,int_stack+405795,int_stack+403770,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+596730,int_stack+590655,int_stack+578235,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+606450,int_stack+596730,int_stack+583095,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+574455,int_stack+408270,int_stack+405795,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+619050,int_stack+574455,int_stack+590655,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+631200,int_stack+619050,int_stack+596730,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+581880,int_stack+631200,int_stack+606450,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+600780,int_stack+411240,int_stack+408270,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+647400,int_stack+600780,int_stack+574455,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+662250,int_stack+647400,int_stack+619050,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+682500,int_stack+662250,int_stack+631200,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1486195,int_stack+682500,int_stack+581880,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+574455,int_stack+414750,int_stack+411240,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+609690,int_stack+574455,int_stack+600780,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+574455,int_stack+609690,int_stack+647400,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+599205,int_stack+574455,int_stack+662250,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+629580,int_stack+599205,int_stack+682500,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+574455,int_stack+629580,int_stack+1486195,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+609735,int_stack+574455,int_stack+1189456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1677295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3215503,int_stack+609735,int_stack+239844, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hf|ii) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+239844,int_stack+3215503,int_stack+2999119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+916264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2999119,int_stack+419265,int_stack+418845,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3000379,int_stack+419805,int_stack+419265,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3001999,int_stack+3000379,int_stack+2999119,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3004519,int_stack+420480,int_stack+419805,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3006544,int_stack+3004519,int_stack+3000379,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3009784,int_stack+3006544,int_stack+3001999,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2999119,int_stack+421305,int_stack+420480,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3013984,int_stack+2999119,int_stack+3004519,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3018034,int_stack+3013984,int_stack+3006544,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3001594,int_stack+3018034,int_stack+3009784,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3007894,int_stack+422295,int_stack+421305,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3023434,int_stack+3007894,int_stack+2999119,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3028384,int_stack+3023434,int_stack+3013984,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3035134,int_stack+3028384,int_stack+3018034,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3010864,int_stack+3035134,int_stack+3001594,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2999119,int_stack+423465,int_stack+422295,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+3043234,int_stack+2999119,int_stack+3007894,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2999119,int_stack+3043234,int_stack+3023434,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+3043234,int_stack+2999119,int_stack+3028384,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2999119,int_stack+3043234,int_stack+3035134,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2822719,int_stack+2999119,int_stack+3010864,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2999119,int_stack+425418,int_stack+424830,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3000883,int_stack+426174,int_stack+425418,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3003151,int_stack+3000883,int_stack+2999119,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3006679,int_stack+427119,int_stack+426174,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3009514,int_stack+3006679,int_stack+3000883,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3014050,int_stack+3009514,int_stack+3003151,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2999119,int_stack+428274,int_stack+427119,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3019930,int_stack+2999119,int_stack+3006679,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3025600,int_stack+3019930,int_stack+3009514,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3002584,int_stack+3025600,int_stack+3014050,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3011404,int_stack+429660,int_stack+428274,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3033160,int_stack+3011404,int_stack+2999119,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3040090,int_stack+3033160,int_stack+3019930,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3049540,int_stack+3040090,int_stack+3025600,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3015562,int_stack+3049540,int_stack+3002584,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2999119,int_stack+431298,int_stack+429660,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+3060880,int_stack+2999119,int_stack+3011404,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2999119,int_stack+3060880,int_stack+3033160,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+3060880,int_stack+2999119,int_stack+3040090,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+760836,int_stack+3060880,int_stack+3049540,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+3027910,int_stack+760836,int_stack+3015562,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3044374,int_stack+3027910,int_stack+2822719, 0.0, zero_stack, 1.0, int_stack+749076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2822719,int_stack+433993,int_stack+433209,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2825071,int_stack+435001,int_stack+433993,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2828095,int_stack+2825071,int_stack+2822719,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+760836,int_stack+436261,int_stack+435001,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+764616,int_stack+760836,int_stack+2825071,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2999119,int_stack+764616,int_stack+2828095,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2822719,int_stack+437801,int_stack+436261,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3006959,int_stack+2822719,int_stack+760836,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3014519,int_stack+3006959,int_stack+764616,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+760836,int_stack+3014519,int_stack+2999119,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2999119,int_stack+439649,int_stack+437801,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3079654,int_stack+2999119,int_stack+2822719,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3215503,int_stack+3079654,int_stack+3006959,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3228103,int_stack+3215503,int_stack+3014519,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3004663,int_stack+3228103,int_stack+760836,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+760836,int_stack+441833,int_stack+439649,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+2822719,int_stack+760836,int_stack+2999119,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+760836,int_stack+2822719,int_stack+3079654,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+3243223,int_stack+760836,int_stack+3215503,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+3262123,int_stack+3243223,int_stack+3228103,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+3215503,int_stack+3262123,int_stack+3004663,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3237455,int_stack+3215503,int_stack+3027910, 0.0, zero_stack, 1.0, int_stack+776712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+574455,int_stack+3237455,int_stack+3044374, 0.0, zero_stack, 1.0, int_stack+793176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3286847,int_stack+445389,int_stack+444381,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3289871,int_stack+446685,int_stack+445389,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3293759,int_stack+3289871,int_stack+3286847,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3299807,int_stack+448305,int_stack+446685,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3304667,int_stack+3299807,int_stack+3289871,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3312443,int_stack+3304667,int_stack+3293759,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3286847,int_stack+450285,int_stack+448305,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3322523,int_stack+3286847,int_stack+3299807,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3332243,int_stack+3322523,int_stack+3304667,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3292787,int_stack+3332243,int_stack+3312443,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3307907,int_stack+452661,int_stack+450285,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+760836,int_stack+3307907,int_stack+3286847,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2999119,int_stack+760836,int_stack+3322523,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3015319,int_stack+2999119,int_stack+3332243,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3315035,int_stack+3015319,int_stack+3292787,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+3286847,int_stack+455469,int_stack+452661,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+3034759,int_stack+3286847,int_stack+3307907,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+3286847,int_stack+3034759,int_stack+760836,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+3034759,int_stack+3286847,int_stack+2999119,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+3286847,int_stack+3034759,int_stack+3015319,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2999119,int_stack+3286847,int_stack+3315035,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3027343,int_stack+2999119,int_stack+3215503, 0.0, zero_stack, 1.0, int_stack+828456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hd|ii) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+645015,int_stack+3027343,int_stack+3237455, 0.0, zero_stack, 1.0, int_stack+2702767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gf|ii) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+3215503,int_stack+645015,int_stack+574455, 0.0, zero_stack, 1.0, int_stack+2752159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+574455,int_stack+460005,int_stack+458745,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+578235,int_stack+461625,int_stack+460005,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+583095,int_stack+578235,int_stack+574455,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+590655,int_stack+463650,int_stack+461625,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+596730,int_stack+590655,int_stack+578235,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+606450,int_stack+596730,int_stack+583095,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+574455,int_stack+466125,int_stack+463650,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+619050,int_stack+574455,int_stack+590655,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+404484,int_stack+619050,int_stack+596730,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+581880,int_stack+404484,int_stack+606450,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+600780,int_stack+469095,int_stack+466125,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+760836,int_stack+600780,int_stack+574455,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+420684,int_stack+760836,int_stack+619050,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+609690,int_stack+420684,int_stack+404484,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1486195,int_stack+609690,int_stack+581880,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+404484,int_stack+472605,int_stack+469095,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+574455,int_stack+404484,int_stack+600780,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+440934,int_stack+574455,int_stack+760836,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+574455,int_stack+440934,int_stack+420684,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+404484,int_stack+574455,int_stack+609690,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+574455,int_stack+404484,int_stack+1486195,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1132648,int_stack+574455,int_stack+2999119, 0.0, zero_stack, 1.0, int_stack+1677295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3333103,int_stack+1132648,int_stack+3027343, 0.0, zero_stack, 1.0, int_stack+850408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hf|ii) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3464815,int_stack+3333103,int_stack+645015, 0.0, zero_stack, 1.0, int_stack+916264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3333103,int_stack+483105,int_stack+482685,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3334363,int_stack+483645,int_stack+483105,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3335983,int_stack+3334363,int_stack+3333103,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3338503,int_stack+484320,int_stack+483645,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3340528,int_stack+3338503,int_stack+3334363,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3343768,int_stack+3340528,int_stack+3335983,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3333103,int_stack+485145,int_stack+484320,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3347968,int_stack+3333103,int_stack+3338503,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3352018,int_stack+3347968,int_stack+3340528,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3335578,int_stack+3352018,int_stack+3343768,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3341878,int_stack+486135,int_stack+485145,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3357418,int_stack+3341878,int_stack+3333103,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3362368,int_stack+3357418,int_stack+3347968,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3369118,int_stack+3362368,int_stack+3352018,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3344848,int_stack+3369118,int_stack+3335578,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+3333103,int_stack+487305,int_stack+486135,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+3377218,int_stack+3333103,int_stack+3341878,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+3333103,int_stack+3377218,int_stack+3357418,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+3377218,int_stack+3333103,int_stack+3362368,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+3333103,int_stack+3377218,int_stack+3369118,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2822719,int_stack+3333103,int_stack+3344848,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3333103,int_stack+497637,int_stack+497049,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3334867,int_stack+498393,int_stack+497637,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3337135,int_stack+3334867,int_stack+3333103,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3340663,int_stack+499338,int_stack+498393,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3343498,int_stack+3340663,int_stack+3334867,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3348034,int_stack+3343498,int_stack+3337135,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3333103,int_stack+500493,int_stack+499338,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3353914,int_stack+3333103,int_stack+3340663,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3359584,int_stack+3353914,int_stack+3343498,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3336568,int_stack+3359584,int_stack+3348034,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3345388,int_stack+501879,int_stack+500493,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3367144,int_stack+3345388,int_stack+3333103,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3374074,int_stack+3367144,int_stack+3353914,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3383524,int_stack+3374074,int_stack+3359584,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3349546,int_stack+3383524,int_stack+3336568,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+3333103,int_stack+503517,int_stack+501879,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+3394864,int_stack+3333103,int_stack+3345388,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+3333103,int_stack+3394864,int_stack+3367144,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+3394864,int_stack+3333103,int_stack+3374074,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+760836,int_stack+3394864,int_stack+3383524,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+3361894,int_stack+760836,int_stack+3349546,21);
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+3378358,int_stack+3361894,int_stack+2822719, 1.0, int_stack+749076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2822719,int_stack+517384,int_stack+516600,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2825071,int_stack+518392,int_stack+517384,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2828095,int_stack+2825071,int_stack+2822719,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3333103,int_stack+519652,int_stack+518392,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3336883,int_stack+3333103,int_stack+2825071,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3342931,int_stack+3336883,int_stack+2828095,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2822719,int_stack+521192,int_stack+519652,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3350771,int_stack+2822719,int_stack+3333103,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3413638,int_stack+3350771,int_stack+3336883,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3423718,int_stack+3413638,int_stack+3342931,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3333103,int_stack+523040,int_stack+521192,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3338647,int_stack+3333103,int_stack+2822719,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3435478,int_stack+3338647,int_stack+3350771,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3448078,int_stack+3435478,int_stack+3413638,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1132648,int_stack+3448078,int_stack+3423718,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+3413638,int_stack+525224,int_stack+523040,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+3420190,int_stack+3413638,int_stack+3333103,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1149112,int_stack+3420190,int_stack+3338647,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+3333103,int_stack+1149112,int_stack+3435478,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1149112,int_stack+3333103,int_stack+3448078,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+3333103,int_stack+1149112,int_stack+1132648,28);
 /*--- compute (hp|ii) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1132648,int_stack+3333103,int_stack+3361894, 1.0, int_stack+776712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gd|ii) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2999119,int_stack+1132648,int_stack+3378358, 1.0, int_stack+793176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1182040,int_stack+543144,int_stack+542136,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1185064,int_stack+544440,int_stack+543144,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1188952,int_stack+1185064,int_stack+1182040,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1195000,int_stack+546060,int_stack+544440,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1199860,int_stack+1195000,int_stack+1185064,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1207636,int_stack+1199860,int_stack+1188952,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1182040,int_stack+548040,int_stack+546060,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1217716,int_stack+1182040,int_stack+1195000,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3355055,int_stack+1217716,int_stack+1199860,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1187980,int_stack+3355055,int_stack+1207636,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1203100,int_stack+550416,int_stack+548040,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3368015,int_stack+1203100,int_stack+1182040,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3379895,int_stack+3368015,int_stack+1217716,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1210228,int_stack+3379895,int_stack+3355055,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3396095,int_stack+1210228,int_stack+1187980,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+3355055,int_stack+553224,int_stack+550416,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1182040,int_stack+3355055,int_stack+1203100,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+3417263,int_stack+1182040,int_stack+3368015,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1182040,int_stack+3417263,int_stack+3379895,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+3417263,int_stack+1182040,int_stack+1210228,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+3069679,int_stack+3417263,int_stack+3396095,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3355055,int_stack+3069679,int_stack+3333103, 1.0, int_stack+828456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hd|ii) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+574455,int_stack+3355055,int_stack+1132648, 1.0, int_stack+2702767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gf|ii) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+673239,int_stack+574455,int_stack+2999119, 1.0, int_stack+2752159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2999119,int_stack+557760,int_stack+556500,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3002899,int_stack+559380,int_stack+557760,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3007759,int_stack+3002899,int_stack+2999119,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3015319,int_stack+561405,int_stack+559380,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3021394,int_stack+3015319,int_stack+3002899,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3031114,int_stack+3021394,int_stack+3007759,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2999119,int_stack+563880,int_stack+561405,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3043714,int_stack+2999119,int_stack+3015319,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2702767,int_stack+3043714,int_stack+3021394,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3006544,int_stack+2702767,int_stack+3031114,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3025444,int_stack+566850,int_stack+563880,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2718967,int_stack+3025444,int_stack+2999119,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2733817,int_stack+2718967,int_stack+3043714,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3034354,int_stack+2733817,int_stack+2702767,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1486195,int_stack+3034354,int_stack+3006544,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2702767,int_stack+570360,int_stack+566850,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+2999119,int_stack+2702767,int_stack+3025444,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2754067,int_stack+2999119,int_stack+2718967,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+2999119,int_stack+2754067,int_stack+2733817,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2702767,int_stack+2999119,int_stack+3034354,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2999119,int_stack+2702767,int_stack+1486195,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2702767,int_stack+2999119,int_stack+3069679, 1.0, int_stack+1677295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+404484,int_stack+2702767,int_stack+3355055, 1.0, int_stack+850408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (hf|ii) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3629455,int_stack+404484,int_stack+574455, 1.0, int_stack+916264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (gg|ii) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+404484,int_stack+1512655,int_stack+1368595,784);
     Libderiv->ABCD[11] = int_stack + 404484;
 /*--- compute (gg|ii) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+790839,int_stack+2039503,int_stack+1705519,784);
     Libderiv->ABCD[10] = int_stack + 790839;
 /*--- compute (gg|ii) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1354381,int_stack+1823119,int_stack+2204143,784);
     Libderiv->ABCD[9] = int_stack + 1354381;
 /*--- compute (gg|ii) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1530781,int_stack+2538127,int_stack+1236781,784);
     Libderiv->ABCD[8] = int_stack + 1530781;
 /*--- compute (gg|ii) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1132648,int_stack+2321743,int_stack+122244,784);
     Libderiv->ABCD[7] = int_stack + 1132648;
 /*--- compute (gg|ii) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1707181,int_stack+2834479,int_stack+0,784);
     Libderiv->ABCD[6] = int_stack + 1707181;
 /*--- compute (gg|ii) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+0,int_stack+239844,int_stack+3097903, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1015048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[2] = int_stack + 0;
 /*--- compute (gg|ii) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+176400,int_stack+3464815,int_stack+3215503, 0.0, zero_stack, 1.0, int_stack+1015048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[1] = int_stack + 176400;
 /*--- compute (gg|ii) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1883581,int_stack+3629455,int_stack+673239, 1.0, int_stack+1015048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[0] = int_stack + 1883581;

}
