/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_idii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (id|ii) integrals */

void d1hrr_order_idii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][9][11] = int_stack + 3052;
 Libderiv->deriv_classes[6][10][11] = int_stack + 4592;
 Libderiv->deriv_classes[6][11][11] = int_stack + 6440;
 Libderiv->deriv_classes[6][12][11] = int_stack + 8624;
 Libderiv->deriv_classes[7][6][11] = int_stack + 11172;
 Libderiv->deriv_classes[7][7][11] = int_stack + 12180;
 Libderiv->deriv_classes[7][8][11] = int_stack + 13476;
 Libderiv->deriv_classes[7][9][11] = int_stack + 15096;
 Libderiv->deriv_classes[7][10][11] = int_stack + 17076;
 Libderiv->deriv_classes[7][11][11] = int_stack + 19452;
 Libderiv->deriv_classes[7][12][11] = int_stack + 22260;
 Libderiv->deriv_classes[8][6][11] = int_stack + 25536;
 Libderiv->deriv_classes[8][7][11] = int_stack + 26796;
 Libderiv->deriv_classes[8][8][11] = int_stack + 28416;
 Libderiv->deriv_classes[8][9][11] = int_stack + 30441;
 Libderiv->deriv_classes[8][10][11] = int_stack + 32916;
 Libderiv->deriv_classes[8][11][11] = int_stack + 35886;
 Libderiv->deriv_classes[8][12][11] = int_stack + 39396;
 Libderiv->deriv_classes[6][6][10] = int_stack + 43491;
 Libderiv->deriv_classes[6][7][10] = int_stack + 44275;
 Libderiv->deriv_classes[6][8][10] = int_stack + 45283;
 Libderiv->deriv_classes[6][9][10] = int_stack + 46543;
 Libderiv->deriv_classes[6][10][10] = int_stack + 48083;
 Libderiv->deriv_classes[6][11][10] = int_stack + 49931;
 Libderiv->deriv_classes[6][12][10] = int_stack + 52115;
 Libderiv->deriv_classes[7][6][10] = int_stack + 54663;
 Libderiv->deriv_classes[7][7][10] = int_stack + 55671;
 Libderiv->deriv_classes[7][8][10] = int_stack + 56967;
 Libderiv->deriv_classes[7][9][10] = int_stack + 58587;
 Libderiv->deriv_classes[7][10][10] = int_stack + 60567;
 Libderiv->deriv_classes[7][11][10] = int_stack + 62943;
 Libderiv->deriv_classes[7][12][10] = int_stack + 65751;
 Libderiv->deriv_classes[8][6][10] = int_stack + 69027;
 Libderiv->deriv_classes[8][7][10] = int_stack + 70287;
 Libderiv->deriv_classes[8][8][10] = int_stack + 71907;
 Libderiv->deriv_classes[8][9][10] = int_stack + 73932;
 Libderiv->deriv_classes[8][10][10] = int_stack + 76407;
 Libderiv->deriv_classes[8][11][10] = int_stack + 79377;
 Libderiv->deriv_classes[8][12][10] = int_stack + 82887;
 Libderiv->deriv_classes[6][6][9] = int_stack + 86982;
 Libderiv->deriv_classes[6][7][9] = int_stack + 87766;
 Libderiv->deriv_classes[6][8][9] = int_stack + 88774;
 Libderiv->deriv_classes[6][9][9] = int_stack + 90034;
 Libderiv->deriv_classes[6][10][9] = int_stack + 91574;
 Libderiv->deriv_classes[6][11][9] = int_stack + 93422;
 Libderiv->deriv_classes[6][12][9] = int_stack + 95606;
 Libderiv->deriv_classes[7][6][9] = int_stack + 98154;
 Libderiv->deriv_classes[7][7][9] = int_stack + 99162;
 Libderiv->deriv_classes[7][8][9] = int_stack + 100458;
 Libderiv->deriv_classes[7][9][9] = int_stack + 102078;
 Libderiv->deriv_classes[7][10][9] = int_stack + 104058;
 Libderiv->deriv_classes[7][11][9] = int_stack + 106434;
 Libderiv->deriv_classes[7][12][9] = int_stack + 109242;
 Libderiv->deriv_classes[8][6][9] = int_stack + 112518;
 Libderiv->deriv_classes[8][7][9] = int_stack + 113778;
 Libderiv->deriv_classes[8][8][9] = int_stack + 115398;
 Libderiv->deriv_classes[8][9][9] = int_stack + 117423;
 Libderiv->deriv_classes[8][10][9] = int_stack + 119898;
 Libderiv->deriv_classes[8][11][9] = int_stack + 122868;
 Libderiv->deriv_classes[8][12][9] = int_stack + 126378;
 Libderiv->deriv_classes[6][6][8] = int_stack + 130473;
 Libderiv->deriv_classes[6][7][8] = int_stack + 131257;
 Libderiv->deriv_classes[6][8][8] = int_stack + 132265;
 Libderiv->deriv_classes[6][9][8] = int_stack + 133525;
 Libderiv->deriv_classes[6][10][8] = int_stack + 135065;
 Libderiv->deriv_classes[6][11][8] = int_stack + 136913;
 Libderiv->deriv_classes[6][12][8] = int_stack + 139097;
 Libderiv->deriv_classes[7][6][8] = int_stack + 141645;
 Libderiv->deriv_classes[7][7][8] = int_stack + 142653;
 Libderiv->deriv_classes[7][8][8] = int_stack + 143949;
 Libderiv->deriv_classes[7][9][8] = int_stack + 145569;
 Libderiv->deriv_classes[7][10][8] = int_stack + 147549;
 Libderiv->deriv_classes[7][11][8] = int_stack + 149925;
 Libderiv->deriv_classes[7][12][8] = int_stack + 152733;
 Libderiv->deriv_classes[8][6][8] = int_stack + 156009;
 Libderiv->deriv_classes[8][7][8] = int_stack + 157269;
 Libderiv->deriv_classes[8][8][8] = int_stack + 158889;
 Libderiv->deriv_classes[8][9][8] = int_stack + 160914;
 Libderiv->deriv_classes[8][10][8] = int_stack + 163389;
 Libderiv->deriv_classes[8][11][8] = int_stack + 166359;
 Libderiv->deriv_classes[8][12][8] = int_stack + 169869;
 Libderiv->deriv_classes[6][6][7] = int_stack + 173964;
 Libderiv->deriv_classes[6][7][7] = int_stack + 174748;
 Libderiv->deriv_classes[6][8][7] = int_stack + 175756;
 Libderiv->deriv_classes[6][9][7] = int_stack + 177016;
 Libderiv->deriv_classes[6][10][7] = int_stack + 178556;
 Libderiv->deriv_classes[6][11][7] = int_stack + 180404;
 Libderiv->deriv_classes[6][12][7] = int_stack + 182588;
 Libderiv->deriv_classes[7][6][7] = int_stack + 185136;
 Libderiv->deriv_classes[7][7][7] = int_stack + 186144;
 Libderiv->deriv_classes[7][8][7] = int_stack + 187440;
 Libderiv->deriv_classes[7][9][7] = int_stack + 189060;
 Libderiv->deriv_classes[7][10][7] = int_stack + 191040;
 Libderiv->deriv_classes[7][11][7] = int_stack + 193416;
 Libderiv->deriv_classes[7][12][7] = int_stack + 196224;
 Libderiv->deriv_classes[8][6][7] = int_stack + 199500;
 Libderiv->deriv_classes[8][7][7] = int_stack + 200760;
 Libderiv->deriv_classes[8][8][7] = int_stack + 202380;
 Libderiv->deriv_classes[8][9][7] = int_stack + 204405;
 Libderiv->deriv_classes[8][10][7] = int_stack + 206880;
 Libderiv->deriv_classes[8][11][7] = int_stack + 209850;
 Libderiv->deriv_classes[8][12][7] = int_stack + 213360;
 Libderiv->deriv_classes[6][6][6] = int_stack + 217455;
 Libderiv->deriv_classes[6][7][6] = int_stack + 218239;
 Libderiv->deriv_classes[6][8][6] = int_stack + 219247;
 Libderiv->deriv_classes[6][9][6] = int_stack + 220507;
 Libderiv->deriv_classes[6][10][6] = int_stack + 222047;
 Libderiv->deriv_classes[6][11][6] = int_stack + 223895;
 Libderiv->deriv_classes[6][12][6] = int_stack + 226079;
 Libderiv->deriv_classes[7][6][6] = int_stack + 228627;
 Libderiv->deriv_classes[7][7][6] = int_stack + 229635;
 Libderiv->deriv_classes[7][8][6] = int_stack + 230931;
 Libderiv->deriv_classes[7][9][6] = int_stack + 232551;
 Libderiv->deriv_classes[7][10][6] = int_stack + 234531;
 Libderiv->deriv_classes[7][11][6] = int_stack + 236907;
 Libderiv->deriv_classes[7][12][6] = int_stack + 239715;
 Libderiv->dvrr_classes[8][6] = int_stack + 242991;
 Libderiv->deriv_classes[8][6][6] = int_stack + 244251;
 Libderiv->dvrr_classes[8][7] = int_stack + 245511;
 Libderiv->deriv_classes[8][7][6] = int_stack + 247131;
 Libderiv->dvrr_classes[8][8] = int_stack + 248751;
 Libderiv->deriv_classes[8][8][6] = int_stack + 250776;
 Libderiv->dvrr_classes[8][9] = int_stack + 252801;
 Libderiv->deriv_classes[8][9][6] = int_stack + 255276;
 Libderiv->dvrr_classes[8][10] = int_stack + 257751;
 Libderiv->deriv_classes[8][10][6] = int_stack + 260721;
 Libderiv->dvrr_classes[8][11] = int_stack + 263691;
 Libderiv->deriv_classes[8][11][6] = int_stack + 267201;
 Libderiv->deriv_classes[8][12][6] = int_stack + 270711;
 Libderiv->deriv_classes[6][6][2] = int_stack + 274806;
 Libderiv->deriv_classes[6][7][2] = int_stack + 275590;
 Libderiv->deriv_classes[6][8][2] = int_stack + 276598;
 Libderiv->deriv_classes[6][9][2] = int_stack + 277858;
 Libderiv->deriv_classes[6][10][2] = int_stack + 279398;
 Libderiv->deriv_classes[6][11][2] = int_stack + 281246;
 Libderiv->deriv_classes[6][12][2] = int_stack + 283430;
 Libderiv->deriv_classes[7][6][2] = int_stack + 285978;
 Libderiv->deriv_classes[7][7][2] = int_stack + 286986;
 Libderiv->deriv_classes[7][8][2] = int_stack + 288282;
 Libderiv->deriv_classes[7][9][2] = int_stack + 289902;
 Libderiv->deriv_classes[7][10][2] = int_stack + 291882;
 Libderiv->deriv_classes[7][11][2] = int_stack + 294258;
 Libderiv->deriv_classes[7][12][2] = int_stack + 297066;
 Libderiv->deriv_classes[8][6][2] = int_stack + 300342;
 Libderiv->deriv_classes[8][7][2] = int_stack + 301602;
 Libderiv->deriv_classes[8][8][2] = int_stack + 303222;
 Libderiv->deriv_classes[8][9][2] = int_stack + 305247;
 Libderiv->deriv_classes[8][10][2] = int_stack + 307722;
 Libderiv->deriv_classes[8][11][2] = int_stack + 310692;
 Libderiv->deriv_classes[8][12][2] = int_stack + 314202;
 Libderiv->deriv_classes[6][6][1] = int_stack + 318297;
 Libderiv->deriv_classes[6][7][1] = int_stack + 319081;
 Libderiv->deriv_classes[6][8][1] = int_stack + 320089;
 Libderiv->deriv_classes[6][9][1] = int_stack + 321349;
 Libderiv->deriv_classes[6][10][1] = int_stack + 322889;
 Libderiv->deriv_classes[6][11][1] = int_stack + 324737;
 Libderiv->deriv_classes[6][12][1] = int_stack + 326921;
 Libderiv->deriv_classes[7][6][1] = int_stack + 329469;
 Libderiv->deriv_classes[7][7][1] = int_stack + 330477;
 Libderiv->deriv_classes[7][8][1] = int_stack + 331773;
 Libderiv->deriv_classes[7][9][1] = int_stack + 333393;
 Libderiv->deriv_classes[7][10][1] = int_stack + 335373;
 Libderiv->deriv_classes[7][11][1] = int_stack + 337749;
 Libderiv->deriv_classes[7][12][1] = int_stack + 340557;
 Libderiv->deriv_classes[8][6][1] = int_stack + 343833;
 Libderiv->deriv_classes[8][7][1] = int_stack + 345093;
 Libderiv->deriv_classes[8][8][1] = int_stack + 346713;
 Libderiv->deriv_classes[8][9][1] = int_stack + 348738;
 Libderiv->deriv_classes[8][10][1] = int_stack + 351213;
 Libderiv->deriv_classes[8][11][1] = int_stack + 354183;
 Libderiv->deriv_classes[8][12][1] = int_stack + 357693;
 Libderiv->dvrr_classes[6][6] = int_stack + 361788;
 Libderiv->dvrr_classes[6][7] = int_stack + 362572;
 Libderiv->dvrr_classes[6][8] = int_stack + 363580;
 Libderiv->dvrr_classes[6][9] = int_stack + 364840;
 Libderiv->dvrr_classes[6][10] = int_stack + 366380;
 Libderiv->dvrr_classes[6][11] = int_stack + 368228;
 Libderiv->dvrr_classes[6][12] = int_stack + 370412;
 Libderiv->deriv_classes[6][6][0] = int_stack + 372960;
 Libderiv->deriv_classes[6][7][0] = int_stack + 373744;
 Libderiv->deriv_classes[6][8][0] = int_stack + 374752;
 Libderiv->deriv_classes[6][9][0] = int_stack + 376012;
 Libderiv->deriv_classes[6][10][0] = int_stack + 377552;
 Libderiv->deriv_classes[6][11][0] = int_stack + 379400;
 Libderiv->deriv_classes[6][12][0] = int_stack + 381584;
 Libderiv->dvrr_classes[7][6] = int_stack + 384132;
 Libderiv->dvrr_classes[7][7] = int_stack + 385140;
 Libderiv->dvrr_classes[7][8] = int_stack + 386436;
 Libderiv->dvrr_classes[7][9] = int_stack + 388056;
 Libderiv->dvrr_classes[7][10] = int_stack + 390036;
 Libderiv->dvrr_classes[7][11] = int_stack + 392412;
 Libderiv->dvrr_classes[7][12] = int_stack + 395220;
 Libderiv->deriv_classes[7][6][0] = int_stack + 398496;
 Libderiv->deriv_classes[7][7][0] = int_stack + 399504;
 Libderiv->deriv_classes[7][8][0] = int_stack + 400800;
 Libderiv->deriv_classes[7][9][0] = int_stack + 402420;
 Libderiv->deriv_classes[7][10][0] = int_stack + 404400;
 Libderiv->deriv_classes[7][11][0] = int_stack + 406776;
 Libderiv->deriv_classes[7][12][0] = int_stack + 409584;
 Libderiv->deriv_classes[8][6][0] = int_stack + 412860;
 Libderiv->deriv_classes[8][7][0] = int_stack + 414120;
 Libderiv->deriv_classes[8][8][0] = int_stack + 415740;
 Libderiv->deriv_classes[8][9][0] = int_stack + 417765;
 Libderiv->deriv_classes[8][10][0] = int_stack + 420240;
 Libderiv->deriv_classes[8][11][0] = int_stack + 423210;
 Libderiv->deriv_classes[8][12][0] = int_stack + 426720;
 memset(int_stack,0,3446520);

 Libderiv->dvrr_stack = int_stack + 1936767;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_idii(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+430815,int_stack+362572,int_stack+361788,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+433167,int_stack+363580,int_stack+362572,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+436191,int_stack+433167,int_stack+430815,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+440895,int_stack+364840,int_stack+363580,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+444675,int_stack+440895,int_stack+433167,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+450723,int_stack+444675,int_stack+436191,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+458563,int_stack+366380,int_stack+364840,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+463183,int_stack+458563,int_stack+440895,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+470743,int_stack+463183,int_stack+444675,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+480823,int_stack+470743,int_stack+450723,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+492583,int_stack+368228,int_stack+366380,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+498127,int_stack+492583,int_stack+458563,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+507367,int_stack+498127,int_stack+463183,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+519967,int_stack+507367,int_stack+470743,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+535087,int_stack+519967,int_stack+480823,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+551551,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361788,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+553903,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362572,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+556927,int_stack+553903,int_stack+551551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430815,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+561631,int_stack+3052,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363580,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+565411,int_stack+561631,int_stack+553903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433167,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+571459,int_stack+565411,int_stack+556927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436191,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+551551,int_stack+4592,int_stack+3052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364840,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+579299,int_stack+551551,int_stack+561631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440895,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+586859,int_stack+579299,int_stack+565411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444675,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+556171,int_stack+586859,int_stack+571459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450723,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+567931,int_stack+6440,int_stack+4592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366380,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+596939,int_stack+567931,int_stack+551551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458563,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+606179,int_stack+596939,int_stack+579299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463183,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+618779,int_stack+606179,int_stack+586859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470743,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+573475,int_stack+618779,int_stack+556171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480823,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+551551,int_stack+8624,int_stack+6440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368228,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+551551,int_stack+567931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492583,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+551551,int_stack+0,int_stack+596939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498127,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+633899,int_stack+551551,int_stack+606179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+551551,int_stack+633899,int_stack+618779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519967,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+589939,int_stack+551551,int_stack+573475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535087,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+551551,int_stack+385140,int_stack+384132,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+554575,int_stack+386436,int_stack+385140,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+558463,int_stack+554575,int_stack+551551,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+564511,int_stack+388056,int_stack+386436,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+569371,int_stack+564511,int_stack+554575,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+577147,int_stack+569371,int_stack+558463,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+390036,int_stack+388056,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+611891,int_stack+0,int_stack+564511,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+621611,int_stack+611891,int_stack+569371,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+634571,int_stack+621611,int_stack+577147,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+649691,int_stack+392412,int_stack+390036,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+656819,int_stack+649691,int_stack+0,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+668699,int_stack+656819,int_stack+611891,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+684899,int_stack+668699,int_stack+621611,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+704339,int_stack+684899,int_stack+634571,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+12180,int_stack+11172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384132,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+725507,int_stack+13476,int_stack+12180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385140,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+729395,int_stack+725507,int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551551,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5940,int_stack+15096,int_stack+13476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386436,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+735443,int_stack+5940,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554575,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+743219,int_stack+735443,int_stack+729395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558463,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+725507,int_stack+17076,int_stack+15096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388056,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+753299,int_stack+725507,int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564511,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+763019,int_stack+753299,int_stack+735443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569371,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+775979,int_stack+763019,int_stack+743219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577147,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+5940,int_stack+19452,int_stack+17076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390036,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+731447,int_stack+5940,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+791099,int_stack+731447,int_stack+753299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611891,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+743327,int_stack+791099,int_stack+763019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621611,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+807299,int_stack+743327,int_stack+775979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634571,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+762767,int_stack+22260,int_stack+19452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392412,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+771191,int_stack+762767,int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649691,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+828467,int_stack+771191,int_stack+731447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656819,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+762767,int_stack+828467,int_stack+791099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668699,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+828467,int_stack+762767,int_stack+743327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684899,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+725507,int_stack+828467,int_stack+807299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704339,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+753731,int_stack+725507,int_stack+589939,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+245511,int_stack+242991,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9720,int_stack+248751,int_stack+245511,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+14580,int_stack+9720,int_stack+5940,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+819587,int_stack+252801,int_stack+248751,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+825662,int_stack+819587,int_stack+9720,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+835382,int_stack+825662,int_stack+14580,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+847982,int_stack+257751,int_stack+252801,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+587227,int_stack+847982,int_stack+819587,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+855407,int_stack+587227,int_stack+825662,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+871607,int_stack+855407,int_stack+835382,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+599377,int_stack+263691,int_stack+257751,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+890507,int_stack+599377,int_stack+847982,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+905357,int_stack+890507,int_stack+587227,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+925607,int_stack+905357,int_stack+855407,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+949907,int_stack+925607,int_stack+871607,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+976367,int_stack+26796,int_stack+25536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242991,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+980147,int_stack+28416,int_stack+26796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245511,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+985007,int_stack+980147,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+22140,int_stack+30441,int_stack+28416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248751,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+992567,int_stack+22140,int_stack+980147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1002287,int_stack+992567,int_stack+985007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+976367,int_stack+32916,int_stack+30441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252801,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1014887,int_stack+976367,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819587,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1027037,int_stack+1014887,int_stack+992567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+825662,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1043237,int_stack+1027037,int_stack+1002287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+835382,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+22140,int_stack+35886,int_stack+32916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257751,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+983792,int_stack+22140,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847982,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1062137,int_stack+983792,int_stack+1014887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587227,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+998642,int_stack+1062137,int_stack+1027037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+855407,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1082387,int_stack+998642,int_stack+1043237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871607,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1022942,int_stack+39396,int_stack+35886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263691,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1033472,int_stack+1022942,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599377,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1108847,int_stack+1033472,int_stack+983792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890507,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1022942,int_stack+1108847,int_stack+1062137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905357,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1108847,int_stack+1022942,int_stack+998642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925607,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+976367,int_stack+1108847,int_stack+1082387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949907,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1011647,int_stack+976367,int_stack+725507,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+725507,int_stack+44275,int_stack+43491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361788, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+727859,int_stack+45283,int_stack+44275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362572, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+730883,int_stack+727859,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430815, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+735587,int_stack+46543,int_stack+45283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363580, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+739367,int_stack+735587,int_stack+727859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433167, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+745415,int_stack+739367,int_stack+730883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436191, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+725507,int_stack+48083,int_stack+46543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364840, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+976367,int_stack+725507,int_stack+735587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440895, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+983927,int_stack+976367,int_stack+739367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444675, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+730127,int_stack+983927,int_stack+745415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450723, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+741887,int_stack+49931,int_stack+48083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366380, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+994007,int_stack+741887,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458563, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+22140,int_stack+994007,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463183, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+34740,int_stack+22140,int_stack+983927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470743, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+976367,int_stack+34740,int_stack+730127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480823, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+725507,int_stack+52115,int_stack+49931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368228, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1096319,int_stack+725507,int_stack+741887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492583, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+725507,int_stack+1096319,int_stack+994007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498127, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1096319,int_stack+725507,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+725507,int_stack+1096319,int_stack+34740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519967, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1096319,int_stack+725507,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535087, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+976367,int_stack+55671,int_stack+54663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384132, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+979391,int_stack+56967,int_stack+55671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385140, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+983279,int_stack+979391,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551551, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+989327,int_stack+58587,int_stack+56967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386436, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+994187,int_stack+989327,int_stack+979391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554575, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725507,int_stack+994187,int_stack+983279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558463, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+976367,int_stack+60567,int_stack+58587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388056, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+735587,int_stack+976367,int_stack+989327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564511, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1118271,int_stack+735587,int_stack+994187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569371, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+982307,int_stack+1118271,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577147, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+725507,int_stack+62943,int_stack+60567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390036, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+997427,int_stack+725507,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+22140,int_stack+997427,int_stack+735587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611891, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+732635,int_stack+22140,int_stack+1118271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621611, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1118271,int_stack+732635,int_stack+982307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634571, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+976367,int_stack+65751,int_stack+62943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392412, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+38340,int_stack+976367,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649691, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+976367,int_stack+38340,int_stack+997427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656819, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+38340,int_stack+976367,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668699, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+976367,int_stack+38340,int_stack+732635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684899, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+725507,int_stack+976367,int_stack+1118271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704339, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1118271,int_stack+725507,int_stack+1096319,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1096319,int_stack+70287,int_stack+69027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242991, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1100099,int_stack+71907,int_stack+70287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245511, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1104959,int_stack+1100099,int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+976367,int_stack+73932,int_stack+71907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248751, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+982442,int_stack+976367,int_stack+1100099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+992162,int_stack+982442,int_stack+1104959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1096319,int_stack+76407,int_stack+73932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252801, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1103744,int_stack+1096319,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819587, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+22140,int_stack+1103744,int_stack+982442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+825662, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+38340,int_stack+22140,int_stack+992162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+835382, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+976367,int_stack+79377,int_stack+76407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257751, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+985277,int_stack+976367,int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847982, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+57240,int_stack+985277,int_stack+1103744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587227, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1184127,int_stack+57240,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+855407, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1208427,int_stack+1184127,int_stack+38340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871607, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+22140,int_stack+82887,int_stack+79377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263691, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+32670,int_stack+22140,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599377, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1234887,int_stack+32670,int_stack+985277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890507, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+976367,int_stack+1234887,int_stack+57240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905357, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+22140,int_stack+976367,int_stack+1184127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925607, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+976367,int_stack+22140,int_stack+1208427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949907, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1184127,int_stack+976367,int_stack+725507,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+725507,int_stack+87766,int_stack+86982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361788, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+727859,int_stack+88774,int_stack+87766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362572, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+730883,int_stack+727859,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430815, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+735587,int_stack+90034,int_stack+88774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363580, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+739367,int_stack+735587,int_stack+727859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433167, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+745415,int_stack+739367,int_stack+730883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436191, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+725507,int_stack+91574,int_stack+90034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364840, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+976367,int_stack+725507,int_stack+735587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440895, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+983927,int_stack+976367,int_stack+739367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444675, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+730127,int_stack+983927,int_stack+745415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450723, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+741887,int_stack+93422,int_stack+91574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366380, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+994007,int_stack+741887,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458563, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+22140,int_stack+994007,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463183, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+34740,int_stack+22140,int_stack+983927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470743, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+976367,int_stack+34740,int_stack+730127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480823, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+725507,int_stack+95606,int_stack+93422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368228, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+49860,int_stack+725507,int_stack+741887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492583, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+725507,int_stack+49860,int_stack+994007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498127, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+49860,int_stack+725507,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+725507,int_stack+49860,int_stack+34740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519967, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1096319,int_stack+725507,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535087, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+976367,int_stack+99162,int_stack+98154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384132, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+979391,int_stack+100458,int_stack+99162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385140, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+983279,int_stack+979391,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551551, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+989327,int_stack+102078,int_stack+100458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386436, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+994187,int_stack+989327,int_stack+979391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554575, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725507,int_stack+994187,int_stack+983279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558463, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+976367,int_stack+104058,int_stack+102078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388056, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+735587,int_stack+976367,int_stack+989327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564511, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+22140,int_stack+735587,int_stack+994187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569371, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+982307,int_stack+22140,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577147, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+725507,int_stack+106434,int_stack+104058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390036, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+997427,int_stack+725507,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+35100,int_stack+997427,int_stack+735587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611891, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+732635,int_stack+35100,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621611, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+51300,int_stack+732635,int_stack+982307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634571, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+22140,int_stack+109242,int_stack+106434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392412, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+976367,int_stack+22140,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649691, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+72468,int_stack+976367,int_stack+997427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656819, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+976367,int_stack+72468,int_stack+35100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668699, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+72468,int_stack+976367,int_stack+732635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684899, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+725507,int_stack+72468,int_stack+51300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704339, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+22140,int_stack+725507,int_stack+1096319,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1096319,int_stack+113778,int_stack+112518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242991, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1100099,int_stack+115398,int_stack+113778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245511, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1104959,int_stack+1100099,int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+976367,int_stack+117423,int_stack+115398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248751, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+982442,int_stack+976367,int_stack+1100099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+992162,int_stack+982442,int_stack+1104959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1096319,int_stack+119898,int_stack+117423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252801, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1103744,int_stack+1096319,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819587, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+87996,int_stack+1103744,int_stack+982442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+825662, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1268799,int_stack+87996,int_stack+992162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+835382, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+976367,int_stack+122868,int_stack+119898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257751, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+985277,int_stack+976367,int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847982, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1287699,int_stack+985277,int_stack+1103744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587227, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1307949,int_stack+1287699,int_stack+87996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+855407, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+87996,int_stack+1307949,int_stack+1268799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871607, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1268799,int_stack+126378,int_stack+122868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263691, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1096319,int_stack+1268799,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599377, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1332249,int_stack+1096319,int_stack+985277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890507, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+976367,int_stack+1332249,int_stack+1287699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905357, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1268799,int_stack+976367,int_stack+1307949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925607, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+976367,int_stack+1268799,int_stack+87996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949907, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1268799,int_stack+976367,int_stack+725507,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+725507,int_stack+131257,int_stack+130473, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+727859,int_stack+132265,int_stack+131257, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+730883,int_stack+727859,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+735587,int_stack+133525,int_stack+132265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+739367,int_stack+735587,int_stack+727859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+745415,int_stack+739367,int_stack+730883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+436191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+725507,int_stack+135065,int_stack+133525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+976367,int_stack+725507,int_stack+735587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+983927,int_stack+976367,int_stack+739367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+730127,int_stack+983927,int_stack+745415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+741887,int_stack+136913,int_stack+135065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+994007,int_stack+741887,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+87996,int_stack+994007,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+100596,int_stack+87996,int_stack+983927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+976367,int_stack+100596,int_stack+730127, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+725507,int_stack+139097,int_stack+136913, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+115716,int_stack+725507,int_stack+741887, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+725507,int_stack+115716,int_stack+994007, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+115716,int_stack+725507,int_stack+87996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+725507,int_stack+115716,int_stack+100596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1096319,int_stack+725507,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+976367,int_stack+142653,int_stack+141645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+979391,int_stack+143949,int_stack+142653, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+983279,int_stack+979391,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+989327,int_stack+145569,int_stack+143949, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+994187,int_stack+989327,int_stack+979391, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725507,int_stack+994187,int_stack+983279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+976367,int_stack+147549,int_stack+145569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+735587,int_stack+976367,int_stack+989327, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+87996,int_stack+735587,int_stack+994187, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+982307,int_stack+87996,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+725507,int_stack+149925,int_stack+147549, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+997427,int_stack+725507,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+100956,int_stack+997427,int_stack+735587, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+732635,int_stack+100956,int_stack+87996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+117156,int_stack+732635,int_stack+982307, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+87996,int_stack+152733,int_stack+149925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+976367,int_stack+87996,int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1353471,int_stack+976367,int_stack+997427, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+976367,int_stack+1353471,int_stack+100956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+87996,int_stack+976367,int_stack+732635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+725507,int_stack+87996,int_stack+117156, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+87996,int_stack+725507,int_stack+1096319,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1096319,int_stack+157269,int_stack+156009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1100099,int_stack+158889,int_stack+157269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1104959,int_stack+1100099,int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+976367,int_stack+160914,int_stack+158889, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+982442,int_stack+976367,int_stack+1100099, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+992162,int_stack+982442,int_stack+1104959, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1096319,int_stack+163389,int_stack+160914, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1103744,int_stack+1096319,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1353471,int_stack+1103744,int_stack+982442, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+825662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1369671,int_stack+1353471,int_stack+992162, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+835382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+976367,int_stack+166359,int_stack+163389, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+985277,int_stack+976367,int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1388571,int_stack+985277,int_stack+1103744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1408821,int_stack+1388571,int_stack+1353471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+855407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1433121,int_stack+1408821,int_stack+1369671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1353471,int_stack+169869,int_stack+166359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1364001,int_stack+1353471,int_stack+976367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1459581,int_stack+1364001,int_stack+985277, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+976367,int_stack+1459581,int_stack+1388571, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1353471,int_stack+976367,int_stack+1408821, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+976367,int_stack+1353471,int_stack+1433121, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+949907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1353471,int_stack+976367,int_stack+725507,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+725507,int_stack+174748,int_stack+173964, 0.0, zero_stack, 1.0, int_stack+361788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+727859,int_stack+175756,int_stack+174748, 0.0, zero_stack, 1.0, int_stack+362572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+730883,int_stack+727859,int_stack+725507, 0.0, zero_stack, 1.0, int_stack+430815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+735587,int_stack+177016,int_stack+175756, 0.0, zero_stack, 1.0, int_stack+363580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+739367,int_stack+735587,int_stack+727859, 0.0, zero_stack, 1.0, int_stack+433167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+745415,int_stack+739367,int_stack+730883, 0.0, zero_stack, 1.0, int_stack+436191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+725507,int_stack+178556,int_stack+177016, 0.0, zero_stack, 1.0, int_stack+364840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+976367,int_stack+725507,int_stack+735587, 0.0, zero_stack, 1.0, int_stack+440895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+983927,int_stack+976367,int_stack+739367, 0.0, zero_stack, 1.0, int_stack+444675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+730127,int_stack+983927,int_stack+745415, 0.0, zero_stack, 1.0, int_stack+450723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+741887,int_stack+180404,int_stack+178556, 0.0, zero_stack, 1.0, int_stack+366380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+994007,int_stack+741887,int_stack+725507, 0.0, zero_stack, 1.0, int_stack+458563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1438143,int_stack+994007,int_stack+976367, 0.0, zero_stack, 1.0, int_stack+463183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1450743,int_stack+1438143,int_stack+983927, 0.0, zero_stack, 1.0, int_stack+470743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+976367,int_stack+1450743,int_stack+730127, 0.0, zero_stack, 1.0, int_stack+480823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+725507,int_stack+182588,int_stack+180404, 0.0, zero_stack, 1.0, int_stack+368228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1465863,int_stack+725507,int_stack+741887, 0.0, zero_stack, 1.0, int_stack+492583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+725507,int_stack+1465863,int_stack+994007, 0.0, zero_stack, 1.0, int_stack+498127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1465863,int_stack+725507,int_stack+1438143, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+725507,int_stack+1465863,int_stack+1450743, 0.0, zero_stack, 1.0, int_stack+519967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1096319,int_stack+725507,int_stack+976367, 0.0, zero_stack, 1.0, int_stack+535087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+976367,int_stack+186144,int_stack+185136, 0.0, zero_stack, 1.0, int_stack+384132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+979391,int_stack+187440,int_stack+186144, 0.0, zero_stack, 1.0, int_stack+385140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+983279,int_stack+979391,int_stack+976367, 0.0, zero_stack, 1.0, int_stack+551551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+989327,int_stack+189060,int_stack+187440, 0.0, zero_stack, 1.0, int_stack+386436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+994187,int_stack+989327,int_stack+979391, 0.0, zero_stack, 1.0, int_stack+554575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+725507,int_stack+994187,int_stack+983279, 0.0, zero_stack, 1.0, int_stack+558463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+976367,int_stack+191040,int_stack+189060, 0.0, zero_stack, 1.0, int_stack+388056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+735587,int_stack+976367,int_stack+989327, 0.0, zero_stack, 1.0, int_stack+564511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1438143,int_stack+735587,int_stack+994187, 0.0, zero_stack, 1.0, int_stack+569371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+982307,int_stack+1438143,int_stack+725507, 0.0, zero_stack, 1.0, int_stack+577147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+725507,int_stack+193416,int_stack+191040, 0.0, zero_stack, 1.0, int_stack+390036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+997427,int_stack+725507,int_stack+976367, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1451103,int_stack+997427,int_stack+735587, 0.0, zero_stack, 1.0, int_stack+611891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+732635,int_stack+1451103,int_stack+1438143, 0.0, zero_stack, 1.0, int_stack+621611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+153852,int_stack+732635,int_stack+982307, 0.0, zero_stack, 1.0, int_stack+634571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1438143,int_stack+196224,int_stack+193416, 0.0, zero_stack, 1.0, int_stack+392412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+976367,int_stack+1438143,int_stack+725507, 0.0, zero_stack, 1.0, int_stack+649691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+175020,int_stack+976367,int_stack+997427, 0.0, zero_stack, 1.0, int_stack+656819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+976367,int_stack+175020,int_stack+1451103, 0.0, zero_stack, 1.0, int_stack+668699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1438143,int_stack+976367,int_stack+732635, 0.0, zero_stack, 1.0, int_stack+684899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+725507,int_stack+1438143,int_stack+153852, 0.0, zero_stack, 1.0, int_stack+704339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1438143,int_stack+725507,int_stack+1096319,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1096319,int_stack+200760,int_stack+199500, 0.0, zero_stack, 1.0, int_stack+242991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1100099,int_stack+202380,int_stack+200760, 0.0, zero_stack, 1.0, int_stack+245511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1104959,int_stack+1100099,int_stack+1096319, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+153852,int_stack+204405,int_stack+202380, 0.0, zero_stack, 1.0, int_stack+248751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+159927,int_stack+153852,int_stack+1100099, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+169647,int_stack+159927,int_stack+1104959, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1096319,int_stack+206880,int_stack+204405, 0.0, zero_stack, 1.0, int_stack+252801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1103744,int_stack+1096319,int_stack+153852, 0.0, zero_stack, 1.0, int_stack+819587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+182247,int_stack+1103744,int_stack+159927, 0.0, zero_stack, 1.0, int_stack+825662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+976367,int_stack+182247,int_stack+169647, 0.0, zero_stack, 1.0, int_stack+835382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+153852,int_stack+209850,int_stack+206880, 0.0, zero_stack, 1.0, int_stack+257751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+162762,int_stack+153852,int_stack+1096319, 0.0, zero_stack, 1.0, int_stack+847982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1503999,int_stack+162762,int_stack+1103744, 0.0, zero_stack, 1.0, int_stack+587227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1524249,int_stack+1503999,int_stack+182247, 0.0, zero_stack, 1.0, int_stack+855407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+177612,int_stack+1524249,int_stack+976367, 0.0, zero_stack, 1.0, int_stack+871607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+976367,int_stack+213360,int_stack+209850, 0.0, zero_stack, 1.0, int_stack+263691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+986897,int_stack+976367,int_stack+153852, 0.0, zero_stack, 1.0, int_stack+599377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1548549,int_stack+986897,int_stack+162762, 0.0, zero_stack, 1.0, int_stack+890507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+976367,int_stack+1548549,int_stack+1503999, 0.0, zero_stack, 1.0, int_stack+905357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1548549,int_stack+976367,int_stack+1524249, 0.0, zero_stack, 1.0, int_stack+925607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+976367,int_stack+1548549,int_stack+177612, 0.0, zero_stack, 1.0, int_stack+949907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1503999,int_stack+976367,int_stack+725507,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+725507,int_stack+218239,int_stack+217455, 1.0, int_stack+361788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+727859,int_stack+219247,int_stack+218239, 1.0, int_stack+362572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+730883,int_stack+727859,int_stack+725507, 1.0, int_stack+430815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+735587,int_stack+220507,int_stack+219247, 1.0, int_stack+363580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+739367,int_stack+735587,int_stack+727859, 1.0, int_stack+433167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+745415,int_stack+739367,int_stack+730883, 1.0, int_stack+436191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+430815,int_stack+222047,int_stack+220507, 1.0, int_stack+364840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+725507,int_stack+430815,int_stack+735587, 1.0, int_stack+440895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+976367,int_stack+725507,int_stack+739367, 1.0, int_stack+444675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+435435,int_stack+976367,int_stack+745415, 1.0, int_stack+450723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+447195,int_stack+223895,int_stack+222047, 1.0, int_stack+366380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+733067,int_stack+447195,int_stack+430815, 1.0, int_stack+458563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+986447,int_stack+733067,int_stack+725507, 1.0, int_stack+463183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+452739,int_stack+986447,int_stack+976367, 1.0, int_stack+470743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+153852,int_stack+452739,int_stack+435435, 1.0, int_stack+480823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+976367,int_stack+226079,int_stack+223895, 1.0, int_stack+368228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+430815,int_stack+976367,int_stack+447195, 1.0, int_stack+492583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+467859,int_stack+430815,int_stack+733067, 1.0, int_stack+498127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+430815,int_stack+467859,int_stack+986447, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+467859,int_stack+430815,int_stack+452739, 1.0, int_stack+519967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1096319,int_stack+467859,int_stack+153852, 1.0, int_stack+535087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+153852,int_stack+229635,int_stack+228627, 1.0, int_stack+384132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+156876,int_stack+230931,int_stack+229635, 1.0, int_stack+385140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+160764,int_stack+156876,int_stack+153852, 1.0, int_stack+551551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+166812,int_stack+232551,int_stack+230931, 1.0, int_stack+386436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+171672,int_stack+166812,int_stack+156876, 1.0, int_stack+554575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+179448,int_stack+171672,int_stack+160764, 1.0, int_stack+558463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+551551,int_stack+234531,int_stack+232551, 1.0, int_stack+388056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+153852,int_stack+551551,int_stack+166812, 1.0, int_stack+564511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+189528,int_stack+153852,int_stack+171672, 1.0, int_stack+569371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+557491,int_stack+189528,int_stack+179448, 1.0, int_stack+577147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+572611,int_stack+236907,int_stack+234531, 1.0, int_stack+390036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+163572,int_stack+572611,int_stack+551551, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+202488,int_stack+163572,int_stack+153852, 1.0, int_stack+611891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+430815,int_stack+202488,int_stack+189528, 1.0, int_stack+621611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+175452,int_stack+430815,int_stack+557491, 1.0, int_stack+634571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+153852,int_stack+239715,int_stack+236907, 1.0, int_stack+392412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+551551,int_stack+153852,int_stack+572611, 1.0, int_stack+649691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+565807,int_stack+551551,int_stack+163572, 1.0, int_stack+656819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+218688,int_stack+565807,int_stack+202488, 1.0, int_stack+668699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+551551,int_stack+218688,int_stack+430815, 1.0, int_stack+684899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+725507,int_stack+551551,int_stack+175452, 1.0, int_stack+704339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+153852,int_stack+725507,int_stack+1096319,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1096319,int_stack+247131,int_stack+244251, 1.0, int_stack+242991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1100099,int_stack+250776,int_stack+247131, 1.0, int_stack+245511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1104959,int_stack+1100099,int_stack+1096319, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+551551,int_stack+255276,int_stack+250776, 1.0, int_stack+248751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+551551,int_stack+1100099, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+557626,int_stack+0,int_stack+1104959, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9720,int_stack+260721,int_stack+255276, 1.0, int_stack+252801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1096319,int_stack+9720,int_stack+551551, 1.0, int_stack+819587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+570226,int_stack+1096319,int_stack+0, 1.0, int_stack+825662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+430815,int_stack+570226,int_stack+557626, 1.0, int_stack+835382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+267201,int_stack+260721, 1.0, int_stack+257751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+819587,int_stack+0,int_stack+9720, 1.0, int_stack+847982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+834437,int_stack+819587,int_stack+1096319, 1.0, int_stack+587227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+449715,int_stack+834437,int_stack+570226, 1.0, int_stack+855407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+551551,int_stack+449715,int_stack+430815, 1.0, int_stack+871607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+430815,int_stack+270711,int_stack+267201, 1.0, int_stack+263691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1096319,int_stack+430815,int_stack+0, 1.0, int_stack+599377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+854687,int_stack+1096319,int_stack+819587, 1.0, int_stack+890507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+578011,int_stack+854687,int_stack+834437, 1.0, int_stack+905357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+819587,int_stack+578011,int_stack+449715, 1.0, int_stack+925607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+976367,int_stack+819587,int_stack+551551, 1.0, int_stack+949907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+551551,int_stack+976367,int_stack+725507,784);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+725507,int_stack+370412,int_stack+368228,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+732059,int_stack+725507,int_stack+492583,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+819587,int_stack+732059,int_stack+498127,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+725507,int_stack+819587,int_stack+507367,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+819587,int_stack+725507,int_stack+519967,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1096319,int_stack+819587,int_stack+535087,28);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+819587,int_stack+395220,int_stack+392412,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+828011,int_stack+819587,int_stack+649691,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+842267,int_stack+828011,int_stack+656819,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+862067,int_stack+842267,int_stack+668699,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+819587,int_stack+862067,int_stack+684899,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+725507,int_stack+819587,int_stack+704339,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+819587,int_stack+725507,int_stack+1096319,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+885443,int_stack+275590,int_stack+274806,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+887795,int_stack+276598,int_stack+275590,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+890819,int_stack+887795,int_stack+885443,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+895523,int_stack+277858,int_stack+276598,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+899303,int_stack+895523,int_stack+887795,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+905351,int_stack+899303,int_stack+890819,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+885443,int_stack+279398,int_stack+277858,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+913191,int_stack+885443,int_stack+895523,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+920751,int_stack+913191,int_stack+899303,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+890063,int_stack+920751,int_stack+905351,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+901823,int_stack+281246,int_stack+279398,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+930831,int_stack+901823,int_stack+885443,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+940071,int_stack+930831,int_stack+913191,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+952671,int_stack+940071,int_stack+920751,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+907367,int_stack+952671,int_stack+890063,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+885443,int_stack+283430,int_stack+281246,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+967791,int_stack+885443,int_stack+901823,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+885443,int_stack+967791,int_stack+930831,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+967791,int_stack+885443,int_stack+940071,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+885443,int_stack+967791,int_stack+952671,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+923831,int_stack+885443,int_stack+907367,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+885443,int_stack+286986,int_stack+285978,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+888467,int_stack+288282,int_stack+286986,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+892355,int_stack+888467,int_stack+885443,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+898403,int_stack+289902,int_stack+288282,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+903263,int_stack+898403,int_stack+888467,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+911039,int_stack+903263,int_stack+892355,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+885443,int_stack+291882,int_stack+289902,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+945783,int_stack+885443,int_stack+898403,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+955503,int_stack+945783,int_stack+903263,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+891383,int_stack+955503,int_stack+911039,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+906503,int_stack+294258,int_stack+291882,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+968463,int_stack+906503,int_stack+885443,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+980343,int_stack+968463,int_stack+945783,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+636223,int_stack+980343,int_stack+955503,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+945783,int_stack+636223,int_stack+891383,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+885443,int_stack+297066,int_stack+294258,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+996543,int_stack+885443,int_stack+906503,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+885443,int_stack+996543,int_stack+968463,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+655663,int_stack+885443,int_stack+980343,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+885443,int_stack+655663,int_stack+636223,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+636223,int_stack+885443,int_stack+945783,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+945783,int_stack+636223,int_stack+923831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+885443,int_stack+301602,int_stack+300342,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+889223,int_stack+303222,int_stack+301602,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+894083,int_stack+889223,int_stack+885443,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+901643,int_stack+305247,int_stack+303222,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+907718,int_stack+901643,int_stack+889223,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+917438,int_stack+907718,int_stack+894083,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+885443,int_stack+307722,int_stack+305247,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+930038,int_stack+885443,int_stack+901643,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+664447,int_stack+930038,int_stack+907718,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+892868,int_stack+664447,int_stack+917438,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+911768,int_stack+310692,int_stack+307722,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+680647,int_stack+911768,int_stack+885443,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+695497,int_stack+680647,int_stack+930038,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+920678,int_stack+695497,int_stack+664447,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+430815,int_stack+920678,int_stack+892868,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+664447,int_stack+314202,int_stack+310692,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+885443,int_stack+664447,int_stack+911768,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+457275,int_stack+885443,int_stack+680647,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+885443,int_stack+457275,int_stack+695497,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+457275,int_stack+885443,int_stack+920678,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+885443,int_stack+457275,int_stack+430815,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+430815,int_stack+885443,int_stack+636223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+636223,int_stack+319081,int_stack+318297,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+638575,int_stack+320089,int_stack+319081,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+641599,int_stack+638575,int_stack+636223,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+646303,int_stack+321349,int_stack+320089,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+650083,int_stack+646303,int_stack+638575,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+656131,int_stack+650083,int_stack+641599,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+636223,int_stack+322889,int_stack+321349,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+663971,int_stack+636223,int_stack+646303,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+671531,int_stack+663971,int_stack+650083,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+640843,int_stack+671531,int_stack+656131,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+652603,int_stack+324737,int_stack+322889,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+681611,int_stack+652603,int_stack+636223,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+690851,int_stack+681611,int_stack+663971,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+703451,int_stack+690851,int_stack+671531,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+658147,int_stack+703451,int_stack+640843,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+636223,int_stack+326921,int_stack+324737,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+885443,int_stack+636223,int_stack+652603,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+636223,int_stack+885443,int_stack+681611,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+885443,int_stack+636223,int_stack+690851,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+636223,int_stack+885443,int_stack+703451,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+885443,int_stack+636223,int_stack+658147,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+636223,int_stack+330477,int_stack+329469,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+639247,int_stack+331773,int_stack+330477,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+643135,int_stack+639247,int_stack+636223,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+649183,int_stack+333393,int_stack+331773,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+654043,int_stack+649183,int_stack+639247,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+661819,int_stack+654043,int_stack+643135,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+636223,int_stack+335373,int_stack+333393,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+671899,int_stack+636223,int_stack+649183,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+681619,int_stack+671899,int_stack+654043,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+642163,int_stack+681619,int_stack+661819,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+657283,int_stack+337749,int_stack+335373,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+694579,int_stack+657283,int_stack+636223,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+706459,int_stack+694579,int_stack+671899,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+907395,int_stack+706459,int_stack+681619,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+664411,int_stack+907395,int_stack+642163,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+636223,int_stack+340557,int_stack+337749,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+926835,int_stack+636223,int_stack+657283,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+636223,int_stack+926835,int_stack+694579,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+515487,int_stack+636223,int_stack+706459,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+636223,int_stack+515487,int_stack+907395,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+907395,int_stack+636223,int_stack+664411,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+636223,int_stack+907395,int_stack+885443, 0.0, zero_stack, 1.0, int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+885443,int_stack+345093,int_stack+343833,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+889223,int_stack+346713,int_stack+345093,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+894083,int_stack+889223,int_stack+885443,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+702079,int_stack+348738,int_stack+346713,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+708154,int_stack+702079,int_stack+889223,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+515487,int_stack+708154,int_stack+894083,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+885443,int_stack+351213,int_stack+348738,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+892868,int_stack+885443,int_stack+702079,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+528087,int_stack+892868,int_stack+708154,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+702079,int_stack+528087,int_stack+515487,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+515487,int_stack+354183,int_stack+351213,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+0,int_stack+515487,int_stack+885443,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+219708,int_stack+0,int_stack+892868,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+239958,int_stack+219708,int_stack+528087,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+524397,int_stack+239958,int_stack+702079,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+702079,int_stack+357693,int_stack+354183,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+885443,int_stack+702079,int_stack+515487,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+264258,int_stack+885443,int_stack+0,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+289008,int_stack+264258,int_stack+219708,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+319383,int_stack+289008,int_stack+239958,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+219708,int_stack+319383,int_stack+524397,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+254988,int_stack+219708,int_stack+907395, 0.0, zero_stack, 1.0, int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+219708,int_stack+373744,int_stack+372960,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+222060,int_stack+374752,int_stack+373744,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+225084,int_stack+222060,int_stack+219708,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+229788,int_stack+376012,int_stack+374752,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+233568,int_stack+229788,int_stack+222060,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+239616,int_stack+233568,int_stack+225084,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+219708,int_stack+377552,int_stack+376012,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+339660,int_stack+219708,int_stack+229788,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+347220,int_stack+339660,int_stack+233568,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+224328,int_stack+347220,int_stack+239616,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+236088,int_stack+379400,int_stack+377552,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+241632,int_stack+236088,int_stack+219708,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+357300,int_stack+241632,int_stack+339660,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+357300,int_stack+347220,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+339660,int_stack+0,int_stack+224328,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+219708,int_stack+381584,int_stack+379400,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+369900,int_stack+219708,int_stack+236088,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+219708,int_stack+369900,int_stack+241632,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+369900,int_stack+219708,int_stack+357300,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+219708,int_stack+369900,int_stack+0,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+0,int_stack+219708,int_stack+339660,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+339660,int_stack+399504,int_stack+398496,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+342684,int_stack+400800,int_stack+399504,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+346572,int_stack+342684,int_stack+339660,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+352620,int_stack+402420,int_stack+400800,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+357480,int_stack+352620,int_stack+342684,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+365256,int_stack+357480,int_stack+346572,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+339660,int_stack+404400,int_stack+402420,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+375336,int_stack+339660,int_stack+352620,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+385056,int_stack+375336,int_stack+357480,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+345600,int_stack+385056,int_stack+365256,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+360720,int_stack+406776,int_stack+404400,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+219708,int_stack+360720,int_stack+339660,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+231588,int_stack+219708,int_stack+375336,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+885443,int_stack+231588,int_stack+385056,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+367848,int_stack+885443,int_stack+345600,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+339660,int_stack+409584,int_stack+406776,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+389016,int_stack+339660,int_stack+360720,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+339660,int_stack+389016,int_stack+219708,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+904883,int_stack+339660,int_stack+231588,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+339660,int_stack+904883,int_stack+885443,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+885443,int_stack+339660,int_stack+367848,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+339660,int_stack+885443,int_stack+0, 1.0, int_stack+1096319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1096319,int_stack+414120,int_stack+412860,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1100099,int_stack+415740,int_stack+414120,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1104959,int_stack+1100099,int_stack+1096319,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+417765,int_stack+415740,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6075,int_stack+0,int_stack+1100099,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+913667,int_stack+6075,int_stack+1104959,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1096319,int_stack+420240,int_stack+417765,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1103744,int_stack+1096319,int_stack+0,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+926267,int_stack+1103744,int_stack+6075,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+926267,int_stack+913667,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+913667,int_stack+423210,int_stack+420240,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+405516,int_stack+913667,int_stack+1096319,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+219708,int_stack+405516,int_stack+1103744,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+515487,int_stack+219708,int_stack+926267,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1588671,int_stack+515487,int_stack+0,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+0,int_stack+426720,int_stack+423210,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1096319,int_stack+0,int_stack+913667,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+913667,int_stack+1096319,int_stack+405516,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1615131,int_stack+913667,int_stack+219708,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+219708,int_stack+1615131,int_stack+515487,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+515487,int_stack+219708,int_stack+1588671,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1588671,int_stack+515487,int_stack+885443, 1.0, int_stack+725507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1673343,int_stack+1011647,int_stack+753731,784);
     Libderiv->ABCD[11] = int_stack + 1673343;
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1805055,int_stack+1184127,int_stack+1118271,784);
     Libderiv->ABCD[10] = int_stack + 1805055;
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1011639,int_stack+1268799,int_stack+22140,784);
     Libderiv->ABCD[9] = int_stack + 1011639;
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1143351,int_stack+1353471,int_stack+87996,784);
     Libderiv->ABCD[8] = int_stack + 1143351;
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+0,int_stack+1503999,int_stack+1438143,784);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1275063,int_stack+551551,int_stack+153852,784);
     Libderiv->ABCD[6] = int_stack + 1275063;
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1406775,int_stack+430815,int_stack+945783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[2] = int_stack + 1406775;
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+405516,int_stack+254988,int_stack+636223, 0.0, zero_stack, 1.0, int_stack+819587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[1] = int_stack + 405516;
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+537228,int_stack+1588671,int_stack+339660, 1.0, int_stack+819587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[0] = int_stack + 537228;

}
