/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hg|ii) integrals */

void d1vrr_order_hgii(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+0, dvrr_stack+3, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+0);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+52, dvrr_stack+49, dvrr_stack+12, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+58, dvrr_stack+52, dvrr_stack+15, dvrr_stack+49, dvrr_stack+12, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+71, dvrr_stack+3, dvrr_stack+68, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+77, dvrr_stack+6, dvrr_stack+71, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+87, dvrr_stack+39, dvrr_stack+77, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+117, dvrr_stack+58, dvrr_stack+39, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+147, dvrr_stack+117, dvrr_stack+87, dvrr_stack+58, dvrr_stack+39, dvrr_stack+21);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+39, dvrr_stack+77, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+58, dvrr_stack+39, dvrr_stack+52, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+237, dvrr_stack+222, dvrr_stack+207, NULL, NULL, dvrr_stack+39);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+282, dvrr_stack+49, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+291, dvrr_stack+285, dvrr_stack+52, dvrr_stack+282, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+301, dvrr_stack+291, dvrr_stack+58, dvrr_stack+285, dvrr_stack+52, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+316, dvrr_stack+301, dvrr_stack+222, NULL, NULL, dvrr_stack+58);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+361, dvrr_stack+68, dvrr_stack+49, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+367, dvrr_stack+71, dvrr_stack+361, dvrr_stack+3, dvrr_stack+68, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+377, dvrr_stack+77, dvrr_stack+367, dvrr_stack+6, dvrr_stack+71, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+392, dvrr_stack+207, dvrr_stack+377, NULL, NULL, dvrr_stack+77);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+437, dvrr_stack+237, dvrr_stack+392, dvrr_stack+222, dvrr_stack+207, dvrr_stack+87);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+527, dvrr_stack+316, dvrr_stack+237, dvrr_stack+301, dvrr_stack+222, dvrr_stack+117);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+617, dvrr_stack+527, dvrr_stack+437, dvrr_stack+316, dvrr_stack+237, dvrr_stack+147);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+767, dvrr_stack+222, dvrr_stack+207, dvrr_stack+58, dvrr_stack+39, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+788, dvrr_stack+301, dvrr_stack+222, dvrr_stack+291, dvrr_stack+58, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+809, dvrr_stack+207, dvrr_stack+377, dvrr_stack+39, dvrr_stack+77, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+830, dvrr_stack+767, dvrr_stack+809, NULL, NULL, dvrr_stack+207);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+893, dvrr_stack+788, dvrr_stack+767, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+956, dvrr_stack+893, dvrr_stack+830, dvrr_stack+788, dvrr_stack+767, dvrr_stack+237);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1082, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1085, dvrr_stack+1082, dvrr_stack+282, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1091, dvrr_stack+1085, dvrr_stack+285, dvrr_stack+1082, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1101, dvrr_stack+1091, dvrr_stack+291, dvrr_stack+1085, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1116, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+1091, dvrr_stack+291, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1137, dvrr_stack+1116, dvrr_stack+788, NULL, NULL, dvrr_stack+301);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1200, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+316);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+49, dvrr_stack+282, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+361, dvrr_stack+285, dvrr_stack+68, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+71, dvrr_stack+361, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1351, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+77, dvrr_stack+367, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1372, dvrr_stack+809, dvrr_stack+1351, NULL, NULL, dvrr_stack+377);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1435, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+767, dvrr_stack+809, dvrr_stack+392);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1561, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+893, dvrr_stack+830, dvrr_stack+437);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1771, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+527);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+1981, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+617);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+809, dvrr_stack+222, dvrr_stack+207, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2324, dvrr_stack+788, dvrr_stack+767, dvrr_stack+301, dvrr_stack+222, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2352, dvrr_stack+2324, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2436, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+1101, dvrr_stack+301, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2464, dvrr_stack+2436, dvrr_stack+2324, NULL, NULL, dvrr_stack+788);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2548, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+207, dvrr_stack+377, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2576, dvrr_stack+2296, dvrr_stack+2548, NULL, NULL, dvrr_stack+809);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2660, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+830);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2828, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+893);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2996, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+956);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+893, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+896, dvrr_stack+893, dvrr_stack+1082, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+902, dvrr_stack+896, dvrr_stack+1085, dvrr_stack+893, dvrr_stack+1082, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+902, dvrr_stack+1091, dvrr_stack+896, dvrr_stack+1085, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+912, dvrr_stack+222, dvrr_stack+1101, dvrr_stack+902, dvrr_stack+1091, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+222, dvrr_stack+1101, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3304, dvrr_stack+3276, dvrr_stack+2436, NULL, NULL, dvrr_stack+1116);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3388, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+1137);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+3556, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+1200);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3304, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3307, dvrr_stack+282, dvrr_stack+3304, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3313, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+49, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+361, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+367, dvrr_stack+1326, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3344, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+377, dvrr_stack+1336, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3836, dvrr_stack+2548, dvrr_stack+3344, NULL, NULL, dvrr_stack+1351);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3920, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+1372);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4088, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+1435);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4368, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+1561);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4788, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+1771);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+5208, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+1981);
 tmp = dvrr_stack + 5208;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+767, dvrr_stack+809, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3408, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+788, dvrr_stack+767, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+3408, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3552, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+1116, dvrr_stack+788, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3588, dvrr_stack+3552, dvrr_stack+3408, NULL, NULL, dvrr_stack+2324);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+809, dvrr_stack+1351, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3696, dvrr_stack+3372, dvrr_stack+767, NULL, NULL, dvrr_stack+2548);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2576);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6012, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2352);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6228, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+2660);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2352, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+912, dvrr_stack+1116, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+2352, dvrr_stack+3552, NULL, NULL, dvrr_stack+2436);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+2464);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6912, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2828);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2828, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+803, dvrr_stack+3304, dvrr_stack+2828, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2831, dvrr_stack+3307, dvrr_stack+803, dvrr_stack+282, dvrr_stack+3304, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2841, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+285, dvrr_stack+3307, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2856, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+1326, dvrr_stack+3313, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2877, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+1336, dvrr_stack+222, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+1351, dvrr_stack+3323, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+767, dvrr_stack+2905, NULL, NULL, dvrr_stack+3344);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+3836);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7488, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3920);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7848, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+4088);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8388, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+2996);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8928, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+4368);
 tmp = dvrr_stack + 8928;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+9684,dvrr_stack+8928,dvrr_stack+5208,21);


 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+2296, dvrr_stack+2548, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6741, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2324, dvrr_stack+2296, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+6741, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6921, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2436, dvrr_stack+2324, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6966, dvrr_stack+6921, dvrr_stack+6741, NULL, NULL, dvrr_stack+3408);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+2548, dvrr_stack+3344, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7101, dvrr_stack+6696, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3696);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11718, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3444);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11988, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+5796);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+3276, dvrr_stack+2436, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+3444, dvrr_stack+6921, NULL, NULL, dvrr_stack+3552);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+3588);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12708, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+6012);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6012, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6015, dvrr_stack+2828, dvrr_stack+6012, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6021, dvrr_stack+803, dvrr_stack+6015, dvrr_stack+3304, dvrr_stack+2828, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6031, dvrr_stack+2831, dvrr_stack+6021, dvrr_stack+3307, dvrr_stack+803, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6046, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+3313, dvrr_stack+2831, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+222, dvrr_stack+2841, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7236, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+3323, dvrr_stack+2856, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+3344, dvrr_stack+2877, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+2296, dvrr_stack+6067, NULL, NULL, dvrr_stack+2905);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13158, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+6588);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13428, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+7272);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13878, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+7488);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14553, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+6228);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15228, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+7848);
 tmp = dvrr_stack + 15228;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+16173,dvrr_stack+15228,dvrr_stack+8928,21);


 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+3372, dvrr_stack+767, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3408, dvrr_stack+3372, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+12438, dvrr_stack+2941, NULL, NULL, dvrr_stack+6696);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12658, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3552, dvrr_stack+3408, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12713, dvrr_stack+12658, dvrr_stack+12438, NULL, NULL, dvrr_stack+6741);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12878, dvrr_stack+2941, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+7101);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18771, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6786);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+11448);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+2352, dvrr_stack+3552, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+6786, dvrr_stack+12658, NULL, NULL, dvrr_stack+6921);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+6966);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+11718);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+11718, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+11721, dvrr_stack+6012, dvrr_stack+11718, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+11727, dvrr_stack+6015, dvrr_stack+11721, dvrr_stack+2828, dvrr_stack+6012, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+11737, dvrr_stack+6021, dvrr_stack+11727, dvrr_stack+803, dvrr_stack+6015, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+11752, dvrr_stack+6031, dvrr_stack+11737, dvrr_stack+2831, dvrr_stack+6021, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11773, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+2841, dvrr_stack+6031, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+2856, dvrr_stack+6046, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11837, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+2877, dvrr_stack+3276, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11882, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+2905, dvrr_stack+7236, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+3372, dvrr_stack+11882, NULL, NULL, dvrr_stack+6067);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20531, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+2388);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20861, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+13158);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21411, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+13428);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22236, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+11988);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+23061, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+13878);
 tmp = dvrr_stack + 23061;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+24216,dvrr_stack+23061,dvrr_stack+15228,21);


 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+6696, dvrr_stack+2296, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19717, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+6741, dvrr_stack+6696, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19783, dvrr_stack+19717, dvrr_stack+19651, NULL, NULL, dvrr_stack+2941);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6921, dvrr_stack+6741, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20047, dvrr_stack+19981, dvrr_stack+19717, NULL, NULL, dvrr_stack+12438);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+2296, dvrr_stack+6067, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20245, dvrr_stack+19651, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27051, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12878);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27447, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12493);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27843, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+18441);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+3444, dvrr_stack+6921, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+12493, dvrr_stack+19981, NULL, NULL, dvrr_stack+12658);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+12713);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28899, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+18771);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2828, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+18771, dvrr_stack+11718, dvrr_stack+2828, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18777, dvrr_stack+11721, dvrr_stack+18771, dvrr_stack+6012, dvrr_stack+11718, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18787, dvrr_stack+11727, dvrr_stack+18777, dvrr_stack+6015, dvrr_stack+11721, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+18802, dvrr_stack+11737, dvrr_stack+18787, dvrr_stack+6021, dvrr_stack+11727, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+18823, dvrr_stack+11752, dvrr_stack+18802, dvrr_stack+6031, dvrr_stack+11737, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18851, dvrr_stack+11773, dvrr_stack+18823, dvrr_stack+6046, dvrr_stack+11752, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18887, dvrr_stack+11801, dvrr_stack+18851, dvrr_stack+3276, dvrr_stack+11773, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18932, dvrr_stack+11837, dvrr_stack+18887, dvrr_stack+7236, dvrr_stack+11801, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18987, dvrr_stack+11882, dvrr_stack+18932, dvrr_stack+6067, dvrr_stack+11837, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+6696, dvrr_stack+18987, NULL, NULL, dvrr_stack+11882);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29559, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+3489);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29955, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+20531);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30615, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20861);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31605, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+19101);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32595, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+21411);
 tmp = dvrr_stack + 32595;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+33981,dvrr_stack+32595,dvrr_stack+23061,21);


 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+2941, dvrr_stack+3372, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28581, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12438, dvrr_stack+2941, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+28581, dvrr_stack+28503, NULL, NULL, dvrr_stack+19651);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28893, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12658, dvrr_stack+12438, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28971, dvrr_stack+28893, dvrr_stack+28581, NULL, NULL, dvrr_stack+19717);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29205, dvrr_stack+6696, dvrr_stack+18987, dvrr_stack+3372, dvrr_stack+11882, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29283, dvrr_stack+28503, dvrr_stack+29205, NULL, NULL, dvrr_stack+6696);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+28659, dvrr_stack+29283, dvrr_stack+28581, dvrr_stack+28503, dvrr_stack+20245);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37914, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+28893, dvrr_stack+28581, dvrr_stack+19783);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38382, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+27051);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19783, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+6786, dvrr_stack+12658, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12559, dvrr_stack+19783, dvrr_stack+28893, NULL, NULL, dvrr_stack+19981);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+12559, dvrr_stack+28971, dvrr_stack+19783, dvrr_stack+28893, dvrr_stack+20047);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39630, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+12559, dvrr_stack+28971, dvrr_stack+27447);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+27447, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+27450, dvrr_stack+2828, dvrr_stack+27447, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+27456, dvrr_stack+18771, dvrr_stack+27450, dvrr_stack+11718, dvrr_stack+2828, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+27466, dvrr_stack+18777, dvrr_stack+27456, dvrr_stack+11721, dvrr_stack+18771, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+27481, dvrr_stack+18787, dvrr_stack+27466, dvrr_stack+11727, dvrr_stack+18777, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+27502, dvrr_stack+18802, dvrr_stack+27481, dvrr_stack+11737, dvrr_stack+18787, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27530, dvrr_stack+18823, dvrr_stack+27502, dvrr_stack+11752, dvrr_stack+18802, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+27566, dvrr_stack+18851, dvrr_stack+27530, dvrr_stack+11773, dvrr_stack+18823, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+18887, dvrr_stack+27566, dvrr_stack+11801, dvrr_stack+18851, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27611, dvrr_stack+18932, dvrr_stack+12438, dvrr_stack+11837, dvrr_stack+18887, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27677, dvrr_stack+18987, dvrr_stack+27611, dvrr_stack+11882, dvrr_stack+18932, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12559, dvrr_stack+29205, dvrr_stack+27677, NULL, NULL, dvrr_stack+18987);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40410, dvrr_stack+29283, dvrr_stack+12559, dvrr_stack+28503, dvrr_stack+29205, dvrr_stack+6841);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40878, dvrr_stack+37446, dvrr_stack+40410, dvrr_stack+28659, dvrr_stack+29283, dvrr_stack+29559);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+41658, dvrr_stack+38382, dvrr_stack+40878, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+29955);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42828, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+27843);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43998, dvrr_stack+42828, dvrr_stack+41658, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+30615);
 tmp = dvrr_stack + 43998;
 target_ptr = Libderiv->dvrr_classes[5][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+45636,dvrr_stack+43998,dvrr_stack+32595,21);


 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+28503, dvrr_stack+29205, dvrr_stack+19651, dvrr_stack+6696, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39253, dvrr_stack+28581, dvrr_stack+28503, dvrr_stack+19717, dvrr_stack+19651, NULL);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39344, dvrr_stack+39253, dvrr_stack+39162, NULL, NULL, dvrr_stack+28503);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39617, dvrr_stack+28893, dvrr_stack+28581, dvrr_stack+19981, dvrr_stack+19717, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39708, dvrr_stack+39617, dvrr_stack+39253, NULL, NULL, dvrr_stack+28581);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+29205, dvrr_stack+27677, dvrr_stack+6696, dvrr_stack+18987, NULL);

 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39981, dvrr_stack+39162, dvrr_stack+19651, NULL, NULL, dvrr_stack+29205);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+39344, dvrr_stack+39981, dvrr_stack+39253, dvrr_stack+39162, dvrr_stack+29283);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50340, dvrr_stack+39708, dvrr_stack+39344, dvrr_stack+39617, dvrr_stack+39253, dvrr_stack+28659);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50886, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+39708, dvrr_stack+39344, dvrr_stack+37446);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+19783, dvrr_stack+28893, dvrr_stack+12493, dvrr_stack+19981, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19861, dvrr_stack+28659, dvrr_stack+39617, NULL, NULL, dvrr_stack+28893);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+51796, dvrr_stack+19861, dvrr_stack+39708, dvrr_stack+28659, dvrr_stack+39617, dvrr_stack+28971);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+52342, dvrr_stack+51796, dvrr_stack+50340, dvrr_stack+19861, dvrr_stack+39708, dvrr_stack+37914);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+37914, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+37917, dvrr_stack+27447, dvrr_stack+37914, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+37923, dvrr_stack+27450, dvrr_stack+37917, dvrr_stack+2828, dvrr_stack+27447, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+37933, dvrr_stack+27456, dvrr_stack+37923, dvrr_stack+18771, dvrr_stack+27450, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+37948, dvrr_stack+27466, dvrr_stack+37933, dvrr_stack+18777, dvrr_stack+27456, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+37969, dvrr_stack+27481, dvrr_stack+37948, dvrr_stack+18787, dvrr_stack+27466, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37997, dvrr_stack+27502, dvrr_stack+37969, dvrr_stack+18802, dvrr_stack+27481, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38033, dvrr_stack+27530, dvrr_stack+37997, dvrr_stack+18823, dvrr_stack+27502, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+27566, dvrr_stack+38033, dvrr_stack+18851, dvrr_stack+27530, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+18887, dvrr_stack+27566, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38078, dvrr_stack+27611, dvrr_stack+12493, dvrr_stack+18932, dvrr_stack+12438, NULL);

 /* compute (0 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+38156, dvrr_stack+27677, dvrr_stack+38078, dvrr_stack+18987, dvrr_stack+27611, NULL);

 /* compute (1 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19861, dvrr_stack+19651, dvrr_stack+38156, NULL, NULL, dvrr_stack+27677);

 /* compute (2 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+53252, dvrr_stack+39981, dvrr_stack+19861, dvrr_stack+39162, dvrr_stack+19651, dvrr_stack+12559);

 /* compute (3 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+53798, dvrr_stack+49794, dvrr_stack+53252, dvrr_stack+39344, dvrr_stack+39981, dvrr_stack+40410);

 /* compute (4 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+54708, dvrr_stack+50886, dvrr_stack+53798, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+40878);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+56073, dvrr_stack+52342, dvrr_stack+50886, dvrr_stack+51796, dvrr_stack+50340, dvrr_stack+38382);

 /* compute (5 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+57438, dvrr_stack+56073, dvrr_stack+54708, dvrr_stack+52342, dvrr_stack+50886, dvrr_stack+41658);
 tmp = dvrr_stack + 57438;
 target_ptr = Libderiv->dvrr_classes[5][12];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+59349,dvrr_stack+57438,dvrr_stack+43998,21);


 /* compute (0 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51796, dvrr_stack+39162, dvrr_stack+19651, dvrr_stack+28503, dvrr_stack+29205, NULL);

 /* compute (0 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51901, dvrr_stack+39253, dvrr_stack+39162, dvrr_stack+28581, dvrr_stack+28503, NULL);

 /* compute (1 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52006, dvrr_stack+51901, dvrr_stack+51796, NULL, NULL, dvrr_stack+39162);

 /* compute (0 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52321, dvrr_stack+39617, dvrr_stack+39253, dvrr_stack+28893, dvrr_stack+28581, NULL);

 /* compute (1 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52426, dvrr_stack+52321, dvrr_stack+51901, NULL, NULL, dvrr_stack+39253);

 /* compute (0 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+19651, dvrr_stack+38156, dvrr_stack+29205, dvrr_stack+27677, NULL);

 /* compute (1 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+52741, dvrr_stack+51796, dvrr_stack+39162, NULL, NULL, dvrr_stack+19651);

 /* compute (2 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+52006, dvrr_stack+52741, dvrr_stack+51901, dvrr_stack+51796, dvrr_stack+39981);

 /* compute (2 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+64893, dvrr_stack+52426, dvrr_stack+52006, dvrr_stack+52321, dvrr_stack+51901, dvrr_stack+39344);

 /* compute (3 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+65523, dvrr_stack+64893, dvrr_stack+64263, dvrr_stack+52426, dvrr_stack+52006, dvrr_stack+49794);

 /* compute (0 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51901, dvrr_stack+28659, dvrr_stack+39617, dvrr_stack+19783, dvrr_stack+28893, NULL);

 /* compute (1 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39267, dvrr_stack+51901, dvrr_stack+52321, NULL, NULL, dvrr_stack+39617);

 /* compute (2 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+39267, dvrr_stack+52426, dvrr_stack+51901, dvrr_stack+52321, dvrr_stack+39708);

 /* compute (3 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+66573, dvrr_stack+28503, dvrr_stack+64893, dvrr_stack+39267, dvrr_stack+52426, dvrr_stack+50340);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2828, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50340, dvrr_stack+37914, dvrr_stack+2828, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+50346, dvrr_stack+37917, dvrr_stack+50340, dvrr_stack+27447, dvrr_stack+37914, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50356, dvrr_stack+37923, dvrr_stack+50346, dvrr_stack+27450, dvrr_stack+37917, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+50371, dvrr_stack+37933, dvrr_stack+50356, dvrr_stack+27456, dvrr_stack+37923, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+50392, dvrr_stack+37948, dvrr_stack+50371, dvrr_stack+27466, dvrr_stack+37933, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+50420, dvrr_stack+37969, dvrr_stack+50392, dvrr_stack+27481, dvrr_stack+37948, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+27447, dvrr_stack+37997, dvrr_stack+50420, dvrr_stack+27502, dvrr_stack+37969, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+50456, dvrr_stack+38033, dvrr_stack+27447, dvrr_stack+27530, dvrr_stack+37997, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50511, dvrr_stack+2941, dvrr_stack+50456, dvrr_stack+27566, dvrr_stack+38033, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50577, dvrr_stack+12493, dvrr_stack+50511, dvrr_stack+12438, dvrr_stack+2941, NULL);

 /* compute (0 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50655, dvrr_stack+38078, dvrr_stack+50577, dvrr_stack+27611, dvrr_stack+12493, NULL);

 /* compute (0 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+51901, dvrr_stack+38156, dvrr_stack+50655, dvrr_stack+27677, dvrr_stack+38078, NULL);

 /* compute (1 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39267, dvrr_stack+39162, dvrr_stack+51901, NULL, NULL, dvrr_stack+38156);

 /* compute (2 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+67623, dvrr_stack+52741, dvrr_stack+39267, dvrr_stack+51796, dvrr_stack+39162, dvrr_stack+19861);

 /* compute (3 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+68253, dvrr_stack+64263, dvrr_stack+67623, dvrr_stack+52006, dvrr_stack+52741, dvrr_stack+53252);

 /* compute (4 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+69303, dvrr_stack+65523, dvrr_stack+68253, dvrr_stack+64893, dvrr_stack+64263, dvrr_stack+53798);

 /* compute (4 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+70878, dvrr_stack+66573, dvrr_stack+65523, dvrr_stack+28503, dvrr_stack+64893, dvrr_stack+50886);

 /* compute (5 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+72453, dvrr_stack+70878, dvrr_stack+69303, dvrr_stack+66573, dvrr_stack+65523, dvrr_stack+54708);

 /* compute (5 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+74658,dvrr_stack+72453,dvrr_stack+57438,21);


 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6012, dvrr_stack+0, dvrr_stack+3, NULL, NULL, Data->F+6);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+66573, dvrr_stack+6, dvrr_stack+71, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+66591, dvrr_stack+21, dvrr_stack+66573, dvrr_stack+15, dvrr_stack+6, dvrr_stack+6012);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+66627, dvrr_stack+77, dvrr_stack+367, NULL, NULL, dvrr_stack+71);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+66657, dvrr_stack+87, dvrr_stack+66627, dvrr_stack+39, dvrr_stack+77, dvrr_stack+66573);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+66717, dvrr_stack+147, dvrr_stack+66657, dvrr_stack+117, dvrr_stack+87, dvrr_stack+66591);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+66817, dvrr_stack+377, dvrr_stack+1336, NULL, NULL, dvrr_stack+367);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+66862, dvrr_stack+392, dvrr_stack+66817, dvrr_stack+207, dvrr_stack+377, dvrr_stack+66627);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+66952, dvrr_stack+437, dvrr_stack+66862, dvrr_stack+237, dvrr_stack+392, dvrr_stack+66657);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+67102, dvrr_stack+617, dvrr_stack+66952, dvrr_stack+527, dvrr_stack+437, dvrr_stack+66717);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+67327, dvrr_stack+1351, dvrr_stack+3323, NULL, NULL, dvrr_stack+1336);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+67390, dvrr_stack+1372, dvrr_stack+67327, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+66817);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+64893, dvrr_stack+1435, dvrr_stack+67390, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+66862);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+65103, dvrr_stack+1561, dvrr_stack+64893, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+66952);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+28503, dvrr_stack+1981, dvrr_stack+65103, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+67102);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+809, dvrr_stack+3344, dvrr_stack+2877, NULL, NULL, dvrr_stack+3323);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+933, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+67327);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+52006, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+67390);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+52286, dvrr_stack+4088, dvrr_stack+52006, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+64893);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+80391, dvrr_stack+4368, dvrr_stack+52286, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+65103);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+80979, dvrr_stack+5208, dvrr_stack+80391, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+28503);
 tmp = dvrr_stack + 80979;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2996, dvrr_stack+2905, dvrr_stack+7236, NULL, NULL, dvrr_stack+2877);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28944, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+809);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39582, dvrr_stack+7272, dvrr_stack+28944, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+933);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+81763, dvrr_stack+7488, dvrr_stack+39582, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+52006);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+82303, dvrr_stack+7848, dvrr_stack+81763, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+52286);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+83059, dvrr_stack+8928, dvrr_stack+82303, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+80391);
 tmp = dvrr_stack + 83059;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+84067,dvrr_stack+83059,dvrr_stack+80979,28);


 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38247, dvrr_stack+6067, dvrr_stack+11837, NULL, NULL, dvrr_stack+7236);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+2388, dvrr_stack+38247, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+2996);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+86419, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+28944);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+86869, dvrr_stack+13428, dvrr_stack+86419, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+39582);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+87544, dvrr_stack+13878, dvrr_stack+86869, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+81763);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+88489, dvrr_stack+15228, dvrr_stack+87544, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+82303);
 tmp = dvrr_stack + 88489;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+89749,dvrr_stack+88489,dvrr_stack+83059,28);


 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+11882, dvrr_stack+18932, NULL, NULL, dvrr_stack+11837);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11937, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+38247);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+92773, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+6112);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+93323, dvrr_stack+20861, dvrr_stack+92773, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+86419);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+94148, dvrr_stack+21411, dvrr_stack+93323, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+86869);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+95303, dvrr_stack+23061, dvrr_stack+94148, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+87544);
 tmp = dvrr_stack + 95303;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+96843,dvrr_stack+95303,dvrr_stack+88489,28);


 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+18987, dvrr_stack+27611, NULL, NULL, dvrr_stack+18932);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19053, dvrr_stack+6841, dvrr_stack+18441, dvrr_stack+6696, dvrr_stack+18987, dvrr_stack+11448);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+100623, dvrr_stack+29559, dvrr_stack+19053, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+11937);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+101283, dvrr_stack+29955, dvrr_stack+100623, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+92773);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+102273, dvrr_stack+30615, dvrr_stack+101283, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+93323);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+103659, dvrr_stack+32595, dvrr_stack+102273, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+94148);
 tmp = dvrr_stack + 103659;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+105507,dvrr_stack+103659,dvrr_stack+95303,28);


 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27051, dvrr_stack+27677, dvrr_stack+38078, NULL, NULL, dvrr_stack+27611);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27755, dvrr_stack+12559, dvrr_stack+27051, dvrr_stack+29205, dvrr_stack+27677, dvrr_stack+18441);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+110127, dvrr_stack+40410, dvrr_stack+27755, dvrr_stack+29283, dvrr_stack+12559, dvrr_stack+19053);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+110907, dvrr_stack+40878, dvrr_stack+110127, dvrr_stack+37446, dvrr_stack+40410, dvrr_stack+100623);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+112077, dvrr_stack+41658, dvrr_stack+110907, dvrr_stack+38382, dvrr_stack+40878, dvrr_stack+101283);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+113715, dvrr_stack+43998, dvrr_stack+112077, dvrr_stack+42828, dvrr_stack+41658, dvrr_stack+102273);
 tmp = dvrr_stack + 113715;
 target_ptr = Libderiv->dvrr_classes[6][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+115899,dvrr_stack+113715,dvrr_stack+103659,28);


 /* compute (1 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+38382, dvrr_stack+38156, dvrr_stack+50655, NULL, NULL, dvrr_stack+38078);

 /* compute (2 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+121443, dvrr_stack+19861, dvrr_stack+38382, dvrr_stack+19651, dvrr_stack+38156, dvrr_stack+27051);

 /* compute (3 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+121989, dvrr_stack+53252, dvrr_stack+121443, dvrr_stack+39981, dvrr_stack+19861, dvrr_stack+27755);

 /* compute (4 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+122899, dvrr_stack+53798, dvrr_stack+121989, dvrr_stack+49794, dvrr_stack+53252, dvrr_stack+110127);

 /* compute (5 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+124264, dvrr_stack+54708, dvrr_stack+122899, dvrr_stack+50886, dvrr_stack+53798, dvrr_stack+110907);

 /* compute (6 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+126175, dvrr_stack+57438, dvrr_stack+124264, dvrr_stack+56073, dvrr_stack+54708, dvrr_stack+112077);
 tmp = dvrr_stack + 126175;
 target_ptr = Libderiv->dvrr_classes[6][12];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+128723,dvrr_stack+126175,dvrr_stack+113715,28);


 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49794, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+49797, dvrr_stack+2828, dvrr_stack+49794, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+50340, dvrr_stack+49797, dvrr_stack+37914, dvrr_stack+2828, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+50346, dvrr_stack+39, dvrr_stack+37917, dvrr_stack+50340, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+49803, dvrr_stack+50356, dvrr_stack+207, dvrr_stack+37923, dvrr_stack+50346, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+49824, dvrr_stack+50371, dvrr_stack+49803, dvrr_stack+37933, dvrr_stack+50356, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+50392, dvrr_stack+49824, dvrr_stack+37948, dvrr_stack+50371, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+237, dvrr_stack+50420, dvrr_stack+767, dvrr_stack+37969, dvrr_stack+50392, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+49852, dvrr_stack+27447, dvrr_stack+237, dvrr_stack+37997, dvrr_stack+50420, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49907, dvrr_stack+50456, dvrr_stack+49852, dvrr_stack+38033, dvrr_stack+27447, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49973, dvrr_stack+50511, dvrr_stack+49907, dvrr_stack+2941, dvrr_stack+50456, NULL);

 /* compute (0 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50051, dvrr_stack+50577, dvrr_stack+49973, dvrr_stack+12493, dvrr_stack+50511, NULL);

 /* compute (0 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+65418, dvrr_stack+50655, dvrr_stack+50051, dvrr_stack+38078, dvrr_stack+50577, NULL);

 /* compute (1 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+38655, dvrr_stack+51901, dvrr_stack+65418, NULL, NULL, dvrr_stack+50655);

 /* compute (2 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+50746, dvrr_stack+39267, dvrr_stack+38655, dvrr_stack+39162, dvrr_stack+51901, dvrr_stack+38382);

 /* compute (3 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+135275, dvrr_stack+67623, dvrr_stack+50746, dvrr_stack+52741, dvrr_stack+39267, dvrr_stack+121443);

 /* compute (4 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+136325, dvrr_stack+68253, dvrr_stack+135275, dvrr_stack+64263, dvrr_stack+67623, dvrr_stack+121989);

 /* compute (5 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+137900, dvrr_stack+69303, dvrr_stack+136325, dvrr_stack+65523, dvrr_stack+68253, dvrr_stack+122899);

 /* compute (6 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+140105, dvrr_stack+72453, dvrr_stack+137900, dvrr_stack+70878, dvrr_stack+69303, dvrr_stack+124264);

 /* compute (6 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+143045,dvrr_stack+140105,dvrr_stack+126175,28);


 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+70878, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+70881, dvrr_stack+3, dvrr_stack+68, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+70890, dvrr_stack+6012, dvrr_stack+70881, dvrr_stack+0, dvrr_stack+3, dvrr_stack+70878);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+70908, dvrr_stack+71, dvrr_stack+361, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+70926, dvrr_stack+66573, dvrr_stack+70908, dvrr_stack+6, dvrr_stack+71, dvrr_stack+70881);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+70962, dvrr_stack+66591, dvrr_stack+70926, dvrr_stack+21, dvrr_stack+66573, dvrr_stack+70890);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71022, dvrr_stack+367, dvrr_stack+1326, NULL, NULL, dvrr_stack+361);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+71052, dvrr_stack+66627, dvrr_stack+71022, dvrr_stack+77, dvrr_stack+367, dvrr_stack+70908);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+71112, dvrr_stack+66657, dvrr_stack+71052, dvrr_stack+87, dvrr_stack+66627, dvrr_stack+70926);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+71212, dvrr_stack+66717, dvrr_stack+71112, dvrr_stack+147, dvrr_stack+66657, dvrr_stack+70962);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+71362, dvrr_stack+1336, dvrr_stack+222, NULL, NULL, dvrr_stack+1326);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+71407, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+71022);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+71497, dvrr_stack+66862, dvrr_stack+71407, dvrr_stack+392, dvrr_stack+66817, dvrr_stack+71052);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+71647, dvrr_stack+66952, dvrr_stack+71497, dvrr_stack+437, dvrr_stack+66862, dvrr_stack+71112);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+71872, dvrr_stack+67102, dvrr_stack+71647, dvrr_stack+617, dvrr_stack+66952, dvrr_stack+71212);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+377, dvrr_stack+3323, dvrr_stack+2856, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+72187, dvrr_stack+67327, dvrr_stack+377, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+71362);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+65523, dvrr_stack+67390, dvrr_stack+72187, dvrr_stack+1372, dvrr_stack+67327, dvrr_stack+71407);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+65733, dvrr_stack+64893, dvrr_stack+65523, dvrr_stack+1435, dvrr_stack+67390, dvrr_stack+71497);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+66048, dvrr_stack+65103, dvrr_stack+65733, dvrr_stack+1561, dvrr_stack+64893, dvrr_stack+71647);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+64263, dvrr_stack+28503, dvrr_stack+66048, dvrr_stack+1981, dvrr_stack+65103, dvrr_stack+71872);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+66489, dvrr_stack+2877, dvrr_stack+3276, NULL, NULL, dvrr_stack+2856);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1351, dvrr_stack+809, dvrr_stack+66489, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+377);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+28223, dvrr_stack+933, dvrr_stack+1351, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+72187);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+37446, dvrr_stack+52006, dvrr_stack+28223, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+65523);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+150689, dvrr_stack+52286, dvrr_stack+37446, dvrr_stack+4088, dvrr_stack+52006, dvrr_stack+65733);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+151277, dvrr_stack+80391, dvrr_stack+150689, dvrr_stack+4368, dvrr_stack+52286, dvrr_stack+66048);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+3654, dvrr_stack+80979, dvrr_stack+151277, dvrr_stack+5208, dvrr_stack+80391, dvrr_stack+64263);
 tmp = dvrr_stack + 3654;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3344, dvrr_stack+7236, dvrr_stack+11801, NULL, NULL, dvrr_stack+3276);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+66489);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29160, dvrr_stack+28944, dvrr_stack+5796, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+1351);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+52706, dvrr_stack+39582, dvrr_stack+29160, dvrr_stack+7272, dvrr_stack+28944, dvrr_stack+28223);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+152061, dvrr_stack+81763, dvrr_stack+52706, dvrr_stack+7488, dvrr_stack+39582, dvrr_stack+37446);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+152817, dvrr_stack+82303, dvrr_stack+152061, dvrr_stack+7848, dvrr_stack+81763, dvrr_stack+150689);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+153825, dvrr_stack+83059, dvrr_stack+152817, dvrr_stack+8928, dvrr_stack+82303, dvrr_stack+151277);
 tmp = dvrr_stack + 153825;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+155121,dvrr_stack+153825,dvrr_stack+3654,36);


 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+11837, dvrr_stack+18887, NULL, NULL, dvrr_stack+11801);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7407, dvrr_stack+38247, dvrr_stack+7272, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+3344);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7677, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+2388, dvrr_stack+38247, dvrr_stack+5796);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+158145, dvrr_stack+86419, dvrr_stack+7677, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+29160);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+158820, dvrr_stack+86869, dvrr_stack+158145, dvrr_stack+13428, dvrr_stack+86419, dvrr_stack+52706);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+159765, dvrr_stack+87544, dvrr_stack+158820, dvrr_stack+13878, dvrr_stack+86869, dvrr_stack+152061);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12793, dvrr_stack+88489, dvrr_stack+159765, dvrr_stack+15228, dvrr_stack+87544, dvrr_stack+152817);
 tmp = dvrr_stack + 12793;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+161025,dvrr_stack+12793,dvrr_stack+153825,36);


 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8127, dvrr_stack+18932, dvrr_stack+12438, NULL, NULL, dvrr_stack+18887);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+11448, dvrr_stack+8127, dvrr_stack+11882, dvrr_stack+18932, dvrr_stack+7272);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+164913, dvrr_stack+11937, dvrr_stack+2296, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+7407);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+165463, dvrr_stack+92773, dvrr_stack+164913, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+7677);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+166288, dvrr_stack+93323, dvrr_stack+165463, dvrr_stack+20861, dvrr_stack+92773, dvrr_stack+158145);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+167443, dvrr_stack+94148, dvrr_stack+166288, dvrr_stack+21411, dvrr_stack+93323, dvrr_stack+158820);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20134, dvrr_stack+95303, dvrr_stack+167443, dvrr_stack+23061, dvrr_stack+94148, dvrr_stack+159765);
 tmp = dvrr_stack + 20134;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+168983,dvrr_stack+20134,dvrr_stack+12793,36);


 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50142, dvrr_stack+27611, dvrr_stack+12493, NULL, NULL, dvrr_stack+12438);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51376, dvrr_stack+18441, dvrr_stack+50142, dvrr_stack+18987, dvrr_stack+27611, dvrr_stack+8127);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+173843, dvrr_stack+19053, dvrr_stack+51376, dvrr_stack+6841, dvrr_stack+18441, dvrr_stack+2296);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+174503, dvrr_stack+100623, dvrr_stack+173843, dvrr_stack+29559, dvrr_stack+19053, dvrr_stack+164913);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+175493, dvrr_stack+101283, dvrr_stack+174503, dvrr_stack+29955, dvrr_stack+100623, dvrr_stack+165463);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+176879, dvrr_stack+102273, dvrr_stack+175493, dvrr_stack+30615, dvrr_stack+101283, dvrr_stack+166288);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+178727, dvrr_stack+103659, dvrr_stack+176879, dvrr_stack+32595, dvrr_stack+102273, dvrr_stack+167443);
 tmp = dvrr_stack + 178727;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+181103,dvrr_stack+178727,dvrr_stack+20134,36);


 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1519, dvrr_stack+38078, dvrr_stack+50577, NULL, NULL, dvrr_stack+12493);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39942, dvrr_stack+27051, dvrr_stack+1519, dvrr_stack+27677, dvrr_stack+38078, dvrr_stack+50142);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29520, dvrr_stack+27755, dvrr_stack+39942, dvrr_stack+12559, dvrr_stack+27051, dvrr_stack+51376);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30300, dvrr_stack+110127, dvrr_stack+29520, dvrr_stack+40410, dvrr_stack+27755, dvrr_stack+173843);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+187043, dvrr_stack+110907, dvrr_stack+30300, dvrr_stack+40878, dvrr_stack+110127, dvrr_stack+174503);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+188681, dvrr_stack+112077, dvrr_stack+187043, dvrr_stack+41658, dvrr_stack+110907, dvrr_stack+175493);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+190865, dvrr_stack+113715, dvrr_stack+188681, dvrr_stack+43998, dvrr_stack+112077, dvrr_stack+176879);
 tmp = dvrr_stack + 190865;
 target_ptr = Libderiv->dvrr_classes[7][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+193673,dvrr_stack+190865,dvrr_stack+178727,36);


 /* compute (1 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+40410, dvrr_stack+50655, dvrr_stack+50051, NULL, NULL, dvrr_stack+50577);

 /* compute (2 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+40683, dvrr_stack+38382, dvrr_stack+40410, dvrr_stack+38156, dvrr_stack+50655, dvrr_stack+1519);

 /* compute (3 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+41229, dvrr_stack+121443, dvrr_stack+40683, dvrr_stack+19861, dvrr_stack+38382, dvrr_stack+39942);

 /* compute (4 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+200801, dvrr_stack+121989, dvrr_stack+41229, dvrr_stack+53252, dvrr_stack+121443, dvrr_stack+29520);

 /* compute (5 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+202166, dvrr_stack+122899, dvrr_stack+200801, dvrr_stack+53798, dvrr_stack+121989, dvrr_stack+30300);

 /* compute (6 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+204077, dvrr_stack+124264, dvrr_stack+202166, dvrr_stack+54708, dvrr_stack+122899, dvrr_stack+187043);

 /* compute (7 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+206625, dvrr_stack+126175, dvrr_stack+204077, dvrr_stack+57438, dvrr_stack+124264, dvrr_stack+188681);
 tmp = dvrr_stack + 206625;
 target_ptr = Libderiv->dvrr_classes[7][12];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+209901,dvrr_stack+206625,dvrr_stack+190865,36);


 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+38156, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+49794, dvrr_stack+38156, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+27492, dvrr_stack+49797, dvrr_stack+6, dvrr_stack+2828, dvrr_stack+49794, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+38159, dvrr_stack+39, dvrr_stack+27492, dvrr_stack+50340, dvrr_stack+49797, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+38174, dvrr_stack+207, dvrr_stack+38159, dvrr_stack+50346, dvrr_stack+39, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+38195, dvrr_stack+49803, dvrr_stack+38174, dvrr_stack+50356, dvrr_stack+207, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+49824, dvrr_stack+38195, dvrr_stack+50371, dvrr_stack+49803, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+50392, dvrr_stack+49824, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11882, dvrr_stack+237, dvrr_stack+6067, dvrr_stack+50420, dvrr_stack+767, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18987, dvrr_stack+49852, dvrr_stack+11882, dvrr_stack+27447, dvrr_stack+237, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27677, dvrr_stack+49907, dvrr_stack+18987, dvrr_stack+50456, dvrr_stack+49852, NULL);

 /* compute (0 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50340, dvrr_stack+49973, dvrr_stack+27677, dvrr_stack+50511, dvrr_stack+49907, NULL);

 /* compute (0 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+42139, dvrr_stack+50051, dvrr_stack+50340, dvrr_stack+50577, dvrr_stack+49973, NULL);

 /* compute (1 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+42244, dvrr_stack+65418, dvrr_stack+42139, NULL, NULL, dvrr_stack+50051);

 /* compute (2 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+53246, dvrr_stack+38655, dvrr_stack+42244, dvrr_stack+51901, dvrr_stack+65418, dvrr_stack+40410);

 /* compute (3 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+53876, dvrr_stack+50746, dvrr_stack+53246, dvrr_stack+39267, dvrr_stack+38655, dvrr_stack+40683);

 /* compute (4 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+218325, dvrr_stack+135275, dvrr_stack+53876, dvrr_stack+67623, dvrr_stack+50746, dvrr_stack+41229);

 /* compute (5 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+219900, dvrr_stack+136325, dvrr_stack+218325, dvrr_stack+68253, dvrr_stack+135275, dvrr_stack+200801);

 /* compute (6 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+222105, dvrr_stack+137900, dvrr_stack+219900, dvrr_stack+69303, dvrr_stack+136325, dvrr_stack+202166);

 /* compute (7 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+225045, dvrr_stack+140105, dvrr_stack+222105, dvrr_stack+72453, dvrr_stack+137900, dvrr_stack+204077);

 /* compute (7 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+228825,dvrr_stack+225045,dvrr_stack+206625,36);


 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+50431, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+50434, dvrr_stack+70878, dvrr_stack+50431, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+50440, dvrr_stack+68, dvrr_stack+49, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1753, dvrr_stack+70881, dvrr_stack+50440, dvrr_stack+3, dvrr_stack+68, dvrr_stack+50431);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+42559, dvrr_stack+70890, dvrr_stack+1753, dvrr_stack+6012, dvrr_stack+70881, dvrr_stack+50434);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+38223, dvrr_stack+361, dvrr_stack+285, NULL, NULL, dvrr_stack+49);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+42589, dvrr_stack+70908, dvrr_stack+38223, dvrr_stack+71, dvrr_stack+361, dvrr_stack+50440);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+42625, dvrr_stack+70926, dvrr_stack+42589, dvrr_stack+66573, dvrr_stack+70908, dvrr_stack+1753);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+42685, dvrr_stack+70962, dvrr_stack+42625, dvrr_stack+66591, dvrr_stack+70926, dvrr_stack+42559);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71, dvrr_stack+1326, dvrr_stack+3313, NULL, NULL, dvrr_stack+285);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+12559, dvrr_stack+71022, dvrr_stack+71, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+38223);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+12619, dvrr_stack+71052, dvrr_stack+12559, dvrr_stack+66627, dvrr_stack+71022, dvrr_stack+42589);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+3452, dvrr_stack+71112, dvrr_stack+12619, dvrr_stack+66657, dvrr_stack+71052, dvrr_stack+42625);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+38970, dvrr_stack+71212, dvrr_stack+3452, dvrr_stack+66717, dvrr_stack+71112, dvrr_stack+42685);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+66627, dvrr_stack+222, dvrr_stack+2841, NULL, NULL, dvrr_stack+3313);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+8292, dvrr_stack+71362, dvrr_stack+66627, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+71);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+39180, dvrr_stack+71407, dvrr_stack+8292, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+12559);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+39330, dvrr_stack+71497, dvrr_stack+39180, dvrr_stack+66862, dvrr_stack+71407, dvrr_stack+12619);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+67516, dvrr_stack+71647, dvrr_stack+39330, dvrr_stack+66952, dvrr_stack+71497, dvrr_stack+3452);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+67831, dvrr_stack+71872, dvrr_stack+67516, dvrr_stack+67102, dvrr_stack+71647, dvrr_stack+38970);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+66817, dvrr_stack+2856, dvrr_stack+6046, NULL, NULL, dvrr_stack+2841);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+377, dvrr_stack+66817, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+66627);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+66880, dvrr_stack+72187, dvrr_stack+4662, dvrr_stack+67327, dvrr_stack+377, dvrr_stack+8292);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+68251, dvrr_stack+65523, dvrr_stack+66880, dvrr_stack+67390, dvrr_stack+72187, dvrr_stack+39180);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+68566, dvrr_stack+65733, dvrr_stack+68251, dvrr_stack+64893, dvrr_stack+65523, dvrr_stack+39330);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+69007, dvrr_stack+66048, dvrr_stack+68566, dvrr_stack+65103, dvrr_stack+65733, dvrr_stack+67516);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+69595, dvrr_stack+64263, dvrr_stack+69007, dvrr_stack+28503, dvrr_stack+66048, dvrr_stack+67831);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+67327, dvrr_stack+3276, dvrr_stack+11773, NULL, NULL, dvrr_stack+6046);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+64851, dvrr_stack+66489, dvrr_stack+67327, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+66817);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+65019, dvrr_stack+1351, dvrr_stack+64851, dvrr_stack+809, dvrr_stack+66489, dvrr_stack+4662);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+70351, dvrr_stack+28223, dvrr_stack+65019, dvrr_stack+933, dvrr_stack+1351, dvrr_stack+66880);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+54926, dvrr_stack+37446, dvrr_stack+70351, dvrr_stack+52006, dvrr_stack+28223, dvrr_stack+68251);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+6382, dvrr_stack+150689, dvrr_stack+54926, dvrr_stack+52286, dvrr_stack+37446, dvrr_stack+68566);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+238653, dvrr_stack+151277, dvrr_stack+6382, dvrr_stack+80391, dvrr_stack+150689, dvrr_stack+69007);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+239661, dvrr_stack+3654, dvrr_stack+238653, dvrr_stack+80979, dvrr_stack+151277, dvrr_stack+69595);
 tmp = dvrr_stack + 239661;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+80391, dvrr_stack+11801, dvrr_stack+18851, NULL, NULL, dvrr_stack+11773);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+80499, dvrr_stack+3344, dvrr_stack+80391, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+67327);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+55514, dvrr_stack+5796, dvrr_stack+80499, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+64851);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+51772, dvrr_stack+29160, dvrr_stack+55514, dvrr_stack+28944, dvrr_stack+5796, dvrr_stack+65019);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+240921, dvrr_stack+52706, dvrr_stack+51772, dvrr_stack+39582, dvrr_stack+29160, dvrr_stack+70351);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+241677, dvrr_stack+152061, dvrr_stack+240921, dvrr_stack+81763, dvrr_stack+52706, dvrr_stack+54926);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+242685, dvrr_stack+152817, dvrr_stack+241677, dvrr_stack+82303, dvrr_stack+152061, dvrr_stack+6382);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+243981, dvrr_stack+153825, dvrr_stack+242685, dvrr_stack+83059, dvrr_stack+152817, dvrr_stack+238653);
 tmp = dvrr_stack + 243981;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+245601,dvrr_stack+243981,dvrr_stack+239661,45);


 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+31470, dvrr_stack+18887, dvrr_stack+27566, NULL, NULL, dvrr_stack+18851);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+81763, dvrr_stack+7272, dvrr_stack+31470, dvrr_stack+11837, dvrr_stack+18887, dvrr_stack+80391);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+82033, dvrr_stack+7407, dvrr_stack+81763, dvrr_stack+38247, dvrr_stack+7272, dvrr_stack+80499);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19449, dvrr_stack+7677, dvrr_stack+82033, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+55514);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+249381, dvrr_stack+158145, dvrr_stack+19449, dvrr_stack+86419, dvrr_stack+7677, dvrr_stack+51772);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+250326, dvrr_stack+158820, dvrr_stack+249381, dvrr_stack+86869, dvrr_stack+158145, dvrr_stack+240921);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+251586, dvrr_stack+159765, dvrr_stack+250326, dvrr_stack+87544, dvrr_stack+158820, dvrr_stack+241677);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+86419, dvrr_stack+12793, dvrr_stack+251586, dvrr_stack+88489, dvrr_stack+159765, dvrr_stack+242685);
 tmp = dvrr_stack + 86419;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+253206,dvrr_stack+86419,dvrr_stack+243981,45);


 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+12438, dvrr_stack+2941, NULL, NULL, dvrr_stack+27566);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+82483, dvrr_stack+8127, dvrr_stack+6112, dvrr_stack+18932, dvrr_stack+12438, dvrr_stack+31470);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+258066, dvrr_stack+2296, dvrr_stack+82483, dvrr_stack+11448, dvrr_stack+8127, dvrr_stack+81763);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+258616, dvrr_stack+164913, dvrr_stack+258066, dvrr_stack+11937, dvrr_stack+2296, dvrr_stack+82033);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+259441, dvrr_stack+165463, dvrr_stack+258616, dvrr_stack+92773, dvrr_stack+164913, dvrr_stack+19449);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+260596, dvrr_stack+166288, dvrr_stack+259441, dvrr_stack+93323, dvrr_stack+165463, dvrr_stack+249381);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+262136, dvrr_stack+167443, dvrr_stack+260596, dvrr_stack+94148, dvrr_stack+166288, dvrr_stack+250326);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+92773, dvrr_stack+20134, dvrr_stack+262136, dvrr_stack+95303, dvrr_stack+167443, dvrr_stack+251586);
 tmp = dvrr_stack + 92773;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+264116,dvrr_stack+92773,dvrr_stack+86419,45);


 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11937, dvrr_stack+12493, dvrr_stack+50511, NULL, NULL, dvrr_stack+2941);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+270191, dvrr_stack+50142, dvrr_stack+11937, dvrr_stack+27611, dvrr_stack+12493, dvrr_stack+6112);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+270587, dvrr_stack+51376, dvrr_stack+270191, dvrr_stack+18441, dvrr_stack+50142, dvrr_stack+82483);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+271247, dvrr_stack+173843, dvrr_stack+270587, dvrr_stack+19053, dvrr_stack+51376, dvrr_stack+258066);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+272237, dvrr_stack+174503, dvrr_stack+271247, dvrr_stack+100623, dvrr_stack+173843, dvrr_stack+258616);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+273623, dvrr_stack+175493, dvrr_stack+272237, dvrr_stack+101283, dvrr_stack+174503, dvrr_stack+259441);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+275471, dvrr_stack+176879, dvrr_stack+273623, dvrr_stack+102273, dvrr_stack+175493, dvrr_stack+260596);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+100623, dvrr_stack+178727, dvrr_stack+275471, dvrr_stack+103659, dvrr_stack+176879, dvrr_stack+262136);
 tmp = dvrr_stack + 100623;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+277847,dvrr_stack+100623,dvrr_stack+92773,45);


 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19053, dvrr_stack+50577, dvrr_stack+49973, NULL, NULL, dvrr_stack+50511);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+285272, dvrr_stack+1519, dvrr_stack+19053, dvrr_stack+38078, dvrr_stack+50577, dvrr_stack+11937);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+285740, dvrr_stack+39942, dvrr_stack+285272, dvrr_stack+27051, dvrr_stack+1519, dvrr_stack+270191);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+286520, dvrr_stack+29520, dvrr_stack+285740, dvrr_stack+27755, dvrr_stack+39942, dvrr_stack+270587);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+287690, dvrr_stack+30300, dvrr_stack+286520, dvrr_stack+110127, dvrr_stack+29520, dvrr_stack+271247);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+289328, dvrr_stack+187043, dvrr_stack+287690, dvrr_stack+110907, dvrr_stack+30300, dvrr_stack+272237);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+291512, dvrr_stack+188681, dvrr_stack+289328, dvrr_stack+112077, dvrr_stack+187043, dvrr_stack+273623);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+110127, dvrr_stack+190865, dvrr_stack+291512, dvrr_stack+113715, dvrr_stack+188681, dvrr_stack+275471);
 tmp = dvrr_stack + 110127;
 target_ptr = Libderiv->dvrr_classes[8][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+294320,dvrr_stack+110127,dvrr_stack+100623,45);


 /* compute (1 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+27755, dvrr_stack+50051, dvrr_stack+50340, NULL, NULL, dvrr_stack+49973);

 /* compute (2 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+303230, dvrr_stack+40410, dvrr_stack+27755, dvrr_stack+50655, dvrr_stack+50051, dvrr_stack+19053);

 /* compute (3 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+303776, dvrr_stack+40683, dvrr_stack+303230, dvrr_stack+38382, dvrr_stack+40410, dvrr_stack+285272);

 /* compute (4 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+304686, dvrr_stack+41229, dvrr_stack+303776, dvrr_stack+121443, dvrr_stack+40683, dvrr_stack+285740);

 /* compute (5 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+306051, dvrr_stack+200801, dvrr_stack+304686, dvrr_stack+121989, dvrr_stack+41229, dvrr_stack+286520);

 /* compute (6 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+307962, dvrr_stack+202166, dvrr_stack+306051, dvrr_stack+122899, dvrr_stack+200801, dvrr_stack+287690);

 /* compute (7 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+310510, dvrr_stack+204077, dvrr_stack+307962, dvrr_stack+124264, dvrr_stack+202166, dvrr_stack+289328);

 /* compute (8 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+121443, dvrr_stack+206625, dvrr_stack+310510, dvrr_stack+126175, dvrr_stack+204077, dvrr_stack+291512);
 tmp = dvrr_stack + 121443;
 target_ptr = Libderiv->dvrr_classes[8][12];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+313786,dvrr_stack+121443,dvrr_stack+110127,45);


 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+8382, dvrr_stack+38156, dvrr_stack+3, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+367, dvrr_stack+6, dvrr_stack+8382, dvrr_stack+49794, dvrr_stack+38156, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+27492, dvrr_stack+367, dvrr_stack+49797, dvrr_stack+6, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+38159, dvrr_stack+1336, dvrr_stack+39, dvrr_stack+27492, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2877, dvrr_stack+38174, dvrr_stack+3323, dvrr_stack+207, dvrr_stack+38159, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+125538, dvrr_stack+38195, dvrr_stack+2877, dvrr_stack+49803, dvrr_stack+38174, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+88444, dvrr_stack+2905, dvrr_stack+125538, dvrr_stack+49824, dvrr_stack+38195, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+95248, dvrr_stack+6067, dvrr_stack+88444, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+103593, dvrr_stack+11882, dvrr_stack+95248, dvrr_stack+237, dvrr_stack+6067, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+113637, dvrr_stack+18987, dvrr_stack+103593, dvrr_stack+49852, dvrr_stack+11882, NULL);

 /* compute (0 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50655, dvrr_stack+27677, dvrr_stack+113637, dvrr_stack+49907, dvrr_stack+18987, NULL);

 /* compute (0 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+6277, dvrr_stack+50340, dvrr_stack+50655, dvrr_stack+49973, dvrr_stack+27677, NULL);

 /* compute (1 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+125574, dvrr_stack+42139, dvrr_stack+6277, NULL, NULL, dvrr_stack+50340);

 /* compute (2 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+324316, dvrr_stack+42244, dvrr_stack+125574, dvrr_stack+65418, dvrr_stack+42139, dvrr_stack+27755);

 /* compute (3 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+324946, dvrr_stack+53246, dvrr_stack+324316, dvrr_stack+38655, dvrr_stack+42244, dvrr_stack+303230);

 /* compute (4 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+325996, dvrr_stack+53876, dvrr_stack+324946, dvrr_stack+50746, dvrr_stack+53246, dvrr_stack+303776);

 /* compute (5 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+327571, dvrr_stack+218325, dvrr_stack+325996, dvrr_stack+135275, dvrr_stack+53876, dvrr_stack+304686);

 /* compute (6 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+329776, dvrr_stack+219900, dvrr_stack+327571, dvrr_stack+136325, dvrr_stack+218325, dvrr_stack+306051);

 /* compute (7 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+332716, dvrr_stack+222105, dvrr_stack+329776, dvrr_stack+137900, dvrr_stack+219900, dvrr_stack+307962);

 /* compute (8 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+135275, dvrr_stack+225045, dvrr_stack+332716, dvrr_stack+140105, dvrr_stack+222105, dvrr_stack+310510);

 /* compute (8 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+336496,dvrr_stack+135275,dvrr_stack+121443,45);


 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+140000, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+140003, dvrr_stack+50431, dvrr_stack+140000, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+39, dvrr_stack+50434, dvrr_stack+140003, dvrr_stack+70878, dvrr_stack+50431, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+140009, dvrr_stack+49, dvrr_stack+282, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+66573, dvrr_stack+50440, dvrr_stack+140009, dvrr_stack+68, dvrr_stack+49, dvrr_stack+140000);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+140018, dvrr_stack+1753, dvrr_stack+66573, dvrr_stack+70881, dvrr_stack+50440, dvrr_stack+140003);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+237, dvrr_stack+42559, dvrr_stack+140018, dvrr_stack+70890, dvrr_stack+1753, dvrr_stack+39);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+140048, dvrr_stack+285, dvrr_stack+3307, NULL, NULL, dvrr_stack+282);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+767, dvrr_stack+38223, dvrr_stack+140048, dvrr_stack+361, dvrr_stack+285, dvrr_stack+140009);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+50746, dvrr_stack+42589, dvrr_stack+767, dvrr_stack+70908, dvrr_stack+38223, dvrr_stack+66573);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+50806, dvrr_stack+42625, dvrr_stack+50746, dvrr_stack+70926, dvrr_stack+42589, dvrr_stack+140018);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+50896, dvrr_stack+42685, dvrr_stack+50806, dvrr_stack+70962, dvrr_stack+42625, dvrr_stack+237);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+70908, dvrr_stack+3313, dvrr_stack+2831, NULL, NULL, dvrr_stack+3307);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+51022, dvrr_stack+71, dvrr_stack+70908, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+140048);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+51082, dvrr_stack+12559, dvrr_stack+51022, dvrr_stack+71022, dvrr_stack+71, dvrr_stack+767);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+51182, dvrr_stack+12619, dvrr_stack+51082, dvrr_stack+71052, dvrr_stack+12559, dvrr_stack+50746);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+125889, dvrr_stack+3452, dvrr_stack+51182, dvrr_stack+71112, dvrr_stack+12619, dvrr_stack+50806);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+2996, dvrr_stack+38970, dvrr_stack+125889, dvrr_stack+71212, dvrr_stack+3452, dvrr_stack+50896);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+11837, dvrr_stack+2841, dvrr_stack+6031, NULL, NULL, dvrr_stack+2831);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+71022, dvrr_stack+66627, dvrr_stack+11837, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+70908);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+28028, dvrr_stack+8292, dvrr_stack+71022, dvrr_stack+71362, dvrr_stack+66627, dvrr_stack+51022);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+27051, dvrr_stack+39180, dvrr_stack+28028, dvrr_stack+71407, dvrr_stack+8292, dvrr_stack+51082);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+18441, dvrr_stack+39330, dvrr_stack+27051, dvrr_stack+71497, dvrr_stack+39180, dvrr_stack+51182);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+38241, dvrr_stack+67516, dvrr_stack+18441, dvrr_stack+71647, dvrr_stack+39330, dvrr_stack+125889);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+348781, dvrr_stack+67831, dvrr_stack+38241, dvrr_stack+71872, dvrr_stack+67516, dvrr_stack+2996);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+71362, dvrr_stack+6046, dvrr_stack+11752, NULL, NULL, dvrr_stack+6031);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+71425, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+11837);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+71551, dvrr_stack+4662, dvrr_stack+71425, dvrr_stack+377, dvrr_stack+66817, dvrr_stack+71022);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+39555, dvrr_stack+66880, dvrr_stack+71551, dvrr_stack+72187, dvrr_stack+4662, dvrr_stack+28028);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+349321, dvrr_stack+68251, dvrr_stack+39555, dvrr_stack+65523, dvrr_stack+66880, dvrr_stack+27051);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+349762, dvrr_stack+68566, dvrr_stack+349321, dvrr_stack+65733, dvrr_stack+68251, dvrr_stack+18441);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+350350, dvrr_stack+69007, dvrr_stack+349762, dvrr_stack+66048, dvrr_stack+68566, dvrr_stack+38241);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+65299, dvrr_stack+69595, dvrr_stack+350350, dvrr_stack+64263, dvrr_stack+69007, dvrr_stack+348781);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+72187, dvrr_stack+11773, dvrr_stack+18823, NULL, NULL, dvrr_stack+11752);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+933, dvrr_stack+67327, dvrr_stack+72187, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+71362);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+12135, dvrr_stack+64851, dvrr_stack+933, dvrr_stack+66489, dvrr_stack+67327, dvrr_stack+71425);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+351106, dvrr_stack+65019, dvrr_stack+12135, dvrr_stack+1351, dvrr_stack+64851, dvrr_stack+71551);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+351526, dvrr_stack+70351, dvrr_stack+351106, dvrr_stack+28223, dvrr_stack+65019, dvrr_stack+39555);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+352114, dvrr_stack+54926, dvrr_stack+351526, dvrr_stack+37446, dvrr_stack+70351, dvrr_stack+349321);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+352898, dvrr_stack+6382, dvrr_stack+352114, dvrr_stack+150689, dvrr_stack+54926, dvrr_stack+349762);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+353906, dvrr_stack+238653, dvrr_stack+352898, dvrr_stack+151277, dvrr_stack+6382, dvrr_stack+350350);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+355166, dvrr_stack+239661, dvrr_stack+353906, dvrr_stack+3654, dvrr_stack+238653, dvrr_stack+65299);
 tmp = dvrr_stack + 355166;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+150689, dvrr_stack+18851, dvrr_stack+27530, NULL, NULL, dvrr_stack+18823);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28944, dvrr_stack+80391, dvrr_stack+150689, dvrr_stack+11801, dvrr_stack+18851, dvrr_stack+72187);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+150797, dvrr_stack+80499, dvrr_stack+28944, dvrr_stack+3344, dvrr_stack+80391, dvrr_stack+933);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+151157, dvrr_stack+55514, dvrr_stack+150797, dvrr_stack+5796, dvrr_stack+80499, dvrr_stack+12135);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+356706, dvrr_stack+51772, dvrr_stack+151157, dvrr_stack+29160, dvrr_stack+55514, dvrr_stack+351106);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+357462, dvrr_stack+240921, dvrr_stack+356706, dvrr_stack+52706, dvrr_stack+51772, dvrr_stack+351526);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+358470, dvrr_stack+241677, dvrr_stack+357462, dvrr_stack+152061, dvrr_stack+240921, dvrr_stack+352114);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+359766, dvrr_stack+242685, dvrr_stack+358470, dvrr_stack+152817, dvrr_stack+241677, dvrr_stack+352898);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+151697, dvrr_stack+243981, dvrr_stack+359766, dvrr_stack+153825, dvrr_stack+242685, dvrr_stack+353906);
 tmp = dvrr_stack + 151697;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+361386,dvrr_stack+151697,dvrr_stack+355166,55);


 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+29160, dvrr_stack+27566, dvrr_stack+38033, NULL, NULL, dvrr_stack+27530);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+31470, dvrr_stack+29160, dvrr_stack+18887, dvrr_stack+27566, dvrr_stack+150689);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+52312, dvrr_stack+81763, dvrr_stack+37446, dvrr_stack+7272, dvrr_stack+31470, dvrr_stack+28944);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+366006, dvrr_stack+82033, dvrr_stack+52312, dvrr_stack+7407, dvrr_stack+81763, dvrr_stack+150797);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+366681, dvrr_stack+19449, dvrr_stack+366006, dvrr_stack+7677, dvrr_stack+82033, dvrr_stack+151157);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+367626, dvrr_stack+249381, dvrr_stack+366681, dvrr_stack+158145, dvrr_stack+19449, dvrr_stack+356706);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+368886, dvrr_stack+250326, dvrr_stack+367626, dvrr_stack+158820, dvrr_stack+249381, dvrr_stack+357462);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+370506, dvrr_stack+251586, dvrr_stack+368886, dvrr_stack+159765, dvrr_stack+250326, dvrr_stack+358470);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+158145, dvrr_stack+86419, dvrr_stack+370506, dvrr_stack+12793, dvrr_stack+251586, dvrr_stack+359766);
 tmp = dvrr_stack + 158145;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+372531,dvrr_stack+158145,dvrr_stack+151697,55);


 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+160620, dvrr_stack+2941, dvrr_stack+50456, NULL, NULL, dvrr_stack+38033);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+52762, dvrr_stack+6112, dvrr_stack+160620, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+29160);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7166, dvrr_stack+82483, dvrr_stack+52762, dvrr_stack+8127, dvrr_stack+6112, dvrr_stack+37446);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+378471, dvrr_stack+258066, dvrr_stack+7166, dvrr_stack+2296, dvrr_stack+82483, dvrr_stack+52312);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+379296, dvrr_stack+258616, dvrr_stack+378471, dvrr_stack+164913, dvrr_stack+258066, dvrr_stack+366006);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+380451, dvrr_stack+259441, dvrr_stack+379296, dvrr_stack+165463, dvrr_stack+258616, dvrr_stack+366681);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+381991, dvrr_stack+260596, dvrr_stack+380451, dvrr_stack+166288, dvrr_stack+259441, dvrr_stack+367626);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+164913, dvrr_stack+262136, dvrr_stack+381991, dvrr_stack+167443, dvrr_stack+260596, dvrr_stack+368886);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+383971, dvrr_stack+92773, dvrr_stack+164913, dvrr_stack+20134, dvrr_stack+262136, dvrr_stack+370506);
 tmp = dvrr_stack + 383971;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+386996,dvrr_stack+383971,dvrr_stack+158145,55);


 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+167388, dvrr_stack+50511, dvrr_stack+49907, NULL, NULL, dvrr_stack+50456);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+167586, dvrr_stack+11937, dvrr_stack+167388, dvrr_stack+12493, dvrr_stack+50511, dvrr_stack+160620);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+167982, dvrr_stack+270191, dvrr_stack+167586, dvrr_stack+50142, dvrr_stack+11937, dvrr_stack+52762);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+394421, dvrr_stack+270587, dvrr_stack+167982, dvrr_stack+51376, dvrr_stack+270191, dvrr_stack+7166);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+395411, dvrr_stack+271247, dvrr_stack+394421, dvrr_stack+173843, dvrr_stack+270587, dvrr_stack+378471);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+396797, dvrr_stack+272237, dvrr_stack+395411, dvrr_stack+174503, dvrr_stack+271247, dvrr_stack+379296);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+398645, dvrr_stack+273623, dvrr_stack+396797, dvrr_stack+175493, dvrr_stack+272237, dvrr_stack+380451);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+173843, dvrr_stack+275471, dvrr_stack+398645, dvrr_stack+176879, dvrr_stack+273623, dvrr_stack+381991);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+401021, dvrr_stack+100623, dvrr_stack+173843, dvrr_stack+178727, dvrr_stack+275471, dvrr_stack+164913);
 tmp = dvrr_stack + 401021;
 target_ptr = Libderiv->dvrr_classes[9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+404651,dvrr_stack+401021,dvrr_stack+383971,55);


 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+176813, dvrr_stack+49973, dvrr_stack+27677, NULL, NULL, dvrr_stack+49907);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+177047, dvrr_stack+19053, dvrr_stack+176813, dvrr_stack+50577, dvrr_stack+49973, dvrr_stack+167388);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+177515, dvrr_stack+285272, dvrr_stack+177047, dvrr_stack+1519, dvrr_stack+19053, dvrr_stack+167586);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+413726, dvrr_stack+285740, dvrr_stack+177515, dvrr_stack+39942, dvrr_stack+285272, dvrr_stack+167982);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+414896, dvrr_stack+286520, dvrr_stack+413726, dvrr_stack+29520, dvrr_stack+285740, dvrr_stack+394421);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+416534, dvrr_stack+287690, dvrr_stack+414896, dvrr_stack+30300, dvrr_stack+286520, dvrr_stack+395411);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+418718, dvrr_stack+289328, dvrr_stack+416534, dvrr_stack+187043, dvrr_stack+287690, dvrr_stack+396797);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+421526, dvrr_stack+291512, dvrr_stack+418718, dvrr_stack+188681, dvrr_stack+289328, dvrr_stack+398645);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+425036, dvrr_stack+110127, dvrr_stack+421526, dvrr_stack+190865, dvrr_stack+291512, dvrr_stack+173843);
 tmp = dvrr_stack + 425036;
 target_ptr = Libderiv->dvrr_classes[9][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+429326,dvrr_stack+425036,dvrr_stack+401021,55);


 /* compute (1 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+187043, dvrr_stack+50340, dvrr_stack+50655, NULL, NULL, dvrr_stack+27677);

 /* compute (2 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+187316, dvrr_stack+27755, dvrr_stack+187043, dvrr_stack+50051, dvrr_stack+50340, dvrr_stack+176813);

 /* compute (3 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+187862, dvrr_stack+303230, dvrr_stack+187316, dvrr_stack+40410, dvrr_stack+27755, dvrr_stack+177047);

 /* compute (4 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+188772, dvrr_stack+303776, dvrr_stack+187862, dvrr_stack+40683, dvrr_stack+303230, dvrr_stack+177515);

 /* compute (5 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+29295, dvrr_stack+304686, dvrr_stack+188772, dvrr_stack+41229, dvrr_stack+303776, dvrr_stack+413726);

 /* compute (6 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+440216, dvrr_stack+306051, dvrr_stack+29295, dvrr_stack+200801, dvrr_stack+304686, dvrr_stack+414896);

 /* compute (7 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+442764, dvrr_stack+307962, dvrr_stack+440216, dvrr_stack+202166, dvrr_stack+306051, dvrr_stack+416534);

 /* compute (8 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+446040, dvrr_stack+310510, dvrr_stack+442764, dvrr_stack+204077, dvrr_stack+307962, dvrr_stack+418718);

 /* compute (9 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+200801, dvrr_stack+121443, dvrr_stack+446040, dvrr_stack+206625, dvrr_stack+310510, dvrr_stack+421526);

 /* compute (9 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+450135,dvrr_stack+200801,dvrr_stack+425036,55);


 /* compute (0 0 | 1 0) m=21 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+21, Data->F+22, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+361, dvrr_stack+3, dvrr_stack+68, Data->F+20, Data->F+21, NULL);

 /* compute (0 0 | 3 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+8382, dvrr_stack+361, dvrr_stack+38156, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+205806, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+6, dvrr_stack+8382, NULL);

 /* compute (0 0 | 5 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2856, dvrr_stack+1336, dvrr_stack+205806, dvrr_stack+27492, dvrr_stack+367, NULL);

 /* compute (0 0 | 6 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+38159, dvrr_stack+1336, NULL);

 /* compute (0 0 | 7 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+38174, dvrr_stack+3323, NULL);

 /* compute (0 0 | 8 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+66672, dvrr_stack+125538, dvrr_stack+11801, dvrr_stack+38195, dvrr_stack+2877, NULL);

 /* compute (0 0 | 9 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3323, dvrr_stack+88444, dvrr_stack+66672, dvrr_stack+2905, dvrr_stack+125538, NULL);

 /* compute (0 0 | 10 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27611, dvrr_stack+95248, dvrr_stack+3323, dvrr_stack+6067, dvrr_stack+88444, NULL);

 /* compute (0 0 | 11 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50577, dvrr_stack+103593, dvrr_stack+27611, dvrr_stack+11882, dvrr_stack+95248, NULL);

 /* compute (0 0 | 12 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+3323, dvrr_stack+113637, dvrr_stack+50577, dvrr_stack+18987, dvrr_stack+103593, NULL);

 /* compute (0 0 | 13 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+67411, dvrr_stack+50655, dvrr_stack+3323, dvrr_stack+27677, dvrr_stack+113637, NULL);

 /* compute (1 0 | 13 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+205806, dvrr_stack+6277, dvrr_stack+67411, NULL, NULL, dvrr_stack+50655);

 /* compute (2 0 | 13 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+190137, dvrr_stack+125574, dvrr_stack+205806, dvrr_stack+42139, dvrr_stack+6277, dvrr_stack+187043);

 /* compute (3 0 | 13 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+39870, dvrr_stack+324316, dvrr_stack+190137, dvrr_stack+42244, dvrr_stack+125574, dvrr_stack+187316);

 /* compute (4 0 | 13 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+40920, dvrr_stack+324946, dvrr_stack+39870, dvrr_stack+53246, dvrr_stack+324316, dvrr_stack+187862);

 /* compute (5 0 | 13 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+463005, dvrr_stack+325996, dvrr_stack+40920, dvrr_stack+53876, dvrr_stack+324946, dvrr_stack+188772);

 /* compute (6 0 | 13 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+465210, dvrr_stack+327571, dvrr_stack+463005, dvrr_stack+218325, dvrr_stack+325996, dvrr_stack+29295);

 /* compute (7 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+468150, dvrr_stack+329776, dvrr_stack+465210, dvrr_stack+219900, dvrr_stack+327571, dvrr_stack+440216);

 /* compute (8 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+463005, dvrr_stack+332716, dvrr_stack+468150, dvrr_stack+222105, dvrr_stack+329776, dvrr_stack+442764);

 /* compute (9 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+218325, dvrr_stack+135275, dvrr_stack+463005, dvrr_stack+225045, dvrr_stack+332716, dvrr_stack+446040);

 /* compute (9 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+463005,dvrr_stack+218325,dvrr_stack+200801,55);


 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+3, dvrr_stack+12, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+478020, dvrr_stack+52, dvrr_stack+15, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+11801, dvrr_stack+478020, dvrr_stack+21, dvrr_stack+52, dvrr_stack+15, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+207, dvrr_stack+291, dvrr_stack+58, NULL, NULL, dvrr_stack+52);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+478038, dvrr_stack+207, dvrr_stack+117, dvrr_stack+291, dvrr_stack+58, dvrr_stack+478020);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+18887, dvrr_stack+478038, dvrr_stack+147, dvrr_stack+207, dvrr_stack+117, dvrr_stack+11801);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+88444, dvrr_stack+1101, dvrr_stack+301, NULL, NULL, dvrr_stack+291);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+478098, dvrr_stack+88444, dvrr_stack+316, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+207);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+478188, dvrr_stack+478098, dvrr_stack+527, dvrr_stack+88444, dvrr_stack+316, dvrr_stack+478038);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+291, dvrr_stack+478188, dvrr_stack+617, dvrr_stack+478098, dvrr_stack+527, dvrr_stack+18887);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+516, dvrr_stack+912, dvrr_stack+1116, NULL, NULL, dvrr_stack+1101);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+478338, dvrr_stack+516, dvrr_stack+1137, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+88444);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+478464, dvrr_stack+478338, dvrr_stack+1200, dvrr_stack+516, dvrr_stack+1137, dvrr_stack+478098);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+478674, dvrr_stack+478464, dvrr_stack+1771, dvrr_stack+478338, dvrr_stack+1200, dvrr_stack+478188);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+1101, dvrr_stack+478674, dvrr_stack+1981, dvrr_stack+478464, dvrr_stack+1771, dvrr_stack+291);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+1771, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1774, dvrr_stack+3, dvrr_stack+6012, dvrr_stack+12, dvrr_stack+0, dvrr_stack+1771);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1792, dvrr_stack+11801, dvrr_stack+66591, dvrr_stack+478020, dvrr_stack+21, dvrr_stack+1774);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+478338, dvrr_stack+18887, dvrr_stack+66717, dvrr_stack+478038, dvrr_stack+147, dvrr_stack+1792);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+224100, dvrr_stack+291, dvrr_stack+67102, dvrr_stack+478188, dvrr_stack+617, dvrr_stack+478338);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+224415, dvrr_stack+1101, dvrr_stack+28503, dvrr_stack+478674, dvrr_stack+1981, dvrr_stack+224100);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+8382, dvrr_stack+1771, dvrr_stack+70878, Data->F+5, Data->F+6, NULL);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+478020, dvrr_stack+1774, dvrr_stack+70890, dvrr_stack+3, dvrr_stack+6012, dvrr_stack+8382);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+478050, dvrr_stack+1792, dvrr_stack+70962, dvrr_stack+11801, dvrr_stack+66591, dvrr_stack+478020);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+1852, dvrr_stack+478338, dvrr_stack+71212, dvrr_stack+18887, dvrr_stack+66717, dvrr_stack+478050);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+2062, dvrr_stack+224100, dvrr_stack+71872, dvrr_stack+291, dvrr_stack+67102, dvrr_stack+1852);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+324316, dvrr_stack+224415, dvrr_stack+64263, dvrr_stack+1101, dvrr_stack+28503, dvrr_stack+2062);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+27492, dvrr_stack+8382, dvrr_stack+50434, dvrr_stack+1771, dvrr_stack+70878, NULL);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+88444, dvrr_stack+478020, dvrr_stack+42559, dvrr_stack+1774, dvrr_stack+70890, dvrr_stack+27492);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+291, dvrr_stack+478050, dvrr_stack+42685, dvrr_stack+1792, dvrr_stack+70962, dvrr_stack+88444);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+417, dvrr_stack+1852, dvrr_stack+38970, dvrr_stack+478338, dvrr_stack+71212, dvrr_stack+291);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+478140, dvrr_stack+2062, dvrr_stack+67831, dvrr_stack+224100, dvrr_stack+71872, dvrr_stack+417);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+325072, dvrr_stack+324316, dvrr_stack+69595, dvrr_stack+224415, dvrr_stack+64263, dvrr_stack+478140);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+64263, dvrr_stack+27492, dvrr_stack+39, dvrr_stack+8382, dvrr_stack+50434, NULL);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+64278, dvrr_stack+88444, dvrr_stack+237, dvrr_stack+478020, dvrr_stack+42559, dvrr_stack+64263);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+64341, dvrr_stack+291, dvrr_stack+50896, dvrr_stack+478050, dvrr_stack+42685, dvrr_stack+64278);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+326017, dvrr_stack+417, dvrr_stack+2996, dvrr_stack+1852, dvrr_stack+38970, dvrr_stack+64341);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+326377, dvrr_stack+478140, dvrr_stack+348781, dvrr_stack+2062, dvrr_stack+67831, dvrr_stack+326017);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+327052, dvrr_stack+325072, dvrr_stack+65299, dvrr_stack+324316, dvrr_stack+69595, dvrr_stack+326377);

 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+326017, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+8382, dvrr_stack+140000, dvrr_stack+326017, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+27492, dvrr_stack+140003, dvrr_stack+8382, dvrr_stack+50431, dvrr_stack+140000, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+326020, dvrr_stack+39, dvrr_stack+27492, dvrr_stack+50434, dvrr_stack+140003, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+140000, dvrr_stack+282, dvrr_stack+3304, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+326035, dvrr_stack+140009, dvrr_stack+140000, dvrr_stack+49, dvrr_stack+282, dvrr_stack+326017);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+326053, dvrr_stack+66573, dvrr_stack+326035, dvrr_stack+50440, dvrr_stack+140009, dvrr_stack+8382);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+88444, dvrr_stack+140018, dvrr_stack+326053, dvrr_stack+1753, dvrr_stack+66573, dvrr_stack+27492);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+326083, dvrr_stack+237, dvrr_stack+88444, dvrr_stack+42559, dvrr_stack+140018, dvrr_stack+326020);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+326017, dvrr_stack+3307, dvrr_stack+803, NULL, NULL, dvrr_stack+3304);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+11801, dvrr_stack+140048, dvrr_stack+326017, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+140000);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+326146, dvrr_stack+767, dvrr_stack+11801, dvrr_stack+38223, dvrr_stack+140048, dvrr_stack+326035);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+140000, dvrr_stack+50746, dvrr_stack+326146, dvrr_stack+42589, dvrr_stack+767, dvrr_stack+326053);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+326206, dvrr_stack+50806, dvrr_stack+140000, dvrr_stack+42625, dvrr_stack+50746, dvrr_stack+88444);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+326332, dvrr_stack+50896, dvrr_stack+326206, dvrr_stack+42685, dvrr_stack+50806, dvrr_stack+326083);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+88444, dvrr_stack+2831, dvrr_stack+6021, NULL, NULL, dvrr_stack+803);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+50746, dvrr_stack+70908, dvrr_stack+88444, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+326017);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+18887, dvrr_stack+51022, dvrr_stack+50746, dvrr_stack+71, dvrr_stack+70908, dvrr_stack+11801);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+50806, dvrr_stack+51082, dvrr_stack+18887, dvrr_stack+12559, dvrr_stack+51022, dvrr_stack+326146);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+326500, dvrr_stack+51182, dvrr_stack+50806, dvrr_stack+12619, dvrr_stack+51082, dvrr_stack+140000);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+326710, dvrr_stack+125889, dvrr_stack+326500, dvrr_stack+3452, dvrr_stack+51182, dvrr_stack+326206);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+50956, dvrr_stack+2996, dvrr_stack+326710, dvrr_stack+38970, dvrr_stack+125889, dvrr_stack+326332);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+6067, dvrr_stack+6031, dvrr_stack+11737, NULL, NULL, dvrr_stack+6021);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+2996, dvrr_stack+11837, dvrr_stack+6067, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+88444);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+3086, dvrr_stack+71022, dvrr_stack+2996, dvrr_stack+66627, dvrr_stack+11837, dvrr_stack+50746);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+326017, dvrr_stack+28028, dvrr_stack+3086, dvrr_stack+8292, dvrr_stack+71022, dvrr_stack+18887);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+224100, dvrr_stack+27051, dvrr_stack+326017, dvrr_stack+39180, dvrr_stack+28028, dvrr_stack+50806);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+28028, dvrr_stack+18441, dvrr_stack+224100, dvrr_stack+39330, dvrr_stack+27051, dvrr_stack+326500);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+38241, dvrr_stack+28028, dvrr_stack+67516, dvrr_stack+18441, dvrr_stack+326710);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+326242, dvrr_stack+348781, dvrr_stack+64263, dvrr_stack+67831, dvrr_stack+38241, dvrr_stack+50956);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+348781, dvrr_stack+11752, dvrr_stack+18802, NULL, NULL, dvrr_stack+11737);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+348844, dvrr_stack+71362, dvrr_stack+348781, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+6067);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+348970, dvrr_stack+71425, dvrr_stack+348844, dvrr_stack+66817, dvrr_stack+71362, dvrr_stack+2996);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+18441, dvrr_stack+71551, dvrr_stack+348970, dvrr_stack+4662, dvrr_stack+71425, dvrr_stack+3086);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+28448, dvrr_stack+39555, dvrr_stack+18441, dvrr_stack+66880, dvrr_stack+71551, dvrr_stack+326017);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+50746, dvrr_stack+349321, dvrr_stack+28448, dvrr_stack+68251, dvrr_stack+39555, dvrr_stack+224100);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+478020, dvrr_stack+349762, dvrr_stack+50746, dvrr_stack+68566, dvrr_stack+349321, dvrr_stack+28028);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+1542, dvrr_stack+350350, dvrr_stack+478020, dvrr_stack+69007, dvrr_stack+349762, dvrr_stack+64263);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+349180, dvrr_stack+65299, dvrr_stack+1542, dvrr_stack+69595, dvrr_stack+350350, dvrr_stack+326242);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+65299, dvrr_stack+18823, dvrr_stack+27502, NULL, NULL, dvrr_stack+18802);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+65383, dvrr_stack+72187, dvrr_stack+65299, dvrr_stack+11773, dvrr_stack+18823, dvrr_stack+348781);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+65551, dvrr_stack+933, dvrr_stack+65383, dvrr_stack+67327, dvrr_stack+72187, dvrr_stack+348844);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+28028, dvrr_stack+12135, dvrr_stack+65551, dvrr_stack+64851, dvrr_stack+933, dvrr_stack+348970);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+65831, dvrr_stack+351106, dvrr_stack+28028, dvrr_stack+65019, dvrr_stack+12135, dvrr_stack+18441);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+66419, dvrr_stack+351526, dvrr_stack+65831, dvrr_stack+70351, dvrr_stack+351106, dvrr_stack+28448);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+67203, dvrr_stack+352114, dvrr_stack+66419, dvrr_stack+54926, dvrr_stack+351526, dvrr_stack+50746);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+68211, dvrr_stack+352898, dvrr_stack+67203, dvrr_stack+6382, dvrr_stack+352114, dvrr_stack+478020);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+69471, dvrr_stack+353906, dvrr_stack+68211, dvrr_stack+238653, dvrr_stack+352898, dvrr_stack+1542);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+350335, dvrr_stack+355166, dvrr_stack+69471, dvrr_stack+239661, dvrr_stack+353906, dvrr_stack+349180);

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1542, dvrr_stack+27530, dvrr_stack+37997, NULL, NULL, dvrr_stack+27502);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1650, dvrr_stack+150689, dvrr_stack+1542, dvrr_stack+18851, dvrr_stack+27530, dvrr_stack+65299);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1866, dvrr_stack+28944, dvrr_stack+1650, dvrr_stack+80391, dvrr_stack+150689, dvrr_stack+65383);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2226, dvrr_stack+150797, dvrr_stack+1866, dvrr_stack+80499, dvrr_stack+28944, dvrr_stack+65551);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+238653, dvrr_stack+151157, dvrr_stack+2226, dvrr_stack+55514, dvrr_stack+150797, dvrr_stack+28028);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28028, dvrr_stack+356706, dvrr_stack+238653, dvrr_stack+51772, dvrr_stack+151157, dvrr_stack+65831);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+50746, dvrr_stack+357462, dvrr_stack+28028, dvrr_stack+240921, dvrr_stack+356706, dvrr_stack+66419);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+358470, dvrr_stack+50746, dvrr_stack+241677, dvrr_stack+357462, dvrr_stack+67203);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+65883, dvrr_stack+359766, dvrr_stack+64263, dvrr_stack+242685, dvrr_stack+358470, dvrr_stack+68211);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+356706, dvrr_stack+151697, dvrr_stack+65883, dvrr_stack+243981, dvrr_stack+359766, dvrr_stack+69471);

 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+359082, dvrr_stack+38033, dvrr_stack+27447, NULL, NULL, dvrr_stack+37997);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+52042, dvrr_stack+29160, dvrr_stack+359082, dvrr_stack+27566, dvrr_stack+38033, dvrr_stack+1542);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+359217, dvrr_stack+37446, dvrr_stack+52042, dvrr_stack+31470, dvrr_stack+29160, dvrr_stack+1650);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+359667, dvrr_stack+52312, dvrr_stack+359217, dvrr_stack+81763, dvrr_stack+37446, dvrr_stack+1866);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+366006, dvrr_stack+359667, dvrr_stack+82033, dvrr_stack+52312, dvrr_stack+2226);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38391, dvrr_stack+366681, dvrr_stack+37446, dvrr_stack+19449, dvrr_stack+366006, dvrr_stack+238653);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+39651, dvrr_stack+367626, dvrr_stack+38391, dvrr_stack+249381, dvrr_stack+366681, dvrr_stack+28028);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+240921, dvrr_stack+368886, dvrr_stack+39651, dvrr_stack+250326, dvrr_stack+367626, dvrr_stack+50746);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+366006, dvrr_stack+370506, dvrr_stack+240921, dvrr_stack+251586, dvrr_stack+368886, dvrr_stack+64263);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+249381, dvrr_stack+158145, dvrr_stack+366006, dvrr_stack+86419, dvrr_stack+370506, dvrr_stack+65883);

 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+50456, dvrr_stack+49852, NULL, NULL, dvrr_stack+27447);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+64428, dvrr_stack+160620, dvrr_stack+64263, dvrr_stack+2941, dvrr_stack+50456, dvrr_stack+359082);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+64758, dvrr_stack+52762, dvrr_stack+64428, dvrr_stack+6112, dvrr_stack+160620, dvrr_stack+52042);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+65308, dvrr_stack+7166, dvrr_stack+64758, dvrr_stack+82483, dvrr_stack+52762, dvrr_stack+359217);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66133, dvrr_stack+378471, dvrr_stack+65308, dvrr_stack+258066, dvrr_stack+7166, dvrr_stack+359667);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+359082, dvrr_stack+379296, dvrr_stack+66133, dvrr_stack+258616, dvrr_stack+378471, dvrr_stack+37446);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+67288, dvrr_stack+380451, dvrr_stack+359082, dvrr_stack+259441, dvrr_stack+379296, dvrr_stack+38391);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+258066, dvrr_stack+381991, dvrr_stack+67288, dvrr_stack+260596, dvrr_stack+380451, dvrr_stack+39651);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+164913, dvrr_stack+258066, dvrr_stack+262136, dvrr_stack+381991, dvrr_stack+240921);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+378471, dvrr_stack+383971, dvrr_stack+37446, dvrr_stack+92773, dvrr_stack+164913, dvrr_stack+366006);

 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+366006, dvrr_stack+49907, dvrr_stack+18987, NULL, NULL, dvrr_stack+49852);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+366204, dvrr_stack+167388, dvrr_stack+366006, dvrr_stack+50511, dvrr_stack+49907, dvrr_stack+64263);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+366600, dvrr_stack+167586, dvrr_stack+366204, dvrr_stack+11937, dvrr_stack+167388, dvrr_stack+64428);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+367260, dvrr_stack+167982, dvrr_stack+366600, dvrr_stack+270191, dvrr_stack+167586, dvrr_stack+64758);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+368250, dvrr_stack+394421, dvrr_stack+367260, dvrr_stack+270587, dvrr_stack+167982, dvrr_stack+65308);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+395411, dvrr_stack+368250, dvrr_stack+271247, dvrr_stack+394421, dvrr_stack+66133);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+369636, dvrr_stack+396797, dvrr_stack+64263, dvrr_stack+272237, dvrr_stack+395411, dvrr_stack+359082);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+270191, dvrr_stack+398645, dvrr_stack+369636, dvrr_stack+273623, dvrr_stack+396797, dvrr_stack+67288);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+394421, dvrr_stack+173843, dvrr_stack+270191, dvrr_stack+275471, dvrr_stack+398645, dvrr_stack+258066);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+258066, dvrr_stack+401021, dvrr_stack+394421, dvrr_stack+100623, dvrr_stack+173843, dvrr_stack+37446);

 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+27677, dvrr_stack+113637, NULL, NULL, dvrr_stack+18987);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37680, dvrr_stack+176813, dvrr_stack+37446, dvrr_stack+49973, dvrr_stack+27677, dvrr_stack+366006);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38148, dvrr_stack+177047, dvrr_stack+37680, dvrr_stack+19053, dvrr_stack+176813, dvrr_stack+366204);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38928, dvrr_stack+177515, dvrr_stack+38148, dvrr_stack+285272, dvrr_stack+177047, dvrr_stack+366600);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40098, dvrr_stack+413726, dvrr_stack+38928, dvrr_stack+285740, dvrr_stack+177515, dvrr_stack+367260);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+366006, dvrr_stack+414896, dvrr_stack+40098, dvrr_stack+286520, dvrr_stack+413726, dvrr_stack+368250);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+173843, dvrr_stack+416534, dvrr_stack+366006, dvrr_stack+287690, dvrr_stack+414896, dvrr_stack+64263);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+64263, dvrr_stack+418718, dvrr_stack+173843, dvrr_stack+289328, dvrr_stack+416534, dvrr_stack+369636);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67773, dvrr_stack+421526, dvrr_stack+64263, dvrr_stack+291512, dvrr_stack+418718, dvrr_stack+270191);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+270191, dvrr_stack+425036, dvrr_stack+67773, dvrr_stack+110127, dvrr_stack+421526, dvrr_stack+394421);

 /* compute (1 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+394421, dvrr_stack+50655, dvrr_stack+3323, NULL, NULL, dvrr_stack+113637);

 /* compute (2 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+187043, dvrr_stack+394421, dvrr_stack+50340, dvrr_stack+50655, dvrr_stack+37446);

 /* compute (3 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50340, dvrr_stack+187316, dvrr_stack+49794, dvrr_stack+27755, dvrr_stack+187043, dvrr_stack+37680);

 /* compute (4 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+51250, dvrr_stack+187862, dvrr_stack+50340, dvrr_stack+303230, dvrr_stack+187316, dvrr_stack+38148);

 /* compute (5 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+52615, dvrr_stack+188772, dvrr_stack+51250, dvrr_stack+303776, dvrr_stack+187862, dvrr_stack+38928);

 /* compute (6 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+29295, dvrr_stack+52615, dvrr_stack+304686, dvrr_stack+188772, dvrr_stack+40098);

 /* compute (7 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+187043, dvrr_stack+440216, dvrr_stack+49794, dvrr_stack+306051, dvrr_stack+29295, dvrr_stack+366006);

 /* compute (8 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+366006, dvrr_stack+442764, dvrr_stack+187043, dvrr_stack+307962, dvrr_stack+440216, dvrr_stack+173843);

 /* compute (9 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+446040, dvrr_stack+366006, dvrr_stack+310510, dvrr_stack+442764, dvrr_stack+64263);

 /* compute (10 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+366006, dvrr_stack+200801, dvrr_stack+49794, dvrr_stack+121443, dvrr_stack+446040, dvrr_stack+67773);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+80391, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 80391;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+49794, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 49794;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+50550, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 50550;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+51495, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 51495;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+52650, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 52650;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1638,dvrr_stack+54036, dvrr_stack+59349, NULL);
 tmp = dvrr_stack + 54036;
 target_ptr = Libderiv->deriv_classes[5][11][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1911,dvrr_stack+64263, dvrr_stack+74658, NULL);
 tmp = dvrr_stack + 64263;
 target_ptr = Libderiv->deriv_classes[5][12][11];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+66174, dvrr_stack+84067, NULL);
 tmp = dvrr_stack + 66174;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+238653, dvrr_stack+89749, NULL);
 tmp = dvrr_stack + 238653;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+66958, dvrr_stack+96843, NULL);
 tmp = dvrr_stack + 66958;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+68218, dvrr_stack+105507, NULL);
 tmp = dvrr_stack + 68218;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+69758, dvrr_stack+115899, NULL);
 tmp = dvrr_stack + 69758;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+173843, dvrr_stack+128723, NULL);
 tmp = dvrr_stack + 173843;
 target_ptr = Libderiv->deriv_classes[6][11][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2548,dvrr_stack+176027, dvrr_stack+143045, NULL);
 tmp = dvrr_stack + 176027;
 target_ptr = Libderiv->deriv_classes[6][12][11];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+150689, dvrr_stack+155121, NULL);
 tmp = dvrr_stack + 150689;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+81763, dvrr_stack+161025, NULL);
 tmp = dvrr_stack + 81763;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+440216, dvrr_stack+168983, NULL);
 tmp = dvrr_stack + 440216;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+441836, dvrr_stack+181103, NULL);
 tmp = dvrr_stack + 441836;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+443816, dvrr_stack+193673, NULL);
 tmp = dvrr_stack + 443816;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+446192, dvrr_stack+209901, NULL);
 tmp = dvrr_stack + 446192;
 target_ptr = Libderiv->deriv_classes[7][11][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3276,dvrr_stack+187043, dvrr_stack+228825, NULL);
 tmp = dvrr_stack + 187043;
 target_ptr = Libderiv->deriv_classes[7][12][11];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+303230, dvrr_stack+245601, NULL);
 tmp = dvrr_stack + 303230;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+304490, dvrr_stack+253206, NULL);
 tmp = dvrr_stack + 304490;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+306110, dvrr_stack+264116, NULL);
 tmp = dvrr_stack + 306110;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+308135, dvrr_stack+277847, NULL);
 tmp = dvrr_stack + 308135;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+310610, dvrr_stack+294320, NULL);
 tmp = dvrr_stack + 310610;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+37446, dvrr_stack+313786, NULL);
 tmp = dvrr_stack + 37446;
 target_ptr = Libderiv->deriv_classes[8][11][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4095,dvrr_stack+394421, dvrr_stack+336496, NULL);
 tmp = dvrr_stack + 394421;
 target_ptr = Libderiv->deriv_classes[8][12][11];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+40956, dvrr_stack+361386, NULL);
 tmp = dvrr_stack + 40956;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+398516, dvrr_stack+372531, NULL);
 tmp = dvrr_stack + 398516;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+275339, dvrr_stack+386996, NULL);
 tmp = dvrr_stack + 275339;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+413726, dvrr_stack+404651, NULL);
 tmp = dvrr_stack + 413726;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+416751, dvrr_stack+429326, NULL);
 tmp = dvrr_stack + 416751;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+420381, dvrr_stack+450135, NULL);
 tmp = dvrr_stack + 420381;
 target_ptr = Libderiv->deriv_classes[9][11][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,5005,dvrr_stack+285272, dvrr_stack+463005, NULL);
 tmp = dvrr_stack + 285272;
 target_ptr = Libderiv->deriv_classes[9][12][11];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+71606, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 71606;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+449000, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 449000;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+290277, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 290277;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+291222, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 291222;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+292377, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 292377;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1638,dvrr_stack+262422, dvrr_stack+59349, NULL);
 tmp = dvrr_stack + 262422;
 target_ptr = Libderiv->deriv_classes[5][11][10];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1911,dvrr_stack+359082, dvrr_stack+74658, NULL);
 tmp = dvrr_stack + 359082;
 target_ptr = Libderiv->deriv_classes[5][12][10];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+164913, dvrr_stack+84067, NULL);
 tmp = dvrr_stack + 164913;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+165697, dvrr_stack+89749, NULL);
 tmp = dvrr_stack + 165697;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+166705, dvrr_stack+96843, NULL);
 tmp = dvrr_stack + 166705;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+240921, dvrr_stack+105507, NULL);
 tmp = dvrr_stack + 240921;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+382101, dvrr_stack+115899, NULL);
 tmp = dvrr_stack + 382101;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+352183, dvrr_stack+128723, NULL);
 tmp = dvrr_stack + 352183;
 target_ptr = Libderiv->deriv_classes[6][11][10];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2548,dvrr_stack+27051, dvrr_stack+143045, NULL);
 tmp = dvrr_stack + 27051;
 target_ptr = Libderiv->deriv_classes[6][12][10];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+167965, dvrr_stack+155121, NULL);
 tmp = dvrr_stack + 167965;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+242461, dvrr_stack+161025, NULL);
 tmp = dvrr_stack + 242461;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1542, dvrr_stack+168983, NULL);
 tmp = dvrr_stack + 1542;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+29599, dvrr_stack+181103, NULL);
 tmp = dvrr_stack + 29599;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+328207, dvrr_stack+193673, NULL);
 tmp = dvrr_stack + 328207;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+330583, dvrr_stack+209901, NULL);
 tmp = dvrr_stack + 330583;
 target_ptr = Libderiv->deriv_classes[7][11][10];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3276,dvrr_stack+478020, dvrr_stack+228825, NULL);
 tmp = dvrr_stack + 478020;
 target_ptr = Libderiv->deriv_classes[7][12][10];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+18441, dvrr_stack+245601, NULL);
 tmp = dvrr_stack + 18441;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+333391, dvrr_stack+253206, NULL);
 tmp = dvrr_stack + 333391;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+5796, dvrr_stack+264116, NULL);
 tmp = dvrr_stack + 5796;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+481296, dvrr_stack+277847, NULL);
 tmp = dvrr_stack + 481296;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+483771, dvrr_stack+294320, NULL);
 tmp = dvrr_stack + 483771;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+486741, dvrr_stack+313786, NULL);
 tmp = dvrr_stack + 486741;
 target_ptr = Libderiv->deriv_classes[8][11][10];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4095,dvrr_stack+490251, dvrr_stack+336496, NULL);
 tmp = dvrr_stack + 490251;
 target_ptr = Libderiv->deriv_classes[8][12][10];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+348781, dvrr_stack+361386, NULL);
 tmp = dvrr_stack + 348781;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+494346, dvrr_stack+372531, NULL);
 tmp = dvrr_stack + 494346;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+496326, dvrr_stack+386996, NULL);
 tmp = dvrr_stack + 496326;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+498801, dvrr_stack+404651, NULL);
 tmp = dvrr_stack + 498801;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+501826, dvrr_stack+429326, NULL);
 tmp = dvrr_stack + 501826;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+505456, dvrr_stack+450135, NULL);
 tmp = dvrr_stack + 505456;
 target_ptr = Libderiv->deriv_classes[9][11][10];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,5005,dvrr_stack+509746, dvrr_stack+463005, NULL);
 tmp = dvrr_stack + 509746;
 target_ptr = Libderiv->deriv_classes[9][12][10];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+252351, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 252351;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+9684, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 9684;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+16173, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 16173;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+24216, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 24216;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+33981, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 33981;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1638,dvrr_stack+45636, dvrr_stack+59349, NULL);
 tmp = dvrr_stack + 45636;
 target_ptr = Libderiv->deriv_classes[5][11][9];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1911,dvrr_stack+59349, dvrr_stack+74658, NULL);
 tmp = dvrr_stack + 59349;
 target_ptr = Libderiv->deriv_classes[5][12][9];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+74658, dvrr_stack+84067, NULL);
 tmp = dvrr_stack + 74658;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+84067, dvrr_stack+89749, NULL);
 tmp = dvrr_stack + 84067;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+89749, dvrr_stack+96843, NULL);
 tmp = dvrr_stack + 89749;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+96843, dvrr_stack+105507, NULL);
 tmp = dvrr_stack + 96843;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+105507, dvrr_stack+115899, NULL);
 tmp = dvrr_stack + 105507;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+115899, dvrr_stack+128723, NULL);
 tmp = dvrr_stack + 115899;
 target_ptr = Libderiv->deriv_classes[6][11][9];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2548,dvrr_stack+128723, dvrr_stack+143045, NULL);
 tmp = dvrr_stack + 128723;
 target_ptr = Libderiv->deriv_classes[6][12][9];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+143045, dvrr_stack+155121, NULL);
 tmp = dvrr_stack + 143045;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+155121, dvrr_stack+161025, NULL);
 tmp = dvrr_stack + 155121;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+156417, dvrr_stack+168983, NULL);
 tmp = dvrr_stack + 156417;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+144053, dvrr_stack+181103, NULL);
 tmp = dvrr_stack + 144053;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+181103, dvrr_stack+193673, NULL);
 tmp = dvrr_stack + 181103;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+193673, dvrr_stack+209901, NULL);
 tmp = dvrr_stack + 193673;
 target_ptr = Libderiv->deriv_classes[7][11][9];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3276,dvrr_stack+209901, dvrr_stack+228825, NULL);
 tmp = dvrr_stack + 209901;
 target_ptr = Libderiv->deriv_classes[7][12][9];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+228825, dvrr_stack+245601, NULL);
 tmp = dvrr_stack + 228825;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+245601, dvrr_stack+253206, NULL);
 tmp = dvrr_stack + 245601;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+247221, dvrr_stack+264116, NULL);
 tmp = dvrr_stack + 247221;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+230085, dvrr_stack+277847, NULL);
 tmp = dvrr_stack + 230085;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+232560, dvrr_stack+294320, NULL);
 tmp = dvrr_stack + 232560;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+213177, dvrr_stack+313786, NULL);
 tmp = dvrr_stack + 213177;
 target_ptr = Libderiv->deriv_classes[8][11][9];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4095,dvrr_stack+196481, dvrr_stack+336496, NULL);
 tmp = dvrr_stack + 196481;
 target_ptr = Libderiv->deriv_classes[8][12][9];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+235530, dvrr_stack+361386, NULL);
 tmp = dvrr_stack + 235530;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+183479, dvrr_stack+372531, NULL);
 tmp = dvrr_stack + 183479;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+146033, dvrr_stack+386996, NULL);
 tmp = dvrr_stack + 146033;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+386996, dvrr_stack+404651, NULL);
 tmp = dvrr_stack + 386996;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+404651, dvrr_stack+429326, NULL);
 tmp = dvrr_stack + 404651;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+429326, dvrr_stack+450135, NULL);
 tmp = dvrr_stack + 429326;
 target_ptr = Libderiv->deriv_classes[9][11][9];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,5005,dvrr_stack+433616, dvrr_stack+463005, NULL);
 tmp = dvrr_stack + 433616;
 target_ptr = Libderiv->deriv_classes[9][12][9];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+438621, dvrr_stack+8928, dvrr_stack+1101);
 tmp = dvrr_stack + 438621;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+439209, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 439209;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+408281, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 408281;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+409226, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 409226;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+410381, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 410381;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,21,1,dvrr_stack+216687, dvrr_stack+57438, dvrr_stack+32595);
 tmp = dvrr_stack + 216687;
 target_ptr = Libderiv->deriv_classes[5][11][8];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,21,1,dvrr_stack+411767, dvrr_stack+72453, dvrr_stack+43998);
 tmp = dvrr_stack + 411767;
 target_ptr = Libderiv->deriv_classes[5][12][8];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+390021, dvrr_stack+83059, dvrr_stack+224415);
 tmp = dvrr_stack + 390021;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+390805, dvrr_stack+88489, dvrr_stack+80979);
 tmp = dvrr_stack + 390805;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+391813, dvrr_stack+95303, dvrr_stack+83059);
 tmp = dvrr_stack + 391813;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+237070, dvrr_stack+103659, dvrr_stack+88489);
 tmp = dvrr_stack + 237070;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+148508, dvrr_stack+113715, dvrr_stack+95303);
 tmp = dvrr_stack + 148508;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,28,1,dvrr_stack+131271, dvrr_stack+126175, dvrr_stack+103659);
 tmp = dvrr_stack + 131271;
 target_ptr = Libderiv->deriv_classes[6][11][8];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,28,1,dvrr_stack+118083, dvrr_stack+140105, dvrr_stack+113715);
 tmp = dvrr_stack + 118083;
 target_ptr = Libderiv->deriv_classes[6][12][8];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+393073, dvrr_stack+153825, dvrr_stack+324316);
 tmp = dvrr_stack + 393073;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+185459, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 185459;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+133455, dvrr_stack+20134, dvrr_stack+153825);
 tmp = dvrr_stack + 133455;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+107355, dvrr_stack+178727, dvrr_stack+12793);
 tmp = dvrr_stack + 107355;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+75442, dvrr_stack+190865, dvrr_stack+20134);
 tmp = dvrr_stack + 75442;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,36,1,dvrr_stack+61260, dvrr_stack+206625, dvrr_stack+178727);
 tmp = dvrr_stack + 61260;
 target_ptr = Libderiv->deriv_classes[7][11][8];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,36,1,dvrr_stack+372012, dvrr_stack+225045, dvrr_stack+190865);
 tmp = dvrr_stack + 372012;
 target_ptr = Libderiv->deriv_classes[7][12][8];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+98383, dvrr_stack+243981, dvrr_stack+325072);
 tmp = dvrr_stack + 98383;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+91009, dvrr_stack+86419, dvrr_stack+239661);
 tmp = dvrr_stack + 91009;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+77818, dvrr_stack+92773, dvrr_stack+243981);
 tmp = dvrr_stack + 77818;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+47274, dvrr_stack+100623, dvrr_stack+86419);
 tmp = dvrr_stack + 47274;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+375288, dvrr_stack+110127, dvrr_stack+92773);
 tmp = dvrr_stack + 375288;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,45,1,dvrr_stack+449756, dvrr_stack+121443, dvrr_stack+100623);
 tmp = dvrr_stack + 449756;
 target_ptr = Libderiv->deriv_classes[8][11][8];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,45,1,dvrr_stack+453266, dvrr_stack+135275, dvrr_stack+110127);
 tmp = dvrr_stack + 453266;
 target_ptr = Libderiv->deriv_classes[8][12][8];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+35367, dvrr_stack+151697, dvrr_stack+327052);
 tmp = dvrr_stack + 35367;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+10440, dvrr_stack+158145, dvrr_stack+355166);
 tmp = dvrr_stack + 10440;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+457361, dvrr_stack+383971, dvrr_stack+151697);
 tmp = dvrr_stack + 457361;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+459836, dvrr_stack+401021, dvrr_stack+158145);
 tmp = dvrr_stack + 459836;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+462861, dvrr_stack+425036, dvrr_stack+383971);
 tmp = dvrr_stack + 462861;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,55,1,dvrr_stack+466491, dvrr_stack+200801, dvrr_stack+401021);
 tmp = dvrr_stack + 466491;
 target_ptr = Libderiv->deriv_classes[9][11][8];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,55,1,dvrr_stack+470781, dvrr_stack+218325, dvrr_stack+425036);
 tmp = dvrr_stack + 470781;
 target_ptr = Libderiv->deriv_classes[9][12][8];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+120631, dvrr_stack+8928, dvrr_stack+1101);
 tmp = dvrr_stack + 120631;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+109335, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 109335;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+99643, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 99643;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+85075, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 85075;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+25371, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 25371;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,21,1,dvrr_stack+475786, dvrr_stack+57438, dvrr_stack+32595);
 tmp = dvrr_stack + 475786;
 target_ptr = Libderiv->deriv_classes[5][11][7];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,21,1,dvrr_stack+313580, dvrr_stack+72453, dvrr_stack+43998);
 tmp = dvrr_stack + 313580;
 target_ptr = Libderiv->deriv_classes[5][12][7];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+17118, dvrr_stack+83059, dvrr_stack+224415);
 tmp = dvrr_stack + 17118;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+315491, dvrr_stack+88489, dvrr_stack+80979);
 tmp = dvrr_stack + 315491;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+316499, dvrr_stack+95303, dvrr_stack+83059);
 tmp = dvrr_stack + 316499;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+317759, dvrr_stack+103659, dvrr_stack+88489);
 tmp = dvrr_stack + 317759;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+319299, dvrr_stack+113715, dvrr_stack+95303);
 tmp = dvrr_stack + 319299;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,28,1,dvrr_stack+321147, dvrr_stack+126175, dvrr_stack+103659);
 tmp = dvrr_stack + 321147;
 target_ptr = Libderiv->deriv_classes[6][11][7];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,28,1,dvrr_stack+277814, dvrr_stack+140105, dvrr_stack+113715);
 tmp = dvrr_stack + 277814;
 target_ptr = Libderiv->deriv_classes[6][12][7];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+280362, dvrr_stack+153825, dvrr_stack+324316);
 tmp = dvrr_stack + 280362;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+281370, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 281370;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+282666, dvrr_stack+20134, dvrr_stack+153825);
 tmp = dvrr_stack + 282666;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+293763, dvrr_stack+178727, dvrr_stack+12793);
 tmp = dvrr_stack + 293763;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+295743, dvrr_stack+190865, dvrr_stack+20134);
 tmp = dvrr_stack + 295743;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,36,1,dvrr_stack+298119, dvrr_stack+206625, dvrr_stack+178727);
 tmp = dvrr_stack + 298119;
 target_ptr = Libderiv->deriv_classes[7][11][7];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,36,1,dvrr_stack+264060, dvrr_stack+225045, dvrr_stack+190865);
 tmp = dvrr_stack + 264060;
 target_ptr = Libderiv->deriv_classes[7][12][7];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+300927, dvrr_stack+243981, dvrr_stack+325072);
 tmp = dvrr_stack + 300927;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+267336, dvrr_stack+86419, dvrr_stack+239661);
 tmp = dvrr_stack + 267336;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+360993, dvrr_stack+92773, dvrr_stack+243981);
 tmp = dvrr_stack + 360993;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+363018, dvrr_stack+100623, dvrr_stack+86419);
 tmp = dvrr_stack + 363018;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+168973, dvrr_stack+110127, dvrr_stack+92773);
 tmp = dvrr_stack + 168973;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,45,1,dvrr_stack+160620, dvrr_stack+121443, dvrr_stack+100623);
 tmp = dvrr_stack + 160620;
 target_ptr = Libderiv->deriv_classes[8][11][7];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,45,1,dvrr_stack+252939, dvrr_stack+135275, dvrr_stack+110127);
 tmp = dvrr_stack + 252939;
 target_ptr = Libderiv->deriv_classes[8][12][7];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+171943, dvrr_stack+151697, dvrr_stack+327052);
 tmp = dvrr_stack + 171943;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+335011, dvrr_stack+158145, dvrr_stack+355166);
 tmp = dvrr_stack + 335011;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+336991, dvrr_stack+383971, dvrr_stack+151697);
 tmp = dvrr_stack + 336991;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+339466, dvrr_stack+401021, dvrr_stack+158145);
 tmp = dvrr_stack + 339466;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+342491, dvrr_stack+425036, dvrr_stack+383971);
 tmp = dvrr_stack + 342491;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,55,1,dvrr_stack+514751, dvrr_stack+200801, dvrr_stack+401021);
 tmp = dvrr_stack + 514751;
 target_ptr = Libderiv->deriv_classes[9][11][7];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,55,1,dvrr_stack+519041, dvrr_stack+218325, dvrr_stack+425036);
 tmp = dvrr_stack + 519041;
 target_ptr = Libderiv->deriv_classes[9][12][7];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+477424, dvrr_stack+8928, dvrr_stack+1101);
 tmp = dvrr_stack + 477424;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+323331, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 323331;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+284286, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 284286;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+268956, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 268956;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+0, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,21,1,dvrr_stack+346121, dvrr_stack+57438, dvrr_stack+32595);
 tmp = dvrr_stack + 346121;
 target_ptr = Libderiv->deriv_classes[5][11][6];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,21,1,dvrr_stack+524046, dvrr_stack+72453, dvrr_stack+43998);
 tmp = dvrr_stack + 524046;
 target_ptr = Libderiv->deriv_classes[5][12][6];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+72194, dvrr_stack+83059, dvrr_stack+224415);
 tmp = dvrr_stack + 72194;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+72978, dvrr_stack+88489, dvrr_stack+80979);
 tmp = dvrr_stack + 72978;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+525957, dvrr_stack+95303, dvrr_stack+83059);
 tmp = dvrr_stack + 525957;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+527217, dvrr_stack+103659, dvrr_stack+88489);
 tmp = dvrr_stack + 527217;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+528757, dvrr_stack+113715, dvrr_stack+95303);
 tmp = dvrr_stack + 528757;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,28,1,dvrr_stack+530605, dvrr_stack+126175, dvrr_stack+103659);
 tmp = dvrr_stack + 530605;
 target_ptr = Libderiv->deriv_classes[6][11][6];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,28,1,dvrr_stack+532789, dvrr_stack+140105, dvrr_stack+113715);
 tmp = dvrr_stack + 532789;
 target_ptr = Libderiv->deriv_classes[6][12][6];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+302187, dvrr_stack+153825, dvrr_stack+324316);
 tmp = dvrr_stack + 302187;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+140000, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 140000;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+141296, dvrr_stack+20134, dvrr_stack+153825);
 tmp = dvrr_stack + 141296;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+535337, dvrr_stack+178727, dvrr_stack+12793);
 tmp = dvrr_stack + 535337;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+537317, dvrr_stack+190865, dvrr_stack+20134);
 tmp = dvrr_stack + 537317;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,36,1,dvrr_stack+539693, dvrr_stack+206625, dvrr_stack+178727);
 tmp = dvrr_stack + 539693;
 target_ptr = Libderiv->deriv_classes[7][11][6];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,36,1,dvrr_stack+542501, dvrr_stack+225045, dvrr_stack+190865);
 tmp = dvrr_stack + 542501;
 target_ptr = Libderiv->deriv_classes[7][12][6];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+224100, dvrr_stack+243981, dvrr_stack+325072);
 tmp = dvrr_stack + 224100;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+324087, dvrr_stack+86419, dvrr_stack+239661);
 tmp = dvrr_stack + 324087;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+225360, dvrr_stack+92773, dvrr_stack+243981);
 tmp = dvrr_stack + 225360;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+545777, dvrr_stack+100623, dvrr_stack+86419);
 tmp = dvrr_stack + 545777;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+548252, dvrr_stack+110127, dvrr_stack+92773);
 tmp = dvrr_stack + 548252;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,45,1,dvrr_stack+551222, dvrr_stack+121443, dvrr_stack+100623);
 tmp = dvrr_stack + 551222;
 target_ptr = Libderiv->deriv_classes[8][11][6];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,45,1,dvrr_stack+554732, dvrr_stack+135275, dvrr_stack+110127);
 tmp = dvrr_stack + 554732;
 target_ptr = Libderiv->deriv_classes[8][12][6];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+135075, dvrr_stack+151697, dvrr_stack+327052);
 tmp = dvrr_stack + 135075;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+136615, dvrr_stack+158145, dvrr_stack+355166);
 tmp = dvrr_stack + 136615;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+325707, dvrr_stack+383971, dvrr_stack+151697);
 tmp = dvrr_stack + 325707;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+558827, dvrr_stack+401021, dvrr_stack+158145);
 tmp = dvrr_stack + 558827;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+561852, dvrr_stack+425036, dvrr_stack+383971);
 tmp = dvrr_stack + 561852;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,55,1,dvrr_stack+565482, dvrr_stack+200801, dvrr_stack+401021);
 tmp = dvrr_stack + 565482;
 target_ptr = Libderiv->deriv_classes[9][11][6];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,55,1,dvrr_stack+569772, dvrr_stack+218325, dvrr_stack+425036);
 tmp = dvrr_stack + 569772;
 target_ptr = Libderiv->deriv_classes[9][12][6];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+218325, dvrr_stack+80979, dvrr_stack+4788);
 tmp = dvrr_stack + 218325;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+218913, dvrr_stack+83059, dvrr_stack+8388);
 tmp = dvrr_stack + 218913;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+219669, dvrr_stack+88489, dvrr_stack+14553);
 tmp = dvrr_stack + 219669;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+220614, dvrr_stack+95303, dvrr_stack+22236);
 tmp = dvrr_stack + 220614;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+221769, dvrr_stack+103659, dvrr_stack+31605);
 tmp = dvrr_stack + 221769;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,78,dvrr_stack+574777, dvrr_stack+113715, dvrr_stack+42828);
 tmp = dvrr_stack + 574777;
 target_ptr = Libderiv->deriv_classes[5][11][2];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,91,dvrr_stack+576415, dvrr_stack+126175, dvrr_stack+56073);
 tmp = dvrr_stack + 576415;
 target_ptr = Libderiv->deriv_classes[5][12][2];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+223155, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 223155;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+138595, dvrr_stack+153825, dvrr_stack+8928);
 tmp = dvrr_stack + 138595;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+227385, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 227385;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+578326, dvrr_stack+20134, dvrr_stack+23061);
 tmp = dvrr_stack + 578326;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+579866, dvrr_stack+178727, dvrr_stack+32595);
 tmp = dvrr_stack + 579866;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,78,dvrr_stack+581714, dvrr_stack+190865, dvrr_stack+43998);
 tmp = dvrr_stack + 581714;
 target_ptr = Libderiv->deriv_classes[6][11][2];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,91,dvrr_stack+583898, dvrr_stack+206625, dvrr_stack+57438);
 tmp = dvrr_stack + 583898;
 target_ptr = Libderiv->deriv_classes[6][12][2];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+257034, dvrr_stack+239661, dvrr_stack+80979);
 tmp = dvrr_stack + 257034;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+586446, dvrr_stack+243981, dvrr_stack+83059);
 tmp = dvrr_stack + 586446;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+587742, dvrr_stack+86419, dvrr_stack+88489);
 tmp = dvrr_stack + 587742;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+589362, dvrr_stack+92773, dvrr_stack+95303);
 tmp = dvrr_stack + 589362;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+591342, dvrr_stack+100623, dvrr_stack+103659);
 tmp = dvrr_stack + 591342;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,78,dvrr_stack+593718, dvrr_stack+110127, dvrr_stack+113715);
 tmp = dvrr_stack + 593718;
 target_ptr = Libderiv->deriv_classes[7][11][2];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,91,dvrr_stack+596526, dvrr_stack+121443, dvrr_stack+126175);
 tmp = dvrr_stack + 596526;
 target_ptr = Libderiv->deriv_classes[7][12][2];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+599802, dvrr_stack+355166, dvrr_stack+3654);
 tmp = dvrr_stack + 599802;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+601062, dvrr_stack+151697, dvrr_stack+153825);
 tmp = dvrr_stack + 601062;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+602682, dvrr_stack+158145, dvrr_stack+12793);
 tmp = dvrr_stack + 602682;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+604707, dvrr_stack+383971, dvrr_stack+20134);
 tmp = dvrr_stack + 604707;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+607182, dvrr_stack+401021, dvrr_stack+178727);
 tmp = dvrr_stack + 607182;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,78,dvrr_stack+610152, dvrr_stack+425036, dvrr_stack+190865);
 tmp = dvrr_stack + 610152;
 target_ptr = Libderiv->deriv_classes[8][11][2];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,91,dvrr_stack+613662, dvrr_stack+200801, dvrr_stack+206625);
 tmp = dvrr_stack + 613662;
 target_ptr = Libderiv->deriv_classes[8][12][2];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+617757, dvrr_stack+350335, dvrr_stack+239661);
 tmp = dvrr_stack + 617757;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+619297, dvrr_stack+356706, dvrr_stack+243981);
 tmp = dvrr_stack + 619297;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+621277, dvrr_stack+249381, dvrr_stack+86419);
 tmp = dvrr_stack + 621277;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+623752, dvrr_stack+378471, dvrr_stack+92773);
 tmp = dvrr_stack + 623752;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+626777, dvrr_stack+258066, dvrr_stack+100623);
 tmp = dvrr_stack + 626777;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,78,dvrr_stack+630407, dvrr_stack+270191, dvrr_stack+110127);
 tmp = dvrr_stack + 630407;
 target_ptr = Libderiv->deriv_classes[9][11][2];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,91,dvrr_stack+634697, dvrr_stack+366006, dvrr_stack+121443);
 tmp = dvrr_stack + 634697;
 target_ptr = Libderiv->deriv_classes[9][12][2];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+73986, dvrr_stack+80979, dvrr_stack+4788);
 tmp = dvrr_stack + 73986;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+164130, dvrr_stack+83059, dvrr_stack+8388);
 tmp = dvrr_stack + 164130;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+347759, dvrr_stack+88489, dvrr_stack+14553);
 tmp = dvrr_stack + 347759;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+639702, dvrr_stack+95303, dvrr_stack+22236);
 tmp = dvrr_stack + 639702;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+640857, dvrr_stack+103659, dvrr_stack+31605);
 tmp = dvrr_stack + 640857;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,78,dvrr_stack+642243, dvrr_stack+113715, dvrr_stack+42828);
 tmp = dvrr_stack + 642243;
 target_ptr = Libderiv->deriv_classes[5][11][1];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,91,dvrr_stack+643881, dvrr_stack+126175, dvrr_stack+56073);
 tmp = dvrr_stack + 643881;
 target_ptr = Libderiv->deriv_classes[5][12][1];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+354367, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 354367;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+645792, dvrr_stack+153825, dvrr_stack+8928);
 tmp = dvrr_stack + 645792;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+646800, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 646800;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+648060, dvrr_stack+20134, dvrr_stack+23061);
 tmp = dvrr_stack + 648060;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+649600, dvrr_stack+178727, dvrr_stack+32595);
 tmp = dvrr_stack + 649600;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,78,dvrr_stack+651448, dvrr_stack+190865, dvrr_stack+43998);
 tmp = dvrr_stack + 651448;
 target_ptr = Libderiv->deriv_classes[6][11][1];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,91,dvrr_stack+653632, dvrr_stack+206625, dvrr_stack+57438);
 tmp = dvrr_stack + 653632;
 target_ptr = Libderiv->deriv_classes[6][12][1];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+656180, dvrr_stack+239661, dvrr_stack+80979);
 tmp = dvrr_stack + 656180;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+657188, dvrr_stack+243981, dvrr_stack+83059);
 tmp = dvrr_stack + 657188;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+658484, dvrr_stack+86419, dvrr_stack+88489);
 tmp = dvrr_stack + 658484;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+660104, dvrr_stack+92773, dvrr_stack+95303);
 tmp = dvrr_stack + 660104;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+662084, dvrr_stack+100623, dvrr_stack+103659);
 tmp = dvrr_stack + 662084;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,78,dvrr_stack+664460, dvrr_stack+110127, dvrr_stack+113715);
 tmp = dvrr_stack + 664460;
 target_ptr = Libderiv->deriv_classes[7][11][1];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,91,dvrr_stack+667268, dvrr_stack+121443, dvrr_stack+126175);
 tmp = dvrr_stack + 667268;
 target_ptr = Libderiv->deriv_classes[7][12][1];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+670544, dvrr_stack+355166, dvrr_stack+3654);
 tmp = dvrr_stack + 670544;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+671804, dvrr_stack+151697, dvrr_stack+153825);
 tmp = dvrr_stack + 671804;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+673424, dvrr_stack+158145, dvrr_stack+12793);
 tmp = dvrr_stack + 673424;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+675449, dvrr_stack+383971, dvrr_stack+20134);
 tmp = dvrr_stack + 675449;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+677924, dvrr_stack+401021, dvrr_stack+178727);
 tmp = dvrr_stack + 677924;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,78,dvrr_stack+680894, dvrr_stack+425036, dvrr_stack+190865);
 tmp = dvrr_stack + 680894;
 target_ptr = Libderiv->deriv_classes[8][11][1];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,91,dvrr_stack+684404, dvrr_stack+200801, dvrr_stack+206625);
 tmp = dvrr_stack + 684404;
 target_ptr = Libderiv->deriv_classes[8][12][1];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+688499, dvrr_stack+350335, dvrr_stack+239661);
 tmp = dvrr_stack + 688499;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+690039, dvrr_stack+356706, dvrr_stack+243981);
 tmp = dvrr_stack + 690039;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+692019, dvrr_stack+249381, dvrr_stack+86419);
 tmp = dvrr_stack + 692019;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+694494, dvrr_stack+378471, dvrr_stack+92773);
 tmp = dvrr_stack + 694494;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+697519, dvrr_stack+258066, dvrr_stack+100623);
 tmp = dvrr_stack + 697519;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,78,dvrr_stack+701149, dvrr_stack+270191, dvrr_stack+110127);
 tmp = dvrr_stack + 701149;
 target_ptr = Libderiv->deriv_classes[9][11][1];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,91,dvrr_stack+705439, dvrr_stack+366006, dvrr_stack+121443);
 tmp = dvrr_stack + 705439;
 target_ptr = Libderiv->deriv_classes[9][12][1];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+205806, dvrr_stack+80979, dvrr_stack+4788);
 tmp = dvrr_stack + 205806;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+710444, dvrr_stack+83059, dvrr_stack+8388);
 tmp = dvrr_stack + 710444;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+7821, dvrr_stack+88489, dvrr_stack+14553);
 tmp = dvrr_stack + 7821;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+711200, dvrr_stack+95303, dvrr_stack+22236);
 tmp = dvrr_stack + 711200;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+712355, dvrr_stack+103659, dvrr_stack+31605);
 tmp = dvrr_stack + 712355;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,78,dvrr_stack+713741, dvrr_stack+113715, dvrr_stack+42828);
 tmp = dvrr_stack + 713741;
 target_ptr = Libderiv->deriv_classes[5][11][0];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,91,dvrr_stack+715379, dvrr_stack+126175, dvrr_stack+56073);
 tmp = dvrr_stack + 715379;
 target_ptr = Libderiv->deriv_classes[5][12][0];
 for(i=0;i<1911;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+55674, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 55674;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+42496, dvrr_stack+153825, dvrr_stack+8928);
 tmp = dvrr_stack + 42496;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+717290, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 717290;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+14413, dvrr_stack+20134, dvrr_stack+23061);
 tmp = dvrr_stack + 14413;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+22114, dvrr_stack+178727, dvrr_stack+32595);
 tmp = dvrr_stack + 22114;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,78,dvrr_stack+31579, dvrr_stack+190865, dvrr_stack+43998);
 tmp = dvrr_stack + 31579;
 target_ptr = Libderiv->deriv_classes[6][11][0];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,91,dvrr_stack+718550, dvrr_stack+206625, dvrr_stack+57438);
 tmp = dvrr_stack + 718550;
 target_ptr = Libderiv->deriv_classes[6][12][0];
 for(i=0;i<2548;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+56458, dvrr_stack+239661, dvrr_stack+80979);
 tmp = dvrr_stack + 56458;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+57466, dvrr_stack+243981, dvrr_stack+83059);
 tmp = dvrr_stack + 57466;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+43504, dvrr_stack+86419, dvrr_stack+88489);
 tmp = dvrr_stack + 43504;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+721098, dvrr_stack+92773, dvrr_stack+95303);
 tmp = dvrr_stack + 721098;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+723078, dvrr_stack+100623, dvrr_stack+103659);
 tmp = dvrr_stack + 723078;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,78,dvrr_stack+725454, dvrr_stack+110127, dvrr_stack+113715);
 tmp = dvrr_stack + 725454;
 target_ptr = Libderiv->deriv_classes[7][11][0];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,91,dvrr_stack+728262, dvrr_stack+121443, dvrr_stack+126175);
 tmp = dvrr_stack + 728262;
 target_ptr = Libderiv->deriv_classes[7][12][0];
 for(i=0;i<3276;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+113637, dvrr_stack+355166, dvrr_stack+3654);
 tmp = dvrr_stack + 113637;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+3162, dvrr_stack+151697, dvrr_stack+153825);
 tmp = dvrr_stack + 3162;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+151697, dvrr_stack+158145, dvrr_stack+12793);
 tmp = dvrr_stack + 151697;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+158037, dvrr_stack+383971, dvrr_stack+20134);
 tmp = dvrr_stack + 158037;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+383949, dvrr_stack+401021, dvrr_stack+178727);
 tmp = dvrr_stack + 383949;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,78,dvrr_stack+400496, dvrr_stack+425036, dvrr_stack+190865);
 tmp = dvrr_stack + 400496;
 target_ptr = Libderiv->deriv_classes[8][11][0];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,91,dvrr_stack+424671, dvrr_stack+200801, dvrr_stack+206625);
 tmp = dvrr_stack + 424671;
 target_ptr = Libderiv->deriv_classes[8][12][0];
 for(i=0;i<4095;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+200576, dvrr_stack+350335, dvrr_stack+239661);
 tmp = dvrr_stack + 200576;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+202116, dvrr_stack+356706, dvrr_stack+243981);
 tmp = dvrr_stack + 202116;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+178575, dvrr_stack+249381, dvrr_stack+86419);
 tmp = dvrr_stack + 178575;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+249246, dvrr_stack+378471, dvrr_stack+92773);
 tmp = dvrr_stack + 249246;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+92629, dvrr_stack+258066, dvrr_stack+100623);
 tmp = dvrr_stack + 92629;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,78,dvrr_stack+100588, dvrr_stack+270191, dvrr_stack+110127);
 tmp = dvrr_stack + 100588;
 target_ptr = Libderiv->deriv_classes[9][11][0];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,91,dvrr_stack+270111, dvrr_stack+366006, dvrr_stack+121443);
 tmp = dvrr_stack + 270111;
 target_ptr = Libderiv->deriv_classes[9][12][0];
 for(i=0;i<5005;i++)
   target_ptr[i] += tmp[i];


}

