/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_hghg(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+5);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+5, Data->F+6, NULL);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+284, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+294, r12vrr_stack+264, r12vrr_stack+284, NULL, NULL, r12vrr_stack+48);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+354, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+6, r12vrr_stack+78, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+81, r12vrr_stack+6, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+430, r12vrr_stack+420, r12vrr_stack+274, NULL, NULL, r12vrr_stack+81);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+87);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+78, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+520, r12vrr_stack+284, r12vrr_stack+93, NULL, NULL, r12vrr_stack+108);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+550, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+114);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+610, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+132);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+168);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+204);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+960, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+975, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+990, r12vrr_stack+975, r12vrr_stack+960, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1035, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+414, r12vrr_stack+81, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+975, NULL, NULL, r12vrr_stack+274);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1095, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1110, r12vrr_stack+960, r12vrr_stack+1095, NULL, NULL, r12vrr_stack+284);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1155, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+294);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1245, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+324);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1335, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+354);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+324, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+324, r12vrr_stack+6, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+414, r12vrr_stack+324, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+420, r12vrr_stack+81, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1485, r12vrr_stack+337, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+420);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1530, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+430);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1620, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+460);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+78, r12vrr_stack+6, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+430, r12vrr_stack+87, r12vrr_stack+414, r12vrr_stack+105, r12vrr_stack+78, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+440, r12vrr_stack+93, r12vrr_stack+430, r12vrr_stack+108, r12vrr_stack+87, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+455, r12vrr_stack+1095, r12vrr_stack+440, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1770, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+520);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1860, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+550);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2010, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+610);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2235, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+710);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2460, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+810);

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+500, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+54, r12vrr_stack+0, r12vrr_stack+500, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+503, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+2775, r12vrr_stack+12, r12vrr_stack+503, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+500);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+2793, r12vrr_stack+30, r12vrr_stack+2775, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+54);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+2823, r12vrr_stack+108, r12vrr_stack+87, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+2841, r12vrr_stack+114, r12vrr_stack+2823, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+503);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+2877, r12vrr_stack+132, r12vrr_stack+2841, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+2775);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+2937, r12vrr_stack+204, r12vrr_stack+2877, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+2793);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+168, r12vrr_stack+93, r12vrr_stack+430, NULL, NULL, r12vrr_stack+87);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3027, r12vrr_stack+520, r12vrr_stack+168, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+2823);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+3087, r12vrr_stack+550, r12vrr_stack+3027, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+2841);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+3187, r12vrr_stack+610, r12vrr_stack+3087, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+2877);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+3337, r12vrr_stack+810, r12vrr_stack+3187, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+2937);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+198, r12vrr_stack+6, r12vrr_stack+3, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+710, r12vrr_stack+414, r12vrr_stack+198, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+720, r12vrr_stack+430, r12vrr_stack+710, r12vrr_stack+87, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+735, r12vrr_stack+440, r12vrr_stack+720, NULL, NULL, r12vrr_stack+430);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3547, r12vrr_stack+455, r12vrr_stack+735, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+168);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3637, r12vrr_stack+1770, r12vrr_stack+3547, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+3027);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3787, r12vrr_stack+1860, r12vrr_stack+3637, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+3087);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+4012, r12vrr_stack+2010, r12vrr_stack+3787, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+3187);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+4327, r12vrr_stack+2460, r12vrr_stack+4012, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+3337);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+780, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+264, r12vrr_stack+284, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+294, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+284, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4747, r12vrr_stack+780, r12vrr_stack+352, NULL, NULL, r12vrr_stack+1095);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4810, r12vrr_stack+294, r12vrr_stack+780, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4873, r12vrr_stack+4810, r12vrr_stack+4747, r12vrr_stack+294, r12vrr_stack+780, r12vrr_stack+1110);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1110, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+420, r12vrr_stack+274, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4999, r12vrr_stack+1110, r12vrr_stack+294, NULL, NULL, r12vrr_stack+975);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5062, r12vrr_stack+4999, r12vrr_stack+4810, r12vrr_stack+1110, r12vrr_stack+294, r12vrr_stack+990);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+990, r12vrr_stack+440, r12vrr_stack+720, r12vrr_stack+93, r12vrr_stack+430, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+5188, r12vrr_stack+352, r12vrr_stack+990, NULL, NULL, r12vrr_stack+440);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5251, r12vrr_stack+4747, r12vrr_stack+5188, r12vrr_stack+780, r12vrr_stack+352, r12vrr_stack+455);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5377, r12vrr_stack+4873, r12vrr_stack+5251, r12vrr_stack+4810, r12vrr_stack+4747, r12vrr_stack+1770);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5587, r12vrr_stack+5062, r12vrr_stack+4873, r12vrr_stack+4999, r12vrr_stack+4810, r12vrr_stack+1155);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5797, r12vrr_stack+5587, r12vrr_stack+5377, r12vrr_stack+5062, r12vrr_stack+4873, r12vrr_stack+1860);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1011, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+327, r12vrr_stack+420, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1131, r12vrr_stack+1011, r12vrr_stack+1110, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+4999, r12vrr_stack+1011, r12vrr_stack+1110, r12vrr_stack+1050);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+5062, r12vrr_stack+1131, r12vrr_stack+4999, r12vrr_stack+1245);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+5587, r12vrr_stack+6112, r12vrr_stack+5062, r12vrr_stack+1335);

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1032, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+1032, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+198, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1050, r12vrr_stack+710, r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+198, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1065, r12vrr_stack+720, r12vrr_stack+1050, r12vrr_stack+430, r12vrr_stack+710, NULL);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1194, r12vrr_stack+990, r12vrr_stack+1065, NULL, NULL, r12vrr_stack+720);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1257, r12vrr_stack+5188, r12vrr_stack+1194, r12vrr_stack+352, r12vrr_stack+990, r12vrr_stack+735);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6763, r12vrr_stack+5251, r12vrr_stack+1257, r12vrr_stack+4747, r12vrr_stack+5188, r12vrr_stack+3547);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+6973, r12vrr_stack+5377, r12vrr_stack+6763, r12vrr_stack+4873, r12vrr_stack+5251, r12vrr_stack+3637);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7288, r12vrr_stack+5797, r12vrr_stack+6973, r12vrr_stack+5587, r12vrr_stack+5377, r12vrr_stack+3787);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+5797, r12vrr_stack+6238, r12vrr_stack+5587, r12vrr_stack+2010);
 tmp = r12vrr_stack + 7729;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+7288, r12vrr_stack+6448, r12vrr_stack+5797, r12vrr_stack+4012);
 tmp = r12vrr_stack + 8170;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1383, r12vrr_stack+780, r12vrr_stack+352, r12vrr_stack+960, r12vrr_stack+1095, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1411, r12vrr_stack+294, r12vrr_stack+780, r12vrr_stack+975, r12vrr_stack+960, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8758, r12vrr_stack+1411, r12vrr_stack+1383, NULL, NULL, r12vrr_stack+780);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1439, r12vrr_stack+1110, r12vrr_stack+294, r12vrr_stack+1035, r12vrr_stack+975, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8842, r12vrr_stack+1439, r12vrr_stack+1411, NULL, NULL, r12vrr_stack+294);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+960, r12vrr_stack+352, r12vrr_stack+990, r12vrr_stack+1095, r12vrr_stack+440, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8926, r12vrr_stack+1383, r12vrr_stack+960, NULL, NULL, r12vrr_stack+352);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9010, r12vrr_stack+8758, r12vrr_stack+8926, r12vrr_stack+1411, r12vrr_stack+1383, r12vrr_stack+4747);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9178, r12vrr_stack+8842, r12vrr_stack+8758, r12vrr_stack+1439, r12vrr_stack+1411, r12vrr_stack+4810);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+9346, r12vrr_stack+9178, r12vrr_stack+9010, r12vrr_stack+8842, r12vrr_stack+8758, r12vrr_stack+4873);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4747, r12vrr_stack+1011, r12vrr_stack+1110, r12vrr_stack+337, r12vrr_stack+1035, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4775, r12vrr_stack+4747, r12vrr_stack+1439, NULL, NULL, r12vrr_stack+1110);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+8842, r12vrr_stack+4747, r12vrr_stack+1439, r12vrr_stack+4999);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+9178, r12vrr_stack+4775, r12vrr_stack+8842, r12vrr_stack+5062);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4859, r12vrr_stack+990, r12vrr_stack+1065, r12vrr_stack+440, r12vrr_stack+720, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4887, r12vrr_stack+960, r12vrr_stack+4859, NULL, NULL, r12vrr_stack+990);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4971, r12vrr_stack+8926, r12vrr_stack+4887, r12vrr_stack+1383, r12vrr_stack+960, r12vrr_stack+5188);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+10074, r12vrr_stack+9010, r12vrr_stack+4971, r12vrr_stack+8758, r12vrr_stack+8926, r12vrr_stack+5251);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+10354, r12vrr_stack+9346, r12vrr_stack+10074, r12vrr_stack+9178, r12vrr_stack+9010, r12vrr_stack+5377);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+9346, r12vrr_stack+9626, r12vrr_stack+9178, r12vrr_stack+5587);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+10354, r12vrr_stack+9794, r12vrr_stack+9346, r12vrr_stack+5797);
 tmp = r12vrr_stack + 11194;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5587, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5590, r12vrr_stack+1032, r12vrr_stack+5587, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5596, r12vrr_stack+48, r12vrr_stack+5590, r12vrr_stack+3, r12vrr_stack+1032, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1035, r12vrr_stack+420, r12vrr_stack+5596, r12vrr_stack+198, r12vrr_stack+48, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5606, r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+710, r12vrr_stack+420, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5627, r12vrr_stack+1065, r12vrr_stack+5606, r12vrr_stack+720, r12vrr_stack+1050, NULL);

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5655, r12vrr_stack+4859, r12vrr_stack+5627, NULL, NULL, r12vrr_stack+1065);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+11782, r12vrr_stack+4887, r12vrr_stack+5655, r12vrr_stack+960, r12vrr_stack+4859, r12vrr_stack+1194);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+11950, r12vrr_stack+4971, r12vrr_stack+11782, r12vrr_stack+8926, r12vrr_stack+4887, r12vrr_stack+1257);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+12230, r12vrr_stack+10074, r12vrr_stack+11950, r12vrr_stack+9010, r12vrr_stack+4971, r12vrr_stack+6763);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+12650, r12vrr_stack+10354, r12vrr_stack+12230, r12vrr_stack+9346, r12vrr_stack+10074, r12vrr_stack+6973);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+12650, r12vrr_stack+10774, r12vrr_stack+10354, r12vrr_stack+7288);
 tmp = r12vrr_stack + 13238;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+1383, r12vrr_stack+960, r12vrr_stack+780, r12vrr_stack+352, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5139, r12vrr_stack+1411, r12vrr_stack+1383, r12vrr_stack+294, r12vrr_stack+780, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+5139, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+1383);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+373, r12vrr_stack+1439, r12vrr_stack+1411, r12vrr_stack+1110, r12vrr_stack+294, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14130, r12vrr_stack+373, r12vrr_stack+5139, NULL, NULL, r12vrr_stack+1411);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+264, r12vrr_stack+960, r12vrr_stack+4859, r12vrr_stack+352, r12vrr_stack+990, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14238, r12vrr_stack+5739, r12vrr_stack+264, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14346, r12vrr_stack+14022, r12vrr_stack+14238, r12vrr_stack+5139, r12vrr_stack+5739, r12vrr_stack+8926);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14562, r12vrr_stack+14130, r12vrr_stack+14022, r12vrr_stack+373, r12vrr_stack+5139, r12vrr_stack+8758);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14778, r12vrr_stack+14562, r12vrr_stack+14346, r12vrr_stack+14130, r12vrr_stack+14022, r12vrr_stack+9010);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+4747, r12vrr_stack+1439, r12vrr_stack+1011, r12vrr_stack+1110, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8926, r12vrr_stack+8758, r12vrr_stack+373, NULL, NULL, r12vrr_stack+1439);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+14130, r12vrr_stack+8758, r12vrr_stack+373, r12vrr_stack+8842);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+14562, r12vrr_stack+8926, r12vrr_stack+14130, r12vrr_stack+9178);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8794, r12vrr_stack+4859, r12vrr_stack+5627, r12vrr_stack+990, r12vrr_stack+1065, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9034, r12vrr_stack+264, r12vrr_stack+8794, NULL, NULL, r12vrr_stack+4859);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+14238, r12vrr_stack+9034, r12vrr_stack+5739, r12vrr_stack+264, r12vrr_stack+4887);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15930, r12vrr_stack+14346, r12vrr_stack+15714, r12vrr_stack+14022, r12vrr_stack+14238, r12vrr_stack+4971);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16290, r12vrr_stack+14778, r12vrr_stack+15930, r12vrr_stack+14562, r12vrr_stack+14346, r12vrr_stack+10074);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+14778, r12vrr_stack+15138, r12vrr_stack+14562, r12vrr_stack+9346);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+16290, r12vrr_stack+15354, r12vrr_stack+14778, r12vrr_stack+10354);
 tmp = r12vrr_stack + 17370;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+8830, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+8833, r12vrr_stack+5587, r12vrr_stack+8830, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+8839, r12vrr_stack+5590, r12vrr_stack+8833, r12vrr_stack+1032, r12vrr_stack+5587, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+8849, r12vrr_stack+5596, r12vrr_stack+8839, r12vrr_stack+48, r12vrr_stack+5590, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+1035, r12vrr_stack+8849, r12vrr_stack+420, r12vrr_stack+5596, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8864, r12vrr_stack+5606, r12vrr_stack+352, r12vrr_stack+1050, r12vrr_stack+1035, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9142, r12vrr_stack+5627, r12vrr_stack+8864, r12vrr_stack+1065, r12vrr_stack+5606, NULL);

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9178, r12vrr_stack+8794, r12vrr_stack+9142, NULL, NULL, r12vrr_stack+5627);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9286, r12vrr_stack+9034, r12vrr_stack+9178, r12vrr_stack+264, r12vrr_stack+8794, r12vrr_stack+5655);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18126, r12vrr_stack+15714, r12vrr_stack+9286, r12vrr_stack+14238, r12vrr_stack+9034, r12vrr_stack+11782);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18486, r12vrr_stack+15930, r12vrr_stack+18126, r12vrr_stack+14346, r12vrr_stack+15714, r12vrr_stack+11950);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19026, r12vrr_stack+16290, r12vrr_stack+18486, r12vrr_stack+14778, r12vrr_stack+15930, r12vrr_stack+12230);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+19026, r12vrr_stack+16830, r12vrr_stack+16290, r12vrr_stack+12650);
 tmp = r12vrr_stack + 19782;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1086, r12vrr_stack+5739, r12vrr_stack+264, r12vrr_stack+1383, r12vrr_stack+960, NULL);

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9502, r12vrr_stack+5139, r12vrr_stack+5739, r12vrr_stack+1411, r12vrr_stack+1383, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+9502, r12vrr_stack+1086, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9547, r12vrr_stack+373, r12vrr_stack+5139, r12vrr_stack+1439, r12vrr_stack+1411, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20925, r12vrr_stack+9547, r12vrr_stack+9502, NULL, NULL, r12vrr_stack+5139);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1383, r12vrr_stack+264, r12vrr_stack+8794, r12vrr_stack+960, r12vrr_stack+4859, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21060, r12vrr_stack+1086, r12vrr_stack+1383, NULL, NULL, r12vrr_stack+264);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21195, r12vrr_stack+20790, r12vrr_stack+21060, r12vrr_stack+9502, r12vrr_stack+1086, r12vrr_stack+14238);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21465, r12vrr_stack+20925, r12vrr_stack+20790, r12vrr_stack+9547, r12vrr_stack+9502, r12vrr_stack+14022);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21735, r12vrr_stack+21465, r12vrr_stack+21195, r12vrr_stack+20925, r12vrr_stack+20790, r12vrr_stack+14346);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+373, r12vrr_stack+4747, r12vrr_stack+1439, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14238, r12vrr_stack+14022, r12vrr_stack+9547, NULL, NULL, r12vrr_stack+373);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+20925, r12vrr_stack+14022, r12vrr_stack+9547, r12vrr_stack+14130);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+21465, r12vrr_stack+14238, r12vrr_stack+20925, r12vrr_stack+14562);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14067, r12vrr_stack+8794, r12vrr_stack+9142, r12vrr_stack+4859, r12vrr_stack+5627, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14373, r12vrr_stack+1383, r12vrr_stack+14067, NULL, NULL, r12vrr_stack+8794);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14508, r12vrr_stack+21060, r12vrr_stack+14373, r12vrr_stack+1086, r12vrr_stack+1383, r12vrr_stack+9034);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22905, r12vrr_stack+21195, r12vrr_stack+14508, r12vrr_stack+20790, r12vrr_stack+21060, r12vrr_stack+15714);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+23355, r12vrr_stack+21735, r12vrr_stack+22905, r12vrr_stack+21465, r12vrr_stack+21195, r12vrr_stack+15930);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+21735, r12vrr_stack+22185, r12vrr_stack+21465, r12vrr_stack+14778);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+23355, r12vrr_stack+22455, r12vrr_stack+21735, r12vrr_stack+16290);
 tmp = r12vrr_stack + 24705;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+14778, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+14781, r12vrr_stack+8830, r12vrr_stack+14778, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+14787, r12vrr_stack+8833, r12vrr_stack+14781, r12vrr_stack+5587, r12vrr_stack+8830, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+14797, r12vrr_stack+8839, r12vrr_stack+14787, r12vrr_stack+5590, r12vrr_stack+8833, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+14812, r12vrr_stack+8849, r12vrr_stack+14797, r12vrr_stack+5596, r12vrr_stack+8839, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+14833, r12vrr_stack+352, r12vrr_stack+14812, r12vrr_stack+1035, r12vrr_stack+8849, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14861, r12vrr_stack+8864, r12vrr_stack+14833, r12vrr_stack+5606, r12vrr_stack+352, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14897, r12vrr_stack+9142, r12vrr_stack+14861, r12vrr_stack+5627, r12vrr_stack+8864, NULL);

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14942, r12vrr_stack+14067, r12vrr_stack+14897, NULL, NULL, r12vrr_stack+9142);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25650, r12vrr_stack+14373, r12vrr_stack+14942, r12vrr_stack+1383, r12vrr_stack+14067, r12vrr_stack+9178);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25920, r12vrr_stack+14508, r12vrr_stack+25650, r12vrr_stack+21060, r12vrr_stack+14373, r12vrr_stack+9286);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+26370, r12vrr_stack+22905, r12vrr_stack+25920, r12vrr_stack+21195, r12vrr_stack+14508, r12vrr_stack+18126);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27045, r12vrr_stack+23355, r12vrr_stack+26370, r12vrr_stack+21735, r12vrr_stack+22905, r12vrr_stack+18486);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+27045, r12vrr_stack+24030, r12vrr_stack+23355, r12vrr_stack+19026);
 tmp = r12vrr_stack + 27990;
 target_ptr = Libr12->gvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15077, r12vrr_stack+1086, r12vrr_stack+1383, r12vrr_stack+5739, r12vrr_stack+264, NULL);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14112, r12vrr_stack+9502, r12vrr_stack+1086, r12vrr_stack+5139, r12vrr_stack+5739, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+14112, r12vrr_stack+15077, NULL, NULL, r12vrr_stack+1086);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+9547, r12vrr_stack+9502, r12vrr_stack+373, r12vrr_stack+5139, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29415, r12vrr_stack+5739, r12vrr_stack+14112, NULL, NULL, r12vrr_stack+9502);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14167, r12vrr_stack+1383, r12vrr_stack+14067, r12vrr_stack+264, r12vrr_stack+8794, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29580, r12vrr_stack+15077, r12vrr_stack+14167, NULL, NULL, r12vrr_stack+1383);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29745, r12vrr_stack+29250, r12vrr_stack+29580, r12vrr_stack+14112, r12vrr_stack+15077, r12vrr_stack+21060);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30075, r12vrr_stack+29415, r12vrr_stack+29250, r12vrr_stack+5739, r12vrr_stack+14112, r12vrr_stack+20790);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30405, r12vrr_stack+30075, r12vrr_stack+29745, r12vrr_stack+29415, r12vrr_stack+29250, r12vrr_stack+21195);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+9547, r12vrr_stack+8758, r12vrr_stack+373, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21060, r12vrr_stack+20790, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+9547);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+29415, r12vrr_stack+20790, r12vrr_stack+5739, r12vrr_stack+20925);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+30075, r12vrr_stack+21060, r12vrr_stack+29415, r12vrr_stack+21465);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20845, r12vrr_stack+14067, r12vrr_stack+14897, r12vrr_stack+8794, r12vrr_stack+9142, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21225, r12vrr_stack+14167, r12vrr_stack+20845, NULL, NULL, r12vrr_stack+14067);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21390, r12vrr_stack+29580, r12vrr_stack+21225, r12vrr_stack+15077, r12vrr_stack+14167, r12vrr_stack+14373);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+29745, r12vrr_stack+21390, r12vrr_stack+29250, r12vrr_stack+29580, r12vrr_stack+14508);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+32385, r12vrr_stack+30405, r12vrr_stack+31835, r12vrr_stack+30075, r12vrr_stack+29745, r12vrr_stack+22905);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+30405, r12vrr_stack+30955, r12vrr_stack+30075, r12vrr_stack+21735);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+32385, r12vrr_stack+31285, r12vrr_stack+30405, r12vrr_stack+23355);
 tmp = r12vrr_stack + 34035;
 target_ptr = Libr12->gvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^14 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5794, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /*--- compute (00|d0)^13 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15132, r12vrr_stack+14778, r12vrr_stack+5794, Data->F+13, Data->F+14, NULL);

 /*--- compute (00|f0)^12 ---*/
 _BUILD_00f0(Data,r12vrr_stack+373, r12vrr_stack+14781, r12vrr_stack+15132, r12vrr_stack+8830, r12vrr_stack+14778, NULL);

 /*--- compute (00|g0)^11 ---*/
 _BUILD_00g0(Data,r12vrr_stack+383, r12vrr_stack+14787, r12vrr_stack+373, r12vrr_stack+8833, r12vrr_stack+14781, NULL);

 /*--- compute (00|h0)^10 ---*/
 _BUILD_00h0(Data,r12vrr_stack+20900, r12vrr_stack+14797, r12vrr_stack+383, r12vrr_stack+8839, r12vrr_stack+14787, NULL);

 /*--- compute (00|i0)^9 ---*/
 _BUILD_00i0(Data,r12vrr_stack+20921, r12vrr_stack+14812, r12vrr_stack+20900, r12vrr_stack+8849, r12vrr_stack+14797, NULL);

 /*--- compute (00|k0)^8 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+20949, r12vrr_stack+14833, r12vrr_stack+20921, r12vrr_stack+352, r12vrr_stack+14812, NULL);

 /*--- compute (00|l0)^7 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20985, r12vrr_stack+14861, r12vrr_stack+20949, r12vrr_stack+8864, r12vrr_stack+14833, NULL);

 /*--- compute (00|m0)^6 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21720, r12vrr_stack+14897, r12vrr_stack+20985, r12vrr_stack+9142, r12vrr_stack+14861, NULL);

 /*--- compute (p0|m0)^5 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21775, r12vrr_stack+20845, r12vrr_stack+21720, NULL, NULL, r12vrr_stack+14897);

 /*--- compute (d0|m0)^4 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35190, r12vrr_stack+21225, r12vrr_stack+21775, r12vrr_stack+14167, r12vrr_stack+20845, r12vrr_stack+14942);

 /*--- compute (f0|m0)^3 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35520, r12vrr_stack+21390, r12vrr_stack+35190, r12vrr_stack+29580, r12vrr_stack+21225, r12vrr_stack+25650);

 /*--- compute (g0|m0)^2 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+36070, r12vrr_stack+31835, r12vrr_stack+35520, r12vrr_stack+29745, r12vrr_stack+21390, r12vrr_stack+25920);

 /*--- compute (h0|m0)^1 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+36895, r12vrr_stack+32385, r12vrr_stack+36070, r12vrr_stack+30405, r12vrr_stack+31835, r12vrr_stack+26370);

 /*--- compute (i0|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+36895, r12vrr_stack+33210, r12vrr_stack+32385, r12vrr_stack+27045);
 tmp = r12vrr_stack + 38050;
 target_ptr = Libr12->gvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^3 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+21940, r12vrr_stack+15077, r12vrr_stack+14167, r12vrr_stack+1086, r12vrr_stack+1383, NULL);

 /*--- compute (00|n0)^2 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22006, r12vrr_stack+14112, r12vrr_stack+15077, r12vrr_stack+9502, r12vrr_stack+1086, NULL);

 /*--- compute (p0|n0)^2 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+22006, r12vrr_stack+21940, NULL, NULL, r12vrr_stack+15077);

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22072, r12vrr_stack+5739, r12vrr_stack+14112, r12vrr_stack+9547, r12vrr_stack+9502, NULL);

 /*--- compute (p0|n0)^1 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39788, r12vrr_stack+22072, r12vrr_stack+22006, NULL, NULL, r12vrr_stack+14112);

 /*--- compute (00|n0)^4 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39986, r12vrr_stack+14167, r12vrr_stack+20845, r12vrr_stack+1383, r12vrr_stack+14067, NULL);

 /*--- compute (p0|n0)^3 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40052, r12vrr_stack+21940, r12vrr_stack+39986, NULL, NULL, r12vrr_stack+14167);

 /*--- compute (d0|n0)^2 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40250, r12vrr_stack+39590, r12vrr_stack+40052, r12vrr_stack+22006, r12vrr_stack+21940, r12vrr_stack+29580);

 /*--- compute (d0|n0)^1 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40646, r12vrr_stack+39788, r12vrr_stack+39590, r12vrr_stack+22072, r12vrr_stack+22006, r12vrr_stack+29250);

 /*--- compute (f0|n0)^1 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41042, r12vrr_stack+40646, r12vrr_stack+40250, r12vrr_stack+39788, r12vrr_stack+39590, r12vrr_stack+29745);

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22006, r12vrr_stack+20790, r12vrr_stack+5739, r12vrr_stack+14022, r12vrr_stack+9547, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29580, r12vrr_stack+22006, r12vrr_stack+22072, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (d0|n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41702, r12vrr_stack+29580, r12vrr_stack+39788, r12vrr_stack+22006, r12vrr_stack+22072, r12vrr_stack+29415);

 /*--- compute (f0|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42098, r12vrr_stack+41702, r12vrr_stack+40646, r12vrr_stack+29580, r12vrr_stack+39788, r12vrr_stack+30075);

 /*--- compute (00|n0)^5 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39788, r12vrr_stack+20845, r12vrr_stack+21720, r12vrr_stack+14067, r12vrr_stack+14897, NULL);

 /*--- compute (p0|n0)^4 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+39986, r12vrr_stack+39788, NULL, NULL, r12vrr_stack+20845);

 /*--- compute (d0|n0)^3 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29448, r12vrr_stack+40052, r12vrr_stack+29250, r12vrr_stack+21940, r12vrr_stack+39986, r12vrr_stack+21225);

 /*--- compute (f0|n0)^2 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42758, r12vrr_stack+40250, r12vrr_stack+29448, r12vrr_stack+39590, r12vrr_stack+40052, r12vrr_stack+21390);

 /*--- compute (g0|n0)^1 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+43418, r12vrr_stack+41042, r12vrr_stack+42758, r12vrr_stack+40646, r12vrr_stack+40250, r12vrr_stack+31835);

 /*--- compute (g0|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+44408, r12vrr_stack+42098, r12vrr_stack+41042, r12vrr_stack+41702, r12vrr_stack+40646, r12vrr_stack+30405);

 /*--- compute (h0|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+45398, r12vrr_stack+44408, r12vrr_stack+43418, r12vrr_stack+42098, r12vrr_stack+41042, r12vrr_stack+32385);
 tmp = r12vrr_stack + 45398;
 target_ptr = Libr12->gvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^6 ---*/
 _BUILD_p000(Data,r12vrr_stack+5587, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (d0|00)^5 ---*/
 _BUILD_d000(Data,r12vrr_stack+40646, r12vrr_stack+500, r12vrr_stack+5587, Data->F+5, Data->F+6, NULL);

 /*--- compute (f0|00)^4 ---*/
 _BUILD_f000(Data,r12vrr_stack+40652, r12vrr_stack+54, r12vrr_stack+40646, r12vrr_stack+0, r12vrr_stack+500, NULL);

 /*--- compute (p0|p0)^6 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+8830, r12vrr_stack+105, r12vrr_stack+78, NULL, NULL, Data->F+7);

 /*--- compute (d0|p0)^5 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+60, r12vrr_stack+503, r12vrr_stack+8830, r12vrr_stack+9, r12vrr_stack+105, r12vrr_stack+5587);

 /*--- compute (f0|p0)^4 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+21030, r12vrr_stack+2775, r12vrr_stack+60, r12vrr_stack+12, r12vrr_stack+503, r12vrr_stack+40646);

 /*--- compute (g0|p0)^3 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+1086, r12vrr_stack+2793, r12vrr_stack+21030, r12vrr_stack+30, r12vrr_stack+2775, r12vrr_stack+40652);

 /*--- compute (p0|d0)^6 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+9, r12vrr_stack+87, r12vrr_stack+414, NULL, NULL, r12vrr_stack+78);

 /*--- compute (d0|d0)^5 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+40662, r12vrr_stack+2823, r12vrr_stack+9, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+8830);

 /*--- compute (f0|d0)^4 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+264, r12vrr_stack+2841, r12vrr_stack+40662, r12vrr_stack+114, r12vrr_stack+2823, r12vrr_stack+60);

 /*--- compute (g0|d0)^3 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+40698, r12vrr_stack+2877, r12vrr_stack+264, r12vrr_stack+132, r12vrr_stack+2841, r12vrr_stack+21030);

 /*--- compute (h0|d0)^2 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+14112, r12vrr_stack+2937, r12vrr_stack+40698, r12vrr_stack+204, r12vrr_stack+2877, r12vrr_stack+1086);

 /*--- compute (p0|f0)^6 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+960, r12vrr_stack+430, r12vrr_stack+710, NULL, NULL, r12vrr_stack+414);

 /*--- compute (d0|f0)^5 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+960, r12vrr_stack+93, r12vrr_stack+430, r12vrr_stack+9);

 /*--- compute (f0|f0)^4 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+40788, r12vrr_stack+3027, r12vrr_stack+204, r12vrr_stack+520, r12vrr_stack+168, r12vrr_stack+40662);

 /*--- compute (g0|f0)^3 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+40888, r12vrr_stack+3087, r12vrr_stack+40788, r12vrr_stack+550, r12vrr_stack+3027, r12vrr_stack+264);

 /*--- compute (h0|f0)^2 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+41702, r12vrr_stack+3187, r12vrr_stack+40888, r12vrr_stack+610, r12vrr_stack+3087, r12vrr_stack+40698);

 /*--- compute (i0|f0)^1 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+41912, r12vrr_stack+3337, r12vrr_stack+41702, r12vrr_stack+810, r12vrr_stack+3187, r12vrr_stack+14112);

 /*--- compute (p0|g0)^6 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+108, r12vrr_stack+720, r12vrr_stack+1050, NULL, NULL, r12vrr_stack+710);

 /*--- compute (d0|g0)^5 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+42192, r12vrr_stack+735, r12vrr_stack+108, r12vrr_stack+440, r12vrr_stack+720, r12vrr_stack+960);

 /*--- compute (f0|g0)^4 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+42282, r12vrr_stack+3547, r12vrr_stack+42192, r12vrr_stack+455, r12vrr_stack+735, r12vrr_stack+204);

 /*--- compute (g0|g0)^3 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+42432, r12vrr_stack+3637, r12vrr_stack+42282, r12vrr_stack+1770, r12vrr_stack+3547, r12vrr_stack+40788);

 /*--- compute (h0|g0)^2 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+29844, r12vrr_stack+3787, r12vrr_stack+42432, r12vrr_stack+1860, r12vrr_stack+3637, r12vrr_stack+40888);

 /*--- compute (i0|g0)^1 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+30159, r12vrr_stack+4012, r12vrr_stack+29844, r12vrr_stack+2010, r12vrr_stack+3787, r12vrr_stack+41702);

 /*--- compute (k0|g0)^0 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+46784, r12vrr_stack+4327, r12vrr_stack+30159, r12vrr_stack+2460, r12vrr_stack+4012, r12vrr_stack+41912);

 /*--- compute (p0|h0)^6 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1770, r12vrr_stack+1065, r12vrr_stack+5606, NULL, NULL, r12vrr_stack+1050);

 /*--- compute (d0|h0)^5 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1833, r12vrr_stack+1194, r12vrr_stack+1770, r12vrr_stack+990, r12vrr_stack+1065, r12vrr_stack+108);

 /*--- compute (f0|h0)^4 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1959, r12vrr_stack+1257, r12vrr_stack+1833, r12vrr_stack+5188, r12vrr_stack+1194, r12vrr_stack+42192);

 /*--- compute (g0|h0)^3 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+30579, r12vrr_stack+6763, r12vrr_stack+1959, r12vrr_stack+5251, r12vrr_stack+1257, r12vrr_stack+42282);

 /*--- compute (h0|h0)^2 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+47324, r12vrr_stack+6973, r12vrr_stack+30579, r12vrr_stack+5377, r12vrr_stack+6763, r12vrr_stack+42432);

 /*--- compute (i0|h0)^1 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+47765, r12vrr_stack+7288, r12vrr_stack+47324, r12vrr_stack+5797, r12vrr_stack+6973, r12vrr_stack+29844);

 /*--- compute (k0|h0)^0 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+48353, r12vrr_stack+8170, r12vrr_stack+47765, r12vrr_stack+7729, r12vrr_stack+7288, r12vrr_stack+30159);
 tmp = r12vrr_stack + 48353;
 target_ptr = Libr12->gvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^6 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5797, r12vrr_stack+5627, r12vrr_stack+8864, NULL, NULL, r12vrr_stack+5606);

 /*--- compute (d0|i0)^5 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5881, r12vrr_stack+5655, r12vrr_stack+5797, r12vrr_stack+4859, r12vrr_stack+5627, r12vrr_stack+1770);

 /*--- compute (f0|i0)^4 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5139, r12vrr_stack+11782, r12vrr_stack+5881, r12vrr_stack+4887, r12vrr_stack+5655, r12vrr_stack+1833);

 /*--- compute (g0|i0)^3 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+49109, r12vrr_stack+11950, r12vrr_stack+5139, r12vrr_stack+4971, r12vrr_stack+11782, r12vrr_stack+1959);

 /*--- compute (h0|i0)^2 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+49529, r12vrr_stack+12230, r12vrr_stack+49109, r12vrr_stack+10074, r12vrr_stack+11950, r12vrr_stack+30579);

 /*--- compute (i0|i0)^1 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+50117, r12vrr_stack+12650, r12vrr_stack+49529, r12vrr_stack+10354, r12vrr_stack+12230, r12vrr_stack+47324);

 /*--- compute (k0|i0)^0 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+50901, r12vrr_stack+13238, r12vrr_stack+50117, r12vrr_stack+11194, r12vrr_stack+12650, r12vrr_stack+47765);
 tmp = r12vrr_stack + 50901;
 target_ptr = Libr12->gvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^6 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10074, r12vrr_stack+9142, r12vrr_stack+14861, NULL, NULL, r12vrr_stack+8864);

 /*--- compute (d0|k0)^5 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10182, r12vrr_stack+9178, r12vrr_stack+10074, r12vrr_stack+8794, r12vrr_stack+9142, r12vrr_stack+5797);

 /*--- compute (f0|k0)^4 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10398, r12vrr_stack+9286, r12vrr_stack+10182, r12vrr_stack+9034, r12vrr_stack+9178, r12vrr_stack+5881);

 /*--- compute (g0|k0)^3 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+51909, r12vrr_stack+18126, r12vrr_stack+10398, r12vrr_stack+15714, r12vrr_stack+9286, r12vrr_stack+5139);

 /*--- compute (h0|k0)^2 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+52449, r12vrr_stack+18486, r12vrr_stack+51909, r12vrr_stack+15930, r12vrr_stack+18126, r12vrr_stack+49109);

 /*--- compute (i0|k0)^1 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+53205, r12vrr_stack+19026, r12vrr_stack+52449, r12vrr_stack+16290, r12vrr_stack+18486, r12vrr_stack+49529);

 /*--- compute (k0|k0)^0 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+54213, r12vrr_stack+19782, r12vrr_stack+53205, r12vrr_stack+17370, r12vrr_stack+19026, r12vrr_stack+50117);
 tmp = r12vrr_stack + 54213;
 target_ptr = Libr12->gvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^6 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+14897, r12vrr_stack+20985, NULL, NULL, r12vrr_stack+14861);

 /*--- compute (d0|l0)^5 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15849, r12vrr_stack+14942, r12vrr_stack+15714, r12vrr_stack+14067, r12vrr_stack+14897, r12vrr_stack+10074);

 /*--- compute (f0|l0)^4 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16119, r12vrr_stack+25650, r12vrr_stack+15849, r12vrr_stack+14373, r12vrr_stack+14942, r12vrr_stack+10182);

 /*--- compute (g0|l0)^3 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+55509, r12vrr_stack+25920, r12vrr_stack+16119, r12vrr_stack+14508, r12vrr_stack+25650, r12vrr_stack+10398);

 /*--- compute (h0|l0)^2 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+56184, r12vrr_stack+26370, r12vrr_stack+55509, r12vrr_stack+22905, r12vrr_stack+25920, r12vrr_stack+51909);

 /*--- compute (i0|l0)^1 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+57129, r12vrr_stack+27045, r12vrr_stack+56184, r12vrr_stack+23355, r12vrr_stack+26370, r12vrr_stack+52449);

 /*--- compute (k0|l0)^0 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+58389, r12vrr_stack+27990, r12vrr_stack+57129, r12vrr_stack+24705, r12vrr_stack+27045, r12vrr_stack+53205);
 tmp = r12vrr_stack + 58389;
 target_ptr = Libr12->gvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^15 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /*--- compute (00|d0)^14 ---*/
 _BUILD_00d0(Data,r12vrr_stack+22905, r12vrr_stack+5794, r12vrr_stack+0, Data->F+14, Data->F+15, NULL);

 /*--- compute (00|f0)^13 ---*/
 _BUILD_00f0(Data,r12vrr_stack+22911, r12vrr_stack+15132, r12vrr_stack+22905, r12vrr_stack+14778, r12vrr_stack+5794, NULL);

 /*--- compute (00|g0)^12 ---*/
 _BUILD_00g0(Data,r12vrr_stack+153, r12vrr_stack+373, r12vrr_stack+22911, r12vrr_stack+14781, r12vrr_stack+15132, NULL);

 /*--- compute (00|h0)^11 ---*/
 _BUILD_00h0(Data,r12vrr_stack+990, r12vrr_stack+383, r12vrr_stack+153, r12vrr_stack+14787, r12vrr_stack+373, NULL);

 /*--- compute (00|i0)^10 ---*/
 _BUILD_00i0(Data,r12vrr_stack+22921, r12vrr_stack+20900, r12vrr_stack+990, r12vrr_stack+14797, r12vrr_stack+383, NULL);

 /*--- compute (00|k0)^9 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8794, r12vrr_stack+20921, r12vrr_stack+22921, r12vrr_stack+14812, r12vrr_stack+20900, NULL);

 /*--- compute (00|l0)^8 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14067, r12vrr_stack+20949, r12vrr_stack+8794, r12vrr_stack+14833, r12vrr_stack+20921, NULL);

 /*--- compute (00|m0)^7 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+20985, r12vrr_stack+14067, r12vrr_stack+14861, r12vrr_stack+20949, NULL);

 /*--- compute (p0|m0)^6 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22949, r12vrr_stack+21720, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+20985);

 /*--- compute (d0|m0)^5 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23114, r12vrr_stack+21775, r12vrr_stack+22949, r12vrr_stack+20845, r12vrr_stack+21720, r12vrr_stack+15714);

 /*--- compute (f0|m0)^4 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23444, r12vrr_stack+35190, r12vrr_stack+23114, r12vrr_stack+21225, r12vrr_stack+21775, r12vrr_stack+15849);

 /*--- compute (g0|m0)^3 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+60009, r12vrr_stack+35520, r12vrr_stack+23444, r12vrr_stack+21390, r12vrr_stack+35190, r12vrr_stack+16119);

 /*--- compute (h0|m0)^2 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+60834, r12vrr_stack+36070, r12vrr_stack+60009, r12vrr_stack+31835, r12vrr_stack+35520, r12vrr_stack+55509);

 /*--- compute (i0|m0)^1 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+61989, r12vrr_stack+36895, r12vrr_stack+60834, r12vrr_stack+32385, r12vrr_stack+36070, r12vrr_stack+56184);

 /*--- compute (k0|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+63529, r12vrr_stack+38050, r12vrr_stack+61989, r12vrr_stack+34035, r12vrr_stack+36895, r12vrr_stack+57129);
 tmp = r12vrr_stack + 63529;
 target_ptr = Libr12->gvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^6 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+2169, r12vrr_stack+21720, r12vrr_stack+5739, r12vrr_stack+14897, r12vrr_stack+20985, NULL);

 /*--- compute (p0|n0)^5 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+39788, r12vrr_stack+2169, NULL, NULL, r12vrr_stack+21720);

 /*--- compute (d0|n0)^4 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+29250, r12vrr_stack+39590, r12vrr_stack+39986, r12vrr_stack+39788, r12vrr_stack+21775);

 /*--- compute (f0|n0)^3 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+32231, r12vrr_stack+29448, r12vrr_stack+31835, r12vrr_stack+40052, r12vrr_stack+29250, r12vrr_stack+35190);

 /*--- compute (g0|n0)^2 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+65509, r12vrr_stack+42758, r12vrr_stack+32231, r12vrr_stack+40250, r12vrr_stack+29448, r12vrr_stack+35520);

 /*--- compute (h0|n0)^1 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+66499, r12vrr_stack+43418, r12vrr_stack+65509, r12vrr_stack+41042, r12vrr_stack+42758, r12vrr_stack+36070);

 /*--- compute (i0|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+67885, r12vrr_stack+45398, r12vrr_stack+66499, r12vrr_stack+44408, r12vrr_stack+43418, r12vrr_stack+36895);
 tmp = r12vrr_stack + 67885;
 target_ptr = Libr12->gvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^7 ---*/
 _BUILD_p000(Data,r12vrr_stack+32891, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (d0|00)^6 ---*/
 _BUILD_d000(Data,r12vrr_stack+32894, r12vrr_stack+5587, r12vrr_stack+32891, Data->F+6, Data->F+7, NULL);

 /*--- compute (f0|00)^5 ---*/
 _BUILD_f000(Data,r12vrr_stack+32900, r12vrr_stack+40646, r12vrr_stack+32894, r12vrr_stack+500, r12vrr_stack+5587, NULL);

 /*--- compute (g0|00)^4 ---*/
 _BUILD_g000(Data,r12vrr_stack+32910, r12vrr_stack+40652, r12vrr_stack+32900, r12vrr_stack+54, r12vrr_stack+40646, NULL);

 /*--- compute (p0|p0)^7 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+32925, r12vrr_stack+78, r12vrr_stack+6, NULL, NULL, Data->F+8);

 /*--- compute (d0|p0)^6 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+32934, r12vrr_stack+8830, r12vrr_stack+32925, r12vrr_stack+105, r12vrr_stack+78, r12vrr_stack+32891);

 /*--- compute (f0|p0)^5 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+32952, r12vrr_stack+60, r12vrr_stack+32934, r12vrr_stack+503, r12vrr_stack+8830, r12vrr_stack+32894);

 /*--- compute (g0|p0)^4 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+32982, r12vrr_stack+21030, r12vrr_stack+32952, r12vrr_stack+2775, r12vrr_stack+60, r12vrr_stack+32900);

 /*--- compute (h0|p0)^3 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+6049, r12vrr_stack+1086, r12vrr_stack+32982, r12vrr_stack+2793, r12vrr_stack+21030, r12vrr_stack+32910);

 /*--- compute (p0|d0)^7 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+2775, r12vrr_stack+414, r12vrr_stack+198, NULL, NULL, r12vrr_stack+6);

 /*--- compute (d0|d0)^6 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+23994, r12vrr_stack+9, r12vrr_stack+2775, r12vrr_stack+87, r12vrr_stack+414, r12vrr_stack+32925);

 /*--- compute (f0|d0)^5 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+33027, r12vrr_stack+40662, r12vrr_stack+23994, r12vrr_stack+2823, r12vrr_stack+9, r12vrr_stack+32934);

 /*--- compute (g0|d0)^4 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+33087, r12vrr_stack+264, r12vrr_stack+33027, r12vrr_stack+2841, r12vrr_stack+40662, r12vrr_stack+32952);

 /*--- compute (h0|d0)^3 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+21225, r12vrr_stack+40698, r12vrr_stack+33087, r12vrr_stack+2877, r12vrr_stack+264, r12vrr_stack+32982);

 /*--- compute (i0|d0)^2 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+5419, r12vrr_stack+14112, r12vrr_stack+21225, r12vrr_stack+2937, r12vrr_stack+40698, r12vrr_stack+6049);

 /*--- compute (p0|f0)^7 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+2793, r12vrr_stack+710, r12vrr_stack+420, NULL, NULL, r12vrr_stack+198);

 /*--- compute (d0|f0)^6 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+2823, r12vrr_stack+960, r12vrr_stack+2793, r12vrr_stack+430, r12vrr_stack+710, r12vrr_stack+2775);

 /*--- compute (f0|f0)^5 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+430, r12vrr_stack+204, r12vrr_stack+2823, r12vrr_stack+168, r12vrr_stack+960, r12vrr_stack+23994);

 /*--- compute (g0|f0)^4 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+530, r12vrr_stack+40788, r12vrr_stack+430, r12vrr_stack+3027, r12vrr_stack+204, r12vrr_stack+33027);

 /*--- compute (h0|f0)^3 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+21351, r12vrr_stack+40888, r12vrr_stack+530, r12vrr_stack+3087, r12vrr_stack+40788, r12vrr_stack+33087);

 /*--- compute (i0|f0)^2 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+4859, r12vrr_stack+41702, r12vrr_stack+21351, r12vrr_stack+3187, r12vrr_stack+40888, r12vrr_stack+21225);

 /*--- compute (k0|f0)^1 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+2883, r12vrr_stack+41912, r12vrr_stack+4859, r12vrr_stack+3337, r12vrr_stack+41702, r12vrr_stack+5419);

 /*--- compute (p0|g0)^7 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+3243, r12vrr_stack+1050, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+420);

 /*--- compute (d0|g0)^6 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3288, r12vrr_stack+108, r12vrr_stack+3243, r12vrr_stack+720, r12vrr_stack+1050, r12vrr_stack+2793);

 /*--- compute (f0|g0)^5 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3378, r12vrr_stack+42192, r12vrr_stack+3288, r12vrr_stack+735, r12vrr_stack+108, r12vrr_stack+2823);

 /*--- compute (g0|g0)^4 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+720, r12vrr_stack+42282, r12vrr_stack+3378, r12vrr_stack+3547, r12vrr_stack+42192, r12vrr_stack+430);

 /*--- compute (h0|g0)^3 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+14373, r12vrr_stack+42432, r12vrr_stack+720, r12vrr_stack+3637, r12vrr_stack+42282, r12vrr_stack+530);

 /*--- compute (i0|g0)^2 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+41038, r12vrr_stack+29844, r12vrr_stack+14373, r12vrr_stack+3787, r12vrr_stack+42432, r12vrr_stack+21351);

 /*--- compute (k0|g0)^1 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+39854, r12vrr_stack+30159, r12vrr_stack+41038, r12vrr_stack+4012, r12vrr_stack+29844, r12vrr_stack+4859);

 /*--- compute (l0|g0)^0 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+3528, r12vrr_stack+46784, r12vrr_stack+39854, r12vrr_stack+4327, r12vrr_stack+30159, r12vrr_stack+2883);

 /*--- compute (p0|h0)^7 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4203, r12vrr_stack+5606, r12vrr_stack+352, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|h0)^6 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+21561, r12vrr_stack+1770, r12vrr_stack+4203, r12vrr_stack+1065, r12vrr_stack+5606, r12vrr_stack+3243);

 /*--- compute (f0|h0)^5 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+16569, r12vrr_stack+1833, r12vrr_stack+21561, r12vrr_stack+1194, r12vrr_stack+1770, r12vrr_stack+3288);

 /*--- compute (g0|h0)^4 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+69733, r12vrr_stack+1959, r12vrr_stack+16569, r12vrr_stack+1257, r12vrr_stack+1833, r12vrr_stack+3378);

 /*--- compute (h0|h0)^3 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+70048, r12vrr_stack+30579, r12vrr_stack+69733, r12vrr_stack+6763, r12vrr_stack+1959, r12vrr_stack+720);

 /*--- compute (i0|h0)^2 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+70489, r12vrr_stack+47324, r12vrr_stack+70048, r12vrr_stack+6973, r12vrr_stack+30579, r12vrr_stack+14373);

 /*--- compute (k0|h0)^1 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+71077, r12vrr_stack+47765, r12vrr_stack+70489, r12vrr_stack+7288, r12vrr_stack+47324, r12vrr_stack+41038);

 /*--- compute (l0|h0)^0 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+6763, r12vrr_stack+48353, r12vrr_stack+71077, r12vrr_stack+8170, r12vrr_stack+47765, r12vrr_stack+39854);
 tmp = r12vrr_stack + 6763;
 target_ptr = Libr12->gvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^7 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1194, r12vrr_stack+8864, r12vrr_stack+14833, NULL, NULL, r12vrr_stack+352);

 /*--- compute (d0|i0)^6 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+71833, r12vrr_stack+5797, r12vrr_stack+1194, r12vrr_stack+5627, r12vrr_stack+8864, r12vrr_stack+4203);

 /*--- compute (f0|i0)^5 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+72001, r12vrr_stack+5881, r12vrr_stack+71833, r12vrr_stack+5655, r12vrr_stack+5797, r12vrr_stack+21561);

 /*--- compute (g0|i0)^4 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+72281, r12vrr_stack+5139, r12vrr_stack+72001, r12vrr_stack+11782, r12vrr_stack+5881, r12vrr_stack+16569);

 /*--- compute (h0|i0)^3 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+72701, r12vrr_stack+49109, r12vrr_stack+72281, r12vrr_stack+11950, r12vrr_stack+5139, r12vrr_stack+69733);

 /*--- compute (i0|i0)^2 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+73289, r12vrr_stack+49529, r12vrr_stack+72701, r12vrr_stack+12230, r12vrr_stack+49109, r12vrr_stack+70048);

 /*--- compute (k0|i0)^1 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+74073, r12vrr_stack+50117, r12vrr_stack+73289, r12vrr_stack+12650, r12vrr_stack+49529, r12vrr_stack+70489);

 /*--- compute (l0|i0)^0 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+11782, r12vrr_stack+50901, r12vrr_stack+74073, r12vrr_stack+13238, r12vrr_stack+50117, r12vrr_stack+71077);
 tmp = r12vrr_stack + 11782;
 target_ptr = Libr12->gvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^7 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9034, r12vrr_stack+14861, r12vrr_stack+20949, NULL, NULL, r12vrr_stack+14833);

 /*--- compute (d0|k0)^6 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41458, r12vrr_stack+10074, r12vrr_stack+9034, r12vrr_stack+9142, r12vrr_stack+14861, r12vrr_stack+1194);

 /*--- compute (f0|k0)^5 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+75081, r12vrr_stack+10182, r12vrr_stack+41458, r12vrr_stack+9178, r12vrr_stack+10074, r12vrr_stack+71833);

 /*--- compute (g0|k0)^4 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+75441, r12vrr_stack+10398, r12vrr_stack+75081, r12vrr_stack+9286, r12vrr_stack+10182, r12vrr_stack+72001);

 /*--- compute (h0|k0)^3 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+75981, r12vrr_stack+51909, r12vrr_stack+75441, r12vrr_stack+18126, r12vrr_stack+10398, r12vrr_stack+72281);

 /*--- compute (i0|k0)^2 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+76737, r12vrr_stack+52449, r12vrr_stack+75981, r12vrr_stack+18486, r12vrr_stack+51909, r12vrr_stack+72701);

 /*--- compute (k0|k0)^1 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+77745, r12vrr_stack+53205, r12vrr_stack+76737, r12vrr_stack+19026, r12vrr_stack+52449, r12vrr_stack+73289);

 /*--- compute (l0|k0)^0 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18126, r12vrr_stack+54213, r12vrr_stack+77745, r12vrr_stack+19782, r12vrr_stack+53205, r12vrr_stack+74073);
 tmp = r12vrr_stack + 18126;
 target_ptr = Libr12->gvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^7 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9142, r12vrr_stack+20985, r12vrr_stack+14067, NULL, NULL, r12vrr_stack+20949);

 /*--- compute (d0|l0)^6 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9277, r12vrr_stack+15714, r12vrr_stack+9142, r12vrr_stack+14897, r12vrr_stack+20985, r12vrr_stack+9034);

 /*--- compute (f0|l0)^5 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+79041, r12vrr_stack+15849, r12vrr_stack+9277, r12vrr_stack+14942, r12vrr_stack+15714, r12vrr_stack+41458);

 /*--- compute (g0|l0)^4 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+79491, r12vrr_stack+16119, r12vrr_stack+79041, r12vrr_stack+25650, r12vrr_stack+15849, r12vrr_stack+75081);

 /*--- compute (h0|l0)^3 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+80166, r12vrr_stack+55509, r12vrr_stack+79491, r12vrr_stack+25920, r12vrr_stack+16119, r12vrr_stack+75441);

 /*--- compute (i0|l0)^2 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+81111, r12vrr_stack+56184, r12vrr_stack+80166, r12vrr_stack+26370, r12vrr_stack+55509, r12vrr_stack+75981);

 /*--- compute (k0|l0)^1 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+82371, r12vrr_stack+57129, r12vrr_stack+81111, r12vrr_stack+27045, r12vrr_stack+56184, r12vrr_stack+76737);

 /*--- compute (l0|l0)^0 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25650, r12vrr_stack+58389, r12vrr_stack+82371, r12vrr_stack+27990, r12vrr_stack+57129, r12vrr_stack+77745);
 tmp = r12vrr_stack + 25650;
 target_ptr = Libr12->gvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^16 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27675, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /*--- compute (00|d0)^15 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+0, r12vrr_stack+27675, Data->F+15, Data->F+16, NULL);

 /*--- compute (00|f0)^14 ---*/
 _BUILD_00f0(Data,r12vrr_stack+27678, r12vrr_stack+22905, r12vrr_stack+54, r12vrr_stack+5794, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^13 ---*/
 _BUILD_00g0(Data,r12vrr_stack+945, r12vrr_stack+22911, r12vrr_stack+27678, r12vrr_stack+15132, r12vrr_stack+22905, NULL);

 /*--- compute (00|h0)^12 ---*/
 _BUILD_00h0(Data,r12vrr_stack+7708, r12vrr_stack+153, r12vrr_stack+945, r12vrr_stack+373, r12vrr_stack+22911, NULL);

 /*--- compute (00|i0)^11 ---*/
 _BUILD_00i0(Data,r12vrr_stack+41674, r12vrr_stack+990, r12vrr_stack+7708, r12vrr_stack+383, r12vrr_stack+153, NULL);

 /*--- compute (00|k0)^10 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19746, r12vrr_stack+22921, r12vrr_stack+41674, r12vrr_stack+20900, r12vrr_stack+990, NULL);

 /*--- compute (00|l0)^9 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27688, r12vrr_stack+8794, r12vrr_stack+19746, r12vrr_stack+20921, r12vrr_stack+22921, NULL);

 /*--- compute (00|m0)^8 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20845, r12vrr_stack+14067, r12vrr_stack+27688, r12vrr_stack+20949, r12vrr_stack+8794, NULL);

 /*--- compute (p0|m0)^7 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+27733, r12vrr_stack+5739, r12vrr_stack+20845, NULL, NULL, r12vrr_stack+14067);

 /*--- compute (d0|m0)^6 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+83991, r12vrr_stack+22949, r12vrr_stack+27733, r12vrr_stack+21720, r12vrr_stack+5739, r12vrr_stack+9142);

 /*--- compute (f0|m0)^5 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+84321, r12vrr_stack+23114, r12vrr_stack+83991, r12vrr_stack+21775, r12vrr_stack+22949, r12vrr_stack+9277);

 /*--- compute (g0|m0)^4 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+84871, r12vrr_stack+23444, r12vrr_stack+84321, r12vrr_stack+35190, r12vrr_stack+23114, r12vrr_stack+79041);

 /*--- compute (h0|m0)^3 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+85696, r12vrr_stack+60009, r12vrr_stack+84871, r12vrr_stack+35520, r12vrr_stack+23444, r12vrr_stack+79491);

 /*--- compute (i0|m0)^2 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+86851, r12vrr_stack+60834, r12vrr_stack+85696, r12vrr_stack+36070, r12vrr_stack+60009, r12vrr_stack+80166);

 /*--- compute (k0|m0)^1 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+88391, r12vrr_stack+61989, r12vrr_stack+86851, r12vrr_stack+36895, r12vrr_stack+60834, r12vrr_stack+81111);

 /*--- compute (l0|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35190, r12vrr_stack+63529, r12vrr_stack+88391, r12vrr_stack+38050, r12vrr_stack+61989, r12vrr_stack+82371);
 tmp = r12vrr_stack + 35190;
 target_ptr = Libr12->gvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^7 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+37665, r12vrr_stack+5739, r12vrr_stack+20845, r12vrr_stack+20985, r12vrr_stack+14067, NULL);

 /*--- compute (p0|n0)^6 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+37731, r12vrr_stack+2169, r12vrr_stack+37665, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (d0|n0)^5 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+21687, r12vrr_stack+39590, r12vrr_stack+37731, r12vrr_stack+39788, r12vrr_stack+2169, r12vrr_stack+22949);

 /*--- compute (f0|n0)^4 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+90371, r12vrr_stack+31835, r12vrr_stack+21687, r12vrr_stack+29250, r12vrr_stack+39590, r12vrr_stack+23114);

 /*--- compute (g0|n0)^3 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+91031, r12vrr_stack+32231, r12vrr_stack+90371, r12vrr_stack+29448, r12vrr_stack+31835, r12vrr_stack+23444);

 /*--- compute (h0|n0)^2 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+92021, r12vrr_stack+65509, r12vrr_stack+91031, r12vrr_stack+42758, r12vrr_stack+32231, r12vrr_stack+60009);

 /*--- compute (i0|n0)^1 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+93407, r12vrr_stack+66499, r12vrr_stack+92021, r12vrr_stack+43418, r12vrr_stack+65509, r12vrr_stack+60834);

 /*--- compute (k0|n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+95255, r12vrr_stack+67885, r12vrr_stack+93407, r12vrr_stack+45398, r12vrr_stack+66499, r12vrr_stack+61989);
 tmp = r12vrr_stack + 95255;
 target_ptr = Libr12->gvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^8 ---*/
 _BUILD_p000(Data,r12vrr_stack+5794, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (d0|00)^7 ---*/
 _BUILD_d000(Data,r12vrr_stack+29250, r12vrr_stack+32891, r12vrr_stack+5794, Data->F+7, Data->F+8, NULL);

 /*--- compute (f0|00)^6 ---*/
 _BUILD_f000(Data,r12vrr_stack+29256, r12vrr_stack+32894, r12vrr_stack+29250, r12vrr_stack+5587, r12vrr_stack+32891, NULL);

 /*--- compute (g0|00)^5 ---*/
 _BUILD_g000(Data,r12vrr_stack+29266, r12vrr_stack+32900, r12vrr_stack+29256, r12vrr_stack+40646, r12vrr_stack+32894, NULL);

 /*--- compute (h0|00)^4 ---*/
 _BUILD_h000(Data,r12vrr_stack+1065, r12vrr_stack+32910, r12vrr_stack+29266, r12vrr_stack+40652, r12vrr_stack+32900, NULL);

 /*--- compute (p0|p0)^8 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+29281, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+9);

 /*--- compute (d0|p0)^7 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+29290, r12vrr_stack+32925, r12vrr_stack+29281, r12vrr_stack+78, r12vrr_stack+6, r12vrr_stack+5794);

 /*--- compute (f0|p0)^6 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+168, r12vrr_stack+32934, r12vrr_stack+29290, r12vrr_stack+8830, r12vrr_stack+32925, r12vrr_stack+29250);

 /*--- compute (g0|p0)^5 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+29308, r12vrr_stack+32952, r12vrr_stack+168, r12vrr_stack+60, r12vrr_stack+32934, r12vrr_stack+29256);

 /*--- compute (h0|p0)^4 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+29353, r12vrr_stack+32982, r12vrr_stack+29308, r12vrr_stack+21030, r12vrr_stack+32952, r12vrr_stack+29266);

 /*--- compute (i0|p0)^3 ---*/
 _BUILD_i0p0(Data,r12vrr_stack+29416, r12vrr_stack+6049, r12vrr_stack+29353, r12vrr_stack+1086, r12vrr_stack+32982, r12vrr_stack+1065);

 /*--- compute (p0|d0)^8 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1086, r12vrr_stack+198, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^7 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+29500, r12vrr_stack+2775, r12vrr_stack+1086, r12vrr_stack+414, r12vrr_stack+198, r12vrr_stack+29281);

 /*--- compute (f0|d0)^6 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+29536, r12vrr_stack+23994, r12vrr_stack+29500, r12vrr_stack+9, r12vrr_stack+2775, r12vrr_stack+29290);

 /*--- compute (g0|d0)^5 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+29596, r12vrr_stack+33027, r12vrr_stack+29536, r12vrr_stack+40662, r12vrr_stack+23994, r12vrr_stack+168);

 /*--- compute (h0|d0)^4 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+29686, r12vrr_stack+33087, r12vrr_stack+29596, r12vrr_stack+264, r12vrr_stack+33027, r12vrr_stack+29308);

 /*--- compute (i0|d0)^3 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+14897, r12vrr_stack+21225, r12vrr_stack+29686, r12vrr_stack+40698, r12vrr_stack+33087, r12vrr_stack+29353);

 /*--- compute (k0|d0)^2 ---*/
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,r12vrr_stack+42657, r12vrr_stack+5419, r12vrr_stack+14897, r12vrr_stack+14112, r12vrr_stack+21225, r12vrr_stack+29416);

 /*--- compute (p0|f0)^8 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+21030, r12vrr_stack+420, r12vrr_stack+5596, NULL, NULL, r12vrr_stack+48);

 /*--- compute (d0|f0)^7 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+264, r12vrr_stack+2793, r12vrr_stack+21030, r12vrr_stack+710, r12vrr_stack+420, r12vrr_stack+1086);

 /*--- compute (f0|f0)^6 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+14112, r12vrr_stack+2823, r12vrr_stack+264, r12vrr_stack+960, r12vrr_stack+2793, r12vrr_stack+29500);

 /*--- compute (g0|f0)^5 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+13042, r12vrr_stack+430, r12vrr_stack+14112, r12vrr_stack+204, r12vrr_stack+2823, r12vrr_stack+29536);

 /*--- compute (h0|f0)^4 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+42873, r12vrr_stack+530, r12vrr_stack+13042, r12vrr_stack+40788, r12vrr_stack+430, r12vrr_stack+29596);

 /*--- compute (i0|f0)^3 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+43083, r12vrr_stack+21351, r12vrr_stack+42873, r12vrr_stack+40888, r12vrr_stack+530, r12vrr_stack+29686);

 /*--- compute (k0|f0)^2 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+43363, r12vrr_stack+4859, r12vrr_stack+43083, r12vrr_stack+41702, r12vrr_stack+21351, r12vrr_stack+14897);

 /*--- compute (l0|f0)^1 ---*/
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+43723, r12vrr_stack+2883, r12vrr_stack+43363, r12vrr_stack+41912, r12vrr_stack+4859, r12vrr_stack+42657);

 /*--- compute (p0|g0)^8 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+41702, r12vrr_stack+1035, r12vrr_stack+8849, NULL, NULL, r12vrr_stack+5596);

 /*--- compute (d0|g0)^7 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+41747, r12vrr_stack+3243, r12vrr_stack+41702, r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+21030);

 /*--- compute (f0|g0)^6 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+41837, r12vrr_stack+3288, r12vrr_stack+41747, r12vrr_stack+108, r12vrr_stack+3243, r12vrr_stack+264);

 /*--- compute (g0|g0)^5 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+44173, r12vrr_stack+3378, r12vrr_stack+41837, r12vrr_stack+42192, r12vrr_stack+3288, r12vrr_stack+14112);

 /*--- compute (h0|g0)^4 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+40394, r12vrr_stack+720, r12vrr_stack+44173, r12vrr_stack+42282, r12vrr_stack+3378, r12vrr_stack+13042);

 /*--- compute (i0|g0)^3 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+41987, r12vrr_stack+14373, r12vrr_stack+40394, r12vrr_stack+42432, r12vrr_stack+720, r12vrr_stack+42873);

 /*--- compute (k0|g0)^2 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+97631, r12vrr_stack+41038, r12vrr_stack+41987, r12vrr_stack+29844, r12vrr_stack+14373, r12vrr_stack+43083);

 /*--- compute (l0|g0)^1 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+98171, r12vrr_stack+39854, r12vrr_stack+97631, r12vrr_stack+30159, r12vrr_stack+41038, r12vrr_stack+43363);

 /*--- compute (m0|g0)^0 ---*/
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+98846, r12vrr_stack+3528, r12vrr_stack+98171, r12vrr_stack+46784, r12vrr_stack+39854, r12vrr_stack+43723);

 /*--- compute (p0|h0)^8 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+42407, r12vrr_stack+352, r12vrr_stack+14812, NULL, NULL, r12vrr_stack+8849);

 /*--- compute (d0|h0)^7 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+42470, r12vrr_stack+4203, r12vrr_stack+42407, r12vrr_stack+5606, r12vrr_stack+352, r12vrr_stack+41702);

 /*--- compute (f0|h0)^6 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+29812, r12vrr_stack+21561, r12vrr_stack+42470, r12vrr_stack+1770, r12vrr_stack+4203, r12vrr_stack+41747);

 /*--- compute (g0|h0)^5 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+30022, r12vrr_stack+16569, r12vrr_stack+29812, r12vrr_stack+1833, r12vrr_stack+21561, r12vrr_stack+41837);

 /*--- compute (h0|h0)^4 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+99671, r12vrr_stack+69733, r12vrr_stack+30022, r12vrr_stack+1959, r12vrr_stack+16569, r12vrr_stack+44173);

 /*--- compute (i0|h0)^3 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+100112, r12vrr_stack+70048, r12vrr_stack+99671, r12vrr_stack+30579, r12vrr_stack+69733, r12vrr_stack+40394);

 /*--- compute (k0|h0)^2 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+100700, r12vrr_stack+70489, r12vrr_stack+100112, r12vrr_stack+47324, r12vrr_stack+70048, r12vrr_stack+41987);

 /*--- compute (l0|h0)^1 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+101456, r12vrr_stack+71077, r12vrr_stack+100700, r12vrr_stack+47765, r12vrr_stack+70489, r12vrr_stack+97631);

 /*--- compute (m0|h0)^0 ---*/
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+102401, r12vrr_stack+6763, r12vrr_stack+101456, r12vrr_stack+48353, r12vrr_stack+71077, r12vrr_stack+98171);
 tmp = r12vrr_stack + 102401;
 target_ptr = Libr12->gvrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^8 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+47324, r12vrr_stack+14833, r12vrr_stack+20921, NULL, NULL, r12vrr_stack+14812);

 /*--- compute (d0|i0)^7 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+47408, r12vrr_stack+1194, r12vrr_stack+47324, r12vrr_stack+8864, r12vrr_stack+14833, r12vrr_stack+42407);

 /*--- compute (f0|i0)^6 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+47576, r12vrr_stack+71833, r12vrr_stack+47408, r12vrr_stack+5797, r12vrr_stack+1194, r12vrr_stack+42470);

 /*--- compute (g0|i0)^5 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+47856, r12vrr_stack+72001, r12vrr_stack+47576, r12vrr_stack+5881, r12vrr_stack+71833, r12vrr_stack+29812);

 /*--- compute (h0|i0)^4 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+30337, r12vrr_stack+72281, r12vrr_stack+47856, r12vrr_stack+5139, r12vrr_stack+72001, r12vrr_stack+30022);

 /*--- compute (i0|i0)^3 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+103556, r12vrr_stack+72701, r12vrr_stack+30337, r12vrr_stack+49109, r12vrr_stack+72281, r12vrr_stack+99671);

 /*--- compute (k0|i0)^2 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+104340, r12vrr_stack+73289, r12vrr_stack+103556, r12vrr_stack+49529, r12vrr_stack+72701, r12vrr_stack+100112);

 /*--- compute (l0|i0)^1 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+105348, r12vrr_stack+74073, r12vrr_stack+104340, r12vrr_stack+50117, r12vrr_stack+73289, r12vrr_stack+100700);

 /*--- compute (m0|i0)^0 ---*/
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+49109, r12vrr_stack+11782, r12vrr_stack+105348, r12vrr_stack+50901, r12vrr_stack+74073, r12vrr_stack+101456);
 tmp = r12vrr_stack + 49109;
 target_ptr = Libr12->gvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^8 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+50649, r12vrr_stack+20949, r12vrr_stack+8794, NULL, NULL, r12vrr_stack+20921);

 /*--- compute (d0|k0)^7 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5139, r12vrr_stack+9034, r12vrr_stack+50649, r12vrr_stack+14861, r12vrr_stack+20949, r12vrr_stack+47324);

 /*--- compute (f0|k0)^6 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1770, r12vrr_stack+41458, r12vrr_stack+5139, r12vrr_stack+10074, r12vrr_stack+9034, r12vrr_stack+47408);

 /*--- compute (g0|k0)^5 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+106608, r12vrr_stack+75081, r12vrr_stack+1770, r12vrr_stack+10182, r12vrr_stack+41458, r12vrr_stack+47576);

 /*--- compute (h0|k0)^4 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+107148, r12vrr_stack+75441, r12vrr_stack+106608, r12vrr_stack+10398, r12vrr_stack+75081, r12vrr_stack+47856);

 /*--- compute (i0|k0)^3 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+107904, r12vrr_stack+75981, r12vrr_stack+107148, r12vrr_stack+51909, r12vrr_stack+75441, r12vrr_stack+30337);

 /*--- compute (k0|k0)^2 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+108912, r12vrr_stack+76737, r12vrr_stack+107904, r12vrr_stack+52449, r12vrr_stack+75981, r12vrr_stack+103556);

 /*--- compute (l0|k0)^1 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+110208, r12vrr_stack+77745, r12vrr_stack+108912, r12vrr_stack+53205, r12vrr_stack+76737, r12vrr_stack+104340);

 /*--- compute (m0|k0)^0 ---*/
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+51909, r12vrr_stack+18126, r12vrr_stack+110208, r12vrr_stack+54213, r12vrr_stack+77745, r12vrr_stack+105348);
 tmp = r12vrr_stack + 51909;
 target_ptr = Libr12->gvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^8 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+53889, r12vrr_stack+14067, r12vrr_stack+27688, NULL, NULL, r12vrr_stack+8794);

 /*--- compute (d0|l0)^7 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10074, r12vrr_stack+9142, r12vrr_stack+53889, r12vrr_stack+20985, r12vrr_stack+14067, r12vrr_stack+50649);

 /*--- compute (f0|l0)^6 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+111828, r12vrr_stack+9277, r12vrr_stack+10074, r12vrr_stack+15714, r12vrr_stack+9142, r12vrr_stack+5139);

 /*--- compute (g0|l0)^5 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+112278, r12vrr_stack+79041, r12vrr_stack+111828, r12vrr_stack+15849, r12vrr_stack+9277, r12vrr_stack+1770);

 /*--- compute (h0|l0)^4 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+112953, r12vrr_stack+79491, r12vrr_stack+112278, r12vrr_stack+16119, r12vrr_stack+79041, r12vrr_stack+106608);

 /*--- compute (i0|l0)^3 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+113898, r12vrr_stack+80166, r12vrr_stack+112953, r12vrr_stack+55509, r12vrr_stack+79491, r12vrr_stack+107148);

 /*--- compute (k0|l0)^2 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+115158, r12vrr_stack+81111, r12vrr_stack+113898, r12vrr_stack+56184, r12vrr_stack+80166, r12vrr_stack+107904);

 /*--- compute (l0|l0)^1 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+116778, r12vrr_stack+82371, r12vrr_stack+115158, r12vrr_stack+57129, r12vrr_stack+81111, r12vrr_stack+108912);

 /*--- compute (m0|l0)^0 ---*/
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+55509, r12vrr_stack+25650, r12vrr_stack+116778, r12vrr_stack+58389, r12vrr_stack+82371, r12vrr_stack+110208);
 tmp = r12vrr_stack + 55509;
 target_ptr = Libr12->gvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^17 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5587, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /*--- compute (00|d0)^16 ---*/
 _BUILD_00d0(Data,r12vrr_stack+57984, r12vrr_stack+27675, r12vrr_stack+5587, Data->F+16, Data->F+17, NULL);

 /*--- compute (00|f0)^15 ---*/
 _BUILD_00f0(Data,r12vrr_stack+44398, r12vrr_stack+54, r12vrr_stack+57984, r12vrr_stack+0, r12vrr_stack+27675, NULL);

 /*--- compute (00|g0)^14 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1050, r12vrr_stack+27678, r12vrr_stack+44398, r12vrr_stack+22905, r12vrr_stack+54, NULL);

 /*--- compute (00|h0)^13 ---*/
 _BUILD_00h0(Data,r12vrr_stack+60, r12vrr_stack+945, r12vrr_stack+1050, r12vrr_stack+22911, r12vrr_stack+27678, NULL);

 /*--- compute (00|i0)^12 ---*/
 _BUILD_00i0(Data,r12vrr_stack+57990, r12vrr_stack+7708, r12vrr_stack+60, r12vrr_stack+153, r12vrr_stack+945, NULL);

 /*--- compute (00|k0)^11 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14861, r12vrr_stack+41674, r12vrr_stack+57990, r12vrr_stack+990, r12vrr_stack+7708, NULL);

 /*--- compute (00|l0)^10 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20985, r12vrr_stack+19746, r12vrr_stack+14861, r12vrr_stack+22921, r12vrr_stack+41674, NULL);

 /*--- compute (00|m0)^9 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+58018, r12vrr_stack+27688, r12vrr_stack+20985, r12vrr_stack+8794, r12vrr_stack+19746, NULL);

 /*--- compute (p0|m0)^8 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+58073, r12vrr_stack+20845, r12vrr_stack+58018, NULL, NULL, r12vrr_stack+27688);

 /*--- compute (d0|m0)^7 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+27733, r12vrr_stack+58073, r12vrr_stack+5739, r12vrr_stack+20845, r12vrr_stack+53889);

 /*--- compute (f0|m0)^6 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+118803, r12vrr_stack+83991, r12vrr_stack+15714, r12vrr_stack+22949, r12vrr_stack+27733, r12vrr_stack+10074);

 /*--- compute (g0|m0)^5 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+119353, r12vrr_stack+84321, r12vrr_stack+118803, r12vrr_stack+23114, r12vrr_stack+83991, r12vrr_stack+111828);

 /*--- compute (h0|m0)^4 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+120178, r12vrr_stack+84871, r12vrr_stack+119353, r12vrr_stack+23444, r12vrr_stack+84321, r12vrr_stack+112278);

 /*--- compute (i0|m0)^3 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+121333, r12vrr_stack+85696, r12vrr_stack+120178, r12vrr_stack+60009, r12vrr_stack+84871, r12vrr_stack+112953);

 /*--- compute (k0|m0)^2 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+122873, r12vrr_stack+86851, r12vrr_stack+121333, r12vrr_stack+60834, r12vrr_stack+85696, r12vrr_stack+113898);

 /*--- compute (l0|m0)^1 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+124853, r12vrr_stack+88391, r12vrr_stack+122873, r12vrr_stack+61989, r12vrr_stack+86851, r12vrr_stack+115158);

 /*--- compute (m0|m0)^0 ---*/
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+60009, r12vrr_stack+35190, r12vrr_stack+124853, r12vrr_stack+63529, r12vrr_stack+88391, r12vrr_stack+116778);
 tmp = r12vrr_stack + 60009;
 target_ptr = Libr12->gvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^8 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39788, r12vrr_stack+20845, r12vrr_stack+58018, r12vrr_stack+14067, r12vrr_stack+27688, NULL);

 /*--- compute (p0|n0)^7 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+63034, r12vrr_stack+37665, r12vrr_stack+39788, NULL, NULL, r12vrr_stack+20845);

 /*--- compute (d0|n0)^6 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22949, r12vrr_stack+37731, r12vrr_stack+63034, r12vrr_stack+2169, r12vrr_stack+37665, r12vrr_stack+27733);

 /*--- compute (f0|n0)^5 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+127328, r12vrr_stack+21687, r12vrr_stack+22949, r12vrr_stack+39590, r12vrr_stack+37731, r12vrr_stack+83991);

 /*--- compute (g0|n0)^4 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+127988, r12vrr_stack+90371, r12vrr_stack+127328, r12vrr_stack+31835, r12vrr_stack+21687, r12vrr_stack+84321);

 /*--- compute (h0|n0)^3 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+128978, r12vrr_stack+91031, r12vrr_stack+127988, r12vrr_stack+32231, r12vrr_stack+90371, r12vrr_stack+84871);

 /*--- compute (i0|n0)^2 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+130364, r12vrr_stack+92021, r12vrr_stack+128978, r12vrr_stack+65509, r12vrr_stack+91031, r12vrr_stack+85696);

 /*--- compute (k0|n0)^1 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+132212, r12vrr_stack+93407, r12vrr_stack+130364, r12vrr_stack+66499, r12vrr_stack+92021, r12vrr_stack+86851);

 /*--- compute (l0|n0)^0 ---*/
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+134588, r12vrr_stack+95255, r12vrr_stack+132212, r12vrr_stack+67885, r12vrr_stack+93407, r12vrr_stack+88391);
 tmp = r12vrr_stack + 134588;
 target_ptr = Libr12->gvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^9 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (d0|00)^8 ---*/
 _BUILD_d000(Data,r12vrr_stack+65509, r12vrr_stack+5794, r12vrr_stack+0, Data->F+8, Data->F+9, NULL);

 /*--- compute (f0|00)^7 ---*/
 _BUILD_f000(Data,r12vrr_stack+65515, r12vrr_stack+29250, r12vrr_stack+65509, r12vrr_stack+32891, r12vrr_stack+5794, NULL);

 /*--- compute (g0|00)^6 ---*/
 _BUILD_g000(Data,r12vrr_stack+65525, r12vrr_stack+29256, r12vrr_stack+65515, r12vrr_stack+32894, r12vrr_stack+29250, NULL);

 /*--- compute (h0|00)^5 ---*/
 _BUILD_h000(Data,r12vrr_stack+65540, r12vrr_stack+29266, r12vrr_stack+65525, r12vrr_stack+32900, r12vrr_stack+29256, NULL);

 /*--- compute (i0|00)^4 ---*/
 _BUILD_i000(Data,r12vrr_stack+65561, r12vrr_stack+1065, r12vrr_stack+65540, r12vrr_stack+32910, r12vrr_stack+29266, NULL);

 /*--- compute (p0|p0)^9 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+8830, r12vrr_stack+3, r12vrr_stack+1032, NULL, NULL, Data->F+10);

 /*--- compute (d0|p0)^8 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1065, r12vrr_stack+29281, r12vrr_stack+8830, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (f0|p0)^7 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+30925, r12vrr_stack+29290, r12vrr_stack+1065, r12vrr_stack+32925, r12vrr_stack+29281, r12vrr_stack+65509);

 /*--- compute (g0|p0)^6 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+0, r12vrr_stack+168, r12vrr_stack+30925, r12vrr_stack+32934, r12vrr_stack+29290, r12vrr_stack+65515);

 /*--- compute (h0|p0)^5 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+65589, r12vrr_stack+29308, r12vrr_stack+0, r12vrr_stack+32952, r12vrr_stack+168, r12vrr_stack+65525);

 /*--- compute (i0|p0)^4 ---*/
 _BUILD_i0p0(Data,r12vrr_stack+65652, r12vrr_stack+29353, r12vrr_stack+65589, r12vrr_stack+32982, r12vrr_stack+29308, r12vrr_stack+65540);

 /*--- compute (k0|p0)^3 ---*/
 am[0] = 7;  am[1] = 1;
 vrr_build_xxxx(am,Data,r12vrr_stack+65736, r12vrr_stack+29416, r12vrr_stack+65652, r12vrr_stack+6049, r12vrr_stack+29353, r12vrr_stack+65561);

 /*--- compute (p0|d0)^9 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+65509, r12vrr_stack+48, r12vrr_stack+5590, NULL, NULL, r12vrr_stack+1032);

 /*--- compute (d0|d0)^8 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+65527, r12vrr_stack+1086, r12vrr_stack+65509, r12vrr_stack+198, r12vrr_stack+48, r12vrr_stack+8830);

 /*--- compute (f0|d0)^7 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+29250, r12vrr_stack+29500, r12vrr_stack+65527, r12vrr_stack+2775, r12vrr_stack+1086, r12vrr_stack+1065);

 /*--- compute (g0|d0)^6 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+29310, r12vrr_stack+29536, r12vrr_stack+29250, r12vrr_stack+23994, r12vrr_stack+29500, r12vrr_stack+30925);

 /*--- compute (h0|d0)^5 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+29400, r12vrr_stack+29596, r12vrr_stack+29310, r12vrr_stack+33027, r12vrr_stack+29536, r12vrr_stack+0);

 /*--- compute (i0|d0)^4 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+65844, r12vrr_stack+29686, r12vrr_stack+29400, r12vrr_stack+33087, r12vrr_stack+29596, r12vrr_stack+65589);

 /*--- compute (k0|d0)^3 ---*/
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,r12vrr_stack+66012, r12vrr_stack+14897, r12vrr_stack+65844, r12vrr_stack+21225, r12vrr_stack+29686, r12vrr_stack+65652);

 /*--- compute (l0|d0)^2 ---*/
 am[0] = 8;  am[1] = 2;
 vrr_build_xxxx(am,Data,r12vrr_stack+29526, r12vrr_stack+42657, r12vrr_stack+66012, r12vrr_stack+5419, r12vrr_stack+14897, r12vrr_stack+65736);

 /*--- compute (p0|f0)^9 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+30925, r12vrr_stack+5596, r12vrr_stack+8839, NULL, NULL, r12vrr_stack+5590);

 /*--- compute (d0|f0)^8 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+14897, r12vrr_stack+21030, r12vrr_stack+30925, r12vrr_stack+420, r12vrr_stack+5596, r12vrr_stack+65509);

 /*--- compute (f0|f0)^7 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+5590, r12vrr_stack+264, r12vrr_stack+14897, r12vrr_stack+2793, r12vrr_stack+21030, r12vrr_stack+65527);

 /*--- compute (g0|f0)^6 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+65509, r12vrr_stack+14112, r12vrr_stack+5590, r12vrr_stack+2823, r12vrr_stack+264, r12vrr_stack+29250);

 /*--- compute (h0|f0)^5 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+5690, r12vrr_stack+13042, r12vrr_stack+65509, r12vrr_stack+430, r12vrr_stack+14112, r12vrr_stack+29310);

 /*--- compute (i0|f0)^4 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+66228, r12vrr_stack+42873, r12vrr_stack+5690, r12vrr_stack+530, r12vrr_stack+13042, r12vrr_stack+29400);

 /*--- compute (k0|f0)^3 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+66508, r12vrr_stack+43083, r12vrr_stack+66228, r12vrr_stack+21351, r12vrr_stack+42873, r12vrr_stack+65844);

 /*--- compute (l0|f0)^2 ---*/
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+66868, r12vrr_stack+43363, r12vrr_stack+66508, r12vrr_stack+4859, r12vrr_stack+43083, r12vrr_stack+66012);

 /*--- compute (m0|f0)^1 ---*/
 am[0] = 9;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+65659, r12vrr_stack+43723, r12vrr_stack+66868, r12vrr_stack+2883, r12vrr_stack+43363, r12vrr_stack+29526);

 /*--- compute (p0|g0)^9 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+4859, r12vrr_stack+8849, r12vrr_stack+14797, NULL, NULL, r12vrr_stack+8839);

 /*--- compute (d0|g0)^8 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+4904, r12vrr_stack+41702, r12vrr_stack+4859, r12vrr_stack+1035, r12vrr_stack+8849, r12vrr_stack+30925);

 /*--- compute (f0|g0)^7 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+13042, r12vrr_stack+41747, r12vrr_stack+4904, r12vrr_stack+3243, r12vrr_stack+41702, r12vrr_stack+14897);

 /*--- compute (g0|g0)^6 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+14897, r12vrr_stack+41837, r12vrr_stack+13042, r12vrr_stack+3288, r12vrr_stack+41747, r12vrr_stack+5590);

 /*--- compute (h0|g0)^5 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+29250, r12vrr_stack+44173, r12vrr_stack+14897, r12vrr_stack+3378, r12vrr_stack+41837, r12vrr_stack+65509);

 /*--- compute (i0|g0)^4 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+2775, r12vrr_stack+40394, r12vrr_stack+29250, r12vrr_stack+720, r12vrr_stack+44173, r12vrr_stack+5690);

 /*--- compute (k0|g0)^3 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+67318, r12vrr_stack+41987, r12vrr_stack+2775, r12vrr_stack+14373, r12vrr_stack+40394, r12vrr_stack+66228);

 /*--- compute (l0|g0)^2 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+97631, r12vrr_stack+67318, r12vrr_stack+41038, r12vrr_stack+41987, r12vrr_stack+66508);

 /*--- compute (m0|g0)^1 ---*/
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+40394, r12vrr_stack+98171, r12vrr_stack+31835, r12vrr_stack+39854, r12vrr_stack+97631, r12vrr_stack+66868);

 /*--- compute (n0|g0)^0 ---*/
 am[0] = 10;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+66209, r12vrr_stack+98846, r12vrr_stack+40394, r12vrr_stack+3528, r12vrr_stack+98171, r12vrr_stack+65659);

 /*--- compute (p0|h0)^9 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+97631, r12vrr_stack+14812, r12vrr_stack+20900, NULL, NULL, r12vrr_stack+14797);

 /*--- compute (d0|h0)^8 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+14112, r12vrr_stack+42407, r12vrr_stack+97631, r12vrr_stack+352, r12vrr_stack+14812, r12vrr_stack+4859);

 /*--- compute (f0|h0)^7 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+352, r12vrr_stack+42470, r12vrr_stack+14112, r12vrr_stack+4203, r12vrr_stack+42407, r12vrr_stack+4904);

 /*--- compute (g0|h0)^6 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+562, r12vrr_stack+29812, r12vrr_stack+352, r12vrr_stack+21561, r12vrr_stack+42470, r12vrr_stack+13042);

 /*--- compute (h0|h0)^5 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+97694, r12vrr_stack+30022, r12vrr_stack+562, r12vrr_stack+16569, r12vrr_stack+29812, r12vrr_stack+14897);

 /*--- compute (i0|h0)^4 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+98135, r12vrr_stack+99671, r12vrr_stack+97694, r12vrr_stack+69733, r12vrr_stack+30022, r12vrr_stack+29250);

 /*--- compute (k0|h0)^3 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+100112, r12vrr_stack+98135, r12vrr_stack+70048, r12vrr_stack+99671, r12vrr_stack+2775);

 /*--- compute (l0|h0)^2 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+41702, r12vrr_stack+100700, r12vrr_stack+29250, r12vrr_stack+70489, r12vrr_stack+100112, r12vrr_stack+67318);

 /*--- compute (m0|h0)^1 ---*/
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+101456, r12vrr_stack+41702, r12vrr_stack+71077, r12vrr_stack+100700, r12vrr_stack+31835);

 /*--- compute (n0|h0)^0 ---*/
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+99671, r12vrr_stack+102401, r12vrr_stack+69733, r12vrr_stack+6763, r12vrr_stack+101456, r12vrr_stack+40394);
 tmp = r12vrr_stack + 99671;
 target_ptr = Libr12->gvrr_classes[10][5];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^9 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+31835, r12vrr_stack+20921, r12vrr_stack+22921, NULL, NULL, r12vrr_stack+20900);

 /*--- compute (d0|i0)^8 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+31919, r12vrr_stack+47324, r12vrr_stack+31835, r12vrr_stack+14833, r12vrr_stack+20921, r12vrr_stack+97631);

 /*--- compute (f0|i0)^7 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4859, r12vrr_stack+47408, r12vrr_stack+31919, r12vrr_stack+1194, r12vrr_stack+47324, r12vrr_stack+14112);

 /*--- compute (g0|i0)^6 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+32087, r12vrr_stack+47576, r12vrr_stack+4859, r12vrr_stack+71833, r12vrr_stack+47408, r12vrr_stack+352);

 /*--- compute (h0|i0)^5 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+32507, r12vrr_stack+47856, r12vrr_stack+32087, r12vrr_stack+72001, r12vrr_stack+47576, r12vrr_stack+562);

 /*--- compute (i0|i0)^4 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+101057, r12vrr_stack+30337, r12vrr_stack+32507, r12vrr_stack+72281, r12vrr_stack+47856, r12vrr_stack+97694);

 /*--- compute (k0|i0)^3 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+47324, r12vrr_stack+103556, r12vrr_stack+101057, r12vrr_stack+72701, r12vrr_stack+30337, r12vrr_stack+98135);

 /*--- compute (l0|i0)^2 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+70888, r12vrr_stack+104340, r12vrr_stack+47324, r12vrr_stack+73289, r12vrr_stack+103556, r12vrr_stack+29250);

 /*--- compute (m0|i0)^1 ---*/
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+105348, r12vrr_stack+70888, r12vrr_stack+74073, r12vrr_stack+104340, r12vrr_stack+41702);

 /*--- compute (n0|i0)^0 ---*/
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+41702, r12vrr_stack+49109, r12vrr_stack+29250, r12vrr_stack+11782, r12vrr_stack+105348, r12vrr_stack+69733);
 tmp = r12vrr_stack + 41702;
 target_ptr = Libr12->gvrr_classes[10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^9 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+8794, r12vrr_stack+19746, NULL, NULL, r12vrr_stack+22921);

 /*--- compute (d0|k0)^8 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+69841, r12vrr_stack+50649, r12vrr_stack+69733, r12vrr_stack+20949, r12vrr_stack+8794, r12vrr_stack+31835);

 /*--- compute (f0|k0)^7 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+70057, r12vrr_stack+5139, r12vrr_stack+69841, r12vrr_stack+9034, r12vrr_stack+50649, r12vrr_stack+31919);

 /*--- compute (g0|k0)^6 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+43550, r12vrr_stack+1770, r12vrr_stack+70057, r12vrr_stack+41458, r12vrr_stack+5139, r12vrr_stack+4859);

 /*--- compute (h0|k0)^5 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+103556, r12vrr_stack+106608, r12vrr_stack+43550, r12vrr_stack+75081, r12vrr_stack+1770, r12vrr_stack+32087);

 /*--- compute (i0|k0)^4 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+104312, r12vrr_stack+107148, r12vrr_stack+103556, r12vrr_stack+75441, r12vrr_stack+106608, r12vrr_stack+32507);

 /*--- compute (k0|k0)^3 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+107904, r12vrr_stack+104312, r12vrr_stack+75981, r12vrr_stack+107148, r12vrr_stack+101057);

 /*--- compute (l0|k0)^2 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+105320, r12vrr_stack+108912, r12vrr_stack+31835, r12vrr_stack+76737, r12vrr_stack+107904, r12vrr_stack+47324);

 /*--- compute (m0|k0)^1 ---*/
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+72148, r12vrr_stack+110208, r12vrr_stack+105320, r12vrr_stack+77745, r12vrr_stack+108912, r12vrr_stack+70888);

 /*--- compute (n0|k0)^0 ---*/
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+106940, r12vrr_stack+51909, r12vrr_stack+72148, r12vrr_stack+18126, r12vrr_stack+110208, r12vrr_stack+29250);
 tmp = r12vrr_stack + 106940;
 target_ptr = Libr12->gvrr_classes[10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^9 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+27688, r12vrr_stack+20985, NULL, NULL, r12vrr_stack+19746);

 /*--- compute (d0|l0)^8 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+29385, r12vrr_stack+53889, r12vrr_stack+29250, r12vrr_stack+14067, r12vrr_stack+27688, r12vrr_stack+69733);

 /*--- compute (f0|l0)^7 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+29655, r12vrr_stack+10074, r12vrr_stack+29385, r12vrr_stack+9142, r12vrr_stack+53889, r12vrr_stack+69841);

 /*--- compute (g0|l0)^6 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+30105, r12vrr_stack+111828, r12vrr_stack+29655, r12vrr_stack+9277, r12vrr_stack+10074, r12vrr_stack+70057);

 /*--- compute (h0|l0)^5 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+112278, r12vrr_stack+30105, r12vrr_stack+79041, r12vrr_stack+111828, r12vrr_stack+43550);

 /*--- compute (i0|l0)^4 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+70678, r12vrr_stack+112953, r12vrr_stack+69733, r12vrr_stack+79491, r12vrr_stack+112278, r12vrr_stack+103556);

 /*--- compute (k0|l0)^3 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+109316, r12vrr_stack+113898, r12vrr_stack+70678, r12vrr_stack+80166, r12vrr_stack+112953, r12vrr_stack+104312);

 /*--- compute (l0|l0)^2 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+110936, r12vrr_stack+115158, r12vrr_stack+109316, r12vrr_stack+81111, r12vrr_stack+113898, r12vrr_stack+31835);

 /*--- compute (m0|l0)^1 ---*/
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+74128, r12vrr_stack+116778, r12vrr_stack+110936, r12vrr_stack+82371, r12vrr_stack+115158, r12vrr_stack+105320);

 /*--- compute (n0|l0)^0 ---*/
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+103556, r12vrr_stack+55509, r12vrr_stack+74128, r12vrr_stack+25650, r12vrr_stack+116778, r12vrr_stack+72148);
 tmp = r12vrr_stack + 103556;
 target_ptr = Libr12->gvrr_classes[10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^18 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31835, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /*--- compute (00|d0)^17 ---*/
 _BUILD_00d0(Data,r12vrr_stack+31838, r12vrr_stack+5587, r12vrr_stack+31835, Data->F+17, Data->F+18, NULL);

 /*--- compute (00|f0)^16 ---*/
 _BUILD_00f0(Data,r12vrr_stack+31844, r12vrr_stack+57984, r12vrr_stack+31838, r12vrr_stack+27675, r12vrr_stack+5587, NULL);

 /*--- compute (00|g0)^15 ---*/
 _BUILD_00g0(Data,r12vrr_stack+31854, r12vrr_stack+44398, r12vrr_stack+31844, r12vrr_stack+54, r12vrr_stack+57984, NULL);

 /*--- compute (00|h0)^14 ---*/
 _BUILD_00h0(Data,r12vrr_stack+31869, r12vrr_stack+1050, r12vrr_stack+31854, r12vrr_stack+27678, r12vrr_stack+44398, NULL);

 /*--- compute (00|i0)^13 ---*/
 _BUILD_00i0(Data,r12vrr_stack+31835, r12vrr_stack+60, r12vrr_stack+31869, r12vrr_stack+945, r12vrr_stack+1050, NULL);

 /*--- compute (00|k0)^12 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+31863, r12vrr_stack+57990, r12vrr_stack+31835, r12vrr_stack+7708, r12vrr_stack+60, NULL);

 /*--- compute (00|l0)^11 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+31899, r12vrr_stack+14861, r12vrr_stack+31863, r12vrr_stack+41674, r12vrr_stack+57990, NULL);

 /*--- compute (00|m0)^10 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+20985, r12vrr_stack+31899, r12vrr_stack+19746, r12vrr_stack+14861, NULL);

 /*--- compute (p0|m0)^9 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31890, r12vrr_stack+58018, r12vrr_stack+31835, NULL, NULL, r12vrr_stack+20985);

 /*--- compute (d0|m0)^8 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+32055, r12vrr_stack+58073, r12vrr_stack+31890, r12vrr_stack+20845, r12vrr_stack+58018, r12vrr_stack+29250);

 /*--- compute (f0|m0)^7 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+32385, r12vrr_stack+15714, r12vrr_stack+32055, r12vrr_stack+27733, r12vrr_stack+58073, r12vrr_stack+29385);

 /*--- compute (g0|m0)^6 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+43550, r12vrr_stack+118803, r12vrr_stack+32385, r12vrr_stack+83991, r12vrr_stack+15714, r12vrr_stack+29655);

 /*--- compute (h0|m0)^5 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31890, r12vrr_stack+119353, r12vrr_stack+43550, r12vrr_stack+84321, r12vrr_stack+118803, r12vrr_stack+30105);

 /*--- compute (i0|m0)^4 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+120178, r12vrr_stack+31890, r12vrr_stack+84871, r12vrr_stack+119353, r12vrr_stack+69733);

 /*--- compute (k0|m0)^3 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+71938, r12vrr_stack+121333, r12vrr_stack+29250, r12vrr_stack+85696, r12vrr_stack+120178, r12vrr_stack+70678);

 /*--- compute (l0|m0)^2 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+112961, r12vrr_stack+122873, r12vrr_stack+71938, r12vrr_stack+86851, r12vrr_stack+121333, r12vrr_stack+109316);

 /*--- compute (m0|m0)^1 ---*/
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+124853, r12vrr_stack+112961, r12vrr_stack+88391, r12vrr_stack+122873, r12vrr_stack+110936);

 /*--- compute (n0|m0)^0 ---*/
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+109316, r12vrr_stack+60009, r12vrr_stack+69733, r12vrr_stack+35190, r12vrr_stack+124853, r12vrr_stack+74128);

 /*--- compute (00|n0)^9 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+58018, r12vrr_stack+31835, r12vrr_stack+27688, r12vrr_stack+20985, NULL);

 /*--- compute (p0|n0)^8 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+39788, r12vrr_stack+69733, NULL, NULL, r12vrr_stack+58018);

 /*--- compute (d0|n0)^7 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+63034, r12vrr_stack+39590, r12vrr_stack+37665, r12vrr_stack+39788, r12vrr_stack+58073);

 /*--- compute (f0|n0)^6 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+22949, r12vrr_stack+69733, r12vrr_stack+37731, r12vrr_stack+63034, r12vrr_stack+15714);

 /*--- compute (g0|n0)^5 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+127328, r12vrr_stack+39590, r12vrr_stack+21687, r12vrr_stack+22949, r12vrr_stack+118803);

 /*--- compute (h0|n0)^4 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+127988, r12vrr_stack+15714, r12vrr_stack+90371, r12vrr_stack+127328, r12vrr_stack+119353);

 /*--- compute (i0|n0)^3 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+128978, r12vrr_stack+39590, r12vrr_stack+91031, r12vrr_stack+127988, r12vrr_stack+120178);

 /*--- compute (k0|n0)^2 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+71581, r12vrr_stack+130364, r12vrr_stack+69733, r12vrr_stack+92021, r12vrr_stack+128978, r12vrr_stack+121333);

 /*--- compute (l0|n0)^1 ---*/
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+127328, r12vrr_stack+132212, r12vrr_stack+71581, r12vrr_stack+93407, r12vrr_stack+130364, r12vrr_stack+122873);

 /*--- compute (m0|n0)^0 ---*/
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69733, r12vrr_stack+134588, r12vrr_stack+127328, r12vrr_stack+95255, r12vrr_stack+132212, r12vrr_stack+124853);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+73363, &(Data->ss_r12_ss), NULL, r12vrr_stack+324, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+73366, r12vrr_stack+73363, &(Data->ss_r12_ss), r12vrr_stack+81, r12vrr_stack+324, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+73372, r12vrr_stack+73366, r12vrr_stack+73363, r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+324, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+73382, r12vrr_stack+73372, r12vrr_stack+73366, r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+81, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+7708, r12vrr_stack+73382, r12vrr_stack+73372, r12vrr_stack+1011, r12vrr_stack+337, r12vrr_stack+327, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+73397, r12vrr_stack+7708, NULL, r12vrr_stack+1131, r12vrr_stack+1011, NULL, r12vrr_stack+337);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+73460, r12vrr_stack+73397, r12vrr_stack+7708, r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+1011, r12vrr_stack+1485);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+73586, r12vrr_stack+73460, r12vrr_stack+73397, r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+1530);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+27675, r12vrr_stack+73586, r12vrr_stack+73460, r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+1620);

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+73796, r12vrr_stack+27675, r12vrr_stack+73586, r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+2235);
 tmp = r12vrr_stack + 73796;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||h0)^0 ---*/
 _R_BUILD_i0h0(Data,r12vrr_stack+74237, r12vrr_stack+73796, r12vrr_stack+27675, r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+2460);
 tmp = r12vrr_stack + 74237;
 target_ptr = Libr12->rvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||h0)^0 ---*/
 _R_BUILD_k0h0(Data,r12vrr_stack+74825, r12vrr_stack+74237, r12vrr_stack+73796, r12vrr_stack+48353, r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+4327);
 tmp = r12vrr_stack + 74825;
 target_ptr = Libr12->rvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||h0)^0 ---*/
 _R_BUILD_l0h0(Data,r12vrr_stack+75581, r12vrr_stack+74825, r12vrr_stack+74237, r12vrr_stack+6763, r12vrr_stack+48353, r12vrr_stack+8170, r12vrr_stack+46784);
 tmp = r12vrr_stack + 75581;
 target_ptr = Libr12->rvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+27675, r12vrr_stack+7708, r12vrr_stack+73382, r12vrr_stack+4747, r12vrr_stack+1011, r12vrr_stack+337, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+27703, r12vrr_stack+27675, NULL, r12vrr_stack+4775, r12vrr_stack+4747, NULL, r12vrr_stack+1011);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+27787, r12vrr_stack+27703, r12vrr_stack+27675, r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+4747, r12vrr_stack+1131);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+73363, r12vrr_stack+27787, r12vrr_stack+27703, r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+6112);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+73643, r12vrr_stack+73363, r12vrr_stack+27787, r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+6238);

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+74063, r12vrr_stack+73643, r12vrr_stack+73363, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+6448);
 tmp = r12vrr_stack + 74063;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||i0)^0 ---*/
 _R_BUILD_i0i0(Data,r12vrr_stack+76526, r12vrr_stack+74063, r12vrr_stack+73643, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+7729);
 tmp = r12vrr_stack + 76526;
 target_ptr = Libr12->rvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||i0)^0 ---*/
 _R_BUILD_k0i0(Data,r12vrr_stack+77310, r12vrr_stack+76526, r12vrr_stack+74063, r12vrr_stack+50901, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+8170);
 tmp = r12vrr_stack + 77310;
 target_ptr = Libr12->rvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||i0)^0 ---*/
 _R_BUILD_l0i0(Data,r12vrr_stack+73363, r12vrr_stack+77310, r12vrr_stack+76526, r12vrr_stack+11782, r12vrr_stack+50901, r12vrr_stack+13238, r12vrr_stack+48353);
 tmp = r12vrr_stack + 73363;
 target_ptr = Libr12->rvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+19746, r12vrr_stack+27675, r12vrr_stack+7708, r12vrr_stack+8758, r12vrr_stack+4747, r12vrr_stack+1011, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+76526, r12vrr_stack+19746, NULL, r12vrr_stack+8926, r12vrr_stack+8758, NULL, r12vrr_stack+4747);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+76634, r12vrr_stack+76526, r12vrr_stack+19746, r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+8758, r12vrr_stack+4775);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+4775, r12vrr_stack+76634, r12vrr_stack+76526, r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+9626);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+5135, r12vrr_stack+4775, r12vrr_stack+76634, r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+9794);

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+76526, r12vrr_stack+5135, r12vrr_stack+4775, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+10774);
 tmp = r12vrr_stack + 76526;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||k0)^0 ---*/
 _R_BUILD_i0k0(Data,r12vrr_stack+78318, r12vrr_stack+76526, r12vrr_stack+5135, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+11194);
 tmp = r12vrr_stack + 78318;
 target_ptr = Libr12->rvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||k0)^0 ---*/
 _R_BUILD_k0k0(Data,r12vrr_stack+4775, r12vrr_stack+78318, r12vrr_stack+76526, r12vrr_stack+54213, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+13238);
 tmp = r12vrr_stack + 4775;
 target_ptr = Libr12->rvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||k0)^0 ---*/
 _R_BUILD_l0k0(Data,r12vrr_stack+79326, r12vrr_stack+4775, r12vrr_stack+78318, r12vrr_stack+18126, r12vrr_stack+54213, r12vrr_stack+19782, r12vrr_stack+50901);
 tmp = r12vrr_stack + 79326;
 target_ptr = Libr12->rvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+78318, r12vrr_stack+19746, r12vrr_stack+27675, r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+4747, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+27675, r12vrr_stack+78318, NULL, r12vrr_stack+14238, r12vrr_stack+14022, NULL, r12vrr_stack+8758);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+78363, r12vrr_stack+27675, r12vrr_stack+78318, r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+14022, r12vrr_stack+8926);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+78633, r12vrr_stack+78363, r12vrr_stack+27675, r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+15138);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+76526, r12vrr_stack+78633, r12vrr_stack+78363, r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+15354);

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+80946, r12vrr_stack+76526, r12vrr_stack+78633, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+16830);
 tmp = r12vrr_stack + 80946;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||l0)^0 ---*/
 _R_BUILD_i0l0(Data,r12vrr_stack+81891, r12vrr_stack+80946, r12vrr_stack+76526, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+17370);
 tmp = r12vrr_stack + 81891;
 target_ptr = Libr12->rvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||l0)^0 ---*/
 _R_BUILD_k0l0(Data,r12vrr_stack+83151, r12vrr_stack+81891, r12vrr_stack+80946, r12vrr_stack+58389, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+19782);
 tmp = r12vrr_stack + 83151;
 target_ptr = Libr12->rvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||l0)^0 ---*/
 _R_BUILD_l0l0(Data,r12vrr_stack+84771, r12vrr_stack+83151, r12vrr_stack+81891, r12vrr_stack+25650, r12vrr_stack+58389, r12vrr_stack+27990, r12vrr_stack+54213);
 tmp = r12vrr_stack + 84771;
 target_ptr = Libr12->rvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+80946, r12vrr_stack+78318, r12vrr_stack+19746, r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+8758, NULL);

 /*--- compute (p0||m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+80946, NULL, r12vrr_stack+21060, r12vrr_stack+20790, NULL, r12vrr_stack+14022);

 /*--- compute (d0||m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8923, r12vrr_stack+8758, r12vrr_stack+80946, r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+20790, r12vrr_stack+14238);

 /*--- compute (f0||m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+80946, r12vrr_stack+8923, r12vrr_stack+8758, r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+22185);

 /*--- compute (g0||m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+80946, r12vrr_stack+8923, r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+22455);

 /*--- compute (h0||m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+20790, r12vrr_stack+80946, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+24030);
 tmp = r12vrr_stack + 8758;
 target_ptr = Libr12->rvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+80946, r12vrr_stack+8758, r12vrr_stack+20790, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+24705);
 tmp = r12vrr_stack + 80946;
 target_ptr = Libr12->rvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+80946, r12vrr_stack+8758, r12vrr_stack+63529, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+27990);
 tmp = r12vrr_stack + 20790;
 target_ptr = Libr12->rvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+20790, r12vrr_stack+80946, r12vrr_stack+35190, r12vrr_stack+63529, r12vrr_stack+38050, r12vrr_stack+58389);
 tmp = r12vrr_stack + 14022;
 target_ptr = Libr12->rvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+80946, r12vrr_stack+7729, r12vrr_stack+11194, r12vrr_stack+8170, r12vrr_stack+4327, r12vrr_stack+2460);
 tmp = r12vrr_stack + 80946;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+81387, r12vrr_stack+11194, r12vrr_stack+17370, r12vrr_stack+13238, r12vrr_stack+8170, r12vrr_stack+7729);
 tmp = r12vrr_stack + 81387;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+81975, r12vrr_stack+17370, r12vrr_stack+24705, r12vrr_stack+19782, r12vrr_stack+13238, r12vrr_stack+11194);
 tmp = r12vrr_stack + 81975;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8758, r12vrr_stack+24705, r12vrr_stack+34035, r12vrr_stack+27990, r12vrr_stack+19782, r12vrr_stack+17370);
 tmp = r12vrr_stack + 8758;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+22770, r12vrr_stack+34035, r12vrr_stack+45398, r12vrr_stack+38050, r12vrr_stack+27990, r12vrr_stack+24705);
 tmp = r12vrr_stack + 22770;
 target_ptr = Libr12->t2vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9703, r12vrr_stack+8170, r12vrr_stack+13238, r12vrr_stack+48353, r12vrr_stack+46784, r12vrr_stack+4327);
 tmp = r12vrr_stack + 9703;
 target_ptr = Libr12->t2vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+76526, r12vrr_stack+13238, r12vrr_stack+19782, r12vrr_stack+50901, r12vrr_stack+48353, r12vrr_stack+8170);
 tmp = r12vrr_stack + 76526;
 target_ptr = Libr12->t2vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+78318, r12vrr_stack+19782, r12vrr_stack+27990, r12vrr_stack+54213, r12vrr_stack+50901, r12vrr_stack+13238);
 tmp = r12vrr_stack + 78318;
 target_ptr = Libr12->t2vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+86796, r12vrr_stack+27990, r12vrr_stack+38050, r12vrr_stack+58389, r12vrr_stack+54213, r12vrr_stack+19782);
 tmp = r12vrr_stack + 86796;
 target_ptr = Libr12->t2vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+88056, r12vrr_stack+38050, r12vrr_stack+67885, r12vrr_stack+63529, r12vrr_stack+58389, r12vrr_stack+27990);
 tmp = r12vrr_stack + 88056;
 target_ptr = Libr12->t2vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+89596, r12vrr_stack+48353, r12vrr_stack+50901, r12vrr_stack+6763, r12vrr_stack+3528, r12vrr_stack+46784);
 tmp = r12vrr_stack + 89596;
 target_ptr = Libr12->t2vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+46784, r12vrr_stack+50901, r12vrr_stack+54213, r12vrr_stack+11782, r12vrr_stack+6763, r12vrr_stack+48353);
 tmp = r12vrr_stack + 46784;
 target_ptr = Libr12->t2vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+90352, r12vrr_stack+54213, r12vrr_stack+58389, r12vrr_stack+18126, r12vrr_stack+11782, r12vrr_stack+50901);
 tmp = r12vrr_stack + 90352;
 target_ptr = Libr12->t2vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+91648, r12vrr_stack+58389, r12vrr_stack+63529, r12vrr_stack+25650, r12vrr_stack+18126, r12vrr_stack+54213);
 tmp = r12vrr_stack + 91648;
 target_ptr = Libr12->t2vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+93268, r12vrr_stack+63529, r12vrr_stack+95255, r12vrr_stack+35190, r12vrr_stack+25650, r12vrr_stack+58389);
 tmp = r12vrr_stack + 93268;
 target_ptr = Libr12->t2vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_l0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+39590, r12vrr_stack+6763, r12vrr_stack+11782, r12vrr_stack+102401, r12vrr_stack+98846, r12vrr_stack+3528);
 tmp = r12vrr_stack + 39590;
 target_ptr = Libr12->t2vrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_l0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+112946, r12vrr_stack+11782, r12vrr_stack+18126, r12vrr_stack+49109, r12vrr_stack+102401, r12vrr_stack+6763);
 tmp = r12vrr_stack + 112946;
 target_ptr = Libr12->t2vrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_l0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+114206, r12vrr_stack+18126, r12vrr_stack+25650, r12vrr_stack+51909, r12vrr_stack+49109, r12vrr_stack+11782);
 tmp = r12vrr_stack + 114206;
 target_ptr = Libr12->t2vrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_l0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+115826, r12vrr_stack+25650, r12vrr_stack+35190, r12vrr_stack+55509, r12vrr_stack+51909, r12vrr_stack+18126);
 tmp = r12vrr_stack + 115826;
 target_ptr = Libr12->t2vrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+117851, r12vrr_stack+35190, r12vrr_stack+134588, r12vrr_stack+60009, r12vrr_stack+55509, r12vrr_stack+25650);
 tmp = r12vrr_stack + 117851;
 target_ptr = Libr12->t2vrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T2]|h0)^0 ---*/
 am[0] = 9;  am[1] = 5;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+40535, r12vrr_stack+102401, r12vrr_stack+49109, r12vrr_stack+99671, r12vrr_stack+66209, r12vrr_stack+98846);
 tmp = r12vrr_stack + 40535;
 target_ptr = Libr12->t2vrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T2]|i0)^0 ---*/
 am[0] = 9;  am[1] = 6;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+120326, r12vrr_stack+49109, r12vrr_stack+51909, r12vrr_stack+41702, r12vrr_stack+99671, r12vrr_stack+102401);
 tmp = r12vrr_stack + 120326;
 target_ptr = Libr12->t2vrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T2]|k0)^0 ---*/
 am[0] = 9;  am[1] = 7;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+121866, r12vrr_stack+51909, r12vrr_stack+55509, r12vrr_stack+106940, r12vrr_stack+41702, r12vrr_stack+49109);
 tmp = r12vrr_stack + 121866;
 target_ptr = Libr12->t2vrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T2]|l0)^0 ---*/
 am[0] = 9;  am[1] = 8;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+123846, r12vrr_stack+55509, r12vrr_stack+60009, r12vrr_stack+103556, r12vrr_stack+106940, r12vrr_stack+51909);
 tmp = r12vrr_stack + 123846;
 target_ptr = Libr12->t2vrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T2]|m0)^0 ---*/
 am[0] = 9;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+126321, r12vrr_stack+60009, r12vrr_stack+69733, r12vrr_stack+109316, r12vrr_stack+103556, r12vrr_stack+55509);
 tmp = r12vrr_stack + 126321;
 target_ptr = Libr12->t2vrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+47792, r12vrr_stack+7729, r12vrr_stack+8170, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+6448);
 tmp = r12vrr_stack + 47792;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6071, r12vrr_stack+11194, r12vrr_stack+13238, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+10774);
 tmp = r12vrr_stack + 6071;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+10291, r12vrr_stack+17370, r12vrr_stack+19782, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+16830);
 tmp = r12vrr_stack + 10291;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+129346, r12vrr_stack+24705, r12vrr_stack+27990, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+24030);
 tmp = r12vrr_stack + 129346;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+130291, r12vrr_stack+34035, r12vrr_stack+38050, r12vrr_stack+45398, r12vrr_stack+44408, r12vrr_stack+33210);
 tmp = r12vrr_stack + 130291;
 target_ptr = Libr12->t1vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+23925, r12vrr_stack+8170, r12vrr_stack+48353, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+7729);
 tmp = r12vrr_stack + 23925;
 target_ptr = Libr12->t1vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+16497, r12vrr_stack+13238, r12vrr_stack+50901, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+11194);
 tmp = r12vrr_stack + 16497;
 target_ptr = Libr12->t1vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+131446, r12vrr_stack+19782, r12vrr_stack+54213, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+17370);
 tmp = r12vrr_stack + 131446;
 target_ptr = Libr12->t1vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+132454, r12vrr_stack+27990, r12vrr_stack+58389, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+24705);
 tmp = r12vrr_stack + 132454;
 target_ptr = Libr12->t1vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+29250, r12vrr_stack+38050, r12vrr_stack+63529, r12vrr_stack+67885, r12vrr_stack+45398, r12vrr_stack+34035);
 tmp = r12vrr_stack + 29250;
 target_ptr = Libr12->t1vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+24513, r12vrr_stack+48353, r12vrr_stack+6763, r12vrr_stack+50901, r12vrr_stack+13238, r12vrr_stack+8170);
 tmp = r12vrr_stack + 24513;
 target_ptr = Libr12->t1vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7708, r12vrr_stack+50901, r12vrr_stack+11782, r12vrr_stack+54213, r12vrr_stack+19782, r12vrr_stack+13238);
 tmp = r12vrr_stack + 7708;
 target_ptr = Libr12->t1vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+30790, r12vrr_stack+54213, r12vrr_stack+18126, r12vrr_stack+58389, r12vrr_stack+27990, r12vrr_stack+19782);
 tmp = r12vrr_stack + 30790;
 target_ptr = Libr12->t1vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+32086, r12vrr_stack+58389, r12vrr_stack+25650, r12vrr_stack+63529, r12vrr_stack+38050, r12vrr_stack+27990);
 tmp = r12vrr_stack + 32086;
 target_ptr = Libr12->t1vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+43550, r12vrr_stack+63529, r12vrr_stack+35190, r12vrr_stack+95255, r12vrr_stack+67885, r12vrr_stack+38050);
 tmp = r12vrr_stack + 43550;
 target_ptr = Libr12->t1vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_l0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+19746, r12vrr_stack+6763, r12vrr_stack+102401, r12vrr_stack+11782, r12vrr_stack+50901, r12vrr_stack+48353);
 tmp = r12vrr_stack + 19746;
 target_ptr = Libr12->t1vrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_l0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+27675, r12vrr_stack+11782, r12vrr_stack+49109, r12vrr_stack+18126, r12vrr_stack+54213, r12vrr_stack+50901);
 tmp = r12vrr_stack + 27675;
 target_ptr = Libr12->t1vrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_l0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+37665, r12vrr_stack+18126, r12vrr_stack+51909, r12vrr_stack+25650, r12vrr_stack+58389, r12vrr_stack+54213);
 tmp = r12vrr_stack + 37665;
 target_ptr = Libr12->t1vrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_l0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+97631, r12vrr_stack+25650, r12vrr_stack+55509, r12vrr_stack+35190, r12vrr_stack+63529, r12vrr_stack+58389);
 tmp = r12vrr_stack + 97631;
 target_ptr = Libr12->t1vrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+65509, r12vrr_stack+35190, r12vrr_stack+60009, r12vrr_stack+134588, r12vrr_stack+95255, r12vrr_stack+63529);
 tmp = r12vrr_stack + 65509;
 target_ptr = Libr12->t1vrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T1]|h0)^0 ---*/
 am[0] = 9;  am[1] = 5;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+95248, r12vrr_stack+102401, r12vrr_stack+99671, r12vrr_stack+49109, r12vrr_stack+11782, r12vrr_stack+6763);
 tmp = r12vrr_stack + 95248;
 target_ptr = Libr12->t1vrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T1]|i0)^0 ---*/
 am[0] = 9;  am[1] = 6;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+99656, r12vrr_stack+49109, r12vrr_stack+41702, r12vrr_stack+51909, r12vrr_stack+18126, r12vrr_stack+11782);
 tmp = r12vrr_stack + 99656;
 target_ptr = Libr12->t1vrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T1]|k0)^0 ---*/
 am[0] = 9;  am[1] = 7;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+51909, r12vrr_stack+106940, r12vrr_stack+55509, r12vrr_stack+25650, r12vrr_stack+18126);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t1vrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T1]|l0)^0 ---*/
 am[0] = 9;  am[1] = 8;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+106526, r12vrr_stack+55509, r12vrr_stack+103556, r12vrr_stack+60009, r12vrr_stack+35190, r12vrr_stack+25650);
 tmp = r12vrr_stack + 106526;
 target_ptr = Libr12->t1vrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0|[r12,T1]|m0)^0 ---*/
 am[0] = 9;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+137558, r12vrr_stack+60009, r12vrr_stack+109316, r12vrr_stack+69733, r12vrr_stack+134588, r12vrr_stack+35190);
 tmp = r12vrr_stack + 137558;
 target_ptr = Libr12->t1vrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0||h0)^0 ---*/
 am[0] = 9;  am[1] = 5;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+103556, r12vrr_stack+75581, r12vrr_stack+74825, r12vrr_stack+102401, r12vrr_stack+6763, r12vrr_stack+48353, r12vrr_stack+3528);
 tmp = r12vrr_stack + 103556;
 target_ptr = Libr12->rvrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0||i0)^0 ---*/
 am[0] = 9;  am[1] = 6;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+104711, r12vrr_stack+73363, r12vrr_stack+77310, r12vrr_stack+49109, r12vrr_stack+11782, r12vrr_stack+50901, r12vrr_stack+6763);
 tmp = r12vrr_stack + 104711;
 target_ptr = Libr12->rvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0||k0)^0 ---*/
 am[0] = 9;  am[1] = 7;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+48233, r12vrr_stack+79326, r12vrr_stack+4775, r12vrr_stack+51909, r12vrr_stack+18126, r12vrr_stack+54213, r12vrr_stack+11782);
 tmp = r12vrr_stack + 48233;
 target_ptr = Libr12->rvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0||l0)^0 ---*/
 am[0] = 9;  am[1] = 8;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+50213, r12vrr_stack+84771, r12vrr_stack+83151, r12vrr_stack+55509, r12vrr_stack+25650, r12vrr_stack+58389, r12vrr_stack+18126);
 tmp = r12vrr_stack + 50213;
 target_ptr = Libr12->rvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (m0||m0)^0 ---*/
 am[0] = 9;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+52688, r12vrr_stack+14022, r12vrr_stack+20790, r12vrr_stack+60009, r12vrr_stack+35190, r12vrr_stack+63529, r12vrr_stack+25650);
 tmp = r12vrr_stack + 52688;
 target_ptr = Libr12->rvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];


}

